// For Library Version: 1.136.1

declare module "sap/f/library" {
  export interface IShellBar {
    __implements__sap_f_IShellBar: boolean;
  }

  export interface IDynamicPageStickyContent {
    __implements__sap_f_IDynamicPageStickyContent: boolean;
  }
}

declare module "sap/m/library" {
  import Control from "sap/ui/core/Control";

  import Locale from "sap/ui/core/Locale";

  import LocaleData from "sap/ui/core/LocaleData";

  import RenderManager from "sap/ui/core/RenderManager";

  import { CSSColor, URI } from "sap/ui/core/library";

  import Event from "sap/ui/base/Event";

  import Slider from "sap/m/Slider";

  import RangeSlider from "sap/m/RangeSlider";

  /**
   * Hide the soft keyboard.
   *
   * @since 1.20
   */
  export function closeKeyboard(): void;
  /**
   * Returns invalid date value of UI5.
   *
   * @since 1.10
   * @deprecated As of version 1.12. UI5 returns null for invalid date
   *
   * @returns `null` as value for an invalid date
   */
  export function getInvalidDate(): null;
  /**
   * Search given control's parents and try to find iScroll.
   *
   * @since 1.11
   *
   * @returns iScroll reference or `undefined` if cannot find
   */
  export function getIScroll(
    /**
     * Control to start the search at
     */
    oControl: Control
  ): Object | undefined;
  /**
   * Finds default locale settings once and returns always the same.
   *
   * We should not need to create new instance to get same locale settings This method keeps the locale instance
   * in the scope and returns the same after first run
   *
   * @since 1.10
   *
   * @returns Locale instance
   */
  export function getLocale(): Locale;
  /**
   * Finds default locale data once and returns always the same.
   *
   * @since 1.10
   *
   * @returns LocaleData instance
   */
  export function getLocaleData(): LocaleData;
  /**
   * Search given control's parents and try to find a ScrollDelegate.
   *
   * @since 1.11
   *
   * @returns ScrollDelegate or `undefined` if it cannot be found
   */
  export function getScrollDelegate(
    /**
     * Starting point for the search
     */
    oControl: Control,
    /**
     * Whether the search should stop on component level (`false`) or not
     */
    bGlobal: boolean
  ): Object | undefined;
  /**
   * Checks if the given parameter is a valid JsDate Object.
   *
   * @since 1.10
   *
   * @returns Whether the given parameter is a valid JsDate Object.
   */
  export function isDate(
    /**
     * Any variable to test.
     */
    value: any
  ): boolean;
  /**
   * Available Background Design.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'BackgroundDesign'.
   */
  export enum BackgroundDesign {
    /**
     * A solid background color dependent on the theme.
     */
    Solid = "Solid",
    /**
     * A translucent background depending on the opacity value of the theme.
     */
    Translucent = "Translucent",
    /**
     * Transparent background.
     */
    Transparent = "Transparent",
  }
  /**
   * Helper for rendering themable background.
   *
   * @since 1.12
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  interface BackgroundHelper {
    /**
     * Adds CSS classes and styles to the given RenderManager, depending on the given configuration for background
     * color and background image. To be called by control renderers supporting the global themable background
     * image within their root tag, before they call openEnd, voidEnd, writeClasses() and writeStyles().
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    addBackgroundColorStyles(
      /**
       * The RenderManager
       */
      rm: RenderManager,
      /**
       * A configured custom background color for the control, if any
       */
      sBgColor?: CSSColor,
      /**
       * The configured custom background image for the control, if any
       */
      sBgImgUrl?: URI
    ): void;
    /**
     * Renders an HTML tag into the given RenderManager which carries the background image which is either configured
     * and given or coming from the current theme. Should be called right after the opening root tag has been
     * completed, so this is the first child element inside the control.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    renderBackgroundImageTag(
      /**
       * The RenderManager
       */
      rm: RenderManager,
      /**
       * Control within which the tag will be rendered; its ID will be used to generate the element ID
       */
      oControl: Control,
      /**
       * A CSS class or an array of CSS classes to add to the element
       */
      vCssClass: string | string[],
      /**
       * The image of a configured background image; if this is not given, the theme background will be used and
       * also the other settings are ignored.
       */
      sBgImgUrl?: URI,
      /**
       * Whether the background image should be repeated/tiled (or stretched)
       */
      bRepeat?: boolean,
      /**
       * The background image opacity, if any
       */
      fOpacity?: float
    ): void;
  }
  export const BackgroundHelper: BackgroundHelper;

  /**
   * Types of animation performed by {@link sap.m.BadgeEnabler}.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'BadgeAnimationType'.
   *
   * @since 1.87
   */
  export enum BadgeAnimationType {
    /**
     * Badge indicator will perform Appear,Update,and Disappear animation.
     */
    Full = "Full",
    /**
     * No animation is performed.
     */
    None = "None",
    /**
     * Badge indicator will perform only Update animation (suitable for controls, which invalidate often).
     */
    Update = "Update",
  }
  /**
   * Types of state of {@link sap.m.BadgeEnabler} to expose its current state.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'BadgeState'.
   *
   * @since 1.81
   */
  export enum BadgeState {
    /**
     * Informing interested parties that the badge has appeared.
     */
    Appear = "Appear",
    /**
     * Informing interested parties that the badge has disappeared.
     */
    Disappear = "Disappear",
    /**
     * Informing interested parties that the badge has been updated.
     */
    Updated = "Updated",
  }
  /**
   * Types of badge rendering style.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'BadgeStyle'.
   */
  export enum BadgeStyle {
    /**
     * Attention style. This badge is rendered as a single dot meant to grab attention.
     */
    Attention = "Attention",
    /**
     * Default style. Use for badges which contain text or numbers.
     */
    Default = "Default",
  }
  /**
   * Types of the Bar design.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'BarDesign'.
   *
   * @since 1.20
   */
  export enum BarDesign {
    /**
     * The Bar can be inserted into other controls and if the design is "Auto" then it inherits the design from
     * parent control.
     */
    Auto = "Auto",
    /**
     * The bar will be styled like a footer of the page.
     */
    Footer = "Footer",
    /**
     * The bar will be styled like a header of the page.
     */
    Header = "Header",
    /**
     * The bar will be styled like a subheader of the page.
     */
    SubHeader = "SubHeader",
  }
  /**
   * Available Border Design.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'BorderDesign'.
   */
  export enum BorderDesign {
    /**
     * Specifies no border.
     */
    None = "None",
    /**
     * A solid border color dependent on the theme.
     */
    Solid = "Solid",
  }
  /**
   * Variations of the {@link sap.m.Breadcrumbs} separators.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'BreadcrumbsSeparatorStyle'.
   *
   * @since 1.69
   */
  export enum BreadcrumbsSeparatorStyle {
    /**
     * The separator will appear as "\"
     */
    BackSlash = "BackSlash",
    /**
     * The separator will appear as "\\"
     */
    DoubleBackSlash = "DoubleBackSlash",
    /**
     * The separator will appear as ">>"
     */
    DoubleGreaterThan = "DoubleGreaterThan",
    /**
     * The separator will appear as "//"
     */
    DoubleSlash = "DoubleSlash",
    /**
     * The separator will appear as ">"
     */
    GreaterThan = "GreaterThan",
    /**
     * The separator will appear as "/"
     */
    Slash = "Slash",
  }
  /**
   * Enumeration for possible Button accessibility roles.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ButtonAccessibleRole'.
   *
   * @since 1.114.0
   */
  export enum ButtonAccessibleRole {
    /**
     * Default mode.
     */
    Default = "Default",
    /**
     * Button will receive `role="Link"` attibute.
     */
    Link = "Link",
  }
  /**
   * Different predefined button types for the {@link sap.m.Button sap.m.Button}.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ButtonType'.
   */
  export enum ButtonType {
    /**
     * Accept type
     */
    Accept = "Accept",
    /**
     * Attention type
     *
     * @since 1.77
     */
    Attention = "Attention",
    /**
     * Back type (back navigation button for header)
     */
    Back = "Back",
    /**
     * Critical type
     *
     * **Note:** To be used only in controls of type `sap.m.Button`. When the button opens a `sap.m.MessagePopover`
     * list, use this `ButtonType` if the message with the highest severity is `Warning` type.
     *
     * @since 1.73
     */
    Critical = "Critical",
    /**
     * Default type (no special styling)
     */
    Default = "Default",
    /**
     * Emphasized type
     */
    Emphasized = "Emphasized",
    /**
     * Ghost type
     */
    Ghost = "Ghost",
    /**
     * Negative type
     *
     * **Note:** To be used only in controls of type `sap.m.Button`. When the button opens a `sap.m.MessagePopover`
     * list, use this `ButtonType` if the message with the highest severity is `Error` type.
     *
     * @since 1.73
     */
    Negative = "Negative",
    /**
     * Neutral type
     *
     * **Note:** To be used only in controls of type `sap.m.Button`. When the button opens a `sap.m.MessagePopover`
     * list, use this `ButtonType` if the message with the highest severity is `Information` type.
     *
     * @since 1.73
     */
    Neutral = "Neutral",
    /**
     * Reject style
     */
    Reject = "Reject",
    /**
     * Success type
     *
     * **Note:** To be used only in controls of type `sap.m.Button`. When the button opens a `sap.m.MessagePopover`
     * list, use this `ButtonType` if the message with the highest severity is `Success` type.
     *
     * @since 1.73
     */
    Success = "Success",
    /**
     * Transparent type
     */
    Transparent = "Transparent",
    /**
     * Unstyled type (no styling)
     */
    Unstyled = "Unstyled",
    /**
     * Up type (up navigation button for header)
     */
    Up = "Up",
  }
  /**
   * Carousel arrows align.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'CarouselArrowsPlacement'.
   */
  export enum CarouselArrowsPlacement {
    /**
     * Carousel arrows are placed on the sides of the current Carousel page.
     */
    Content = "Content",
    /**
     * Carousel arrows are placed on the sides of the page indicator of the Carousel.
     */
    PageIndicator = "PageIndicator",
  }
  /**
   * Types for the placement of the page indicator of the Carousel control.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'CarouselPageIndicatorPlacementType'.
   */
  export enum CarouselPageIndicatorPlacementType {
    /**
     * Page indicator will be placed at the bottom of the Carousel.
     */
    Bottom = "Bottom",
    /**
     * Page indicator will be placed over the Carousel content, bottom aligned.
     */
    OverContentBottom = "OverContentBottom",
    /**
     * Page indicator will be placed over the Carousel content, top aligned.
     */
    OverContentTop = "OverContentTop",
    /**
     * Page indicator will be placed at the top of the Carousel.
     */
    Top = "Top",
  }
  /**
   * Defines how pages will be scrolled, when clicking the arrow.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'CarouselScrollMode'.
   */
  export enum CarouselScrollMode {
    /**
     * Pages will be scrolled one at a time
     */
    SinglePage = "SinglePage",
    /**
     * Pages will be scrolled, depending on the value of `visiblePagesCount`
     */
    VisiblePages = "VisiblePages",
  }
  /**
   * Defines the rendering type of the TileAttribute
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ContentConfigType'.
   *
   * @since 1.122
   * @experimental As of version 1.122.
   */
  export enum ContentConfigType {
    /**
     * Renders a link inside the TileAttribute
     */
    Link = "Link",
    /**
     * Renders a text inside the TileAttribute
     */
    Text = "Text",
  }
  /**
   * A subset of DateTimeInput types that fit to a simple API returning one string.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'DateTimeInputType'.
   *
   * @deprecated As of version 1.32.8. Instead, use dedicated `sap.m.DatePicker` and/or `sap.m.TimePicker`
   * controls.
   */
  export enum DateTimeInputType {
    /**
     * An input control for specifying a date value. The user can select a month, day of the month, and year.
     *
     * @deprecated As of version 1.22.0. Instead, use dedicated `sap.m.DatePicker` control.
     */
    Date = "Date",
    /**
     * An input control for specifying a date and time value. The user can select a month, day of the month,
     * year, and time of day.
     *
     * @deprecated As of version 1.32.8. Instead, use dedicated `sap.m.DatePicker` and `sap.m.TimePicker` controls.
     */
    DateTime = "DateTime",
    /**
     * An input control for specifying a time value. The user can select the hour, minute, and optionally AM
     * or PM.
     *
     * @deprecated As of version 1.32.8. Instead, use dedicated `sap.m.TimePicker` control.
     */
    Time = "Time",
  }
  /**
   * Enum of the available deviation markers for the NumericContent control.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'DeviationIndicator'.
   *
   * @since 1.34
   */
  export enum DeviationIndicator {
    /**
     * The actual value is less than the target value.
     */
    Down = "Down",
    /**
     * No value.
     */
    None = "None",
    /**
     * The actual value is more than the target value.
     */
    Up = "Up",
  }
  /**
   * Enum for the ARIA role of {@link sap.m.Dialog} control.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'DialogRoleType'.
   *
   * @since 1.65
   */
  export enum DialogRoleType {
    /**
     * Represents the ARIA role `alertdialog`.
     */
    AlertDialog = "alertdialog",
    /**
     * Represents the ARIA role `dialog`.
     */
    Dialog = "dialog",
  }
  /**
   * Enum for the type of {@link sap.m.Dialog} control.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'DialogType'.
   */
  export enum DialogType {
    /**
     * Dialog with type Message looks the same as the Standard Dialog in Android. It puts the Left and the Right
     * buttons at the bottom of the Dialog in iOS.
     */
    Message = "Message",
    /**
     * This is the default value for Dialog type.
     *
     * The Standard Dialog in iOS has a header on the top. The Left and the Right buttons are put inside the
     * header. In Android, the Left and the Right buttons are put at the bottom of the Dialog.
     */
    Standard = "Standard",
  }
  /**
   * Enum for the state of {@link sap.m.DraftIndicator} control.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'DraftIndicatorState'.
   */
  export enum DraftIndicatorState {
    /**
     * This is the default value for DraftIndicatorState type. This state has no visual information displayed.
     */
    Clear = "Clear",
    /**
     * Indicates that the draft is already saved
     */
    Saved = "Saved",
    /**
     * Indicates that the draft currently is being saved
     */
    Saving = "Saving",
  }
  /**
   * Defines the groups in {@link sap.m.DynamicDateRange}.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'DynamicDateRangeGroups'.
   *
   * @since 1.118
   */
  export enum DynamicDateRangeGroups {
    /**
     * Group of options that provide selection of date ranges.
     */
    DateRanges = "DateRanges",
    /**
     * Group of options that provide selection of month related ranges.
     */
    Month = "Month",
    /**
     * Group of options that provide selection of quarter related ranges.
     */
    Quarters = "Quarters",
    /**
     * Group of options that provide selection of single dates.
     */
    SingleDates = "SingleDates",
    /**
     * Group of options that provide selection of week related ranges.
     */
    Weeks = "Weeks",
    /**
     * Group of options that provide selection of year related ranges.
     */
    Years = "Years",
  }
  /**
   * Defines the `value` property of the DynamicDateRange control. The object has two properties: 'operator'
   * - a string, the key of a DynamicDateOption 'values' - an array of parameters for the same option see
   * {@link sap.m.DynamicDateRange}
   *
   * @since 1.111
   */
  export type DynamicDateRangeValue = {
    /**
     * The key of a DynamicDateOption.
     */
    operator: string;
    /**
     * An array of parameters for the same option.
     */
    values: Array<Date | int | string | any>;
  };

  /**
   * Modes in which a control will render empty indicator if its content is empty.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'EmptyIndicatorMode'.
   *
   * @since 1.87
   */
  export enum EmptyIndicatorMode {
    /**
     * Empty indicator will be rendered depending on the context in which the control is placed. If one of the
     * parents has the context class sapMShowEmpty-CTX then the empty indicator will be shown.
     */
    Auto = "Auto",
    /**
     * Empty indicator is never rendered.
     */
    Off = "Off",
    /**
     * Empty indicator is rendered always when the control's content is empty.
     */
    On = "On",
  }
  /**
   * Expandable text overflow mode
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ExpandableTextOverflowMode'.
   */
  export enum ExpandableTextOverflowMode {
    /**
     * InPlace
     */
    InPlace = "InPlace",
    /**
     * Popover
     */
    Popover = "Popover",
  }
  /**
   * FacetFilterList data types.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'FacetFilterListDataType'.
   */
  export enum FacetFilterListDataType {
    /**
     * An input control for specifying a Boolean value
     */
    Boolean = "Boolean",
    /**
     * An input control for specifying a date value. The user can select a month, day of the month, and year.
     */
    Date = "Date",
    /**
     * An input control for specifying a date and time value. The user can select a month, day of the month,
     * year, and time of day.
     */
    DateTime = "DateTime",
    /**
     * An input control for specifying a Float value
     */
    Float = "Float",
    /**
     * >An input control for specifying an Integer value
     */
    Integer = "Integer",
    /**
     * An input control for specifying a String value
     */
    String = "String",
    /**
     * An input control for specifying a time value. The user can select the hour, minute, and optionally AM
     * or PM.
     */
    Time = "Time",
  }
  /**
   * Used by the FacetFilter control to adapt its design according to type.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'FacetFilterType'.
   */
  export enum FacetFilterType {
    /**
     * Forces FacetFilter to display in light mode.
     */
    Light = "Light",
    /**
     * Forces FacetFilter to display facet lists as a row of buttons, one button per facet.
     *
     * The FacetFilter will automatically adapt to the Light type when it detects smart phone sized displays.
     */
    Simple = "Simple",
  }
  /**
   * An object type that represents sap.m.upload.FilterPanel fields properties.
   */
  export type FilterPanelField = {
    /**
     * field name.
     */
    label: string;
    /**
     * model path.
     */
    path: string;
  };

  /**
   * Available options for the layout of container lines along the cross axis of the flexbox layout.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'FlexAlignContent'.
   */
  export enum FlexAlignContent {
    /**
     * Line are packed toward the center of the line.
     */
    Center = "Center",
    /**
     * Lines are packed toward the end of the line.
     */
    End = "End",
    /**
     * Inherits the value from its parent.
     */
    Inherit = "Inherit",
    /**
     * Lines are evenly distributed in the line, with half-size spaces on either end.
     */
    SpaceAround = "SpaceAround",
    /**
     * Lines are evenly distributed in the line.
     */
    SpaceBetween = "SpaceBetween",
    /**
     * Lines are packed toward the start of the line.
     */
    Start = "Start",
    /**
     * Lines stretch to take up the remaining space.
     */
    Stretch = "Stretch",
  }
  /**
   * Available options for the layout of all elements along the cross axis of the flexbox layout.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'FlexAlignItems'.
   */
  export enum FlexAlignItems {
    /**
     * If the flex item`s inline axes are the same as the cross axis, this value is identical to "Start".
     *
     * Otherwise, it participates in baseline alignment: all participating box items on the line are aligned
     * such that their baselines align, and the item with the largest distance between its baseline and its
     * cross-start margin edge is placed flush against the cross-start edge of the line.
     */
    Baseline = "Baseline",
    /**
     * The flex item's margin boxes are centered in the cross axis within the line.
     */
    Center = "Center",
    /**
     * The cross-start margin edges of the flex items are placed flush with the cross-end edge of the line.
     */
    End = "End",
    /**
     * Inherits the value from its parent.
     */
    Inherit = "Inherit",
    /**
     * The cross-start margin edges of the flex items are placed flush with the cross-start edge of the line.
     */
    Start = "Start",
    /**
     * Make the cross size of the item's margin boxes as close to the same size as the line as possible.
     */
    Stretch = "Stretch",
  }
  /**
   * Available options for the layout of individual elements along the cross axis of the flexbox layout overriding
   * the default alignment.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'FlexAlignSelf'.
   */
  export enum FlexAlignSelf {
    /**
     * Takes up the value of alignItems from the parent FlexBox
     */
    Auto = "Auto",
    /**
     * If the flex item's inline axis is the same as the cross axis, this value is identical to "Start".
     *
     * Otherwise, it participates in baseline alignment: all participating box items on the line are aligned
     * such that their baselines align, and the item with the largest distance between its baseline and its
     * cross-start margin edge is placed flush against the cross-start edge of the line.
     */
    Baseline = "Baseline",
    /**
     * The flex item's margin box is centered in the cross axis within the line.
     */
    Center = "Center",
    /**
     * The cross-start margin edges of the flex item is placed flush with the cross-end edge of the line.
     */
    End = "End",
    /**
     * Inherits the value from its parent.
     */
    Inherit = "Inherit",
    /**
     * The cross-start margin edges of the flex item is placed flush with the cross-start edge of the line.
     */
    Start = "Start",
    /**
     * Make the cross size of the item's margin box as close to the same size as the line as possible.
     */
    Stretch = "Stretch",
  }
  /**
   * Available directions for flex layouts.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'FlexDirection'.
   */
  export enum FlexDirection {
    /**
     * Flex items are laid out along the direction of the block axis (usually top to bottom).
     */
    Column = "Column",
    /**
     * Flex items are laid out along the reverse direction of the block axis (usually bottom to top).
     */
    ColumnReverse = "ColumnReverse",
    /**
     * Inherits the value from its parent.
     */
    Inherit = "Inherit",
    /**
     * Flex items are laid out along the direction of the inline axis (text direction).
     */
    Row = "Row",
    /**
     * Flex items are laid out along the reverse direction of the inline axis (against the text direction).
     */
    RowReverse = "RowReverse",
  }
  /**
   * Available options for the layout of elements along the main axis of the flexbox layout.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'FlexJustifyContent'.
   */
  export enum FlexJustifyContent {
    /**
     * Flex items are packed toward the center of the line.
     */
    Center = "Center",
    /**
     * Flex items are packed toward the end of the line.
     */
    End = "End",
    /**
     * Inherits the value from its parent.
     */
    Inherit = "Inherit",
    /**
     * Flex items are evenly distributed in the line, with half-size spaces on either end.
     */
    SpaceAround = "SpaceAround",
    /**
     * Flex items are evenly distributed in the line.
     */
    SpaceBetween = "SpaceBetween",
    /**
     * Flex items are packed toward the start of the line.
     */
    Start = "Start",
  }
  /**
   * Determines the type of HTML elements used for rendering controls.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'FlexRendertype'.
   */
  export enum FlexRendertype {
    /**
     * The UI5 controls are not wrapped in an additional HTML element, the surrounding Flex Box is a DIV element.
     *
     * @since 1.42.1
     */
    Bare = "Bare",
    /**
     * The UI5 controls are wrapped in DIV elements.
     */
    Div = "Div",
    /**
     * The UI5 controls are wrapped in LI elements, the surrounding Flex Box is an unordered list (UL).
     */
    List = "List",
  }
  /**
   * Available options for the wrapping behavior of a flex container.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'FlexWrap'.
   */
  export enum FlexWrap {
    /**
     * The flex container is single-line.
     */
    NoWrap = "NoWrap",
    /**
     * The flex container is multi-line.
     */
    Wrap = "Wrap",
    /**
     * The flex container is multi-line with the cross-axis start and end being swapped.
     */
    WrapReverse = "WrapReverse",
  }
  /**
   * Enum for possible frame size types for sap.m.TileContent and sap.m.GenericTile control.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'FrameType'.
   *
   * @since 1.34.0
   */
  export enum FrameType {
    /**
     * The Auto frame type that adjusts the size of the control to the content. Support for this type in sap.m.GenericTile
     * is deprecated since 1.48.0.
     *
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    Auto = "Auto",
    /**
     * The 2x1 frame type. **Note:** The 2x1 frame type is currently only supported for Generic tile.
     *
     * @since 1.83
     */
    OneByHalf = "OneByHalf",
    /**
     * The 2x2 frame type.
     */
    OneByOne = "OneByOne",
    /**
     * The 4x1 frame type. **Note:** The 4x1 frame type is currently only supported for Generic tile.
     *
     * @since 1.83
     */
    TwoByHalf = "TwoByHalf",
    /**
     * The 4x2 frame type.
     */
    TwoByOne = "TwoByOne",
    /**
     * The 2/3 frame type.
     *
     * @deprecated As of version 1.48.0.
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    TwoThirds = "TwoThirds",
  }
  /**
   * Design modes for the `GenericTag` control.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'GenericTagDesign'.
   *
   * @since 1.62.0
   */
  export enum GenericTagDesign {
    /**
     * Everything from the control is rendered.
     */
    Full = "Full",
    /**
     * Everything from the control is rendered except the status icon.
     */
    StatusIconHidden = "StatusIconHidden",
  }
  /**
   * Value states for the `GenericTag` control.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'GenericTagValueState'.
   *
   * @since 1.62.0
   */
  export enum GenericTagValueState {
    /**
     * Warning icon is rendered that overrides the control set in the `value` aggregation of the `GenericTag`
     * control.
     */
    Error = "Error",
    /**
     * The value is rendered in its normal state.
     */
    None = "None",
  }
  /**
   * Defines the mode of GenericTile.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'GenericTileMode'.
   *
   * @since 1.38.0
   */
  export enum GenericTileMode {
    /**
     * Action Mode (Two lines for the header).
     *
     * Generic Tile renders buttons that are specified under 'actionButtons' aggregation
     *
     * @experimental As of version 1.96.
     */
    ActionMode = "ActionMode",
    /**
     * Article Mode (Two lines for the header and one line for the subtitle).
     *
     * Enables Article Mode.
     *
     * @experimental As of version 1.96.
     */
    ArticleMode = "ArticleMode",
    /**
     * Default mode (Two lines for the header and one line for the subtitle).
     */
    ContentMode = "ContentMode",
    /**
     * Header mode (Four lines for the header and one line for the subtitle).
     */
    HeaderMode = "HeaderMode",
    /**
     * Icon mode.
     *
     * GenericTile displays a combination of icon and header title.
     *
     * It is applicable only for the OneByOne FrameType and TwoByHalf FrameType.
     *
     * @since 1.96
     * @experimental As of version 1.96.
     */
    IconMode = "IconMode",
    /**
     * Line mode (Implemented for both, cozy and compact densities).
     *
     * Generic Tile is displayed as in-line element, header and subheader are displayed in one line. In case
     * the texts need more than one line, the representation depends on the used density. **Cozy:** The text
     * will be truncated and the full text is shown in a tooltip as soon as the tile is hovered (desktop only).
     * **Compact:** Header and subheader are rendered continuously spanning multiple lines, no tooltip is provided).
     *
     * @since 1.44.0
     */
    LineMode = "LineMode",
  }
  /**
   * Defines the scopes of GenericTile enabling the developer to implement different "flavors" of tiles.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'GenericTileScope'.
   *
   * @since 1.46.0
   */
  export enum GenericTileScope {
    /**
     * More action scope (Only the More icon is added to the tile)
     *
     * @since 1.76
     */
    ActionMore = "ActionMore",
    /**
     * Remove action scope (Only the Remove icon is added to the tile)
     *
     * @since 1.76
     */
    ActionRemove = "ActionRemove",
    /**
     * Action scope (Possible footer and Error State information is overlaid, "Remove" and "More" icons are
     * added to the tile).
     */
    Actions = "Actions",
    /**
     * Default scope (The default scope of the tile, no action icons are rendered).
     */
    Display = "Display",
  }
  /**
   * Different levels for headers.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'HeaderLevel'.
   */
  export enum HeaderLevel {
    /**
     * Header level 1
     */
    H1 = "H1",
    /**
     * Header level 2
     */
    H2 = "H2",
    /**
     * Header level 3
     */
    H3 = "H3",
    /**
     * Header level 4
     */
    H4 = "H4",
    /**
     * Header level 5
     */
    H5 = "H5",
    /**
     * Header level 6
     */
    H6 = "H6",
  }
  /**
   * Interface for controls which implement the notification badge concept.
   *
   * @since 1.80
   */
  export interface IBadge {
    __implements__sap_m_IBadge: boolean;
  }

  /**
   * Interface for controls which are suitable as a Header, Subheader or Footer of a Page. If the control
   * does not want to get a context base style class, it has to implement the isContextSensitive method and
   * return false
   *
   * @since 1.22
   */
  export interface IBar {
    __implements__sap_m_IBar: boolean;
  }

  /**
   * Allowed tags for the implementation of the IBar interface.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'IBarHTMLTag'.
   *
   * @since 1.22
   */
  export enum IBarHTMLTag {
    /**
     * Renders as a div element.
     */
    Div = "Div",
    /**
     * Renders as a footer element.
     */
    Footer = "Footer",
    /**
     * Renders as a header element.
     */
    Header = "Header",
  }
  /**
   * Interface for controls which have the meaning of a breadcrumbs navigation.
   *
   * @since 1.52
   */
  export interface IBreadcrumbs {
    __implements__sap_m_IBreadcrumbs: boolean;
  }

  /**
   * Represents an interface for controls, which are suitable as items for the sap.m.IconTabBar.
   */
  export interface IconTab {
    __implements__sap_m_IconTab: boolean;
  }

  /**
   * Specifies `IconTabBar` tab density mode.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'IconTabDensityMode'.
   */
  export enum IconTabDensityMode {
    /**
     * Compact. In this mode the tabs will be set explicitly to compact mode independent of what mode is applied
     * globally.
     */
    Compact = "Compact",
    /**
     * Cozy. In this mode the tabs will be set explicitly to compact mode independent of what mode is applied
     * globally.
     */
    Cozy = "Cozy",
    /**
     * Inherit. In this mode the global configuration of the density mode will be applied.
     */
    Inherit = "Inherit",
  }
  /**
   * Available Filter Item Design.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'IconTabFilterDesign'.
   */
  export enum IconTabFilterDesign {
    /**
     * A horizontally layouted design providing more space for texts.
     */
    Horizontal = "Horizontal",
    /**
     * A vertically layouted design using minimum horizontal space.
     */
    Vertical = "Vertical",
  }
  /**
   * Available Interaction Modes.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'IconTabFilterInteractionMode'.
   *
   * @experimental As of version 1.121. Behavior might change.
   */
  export enum IconTabFilterInteractionMode {
    /**
     * The item is selectable if it has own content. Select event will not be fired if it has no own content.
     * Note: When IconTabHeader is placed in ToolHeader the items will act as selectable items even if they
     * don’t explicitly have content.
     */
    Auto = "Auto",
    /**
     * The item is selectable and select event will be fired.
     */
    Select = "Select",
    /**
     * The item is selectable (and select event is fired) only if it doesn't have any sub items. Select event
     * will not be fired if it has sub items.
     */
    SelectLeavesOnly = "SelectLeavesOnly",
  }
  /**
   * Specifies `IconTabBar` header mode.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'IconTabHeaderMode'.
   */
  export enum IconTabHeaderMode {
    /**
     * Inline. In this mode when the `count` and the `text` are set, they are displayed in one line.
     */
    Inline = "Inline",
    /**
     * Standard. In this mode when the `count` and the `text` are set, they are displayed in two separate lines.
     */
    Standard = "Standard",
  }
  /**
   * Determines how the source image is used on the output DOM element.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ImageMode'.
   *
   * @since 1.30.0
   */
  export enum ImageMode {
    /**
     * The image is rendered with 'span' tag and the 'src' property is set to the 'background-image' CSS style
     * on the output DOM element
     */
    Background = "Background",
    /**
     * The image is rendered with 'img' tag and the 'src' property is set to the src attribute on the output
     * DOM element.
     */
    Image = "Image",
    /**
     * The image is rendered with 'div' tag, containing the inline 'svg' **Note:** Please, be aware that this
     * feature works under the Browser's Cross-Origin Resource Sharing (CORS) policy. This means that a web
     * application using those APIs can only request resources from the same origin the application was loaded
     * from unless the response from other origins includes the right CORS headers.
     *
     * @experimental As of version 1.106.
     */
    InlineSvg = "InlineSvg",
  }
  /**
   * Interface for controls which are suitable to be added as items of sap.m.Menu.
   *
   * @since 1.127.0
   */
  export interface IMenuItem {
    __implements__sap_m_IMenuItem: boolean;
  }

  /**
   * The object contains accessibility state for a control.
   *
   * @since 1.111
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export type InputBaseAccessibilityState = {
    /**
     * The WAI-ARIA role which is implemented by the control.
     *
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    role?: string;
    /**
     * Whether the control is invalid.
     *
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    invalid?: boolean;
    /**
     * The errormessage property.
     *
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    errormessage?: string;
    /**
     * The labelledby property.
     *
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    labelledby?: {
      value: string;

      append: boolean;
    };
    /**
     * The describedby property.
     *
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    describedby?: {
      value: string;

      append: boolean;
    };
    /**
     * Whether the control is disabled. If not relevant, it shouldn`t be set or set as `null`.
     *
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    disabled?: boolean | null;
    /**
     * Whether the control is readonly. If not relevant, it shouldn`t be set or set as `null`.
     *
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    readonly?: boolean | null;
  };

  /**
   * Defines the available content sizes for the `InputListItem` control.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'InputListItemContentSize'.
   */
  export enum InputListItemContentSize {
    /**
     * Large: Recommended for larger input controls, such as {@link sap.m.Input} or {@link sap.m.RatingIndicator}.
     * If there is limited space, the input control moves to a new line below the label.
     */
    L = "L",
    /**
     * Small: Recommended for smaller controls, such as {@link sap.m.Switch} or {@link sap.m.Checkbox}. If there
     * is limited space, only the label is wrapped. The input control is always right-aligned horizontally and
     * middle-aligned vertically.
     */
    S = "S",
  }
  /**
   * Suggestion helper for `sap.m.Input` fields when used with an OData model.
   *
   * Creates a multi-column suggest list for an `sap.m.Input` field based on a `ValueList` annotation. The
   * `ValueList` annotation will be resolved via the binding information of the input field.
   *
   * If the annotation describes multiple input parameters, the suggest provider will resolve all of these
   * relative to the context of the input field and use them for the suggest query. The suggest provider will
   * write all values that are described as output parameters back to the model (relative to the context of
   * the input field). This can only be done if the model runs in "TwoWay" binding mode. Both features can
   * be switched off via the `bResolveInput/bResolveOutput` parameter of the suggest function.
   *
   * @since 1.21.2
   * @deprecated As of version 1.120. In case of SAPUI5, see demokit sample 'Smart Field with ValueList Annotation'.
   * In case of OpenUI5, see demokit sample 'Input - Suggestions - Dynamic'.
   */
  interface InputODataSuggestProvider {
    suggest(
      oEvent: Event,
      /**
       * SuggestProvider resolves all input parameters for the data query
       */
      bResolveInput: boolean,
      /**
       * SuggestProvider writes back all output parameters.
       */
      bResolveOutput: boolean,
      /**
       * If iLength is provided only these number of entries will be requested.
       */
      iLength: int
    ): void;
  }
  export const InputODataSuggestProvider: InputODataSuggestProvider;

  /**
   * Defines how the input display text should be formatted.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'InputTextFormatMode'.
   *
   * @since 1.44.0
   */
  export enum InputTextFormatMode {
    /**
     * Key
     */
    Key = "Key",
    /**
     * A key-value pair formatted like "(key) text"
     */
    KeyValue = "KeyValue",
    /**
     * Text
     */
    Value = "Value",
    /**
     * A value-key pair formatted like "text (key)"
     */
    ValueKey = "ValueKey",
  }
  /**
   * A subset of input types that fits to a simple API returning one string.
   *
   * Not available on purpose: button, checkbox, hidden, image, password, radio, range, reset, search, submit.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'InputType'.
   */
  export enum InputType {
    /**
     * An input control for specifying a date value. The user can select a month, day of the month, and year.
     *
     * @deprecated As of version 1.9.1. Please use dedicated {@link sap.m.DatePicker} to create date input.
     */
    Date = "Date",
    /**
     * An input control for specifying a date and time value. The user can select a month, day of the month,
     * year, and time of day.
     *
     * @deprecated As of version 1.9.1. Please use dedicated {@link sap.m.DateTimePicker} control to create
     * date-time input.
     */
    Datetime = "Datetime",
    /**
     * An input control for specifying a date and time value where the format depends on the locale.
     *
     * @deprecated As of version 1.9.1. Please use dedicated {@link sap.m.DateTimePicker} control create date-time
     * input.
     */
    DatetimeLocale = "DatetimeLocale",
    /**
     * A text field for specifying an email address. Brings up a keyboard optimized for email address entry.
     */
    Email = "Email",
    /**
     * An input control for selecting a month.
     *
     * @deprecated As of version 1.9.1. There is no cross-platform support. Please do not use this Input type.
     */
    Month = "Month",
    /**
     * A text field for specifying a number. Brings up a number pad keyboard. Specifying an input type of \d*
     * or [0-9]* is equivalent to using this type.
     */
    Number = "Number",
    /**
     * Password input where the user entry cannot be seen.
     */
    Password = "Password",
    /**
     * A text field for specifying a phone number. Brings up a phone pad keyboard.
     */
    Tel = "Tel",
    /**
     * default (text)
     */
    Text = "Text",
    /**
     * An input control for specifying a time value. The user can select the hour, minute, and optionally AM
     * or PM.
     *
     * @deprecated As of version 1.9.1. Please use dedicated {@link sap.m.TimePicker} control to create time
     * input.
     */
    Time = "Time",
    /**
     * A text field for specifying a URL. Brings up a keyboard optimized for URL entry.
     */
    Url = "Url",
    /**
     * An input control for selecting a week.
     *
     * @deprecated As of version 1.9.1. There is no cross-platform support. Please do not use this Input type.
     */
    Week = "Week",
  }
  /**
   * Interface for controls which can have special behavior inside `sap.m.OverflowToolbar`. Controls that
   * implement this interface must provide a `getOverflowToolbarConfig` method that accepts no arguments and
   * returns an object of type `sap.m.OverflowToolbarConfig`.
   *
   * **Important:** In addition, the control can implement a CSS class, scoped with the `.sapMOverflowToolbarMenu-CTX`
   * context selector, that will be applied whenever the control is inside the overflow menu. For example,
   * to make your control take up the whole width of the overflow menu, you can add a context class to your
   * control's base CSS file like this:
   *
   *
   * ```javascript
   *
   *       .sapMOverflowToolbarMenu-CTX .sapMyControlClass {
   *       	width: 100%;
   *       }
   *   ```
   *
   *
   * @since 1.52
   */
  export interface IOverflowToolbarContent {
    __implements__sap_m_IOverflowToolbarContent: boolean;
  }

  /**
   * Interface for controls which are suitable as a Scale for the Slider/RangeSlider. Implementation of this
   * interface should implement the following methods:
   * 	 - `getTickmarksBetweenLabels`
   * 	 - `calcNumberOfTickmarks`
   * 	 - `handleResize`
   * 	 - `getLabel`
   *
   * @since 1.46
   */
  export interface IScale {
    __implements__sap_m_IScale: boolean;

    /**
     * Returns how many tickmarks would be drawn on the screen. The start and the end tickmark should be specified
     * in this method.
     *
     *
     * @returns The number of tickmarks
     */
    calcNumberOfTickmarks(
      /**
       * Size of the scale. This is the distance between the start and end point i.e. 0..100
       */
      fSize: float,
      /**
       * The step walking from start to end.
       */
      fStep: float,
      /**
       * Limits the number of tickmarks.
       */
      iTickmarksThreshold: int
    ): int;
    /**
     * Provides a custom tickmark label.
     *
     * This method is optional. If it is not provided, the slider values will be placed as labels. If provided,
     * the value of the tickmark labels and accessibility attributes (aria-valuenow and aria-valuetext) of the
     * slider are changed accordingly.
     *
     *
     * @returns The label that should be placed in the current position.
     */
    getLabel?(
      /**
       * Value represented by the tickmark
       */
      fValue: float,
      /**
       * Slider control that asks for a label
       */
      oSlider: Slider | RangeSlider
    ): string | number;
    /**
     * Returns the number of tickmarks, which should be placed between labels.
     *
     *
     * @returns The number of tickmarks
     */
    getTickmarksBetweenLabels(): int;
    /**
     * Called, when the slider is getting resized.
     *
     * The Slider/RangeSlider control could be accessed via the oEvent.control parameter.
     *
     * Implementing this method is optional.
     */
    handleResize?(
      /**
       * The event object passed.
       */
      oEvent: jQuery.Event
    ): void;
  }

  /**
   * Common interface for sap.m.ColumnListItem and sap.m.GroupHeaderListItem
   *
   * @since 1.119
   */
  export interface ITableItem {
    __implements__sap_m_ITableItem: boolean;
  }

  /**
   * Interface for controls placed in the `content` aggregation of `{@link sap.m.Toolbar}` or `{@link sap.m.OverflowToolbar}`,
   * which need to indicate whether they are interactive or not.
   *
   * Controls that implement this interface should have the following method: `_getToolbarInteractive` - returns
   * boolean value that shows whether the control is interactive or not
   */
  export interface IToolbarInteractiveControl {
    __implements__sap_m_IToolbarInteractiveControl: boolean;
  }

  /**
   * Available label display modes.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'LabelDesign'.
   */
  export enum LabelDesign {
    /**
     * Displays the label in bold.
     */
    Bold = "Bold",
    /**
     * Displays the label in normal mode.
     */
    Standard = "Standard",
  }
  /**
   * Types of LightBox loading stages.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'LightBoxLoadingStates'.
   *
   * @since 1.40
   */
  export enum LightBoxLoadingStates {
    /**
     * The LightBox image could not load.
     */
    Error = "ERROR",
    /**
     * The LightBox image has loaded.
     */
    Loaded = "LOADED",
    /**
     * The LightBox image is still loading.
     */
    Loading = "LOADING",
    /**
     * The LightBox image has timed out, could not load.
     */
    TimeOutError = "TIME_OUT_ERROR",
  }
  /**
   * Enumeration for possible Link accessibility roles.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'LinkAccessibleRole'.
   *
   * @since 1.104.0
   */
  export enum LinkAccessibleRole {
    /**
     * Link will receive `role="Button"` attibute.
     */
    Button = "Button",
    /**
     * Default mode.
     */
    Default = "Default",
  }
  /**
   * Enumeration for possible link-to-anchor conversion strategy.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'LinkConversion'.
   *
   * @since 1.45.5
   */
  export enum LinkConversion {
    /**
     * Valid links with protocols, such as http, https, ftp and those starting with the string "www".
     */
    All = "All",
    /**
     * Default mode (no conversion).
     */
    None = "None",
    /**
     * Valid links with protocols, such as http, https, ftp.
     */
    ProtocolOnly = "ProtocolOnly",
  }
  /**
   * Defines the growing direction of the `sap.m.List` or `sap.m.Table`.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ListGrowingDirection'.
   *
   * @since 1.40.0
   */
  export enum ListGrowingDirection {
    /**
     * User has to scroll down to load more items or the growing button is displayed at the bottom.
     */
    Downwards = "Downwards",
    /**
     * User has to scroll up to load more items or the growing button is displayed at the top.
     *
     * **Note:** If this option is active, there should not be any other control than `sap.m.List` inside its
     * `ScollContainer`.
     */
    Upwards = "Upwards",
  }
  /**
   * Defines the different header styles.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ListHeaderDesign'.
   *
   * @deprecated As of version 1.16. Has no functionality since 1.16.
   */
  export enum ListHeaderDesign {
    /**
     * Plain header style
     */
    Plain = "Plain",
    /**
     * Standard header style
     */
    Standard = "Standard",
  }
  /**
   * Defines the keyboard handling behavior of the `sap.m.List` or `sap.m.Table`.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ListKeyboardMode'.
   *
   * @since 1.38.0
   */
  export enum ListKeyboardMode {
    /**
     * This mode is suitable if there are only editable fields within the item.
     *
     * In this mode, the first focus goes to the first interactive element within the first item and this is
     * the only difference between the `Edit` and `Navigation` mode.
     */
    Edit = "Edit",
    /**
     * This default mode is suitable if the List or Table contains editable and/or non-editable fields.
     *
     * In this mode, the first focus goes to the first item. If the focus is on the item, or cell, pressing
     * tab/shift+tab moves the focus to the next/previous element in the tab chain after/before the `sap.m.List`
     * or `sap.m.Table` control. If the focus is on the interactive element, pressing tab/shift+tab moves the
     * focus to the next/previous element in the tab chain after/before the focused interactive element.
     */
    Navigation = "Navigation",
  }
  /**
   * Defines the mode of the list.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ListMode'.
   */
  export enum ListMode {
    /**
     * Delete mode (only one list item can be deleted via provided delete button)
     */
    Delete = "Delete",
    /**
     * Multi selection mode (more than one list item can be selected).
     */
    MultiSelect = "MultiSelect",
    /**
     * Default mode (no selection).
     */
    None = "None",
    /**
     * Right-positioned single selection mode (only one list item can be selected).
     */
    SingleSelect = "SingleSelect",
    /**
     * Left-positioned single selection mode (only one list item can be selected).
     */
    SingleSelectLeft = "SingleSelectLeft",
    /**
     * Selected item is highlighted but no selection control is visible (only one list item can be selected).
     */
    SingleSelectMaster = "SingleSelectMaster",
  }
  /**
   * Defines which separator style will be applied for the items.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ListSeparators'.
   */
  export enum ListSeparators {
    /**
     * Separators between the items including the last and the first one.
     */
    All = "All",
    /**
     * Separators between the items. **Note:** This enumeration depends on the theme.
     */
    Inner = "Inner",
    /**
     * No item separators.
     */
    None = "None",
  }
  /**
   * Defines the visual indication and behaviour of the list items.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ListType'.
   */
  export enum ListType {
    /**
     * Indicates that the item is clickable via active feedback when item is pressed.
     */
    Active = "Active",
    /**
     * Enables detail button of the list item that fires `detailPress` event. Also see {@link sap.m.ListItemBase#attachDetailPress}.
     */
    Detail = "Detail",
    /**
     * Enables {@link sap.m.ListType.Detail} and {@link sap.m.ListType.Active} enumerations together.
     */
    DetailAndActive = "DetailAndActive",
    /**
     * Indicates the list item does not have any active feedback when item is pressed. **Note:** `Inactive`
     * type cannot be used to disable list items.
     */
    Inactive = "Inactive",
    /**
     * Indicates the list item is navigable to show extra information about the item.
     */
    Navigation = "Navigation",
  }
  /**
   * Enumeration of possible load statuses.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'LoadState'.
   *
   * @since 1.34.0
   */
  export enum LoadState {
    /**
     * The control is disabled.
     */
    Disabled = "Disabled",
    /**
     * The control failed to load.
     */
    Failed = "Failed",
    /**
     * The control has loaded.
     */
    Loaded = "Loaded",
    /**
     * The control is loading.
     */
    Loading = "Loading",
  }
  /**
   * Different modes for a MenuButton (predefined types).
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'MenuButtonMode'.
   *
   * @since 1.38.0
   */
  export enum MenuButtonMode {
    /**
     * Default Regular type - MenuButton appears as a regular button, pressing it opens a menu.
     */
    Regular = "Regular",
    /**
     * Split type - MenuButton appears as a split button separated into two areas: the text and the arrow button.
     * Pressing the text area fires the default (or last) action, pressing the arrow part opens a menu.
     */
    Split = "Split",
  }
  /**
   * Enumeration of the `multiSelectMode>/code> in ListBase`.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'MultiSelectMode'.
   *
   * @since 1.93
   */
  export enum MultiSelectMode {
    /**
     * The Select All functionality is not available. Instead, it is only possible to remove the selection of
     * all items. For a `sap.m.Table`, a Deselect All icon is rendered.
     */
    ClearAll = "ClearAll",
    /**
     * The Select All functionality is available (default behavior). For a `sap.m.Table`, a Select All checkbox
     * is rendered.
     */
    Default = "Default",
    /**
     * The Select All functionality is available. For a `sap.m.Table`, a Select All checkbox with a warning
     * popover is rendered if not all items could be selected (for example, because of growing).
     *
     * @since 1.109
     */
    SelectAll = "SelectAll",
  }
  /**
   * Marker interface for controls which are suitable as items for the ObjectHeader.
   */
  export interface ObjectHeaderContainer {
    __implements__sap_m_ObjectHeaderContainer: boolean;
  }

  /**
   * Used by the `ObjectHeader` control to define which shape to use for the image.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ObjectHeaderPictureShape'.
   *
   * @since 1.61
   */
  export enum ObjectHeaderPictureShape {
    /**
     * Circle shape for the images in the `ObjectHeader`.
     */
    Circle = "Circle",
    /**
     * Square shape for the images in the `ObjectHeader`.
     */
    Square = "Square",
  }
  /**
   * Predefined types for ObjectMarker.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ObjectMarkerType'.
   */
  export enum ObjectMarkerType {
    /**
     * Draft type
     */
    Draft = "Draft",
    /**
     * Favorite type
     */
    Favorite = "Favorite",
    /**
     * Flagged type
     */
    Flagged = "Flagged",
    /**
     * Locked type
     */
    Locked = "Locked",
    /**
     * LockedBy type Use when you need to display the name of the user who locked the object.
     */
    LockedBy = "LockedBy",
    /**
     * Unsaved type
     */
    Unsaved = "Unsaved",
    /**
     * UnsavedBy type Use when you need to display the name of the user whose changes were unsaved.
     */
    UnsavedBy = "UnsavedBy",
  }
  /**
   * Predefined visibility for ObjectMarker.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ObjectMarkerVisibility'.
   */
  export enum ObjectMarkerVisibility {
    /**
     * Shows icon and text
     */
    IconAndText = "IconAndText",
    /**
     * Shows only icon
     */
    IconOnly = "IconOnly",
    /**
     * Shows only text
     */
    TextOnly = "TextOnly",
  }
  /**
   * The object contains configuration information for the {@link sap.m.IOverflowToolbarContent} interface.
   *
   * @since 1.110
   */
  export type OverflowToolbarConfig = {
    /**
     * A boolean that tells whether the control can move to the overflow menu or not. **Notes:**
     * 	 - Even if `canOverflow` is set to `false`, the `propsUnrelatedToSize` field is taken into account,
     *     allowing to optimize the behavior of controls that do not need to overflow, but are used in an `sap.m.OverflowToolbar`
     *     regardless.
     * 	 - If `canOverflow` is not provided, its default value is `false`. In this case, the control is shown
     *     in the content of the `sap.m.OverflowToolbar` but it's not possible to enter the overflow area.
     */
    canOverflow?: boolean;
    /**
     * An array of strings, listing all of the control's events that should trigger the closing of the overflow
     * menu, when fired.
     */
    autoCloseEvents?: string[];
    /**
     * An array of strings, listing all of the control's events that should trigger the invalidation of the
     * `sap.m.OverflowToolbar`, when fired. **Note:** By default `sap.m.OverflowToolbar` invalidates whenever
     * any property of a child control changes. This is to ensure that whenever the size of a child control
     * changes, the overflow toolbar's layout is recalculated. Some properties however do not affect control
     * size, making it unnecessary to invalidate the overflow toolbar when they change. You can list them here
     * for optimization purposes.
     */
    invalidationEvents?: string[];
    /**
     * An array of strings, listing all of the control's properties that, when changed, should not cause the
     * overflow toolbar to invalidate.
     */
    propsUnrelatedToSize?: string[];
    /**
     * A callback function that will be invoked before moving the control into the overflow menu. The control
     * instance will be passed as an argument. **Note:** The context of the function is not the control instance
     * (use the `oControl` parameter for this purpose), but rather an internal helper object, associated with
     * the current `sap.m.OverflowToolbar` instance. This object only needs to be manipulated in special cases
     * (e.g. when you want to store state on it, rather than on the control instance).
     */
    onBeforeEnterOverflow?: Function;
    /**
     * A callback function that will be invoked after taking the control out of the overflow menu (before moving
     * it back to the toolbar itself). The control instance will be passed as an argument. **Note:** See: `onBeforeEnterOverflow`
     * for details about the function's context.
     */
    onAfterExitOverflow?: Function;
    /**
     * A function that, if provided, will be called to determine the priority of the control. This function
     * must return a value of type `sap.m.OverflowToolbarPriority`. The string "Medium" is also accepted and
     * interpreted as priority between `Low` and `High`. **Note:** Normally priority in `sap.m.OverflowToolbar`
     * is managed with the `priority` property of `sap.m.OverflowToolbarLayoutData`. However, some controls
     * may have other means of defining priority, such as dedicated properties or other types of layout data
     * for that purpose. In summary, implementing this function allows a control to override the default priority
     * logic (`sap.m.OverflowToolbarLayoutData`) by providing its own.
     */
    getCustomImportance?: Function;
  };

  /**
   * Defines the priorities of the controls within {@link sap.m.OverflowToolbar}.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'OverflowToolbarPriority'.
   *
   * @since 1.32
   */
  export enum OverflowToolbarPriority {
    /**
     * Deprecated - Use `sap.m.OverflowToolbarPriority.AlwaysOverflow` instead
     *
     * @deprecated As of version 1.48.
     */
    Always = "Always",
    /**
     * Forces `OverflowToolbar` items to remain always in the overflow area.
     */
    AlwaysOverflow = "AlwaysOverflow",
    /**
     * Items with priority `Disappear` overflow before the items with higher priority, such as `Low` and `High`,
     * and remain hidden in the overflow area.
     */
    Disappear = "Disappear",
    /**
     * Items with priority `High` overflow after the items with lower priority.
     */
    High = "High",
    /**
     * Items with priority `Low` overflow before the items with higher priority, such as `High` priority items.
     */
    Low = "Low",
    /**
     * Deprecated - Use `sap.m.OverflowToolbarPriority.NeverOverflow` instead.
     *
     * @deprecated As of version 1.48.
     */
    Never = "Never",
    /**
     * Forces `OverflowToolbar` items to remain always in the toolbar.
     */
    NeverOverflow = "NeverOverflow",
  }
  /**
   * undefined
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'P13nConditionOperation'.
   */
  export enum P13nConditionOperation {
    Ascending = "Ascending",

    Average = "Average",

    BT = "BT",

    Contains = "Contains",

    Descending = "Descending",

    Empty = "Empty",

    EndsWith = "EndsWith",

    EQ = "EQ",

    GE = "GE",

    GroupAscending = "GroupAscending",

    GroupDescending = "GroupDescending",

    GT = "GT",

    Initial = "Initial",

    LE = "LE",

    LT = "LT",

    Maximum = "Maximum",

    Minimum = "Minimum",

    NotBT = "NotBT",

    NotContains = "NotContains",

    NotEmpty = "NotEmpty",

    NotEndsWith = "NotEndsWith",

    NotEQ = "NotEQ",

    NotGE = "NotGE",

    NotGT = "NotGT",

    NotInitial = "NotInitial",

    NotLE = "NotLE",

    NotLT = "NotLT",

    NotStartsWith = "NotStartsWith",

    StartsWith = "StartsWith",

    Total = "Total",
  }
  /**
   * Type of panels used in the personalization dialog.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'P13nPanelType'.
   */
  export enum P13nPanelType {
    /**
     * Panel type for column settings.
     */
    columns = "columns",
    /**
     * Panel type for dimension and measure settings.
     */
    dimeasure = "dimeasure",
    /**
     * Panel type for filtering.
     */
    filter = "filter",
    /**
     * Panel type for grouping.
     */
    group = "group",
    /**
     * Panel type for sorting.
     */
    sort = "sort",
  }
  /**
   * Type of popup used in the `sap.m.p13n.Popup`.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'P13nPopupMode'.
   */
  export enum P13nPopupMode {
    /**
     * Dialog type as popup type.
     */
    Dialog = "Dialog",
    /**
     * ResponsivePopover type as popup type.
     */
    ResponsivePopover = "ResponsivePopover",
  }
  /**
   * Available Page Background Design.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'PageBackgroundDesign'.
   */
  export enum PageBackgroundDesign {
    /**
     * Page background color when a List is set as the Page content.
     */
    List = "List",
    /**
     * A solid background color dependent on the theme.
     */
    Solid = "Solid",
    /**
     * Standard Page background color.
     */
    Standard = "Standard",
    /**
     * Transparent background for the page.
     */
    Transparent = "Transparent",
  }
  /**
   * Available Panel Accessible Landmark Roles.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'PanelAccessibleRole'.
   */
  export enum PanelAccessibleRole {
    /**
     * Represents the ARIA role `complementary`. A section of the page, designed to be complementary to the
     * main content at a similar level in the DOM hierarchy.
     */
    Complementary = "Complementary",
    /**
     * Represents the ARIA role `Form`. A landmark region that contains a collection of items and objects that,
     * as a whole, create a form.
     */
    Form = "Form",
    /**
     * Represents the ARIA role `Region`. A section of a page, that is important enough to be included in a
     * page summary or table of contents.
     */
    Region = "Region",
  }
  /**
   * PDF viewer display types.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'PDFViewerDisplayType'.
   */
  export enum PDFViewerDisplayType {
    /**
     * The PDF viewer switches between the `Link` display type and the `Embedded` display type, depending on
     * the device being used.
     */
    Auto = "Auto",
    /**
     * The PDF viewer appears embedded in the parent container and displays the PDF file.
     */
    Embedded = "Embedded",
    /**
     * The PDF viewer appears as a toolbar with a download button that can be used to download the PDF file
     * or open it in a new tab.
     */
    Link = "Link",
  }
  /**
   * Types for the placement of Popover control.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'PlacementType'.
   */
  export enum PlacementType {
    /**
     * Popover will be placed automatically at the reference control.
     */
    Auto = "Auto",
    /**
     * Popover will be placed at the bottom of the reference control.
     */
    Bottom = "Bottom",
    /**
     * Popover will be placed at the right or left side of the reference control.
     */
    Horizontal = "Horizontal",
    /**
     * Deprecated - use `sap.m.PlacementType.HorizontalPreferredLeft` type.
     *
     * @since 1.29
     * @deprecated As of version 1.36. Instead, use `sap.m.PlacementType.HorizontalPreferredLeft` type.
     */
    HorizontalPreferedLeft = "HorizontalPreferedLeft",
    /**
     * Deprecated - use `sap.m.PlacementType.HorizontalPreferredRight` type.
     *
     * @since 1.29
     * @deprecated As of version 1.36. Instead, use `sap.m.PlacementType.HorizontalPreferredRight` type.
     */
    HorizontalPreferedRight = "HorizontalPreferedRight",
    /**
     * Popover will be placed at the right or left side of the reference control but will try to position on
     * the left side if the space is greater than the Popover's width.
     *
     * @since 1.36
     */
    HorizontalPreferredLeft = "HorizontalPreferredLeft",
    /**
     * Popover will be placed at the right or left side of the reference control but will try to position on
     * the right side if the space is greater than the Popover's width.
     *
     * @since 1.36
     */
    HorizontalPreferredRight = "HorizontalPreferredRight",
    /**
     * Popover will be placed at the left side of the reference control.
     */
    Left = "Left",
    /**
     * Popover will be placed to the bottom of the reference control. If the available space is less than the
     * Popover's height, it will appear to the top of the same reference control bottom border.
     *
     * @since 1.38
     */
    PreferredBottomOrFlip = "PreferredBottomOrFlip",
    /**
     * Popover will be placed to the left of the reference control. If the available space is less than the
     * Popover's width, it will appear to the right of the same reference control left border.
     *
     * @since 1.38
     */
    PreferredLeftOrFlip = "PreferredLeftOrFlip",
    /**
     * Popover will be placed to the right of the reference control. If the available space is less than the
     * Popover's width, it will appear to the left of the same reference control right border.
     *
     * @since 1.38
     */
    PreferredRightOrFlip = "PreferredRightOrFlip",
    /**
     * Popover will be placed to the top of the reference control. If the available space is less than the Popover's
     * height, it will appear to the bottom of the same reference control top border.
     *
     * @since 1.38
     */
    PreferredTopOrFlip = "PreferredTopOrFlip",
    /**
     * Popover will be placed at the right side of the reference control.
     */
    Right = "Right",
    /**
     * Popover will be placed at the top of the reference control.
     */
    Top = "Top",
    /**
     * Popover will be placed at the top or bottom of the reference control.
     */
    Vertical = "Vertical",
    /**
     * Deprecated - use `sap.m.PlacementType.VerticalPreferredBottom` type.
     *
     * @since 1.29
     * @deprecated As of version 1.36. Instead, use `sap.m.PlacementType.VerticalPreferredBottom` type.
     */
    VerticalPreferedBottom = "VerticalPreferedBottom",
    /**
     * Deprecated - use `sap.m.PlacementType.VerticalPreferredTop` type.
     *
     * @since 1.29
     * @deprecated As of version 1.36. Instead, use `sap.m.PlacementType.VerticalPreferredTop` type.
     */
    VerticalPreferedTop = "VerticalPreferedTop",
    /**
     * Popover will be placed at the top or bottom of the reference control but will try to position on the
     * bottom side if the space is greater than the Popover's height.
     *
     * @since 1.36
     */
    VerticalPreferredBottom = "VerticalPreferredBottom",
    /**
     * Popover will be placed at the top or bottom of the reference control but will try to position on the
     * top side if the space is greater than the Popover's height.
     *
     * @since 1.36
     */
    VerticalPreferredTop = "VerticalPreferredTop",
  }
  /**
   * A list of the default built-in views in a {@link sap.m.PlanningCalendar}, described by their keys.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'PlanningCalendarBuiltInView'.
   *
   * @since 1.50
   */
  export enum PlanningCalendarBuiltInView {
    /**
     * Represents the key of the built-in view, in which the intervals have the size of one day.
     */
    Day = "Day",
    /**
     * Represents the key of the built-in view, in which the intervals have the size of one hour.
     */
    Hour = "Hour",
    /**
     * Represents the key of the built-in view, in which the intervals have the size of one month.
     */
    Month = "Month",
    /**
     * Represents the key of the built-in view, in which the intervals have the size of one day where 31 days
     * are displayed, starting with the first day of the month.
     */
    OneMonth = "One Month",
    /**
     * Represents the key of the built-in view, in which the intervals have the size of one day where 7 days
     * are displayed, starting with the first day of the week.
     */
    Week = "Week",
  }
  /**
   * Available sticky modes for the {@link sap.m.SinglePlanningCalendar}
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'PlanningCalendarStickyMode'.
   *
   * @since 1.62
   */
  export enum PlanningCalendarStickyMode {
    /**
     * Actions toolbar, navigation toolbar and the column headers will be sticky.
     */
    All = "All",
    /**
     * Only the navigation toolbar and column headers will be sticky.
     */
    NavBarAndColHeaders = "NavBarAndColHeaders",
    /**
     * Nothing will stick at the top.
     */
    None = "None",
  }
  /**
   * Defines the display of table pop-ins.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'PopinDisplay'.
   *
   * @since 1.13.2
   */
  export enum PopinDisplay {
    /**
     * Inside the table popin, header is displayed at the first line and cell content is displayed at the next
     * line.
     */
    Block = "Block",
    /**
     * Inside the table popin, cell content is displayed next to the header in the same line. **Note:** If there
     * is not enough space for the cell content then it jumps to the next line.
     */
    Inline = "Inline",
    /**
     * Inside the table popin, only the cell content will be visible.
     *
     * @since 1.28
     */
    WithoutHeader = "WithoutHeader",
  }
  /**
   * Defines the layout options of the table popins.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'PopinLayout'.
   *
   * @since 1.52
   */
  export enum PopinLayout {
    /**
     * Sets block layout for rendering the table popins. The elements inside the popin container are rendered
     * one below the other. **Note:** This option enables the former rendering behavior of the table popins.
     *
     * @since 1.52
     */
    Block = "Block",
    /**
     * Sets grid layout for rendering the table popins. The grid width for each table popin is comparatively
     * larger than `GridSmall`, hence this allows less content to be rendered in a single popin row.
     *
     * **Note:** This feature is currently not supported with Internet Explorer and Edge (version lower than
     * 16) browsers.
     *
     * @since 1.52
     */
    GridLarge = "GridLarge",
    /**
     * Sets grid layout for rendering the table popins. The grid width for each table popin is small, hence
     * this allows more content to be rendered in a single popin row. This value defines small grid width for
     * the table popins.
     *
     * **Note:** This feature is currently not supported with Internet Explorer and Edge (version lower than
     * 16) browsers.
     *
     * @since 1.52
     */
    GridSmall = "GridSmall",
  }
  /**
   * Helper for Popups.
   *
   * @since 1.16.7
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  interface PopupHelper {
    /**
     * Converts the given percentage value to an absolute number based on the given base size.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The calculated size string with "px" as unit or `null` when the format of given parameter is
     * wrong.
     */
    calcPercentageSize(
      /**
       * A percentage value in string format, for example "25%"
       */
      sPercentage: string,
      /**
       * A float number which the calculation is based on.
       */
      fBaseSize: float
    ): string | null;
  }
  export const PopupHelper: PopupHelper;

  /**
   * Defines the priority for the TileContent in ActionMode
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'Priority'.
   */
  export enum Priority {
    /**
     * It displays high priority color for the GenericTag
     */
    High = "High",
    /**
     * It displays low priority color for the GenericTag
     */
    Low = "Low",
    /**
     * It displays medium priority color for the GenericTag
     */
    Medium = "Medium",
    /**
     * The priority is not set
     */
    None = "None",
    /**
     * It displays very high priority color for the GenericTag
     */
    VeryHigh = "VeryHigh",
  }
  /**
   * QuickViewGroupElement is a combination of one label and another control (Link or Text) associated to
   * this label.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'QuickViewGroupElementType'.
   */
  export enum QuickViewGroupElementType {
    /**
     * Displays an e-mail link
     */
    email = "email",
    /**
     * Displays a regular HTML link
     */
    link = "link",
    /**
     * Displays a phone number link for direct dialing and an icon for sending a text message
     */
    mobile = "mobile",
    /**
     * Displays a link for navigating to another QuickViewPage
     */
    pageLink = "pageLink",
    /**
     * Displays a phone number link for direct dialing
     */
    phone = "phone",
    /**
     * Displays text
     */
    text = "text",
  }
  /**
   * Possible values for the visualization of float values in the RatingIndicator control.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'RatingIndicatorVisualMode'.
   */
  export enum RatingIndicatorVisualMode {
    /**
     * Values are rounded to the nearest integer value (e.g. 1.7 -> 2).
     */
    Full = "Full",
    /**
     * Values are rounded to the nearest half value (e.g. 1.7 -> 1.5).
     */
    Half = "Half",
  }
  /**
   * Reactive area modes of interactable elements.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ReactiveAreaMode'.
   */
  export enum ReactiveAreaMode {
    /**
     * The target element is displayed as part of a sentence.
     */
    Inline = "Inline",
    /**
     * The target element is displayed as on overlay on top of other interactive parts of the page.
     */
    Overlay = "Overlay",
  }
  /**
   * Enumeration of the `ResetAllMode` that can be used in a `TablePersoController`.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ResetAllMode'.
   */
  export enum ResetAllMode {
    /**
     * Default behavior of the `TablePersoDialog` Reset All button.
     */
    Default = "Default",
    /**
     * Resets the table to the default of the attached `PersoService`.
     */
    ServiceDefault = "ServiceDefault",
    /**
     * Resets the table to the result of `getResetPersData` of the attached `PersoService`.
     */
    ServiceReset = "ServiceReset",
  }
  /**
   * Breakpoint names for different screen sizes.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ScreenSize'.
   */
  export enum ScreenSize {
    /**
     * 1024px wide
     */
    Desktop = "Desktop",
    /**
     * 768px wide
     */
    Large = "Large",
    /**
     * 560px wide
     */
    Medium = "Medium",
    /**
     * 240px wide
     */
    Phone = "Phone",
    /**
     * 480px wide
     */
    Small = "Small",
    /**
     * 600px wide
     */
    Tablet = "Tablet",
    /**
     * 960px wide
     */
    XLarge = "XLarge",
    /**
     * 320px wide
     */
    XSmall = "XSmall",
    /**
     * 1120px wide
     */
    XXLarge = "XXLarge",
    /**
     * 240px wide
     */
    XXSmall = "XXSmall",
  }
  /**
   * A string type that represents column ratio.
   *
   * Allowed values are strings that follow the number:number (3:2) format.
   *
   * @since 1.86
   */
  export type SelectColumnRatio = string;

  /**
   * Defines the control that will receive the initial focus in the `sap.m.SelectDialog` or `sap.m.TableSelectDialog`.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'SelectDialogInitialFocus'.
   *
   * @since 1.117.0
   */
  export enum SelectDialogInitialFocus {
    /**
     * Content list.
     */
    List = "List",
    /**
     * SearchField control
     */
    SearchField = "SearchField",
  }
  /**
   * Enumeration for different action levels in sap.m.SelectionDetails control.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'SelectionDetailsActionLevel'.
   *
   * @since 1.48
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export enum SelectionDetailsActionLevel {
    /**
     * ActionGroup on SelectionDetails list level.
     *
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    Group = "Group",
    /**
     * Action on SelectionDetailsItem level.
     *
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    Item = "Item",
    /**
     * Action on SelectionDetails list level.
     *
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    List = "List",
  }
  /**
   * Defines the keyboard navigation mode.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'SelectListKeyboardNavigationMode'.
   *
   * @since 1.38
   */
  export enum SelectListKeyboardNavigationMode {
    /**
     * Keyboard navigation is delimited at the last item or first item of the list.
     */
    Delimited = "Delimited",
    /**
     * Keyboard navigation is disabled.
     */
    None = "None",
  }
  /**
   * Enumeration for different Select types.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'SelectType'.
   *
   * @since 1.16
   */
  export enum SelectType {
    /**
     * Will show the text.
     */
    Default = "Default",
    /**
     * Will show only the specified icon.
     */
    IconOnly = "IconOnly",
  }
  /**
   * Enumeration of the `SharingMode` that can be used in a `VariantItem`.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'SharingMode'.
   */
  export enum SharingMode {
    /**
     * Private mode of the `VariantItem`.
     */
    Private = "private",
    /**
     * Public mode of the `VariantItem`.
     */
    Public = "public",
  }
  /**
   * Available selection modes for the {@link sap.m.SinglePlanningCalendar}
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'SinglePlanningCalendarSelectionMode'.
   *
   * @since 1.113
   */
  export enum SinglePlanningCalendarSelectionMode {
    /**
     * Мore than one date will be available to selection.
     */
    MultiSelect = "MultiSelect",
    /**
     * Single date selection.
     */
    SingleSelect = "SingleSelect",
  }
  /**
   * Enumeration of possible size settings.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'Size'.
   *
   * @since 1.34.0
   */
  export enum Size {
    /**
     * The size depends on the device it is running on. It is medium size for desktop and tablet and small size
     * for phone.
     */
    Auto = "Auto",
    /**
     * Large size.
     */
    L = "L",
    /**
     * Medium size.
     */
    M = "M",
    /**
     * The width and height of the control are determined by the width and height of the container the control
     * is placed in. Please note: it is decided by the control whether or not sap.m.Size.Responsive is supported.
     *
     * @since 1.44.0
     */
    Responsive = "Responsive",
    /**
     * Small size.
     */
    S = "S",
    /**
     * Extra small size.
     */
    XS = "XS",
  }
  /**
   * The mode of SplitContainer or SplitApp control to show/hide the master area.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'SplitAppMode'.
   */
  export enum SplitAppMode {
    /**
     * Master area is hidden initially both in portrait and landscape.
     *
     * Master area can be opened by clicking on the top left corner button or swiping right. Swipe is only enabled
     * on mobile devices. Master will keep the open state when changing the orientation of the device.
     */
    HideMode = "HideMode",
    /**
     * Master will be shown inside a Popover when in portrait mode
     */
    PopoverMode = "PopoverMode",
    /**
     * Master will automatically be hidden in portrait mode.
     */
    ShowHideMode = "ShowHideMode",
    /**
     * Master will always be shown but in a compressed version when in portrait mode.
     */
    StretchCompressMode = "StretchCompressMode",
  }
  /**
   * The option keys of all the standard options of a DynamicDateRange control.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'StandardDynamicDateRangeKeys'.
   */
  export enum StandardDynamicDateRangeKeys {
    /**
     * The date will be selected from a calendar.
     */
    DATE = "DATE",
    /**
     * The range will be selected from a calendar.
     */
    DATERANGE = "DATERANGE",
    /**
     * The date and time will be selected from a calendar and time picker.
     */
    DATETIME = "DATETIME",
    /**
     * The range will be selected from two DateTimePicker controls.
     */
    DATETIMERANGE = "DATETIMERANGE",
    /**
     * The range will start from the date selected from a calendar and ends with the last day of the current
     * year.
     */
    DATETOYEAR = "DATETOYEAR",
    /**
     * The date will be the first day of the current month.
     */
    FIRSTDAYMONTH = "FIRSTDAYMONTH",
    /**
     * The date will be the first day of the current quarter.
     */
    FIRSTDAYQUARTER = "FIRSTDAYQUARTER",
    /**
     * The date will be the first day of the current week.
     */
    FIRSTDAYWEEK = "FIRSTDAYWEEK",
    /**
     * The date will be the first day of the current year.
     */
    FIRSTDAYYEAR = "FIRSTDAYYEAR",
    /**
     * The range will start from a date selected from a calendar.
     */
    FROM = "FROM",
    /**
     * The range will start from a date and time selected from a calendar and time picker.
     */
    FROMDATETIME = "FROMDATETIME",
    /**
     * The date will be the last day of the current month.
     */
    LASTDAYMONTH = "LASTDAYMONTH",
    /**
     * The date will be the last day of the current quarter.
     */
    LASTDAYQUARTER = "LASTDAYQUARTER",
    /**
     * The range will contain the last X days. The count of the days is selected from a StepInput.
     */
    LASTDAYS = "LASTDAYS",
    /**
     * The range will contain the last X days including the current one. The count of the days is selected from
     * a StepInput.
     */
    LASTDAYSINCLUDED = "LASTDAYSINCLUDED",
    /**
     * The date will be the last day of the current week.
     */
    LASTDAYWEEK = "LASTDAYWEEK",
    /**
     * The date will be the last day of the current year.
     */
    LASTDAYYEAR = "LASTDAYYEAR",
    /**
     * The range will contain the last X hours. The count of the hours is selected from a StepInput.
     */
    LASTHOURS = "LASTHOURS",
    /**
     * The range will contain the last X hours including the current one. The count of the hours is selected
     * from a StepInput.
     */
    LASTHOURSINCLUDED = "LASTHOURSINCLUDED",
    /**
     * The range will contain the last X minutes. The count of the minutes is selected from a StepInput.
     */
    LASTMINUTES = "LASTMINUTES",
    /**
     * The range will contain the last X minutes including the current one. The count of the minutes is selected
     * from a StepInput.
     */
    LASTMINUTESINCLUDED = "LASTMINUTESINCLUDED",
    /**
     * The range will contain the days in the last month.
     */
    LASTMONTH = "LASTMONTH",
    /**
     * The range will contain the last X months. The count of the months is selected from a StepInput.
     */
    LASTMONTHS = "LASTMONTHS",
    /**
     * The range will contain the last X months including the current one. The count of the months is selected
     * from a StepInput.
     */
    LASTMONTHSINCLUDED = "LASTMONTHSINCLUDED",
    /**
     * The range will contain the days in the last quarter.
     */
    LASTQUARTER = "LASTQUARTER",
    /**
     * The range will contain the last X quarters. The count of the quarters is selected from a StepInput.
     */
    LASTQUARTERS = "LASTQUARTERS",
    /**
     * The range will contain the last X quarters including the current one. The count of the quarters is selected
     * from a StepInput.
     */
    LASTQUARTERSINCLUDED = "LASTQUARTERSINCLUDED",
    /**
     * The range will contain the days of the last week.
     */
    LASTWEEK = "LASTWEEK",
    /**
     * The range will contain the last X weeks. The count of the weeks is selected from a StepInput.
     */
    LASTWEEKS = "LASTWEEKS",
    /**
     * The range will contain the last X weeks including the current one. The count of the weeks is selected
     * from a StepInput.
     */
    LASTWEEKSINCLUDED = "LASTWEEKSINCLUDED",
    /**
     * The range will contain the days in the last year.
     */
    LASTYEAR = "LASTYEAR",
    /**
     * The range will contain the last X years. The count of the years is selected from a StepInput.
     */
    LASTYEARS = "LASTYEARS",
    /**
     * The range will contain the last X years including the current one. The count of the years is selected
     * from a StepInput.
     */
    LASTYEARSINCLUDED = "LASTYEARSINCLUDED",
    /**
     * The range will contain the next X days. The count of the days is selected from a StepInput.
     */
    NEXTDAYS = "NEXTDAYS",
    /**
     * The range will contain the next X days including the current one. The count of the days is selected from
     * a StepInput.
     */
    NEXTDAYSINCLUDED = "NEXTDAYSINCLUDED",
    /**
     * The range will contain the next X hours. The count of the hours is selected from a StepInput.
     */
    NEXTHOURS = "NEXTHOURS",
    /**
     * The range will contain the next X hours including the current one. The count of the hours is selected
     * from a StepInput.
     */
    NEXTHOURSINCLUDED = "NEXTHOURSINCLUDED",
    /**
     * The range will contain the next X minutes. The count of the minutes is selected from a StepInput.
     */
    NEXTMINUTES = "NEXTMINUTES",
    /**
     * The range will contain the next X minutes including the current one. The count of the minutes is selected
     * from a StepInput.
     */
    NEXTMINUTESINCLUDED = "NEXTMINUTESINCLUDED",
    /**
     * The range will contain the days in the next month.
     */
    NEXTMONTH = "NEXTMONTH",
    /**
     * The range will contain the next X months. The count of the months is selected from a StepInput.
     */
    NEXTMONTHS = "NEXTMONTHS",
    /**
     * The range will contain the next X months including the current one. The count of the months is selected
     * from a StepInput.
     */
    NEXTMONTHSINCLUDED = "NEXTMONTHSINCLUDED",
    /**
     * The range will contain the days in the next quarter.
     */
    NEXTQUARTER = "NEXTQUARTER",
    /**
     * The range will contain the next X quarters. The count of the quarters is selected from a StepInput.
     */
    NEXTQUARTERS = "NEXTQUARTERS",
    /**
     * The range will contain the next X quarters including the current one. The count of the quarters is selected
     * from a StepInput.
     */
    NEXTQUARTERSINCLUDED = "NEXTQUARTERSINCLUDED",
    /**
     * The range will contain the days of the next week.
     */
    NEXTWEEK = "NEXTWEEK",
    /**
     * The range will contain the next X weeks. The count of the weeks is selected from a StepInput.
     */
    NEXTWEEKS = "NEXTWEEKS",
    /**
     * The range will contain the next X weeks including the current one. The count of the weeks is selected
     * from a StepInput.
     */
    NEXTWEEKSINCLUDED = "NEXTWEEKSINCLUDED",
    /**
     * The range will contain the days in the next year.
     */
    NEXTYEAR = "NEXTYEAR",
    /**
     * The range will contain the next X years. The count of the years is selected from a StepInput.
     */
    NEXTYEARS = "NEXTYEARS",
    /**
     * The range will contain the next X years including the current one. The count of the years is selected
     * from a StepInput.
     */
    NEXTYEARSINCLUDED = "NEXTYEARSINCLUDED",
    /**
     * The range will contain the days in the first quarter.
     */
    QUARTER1 = "QUARTER1",
    /**
     * The range will contain the days in the second quarter.
     */
    QUARTER2 = "QUARTER2",
    /**
     * The range will contain the days in the third quarter.
     */
    QUARTER3 = "QUARTER3",
    /**
     * The range will contain the days in the fourth quarter.
     */
    QUARTER4 = "QUARTER4",
    /**
     * The range will contain a month selected from a MonthPicker.
     */
    SPECIFICMONTH = "SPECIFICMONTH",
    /**
     * The range will contain a month in exact year selected from a MonthPicker.
     */
    SPECIFICMONTHINYEAR = "SPECIFICMONTHINYEAR",
    /**
     * The range will contain the days in the current month.
     */
    THISMONTH = "THISMONTH",
    /**
     * The range will contain the days in the current quarter.
     */
    THISQUARTER = "THISQUARTER",
    /**
     * The range will contain the days of the current week.
     */
    THISWEEK = "THISWEEK",
    /**
     * The range will contain the days in the current year.
     */
    THISYEAR = "THISYEAR",
    /**
     * The range will end in a date selected from a calendar.
     */
    TO = "TO",
    /**
     * The range will end in a date and time selected from a calendar and time picker.
     */
    TODATETIME = "TODATETIME",
    /**
     * The date will be the day of selection.
     */
    TODAY = "TODAY",
    /**
     * The range will contain the last X days and the next Y days. The count of the days is selected from a
     * StepInput.
     */
    TODAYFROMTO = "TODAYFROMTO",
    /**
     * The date will be the day after the day of selection.
     */
    TOMORROW = "TOMORROW",
    /**
     * The range will start from the first day of the current year and ends with the date selected from a calendar.
     */
    YEARTODATE = "YEARTODATE",
    /**
     * The date will be the day before the day of selection.
     */
    YESTERDAY = "YESTERDAY",
  }
  /**
   * Types for StandardTile.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'StandardTileType'.
   */
  export enum StandardTileType {
    /**
     * Tile representing that something needs to be created
     */
    Create = "Create",
    /**
     * Monitor tile
     */
    Monitor = "Monitor",
    /**
     * Default type
     */
    None = "None",
  }
  /**
   * Available step modes for {@link sap.m.StepInput}.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'StepInputStepModeType'.
   *
   * @since 1.54
   */
  export enum StepInputStepModeType {
    /**
     * Choosing increase/decrease button will add/subtract the `step` value to/from the current value. For example,
     * if `step` is 5, current `value` is 17 and increase button is chosen, the result will be 22 (5+17).
     *
     * **Note:** Using keyboard PageUp/PageDown will add/subtract the `step` multiplied by the `largerStep`
     * values to/from the current `value`. For example, if `step` is 5, `largerStep` is 3, current `value` is
     * 17 and PageUp is chosen, the result would be 32 (5*3+17).
     *
     * For more information, see {@link sap.m.StepInput}'s `step`, `largerStep` and `stepMode` properties.
     */
    AdditionAndSubtraction = "AdditionAndSubtraction",
    /**
     * Pressing increase/decrease button will increase/decrease the current `value` to the closest number that
     * is divisible by the `step`.
     *
     * For example, if `step` is 5, current `value` is 17 and increase button is chosen, the result will be
     * 20 as it is the closest larger number that is divisible by 5.
     *
     * **Note:** Using keyboard PageUp/PageDown will increase/decrease the current `value` to the closest number
     * that is divisible by the multiplication of the `step` and the `largerStep` values. For example, if `step`
     * is 5, `largerStep` is 3, current `value` is 17 and PageUp is chosen, the result would be 30 as it is
     * the closest larger number that is divisible by 15.
     *
     * The logic above will work only if both `step` and `largerStep` are integers.
     *
     * For more information, see {@link sap.m.StepInput}'s `step`, `largerStep` and `stepMode` properties.
     */
    Multiple = "Multiple",
  }
  /**
   * Available validation modes for {@link sap.m.StepInput}.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'StepInputValidationMode'.
   */
  export enum StepInputValidationMode {
    /**
     * Validation happens on `FocusOut`.
     */
    FocusOut = "FocusOut",
    /**
     * Validation happens on `LiveChange`.
     */
    LiveChange = "LiveChange",
  }
  /**
   * Defines which area of the control remains fixed at the top of the page during vertical scrolling as long
   * as the control is in the viewport.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'Sticky'.
   *
   * @since 1.54
   */
  export enum Sticky {
    /**
     * The column headers remain in a fixed position.
     */
    ColumnHeaders = "ColumnHeaders",
    /**
     * The group headers remain in a fixed position at the top of the page during vertical scrolling.
     *
     * @since 1.128
     */
    GroupHeaders = "GroupHeaders",
    /**
     * The header toolbar remains in a fixed position.
     *
     * @since 1.56
     */
    HeaderToolbar = "HeaderToolbar",
    /**
     * The info toolbar remains in a fixed position.
     *
     * @since 1.56
     */
    InfoToolbar = "InfoToolbar",
  }
  /**
   * Types of string filter operators.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'StringFilterOperator'.
   *
   * @since 1.42
   */
  export enum StringFilterOperator {
    /**
     * Checks if any word in the text starts with the search string.
     */
    AnyWordStartsWith = "AnyWordStartsWith",
    /**
     * Checks if the text contains the search string.
     */
    Contains = "Contains",
    /**
     * Checks if the text is equal with the search string.
     */
    Equals = "Equals",
    /**
     * Checks if the text starts with the search string.
     */
    StartsWith = "StartsWith",
  }
  /**
   * Directions for swipe event.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'SwipeDirection'.
   */
  export enum SwipeDirection {
    /**
     * Swipe from the beginning to the end - left to right in LTR languages and right to left in RTL languages.
     *
     * @since 1.72
     */
    BeginToEnd = "BeginToEnd",
    /**
     * Both directions (left to right or right to left)
     */
    Both = "Both",
    /**
     * Swipe from the end to the beginning - right to left in LTR languages and left to right in RTL languages.
     *
     * @since 1.72
     */
    EndToBegin = "EndToBegin",
    /**
     * Swipe from left to right
     *
     * @deprecated As of version 1.72. replaced by {@link BeginToEnd}
     */
    LeftToRight = "LeftToRight",
    /**
     * Swipe from right to left.
     *
     * @deprecated As of version 1.72. replaced by {@link EndToBegin}
     */
    RightToLeft = "RightToLeft",
  }
  /**
   * Enumeration for different switch types.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'SwitchType'.
   */
  export enum SwitchType {
    /**
     * Switch with accept and reject icons
     */
    AcceptReject = "AcceptReject",
    /**
     * Will show "ON" and "OFF" translated to the current language or the custom text if provided
     */
    Default = "Default",
  }
  /**
   * Specifies `IconTabBar` tab overflow mode.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'TabsOverflowMode'.
   *
   * @since 1.90.0
   */
  export enum TabsOverflowMode {
    /**
     * Default behavior: One overflow tab at the end of the header.
     */
    End = "End",
    /**
     * Two overflow tabs at both ends of the header to keep tabs order intact.
     */
    StartAndEnd = "StartAndEnd",
  }
  /**
   * Colors to highlight certain UI elements.
   *
   * In contrast to the `ValueState`, the semantic meaning must be defined by the application.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'TileInfoColor'.
   * See:
   * 	{@link fiori:/how-to-use-semantic-colors/ Semantic Colors}
   *
   * @since 1.124
   */
  export enum TileInfoColor {
    /**
     * SAP Brand Color
     */
    BrandColor = "BrandColor",
    /**
     * Critical Text Color
     */
    CriticalTextColor = "CriticalTextColor",
    /**
     * Indication Color 1
     */
    Indication1 = "Indication1",
    /**
     * Indication Color 10
     */
    Indication10 = "Indication10",
    /**
     * Indication Color 2
     */
    Indication2 = "Indication2",
    /**
     * Indication Color 3
     */
    Indication3 = "Indication3",
    /**
     * Indication Color 4
     */
    Indication4 = "Indication4",
    /**
     * Indication Color 5
     */
    Indication5 = "Indication5",
    /**
     * Indication Color 6
     */
    Indication6 = "Indication6",
    /**
     * Indication Color 7
     */
    Indication7 = "Indication7",
    /**
     * Indication Color 8
     */
    Indication8 = "Indication8",
    /**
     * Indication Color 9
     */
    Indication9 = "Indication9",
    /**
     * Information Background Color
     */
    InformationBackgroundColor = "InformationBackgroundColor",
    /**
     * Information Border Color
     */
    InformationBorderColor = "InformationBorderColor",
    /**
     * Neutral Background Color
     */
    NeutralBackgroundColor = "NeutralBackgroundColor",
    /**
     * Neutral Border Color
     */
    NeutralBorderColor = "NeutralBorderColor",
    /**
     * Neutral Element Color
     */
    NeutralElementColor = "NeutralElementColor",
    /**
     * Warning Background Color
     */
    WarningBackground = "WarningBackground",
    /**
     * Warning Border Color
     */
    WarningBorderColor = "WarningBorderColor",
  }
  /**
   * Describes the behavior of tiles when displayed on a small-screened phone (374px wide and lower).
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'TileSizeBehavior'.
   *
   * @since 1.56.0
   */
  export enum TileSizeBehavior {
    /**
     * Default behavior: Tiles adapt to the size of the screen, getting smaller on small screens.
     */
    Responsive = "Responsive",
    /**
     * Tiles are small all the time, regardless of the actual screen size.
     */
    Small = "Small",
  }
  /**
   * Different modes for the `sap.m.TimePicker` mask.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'TimePickerMaskMode'.
   *
   * @since 1.54
   */
  export enum TimePickerMaskMode {
    /**
     * The mask is disabled for the `sap.m.TimePicker`.
     */
    Off = "Off",
    /**
     * The mask is automatically enabled for all valid fixed-length time patterns, and it is disabled when the
     * time format does not have a fixed length.
     */
    On = "On",
  }
  /**
   * Declares the type of title alignment for some controls
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'TitleAlignment'.
   */
  export enum TitleAlignment {
    /**
     * The default type (if specified in the theme)
     */
    Auto = "Auto",
    /**
     * Explicitly sets the alignment to the center
     */
    Center = "Center",
    /**
     * Disables an automatic title alignment depending on theme Mostly used in sap.m.Bar
     */
    None = "None",
    /**
     * Explicitly sets the alignment to the start (left or right depending on LTR/RTL)
     */
    Start = "Start",
  }
  /**
   * Types of the `sap.m.Tokenizer` responsive modes.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'TokenizerRenderMode'.
   *
   * @since 1.80
   */
  export enum TokenizerRenderMode {
    /**
     * In `Loose` mode, the `sap.m.Tokenizer` will show all its tokens, even if this means that scrolling needs
     * to be used.
     */
    Loose = "Loose",
    /**
     * In `Narrow` mode, the `sap.m.Tokenizer` will show as many tokens as its width allows, as well as an n-More
     * indicator with the count of the hidden tokens. The rest tokens will be hidden.
     */
    Narrow = "Narrow",
  }
  /**
   * Types of the Toolbar Design.
   *
   * To preview the different combinations of `sap.m.ToolbarDesign` and `sap.m.ToolbarStyle`, see the **OverflowToolbar
   * - Design and styling** sample of the {@link sap.m.OverflowToolbar} control.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ToolbarDesign'.
   *
   * @since 1.16.8
   */
  export enum ToolbarDesign {
    /**
     * The toolbar can be inserted into other controls and if the design is "Auto" then it inherits the design
     * from parent control.
     */
    Auto = "Auto",
    /**
     * The toolbar appears smaller than the regular size to show information(e.g: text, icon).
     */
    Info = "Info",
    /**
     * The toolbar has a solid background. Its content will be rendered in a standard way.
     *
     * @since 1.22
     */
    Solid = "Solid",
    /**
     * The toolbar and its content will be displayed transparent.
     */
    Transparent = "Transparent",
  }
  /**
   * Types of visual styles for the {@link sap.m.Toolbar}.
   *
   * **Note:** Keep in mind that the styles are theme-dependent and can differ based on the currently used
   * theme.
   *
   * To preview the different combinations of `sap.m.ToolbarDesign` and `sap.m.ToolbarStyle`, see the **OverflowToolbar
   * - Design and styling** sample of the {@link sap.m.OverflowToolbar} control.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ToolbarStyle'.
   *
   * @since 1.54
   */
  export enum ToolbarStyle {
    /**
     * Simplified visual style dependent on the used theme.
     *
     * **Note:** For the Belize themes, the `sap.m.Toolbar` is displayed with no border.
     */
    Clear = "Clear",
    /**
     * Default visual style dependent on the used theme.
     */
    Standard = "Standard",
  }
  /**
   * Defines the placeholder type for the control to be replaced.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'UploadSetwithTableActionPlaceHolder'.
   *
   * @since 1.120
   */
  export enum UploadSetwithTableActionPlaceHolder {
    /**
     * Placeholder for cloud file picker button.
     */
    CloudFilePickerButtonPlaceholder = "CloudFilePickerButtonPlaceholder",
    /**
     * Placeholder for personalization settings button.
     *
     * @deprecated As of version 1.124. the concept has been discarded.
     */
    PersonalizationSettingsPlaceholder = "PersonalizationSettingsPlaceholder",
    /**
     * Placeholder for upload button control.
     */
    UploadButtonPlaceholder = "UploadButtonPlaceholder",
    /**
     * Placeholder for variant management.
     *
     * @deprecated As of version 1.124. the concept has been discarded.
     */
    VariantManagementPlaceholder = "VariantManagementPlaceholder",
  }
  /**
   * States of the upload process of {@link sap.m.UploadCollectionItem}.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'UploadState'.
   */
  export enum UploadState {
    /**
     * The file has been uploaded successfully.
     */
    Complete = "Complete",
    /**
     * The file cannot be uploaded due to an error.
     */
    Error = "Error",
    /**
     * The file is awaiting an explicit command to start being uploaded.
     */
    Ready = "Ready",
    /**
     * The file is currently being uploaded.
     */
    Uploading = "Uploading",
  }
  /**
   * Type of the upload {@link sap.m.UploadSetItem}.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'UploadType'.
   */
  export enum UploadType {
    /**
     * The file has been uploaded from cloud.
     */
    Cloud = "Cloud",
    /**
     * The file has been uploaded from your system.
     */
    Native = "Native",
  }
  /**
   * URL (Uniform Resource Locator) Helper.
   *
   * This helper can be used to trigger a native application (e.g. email, sms, phone) from the browser. That
   * means we are restricted of browser or application implementation. e.g.
   * 	 - Some browsers do not let you pass more than 2022 characters in the URL
   * 	 - MAPI (Outlook) limit is 2083, max. path under Internet Explorer is 2048
   * 	 - Different Internet Explorer versions have a different URL length limits (IE9 approximately 1000 characters)
   *
   * 	 - MS mail app under Windows 8 cuts mail links after approximately 100 characters
   * 	 - Safari gets a confirmation from user before opening a native application and can block other triggers
   *     if the user cancels it
   * 	 - Some mail applications(Outlook) do not respect all encodings (e.g. Cyrillic texts are not encoded
   *     correctly)
   *
   * **Note:** all the given maximum lengths are for URL encoded text (e.g a space character will be encoded
   * as "%20").
   *
   * It has been reported by some users that the content send through the `URLHelper` is not correctly displayed
   * by the native applications (e.g. a native mail application).
   *
   * After sending the body to the application, `URLHelper` cannot affect its rendering and the application
   * takes responsibility to correctly display the content. Inconsistencies between different native applications
   * or operative systems (OS) can lead to different behaviors and differences in the displayed content.
   *
   * **Example:**
   *
   * What happens with a link added to the content of an email using the `URLHelper` ?
   *
   * Apart from the correct generation of URL, everything else is outside of the scope of `URLHelper` as responsibility
   * from then on is passed to the browser and the native applications handling the URL. For instance, clicking
   * on an email link should result in triggering an action in the default mail application for the user's
   * OS and it is this application's responsibility to correctly handle the URL, given it is generated correctly.
   * See:
   * 	{@link https://ui5.sap.com/#/topic/4f1c1075d88c41a5904389fa12b28f6b URL Helper}
   *
   * @since 1.10
   */
  interface URLHelper {
    /**
     * Adds an event listener for the `redirect` event.
     *
     *
     * @returns The URLHelper instance
     */
    attachRedirect(
      /**
       * The function to call, when the event occurs.
       */
      fnFunction: Function,
      /**
       * The object that wants to be notified when the event occurs.
       */
      oListener?: Object
    ): URLHelper;
    /**
     * Detach an already registered listener of the `redirect` event.
     *
     *
     * @returns The URLHelper instance
     */
    detachRedirect(
      /**
       * The function to call, when the event occurs.
       */
      fnFunction: Function,
      /**
       * The object, that wants to be notified, when the event occurs.
       */
      oListener?: Object
    ): URLHelper;
    /**
     * Builds Email URI from given parameter. Trims spaces from email addresses.
     *
     *
     * @returns Email URI using the `mailto:` scheme
     */
    normalizeEmail(
      /**
       * Destination email address
       */
      sEmail?: string,
      /**
       * Subject of the email address
       */
      sSubject?: string,
      /**
       * Default message text
       */
      sBody?: string,
      /**
       * Carbon Copy email address
       */
      sCC?: string,
      /**
       * Blind carbon copy email address
       */
      sBCC?: string
    ): string;
    /**
     * Sanitizes the given telephone number and returns a URI using the `sms:` scheme.
     *
     *
     * @returns SMS URI using the `sms:` scheme
     */
    normalizeSms(
      /**
       * Telephone number
       */
      sTel?: string
    ): string;
    /**
     * Sanitizes the given telephone number and returns a URI using the `tel:` scheme.
     *
     *
     * @returns Telephone URI using the `tel:` scheme
     */
    normalizeTel(
      /**
       * Telephone number
       */
      sTel?: string
    ): string;
    /**
     * Redirects to the given URL.
     *
     * This method fires "redirect" event before opening the URL.
     */
    redirect(
      /**
       * Uniform resource locator
       */
      sURL: string,
      /**
       * Opens URL in a new browser window or tab. Please note that, opening a new window/tab can be ignored by
       * browsers (e.g. on Windows Phone) or by popup blockers. NOTE: On Windows Phone the URL will be enforced
       * to open in the same window if opening in a new window/tab fails (because of a known system restriction
       * on cross-window communications). Use sap.m.Link instead (with blank target) if you necessarily need to
       * open URL in a new window.
       */
      bNewWindow?: boolean
    ): void;
    /**
     * Trigger email application to send email. Trims spaces from email addresses.
     */
    triggerEmail(
      /**
       * Destination email address
       */
      sEmail?: string,
      /**
       * Subject of the email address
       */
      sSubject?: string,
      /**
       * Default message text
       */
      sBody?: string,
      /**
       * Carbon Copy email address
       */
      sCC?: string,
      /**
       * Blind carbon copy email address
       */
      sBCC?: string,
      /**
       * Opens email template in a new browser window or tab.
       */
      bNewWindow?: boolean
    ): void;
    /**
     * Trigger SMS application to send SMS to given telephone number.
     */
    triggerSms(
      /**
       * Telephone number
       */
      sTel?: string
    ): void;
    /**
     * Trigger telephone app to call the given telephone number.
     */
    triggerTel(
      /**
       * Telephone number
       */
      sTel?: string
    ): void;
  }
  export const URLHelper: URLHelper;

  /**
   * Enumeration of possible value color settings.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'ValueColor'.
   */
  export enum ValueColor {
    /**
     * Critical value color.
     */
    Critical = "Critical",
    /**
     * Error value color.
     */
    Error = "Error",
    /**
     * Good value color.
     */
    Good = "Good",
    /**
     * Neutral value color.
     */
    Neutral = "Neutral",
    /**
     * None value color.
     *
     * **Note:** The None value color is set to prevent the display of tooltip 'Neutral' for numeric content.
     *
     * @since 1.84
     */
    None = "None",
  }
  /**
   * A string type that represents CSS color values, sap.m.ValueColor or less parameter values.
   *
   * Allowed values are {@link sap.ui.core.CSSColor}, {@link sap.m.ValueColor} or a less parameter name (string).
   * In case the less parameter color cannot be determined, the validation fails. You need to check if less
   * parameters are supported on control level. An empty string is also allowed and has the same effect as
   * setting no color.
   *
   * @deprecated As of version 1.135. the concept has been discarded.
   */
  export type ValueCSSColor = string;

  /**
   * An object type that represents the {@link sap.m.VariantManagement} `manage`-event property `exe`.
   */
  export type VariantManagementExe = {
    /**
     * the variant key.
     */
    key: string;
    /**
     * flag describing the associated Appy Automatically indicator.
     */
    exe: boolean;
  };

  /**
   * An object type that represents the {@link sap.m.VariantManagement} `manage`-event property `fav`.
   */
  export type VariantManagementFav = {
    /**
     * the variant key.
     */
    key: string;
    /**
     * flag describing the associated Favorite indicator.
     */
    visible: boolean;
  };

  /**
   * An object type that represents the {@link sap.m.VariantManagement} `manage`-event property `rename`.
   */
  export type VariantManagementRename = {
    /**
     * the variant key.
     */
    key: string;
    /**
     * the new title of the variant.
     */
    name: string;
  };

  /**
   * Types for the placement of message Popover control.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'VerticalPlacementType'.
   */
  export enum VerticalPlacementType {
    /**
     * Popover will be placed at the bottom of the reference control.
     */
    Bottom = "Bottom",
    /**
     * Popover will be placed at the top of the reference control.
     */
    Top = "Top",
    /**
     * Popover will be placed at the top or bottom of the reference control.
     */
    Vertical = "Vertical",
  }
  /**
   * Wizard rendering mode.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'WizardRenderMode'.
   *
   * @since 1.83
   */
  export enum WizardRenderMode {
    /**
     * Display steps as separate, single pages.
     */
    Page = "Page",
    /**
     * Display all steps into a scroll section.
     */
    Scroll = "Scroll",
  }
  /**
   * Available wrapping types for text controls that can be wrapped that enable you to display the text as
   * hyphenated.
   *
   * For more information about text hyphenation, see {@link sap.ui.core.hyphenation.Hyphenation} and {@link https://ui5.sap.com/#/topic/6322164936f047de941ec522b95d7b70 Text Controls Hyphenation}.
   *
   * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'WrappingType'.
   *
   * @since 1.60
   */
  export enum WrappingType {
    /**
     * Hyphenation will be used to break words on syllables where possible.
     */
    Hyphenated = "Hyphenated",
    /**
     * Normal text wrapping will be used. Words won't break based on hyphenation.
     */
    Normal = "Normal",
  }

  export namespace p13n {
    /**
     * Interface for P13nPopup which are suitable as content for the `sap.m.p13n.Popup`. Implementation of this
     * interface should include the following methods:
     *
     *
     * 	 - `getTitle`
     *
     * Implementation of this interface can optionally provide the following methods:
     *
     *
     * 	 - `getVerticalScrolling`
     * 	 - `onReset`
     *
     * @since 1.97
     */
    interface IContent {
      __implements__sap_m_p13n_IContent: boolean;

      /**
       * Returns the title, which should be displayed in the P13nPopup to describe related content.
       *
       *
       * @returns The title for the corresponding content to be displayed in the `sap.m.p13n.Popup`.
       */
      getTitle(): string;
      /**
       * Optionally returns the enablement of the contents vertical scrolling in case only one panel is used to
       * determine if the content provides its own scrolling capabilites.
       *
       *
       * @returns The enablement of the vertical scrolling enablement for the `sap.m.p13n.Popup`.
       */
      getVerticalScrolling?(): boolean;
      /**
       * Optional hook that will be executed when the panel is used by a `sap.m.p13n.Popup` that may trigger a
       * reset on the panel
       */
      onReset?(): void;
    }
  }

  export namespace plugins {
    /**
     * Defines the states of list items when the context menu is opened.
     *
     * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'plugins.ContextMenuScope'.
     *
     * @since 1.121
     */
    enum ContextMenuScope {
      /**
       * The scope is set to the default value where the focus is unaffected by the opening of the context menu.
       */
      Default = "Default",
      /**
       * The focus will be on the clicked item and also on other selected items, if the clicked item is selected.
       */
      Selection = "Selection",
    }
    /**
     * Enumeration of the `copyPreference` in `CopyProvider`. Determines what is copied during a copy operation.
     *
     * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'plugins.CopyPreference'.
     *
     * @since 1.119
     */
    enum CopyPreference {
      /**
       * If cells are selected, only the content of the selected cells is copied, regardless of any other rows
       * or elements that might also be selected. If no cells are selected, the copy operation will default to
       * copying the selected rows.
       */
      Cells = "Cells",
      /**
       * The entire selected scope is copied, including both row and cell selection.
       */
      Full = "Full",
    }
  }

  export namespace semantic {
    /**
     * Marker interface for controls which are suitable as items of the filter aggregation of sap.m.Semantic.MasterPage.
     */
    interface IFilter {
      __implements__sap_m_semantic_IFilter: boolean;
    }

    /**
     * Marker interface for controls which are suitable as items of the group aggregation of sap.m.Semantic.MasterPage.
     */
    interface IGroup {
      __implements__sap_m_semantic_IGroup: boolean;
    }

    /**
     * Marker interface for controls which are suitable as items of the sort aggregation of sap.m.Semantic.MasterPage.
     */
    interface ISort {
      __implements__sap_m_semantic_ISort: boolean;
    }

    /**
     * Declares the type of semantic ruleset that will govern the styling and positioning of semantic content.
     *
     * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'semantic.SemanticRuleSetType'.
     *
     * @since 1.44
     */
    enum SemanticRuleSetType {
      /**
       * The default ruleset type, for which the Share Menu is always in the footer of the page.
       */
      Classic = "Classic",
      /**
       * Offers an optimized user experience, with displaying the Share Menu in the header, rather than the footer,
       * for Fullscreen mode.
       */
      Optimized = "Optimized",
    }
  }

  export namespace table {
    namespace columnmenu {
      /**
       * Categories of column menu entries.
       *
       * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'table.columnmenu.Category'.
       *
       * @since 1.110
       */
      enum Category {
        /**
         * Aggregate category
         */
        Aggregate = "Aggregate",
        /**
         * Filter category
         */
        Filter = "Filter",
        /**
         * Generic category
         */
        Generic = "Generic",
        /**
         * Group category
         */
        Group = "Group",
        /**
         * Sort category
         */
        Sort = "Sort",
      }
      /**
       * Defines the available content sizes for the `sap.m.table.columnmenu.QuickAction` control.
       *
       * This enum is part of the 'sap/m/library' module export and must be accessed by the property 'table.columnmenu.QuickActionContentSize'.
       */
      enum QuickActionContentSize {
        /**
         * Large: Recommended for larger input controls, such as {@link sap.m.Input} or {@link sap.m.RatingIndicator}.
         * If there is limited space, the input control moves to a new line below the label.
         */
        L = "L",
        /**
         * Small: Recommended for smaller controls, such as {@link sap.m.Switch} or {@link sap.m.Checkbox}. If there
         * is limited space, only the label is wrapped. The input control is always right-aligned horizontally and
         * middle-aligned vertically.
         */
        S = "S",
      }
    }
  }

  export namespace touch {
    /**
     * Given a list of touches, count the number of touches related with the given element.
     *
     *
     * @returns The number of touches related with the given element.
     */
    function countContained(
      /**
       * The list of touch objects to search.
       */
      oTouchList: TouchList,
      /**
       * A jQuery element or an element reference or an element id.
       */
      vElement: jQuery | Element | string
    ): number;
    /**
     * Given a list of touch objects, find the touch that matches the given one.
     *
     *
     * @returns The touch matching if any.
     */
    function find(
      /**
       * The list of touch objects to search.
       */
      oTouchList: TouchList,
      /**
       * A touch object to find or a Touch.identifier that uniquely identifies the current finger in the touch
       * session.
       */
      oTouch: Touch | number
    ): object | undefined;
  }
}

declare module "sap/m/Support" {
  /**
   *
   * ```javascript
   *
   * `sap.m.Support` shows the technical information for SAPUI5 Mobile Applications.
   * This technical information includes:
   *    * SAPUI5 Version
   *    * User Agent
   *    * Configurations (Bootstrap and Computed)
   *    * URI parameters
   *    * All loaded module names
   *
   * In order to show the device information, the user must follow the following gestures.
   *    1 - Hold two fingers for 3 seconds minimum.
   *    2 - Tab with a third finger while holding the first two fingers.
   *
   * NOTE: This class is internal and all its functions must not be used by an application
   *
   * Enable Support:
   * --------------------------------------------------
   * //import
   * sap.ui.require("sap/m/Support", function (Support) {
   *   // Support is initialized and is listening for fingers gestures combination
   * });
   *
   * //By default after require, support is enabled but implicitly we can call
   * Support.on();
   *
   * Disable Support:
   * --------------------------------------------------
   * Support.off();
   * ```
   *
   *
   * @since 1.11.0
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  const Support: undefined;

  export default Support;
}

declare module "sap/m/ActionListItem" {
  import {
    default as ListItemBase,
    $ListItemBaseSettings,
  } from "sap/m/ListItemBase";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { ListMode } from "sap/m/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The `sap.m.ActionListItem` can be used like a `button` to fire actions when pressed. **Note:** The inherited
   * `selected` property of the `sap.m.ListItemBase` is not supported.
   */
  export default class ActionListItem extends ListItemBase {
    /**
     * Constructor for a new ActionListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:/action-list-item/ Action List Item}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ActionListItemSettings
    );
    /**
     * Constructor for a new ActionListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:/action-list-item/ Action List Item}
     */
    constructor(
      /**
       * Id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ActionListItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.ActionListItem with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ListItemBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ActionListItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ActionListItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Determines item specific mode.
     *
     * ActionListItems are not selectable because they are command controls (like Button or Link), so triggering
     * the associated command, rather than selection is appropriate to happen upon user action on these items.
     *
     * By overwriting `getMode` (inherited from `ListItemBase`), we exclude the item from processing steps that
     * are specific for selectable list-items.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Mode of the list item.
     */
    getMode(): ListMode | "";
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Defines the text that appears in the control.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Defines the text that appears in the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ActionListItem constructor.
   */
  export interface $ActionListItemSettings extends $ListItemBaseSettings {
    /**
     * Defines the text that appears in the control.
     */
    text?: string | PropertyBindingInfo;
  }
}

declare module "sap/m/ActionSelect" {
  import { default as Select, $SelectSettings } from "sap/m/Select";

  import { ID } from "sap/ui/core/library";

  import Button from "sap/m/Button";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * The ActionSelect control provides a list of predefined items that allows end users to choose options
   * and additionally trigger some actions.
   *
   * @since 1.16
   * @deprecated As of version 1.111. with no replacement. The control is no longer considered part of the
   * Fiori concept.
   */
  export default class ActionSelect extends Select {
    /**
     * Constructor for a new ActionSelect.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $ActionSelectSettings
    );
    /**
     * Constructor for a new ActionSelect.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $ActionSelectSettings
    );

    /**
     * Creates a new subclass of class sap.m.ActionSelect with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.Select.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ActionSelect>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ActionSelect.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some button into the association {@link #getButtons buttons}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addButton(
      /**
       * The buttons to add; if empty, nothing is inserted
       */
      vButton: ID | Button
    ): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getButtons buttons}.
     */
    getButtons(): ID[];
    /**
     * Remove all buttons from the ActionSelect.
     *
     *
     * @returns An array with the ids of the removed elements (might be empty).
     */
    removeAllButtons(): string[];
    /**
     * Removes the given button from the `ActionSelect` content.
     *
     *
     * @returns The ID of the removed button or `null`.
     */
    removeButton(
      /**
       * The button to remove or its index or ID.
       */
      vButton: int | ID | Button
    ): string | null;
  }
  /**
   * Describes the settings that can be provided to the ActionSelect constructor.
   *
   * @deprecated As of version 1.111. with no replacement. The control is no longer considered part of the
   * Fiori concept.
   */
  export interface $ActionSelectSettings extends $SelectSettings {
    /**
     * Buttons to be added to the ActionSelect content.
     */
    buttons?: Array<Button | string>;
  }
}

declare module "sap/m/ActionSheet" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import Button from "sap/m/Button";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PlacementType } from "sap/m/library";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * The action sheet holds a list of options from which the user can select to complete an action. Overview:
   * The options of the action sheet are represented as {@link sap.m.Button buttons} with icons. Elements
   * in the action sheet are left-aligned. Actions should be arranged in order of importance, from top to
   * bottom. Guidelines:
   * 	 - Always display text or text and icons for the actions. Do not use icons only.
   * 	 - Always provide a Cancel button on mobile phones.
   * 	 - Avoid scrolling on action sheets.  Responsive Behavior: On mobile phones the action sheet is
   *     displayed in a {@link sap.m.Dialog dialog}.
   *
   * On tablets and desktop the action sheet is displayed in a {@link sap.m.Popover popover}.
   *
   * When an action is triggered, the action sheet closes and you can display a confirmation as a {@link sap.m.MessageToast message toast}.
   *
   * @since 1.9.1
   */
  export default class ActionSheet extends Control {
    /**
     * Constructor for a new ActionSheet.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/action-sheet/ Action Sheet}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ActionSheetSettings
    );
    /**
     * Constructor for a new ActionSheet.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/action-sheet/ Action Sheet}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ActionSheetSettings
    );

    /**
     * Creates a new subclass of class sap.m.ActionSheet with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ActionSheet>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ActionSheet.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some button to the aggregation {@link #getButtons buttons}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addButton(
      /**
       * The button to add; if empty, nothing is inserted
       */
      oButton: Button
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterClose afterClose} event of this `sap.m.ActionSheet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ActionSheet` itself.
     *
     * This event will be fired after the ActionSheet is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ActionSheet$AfterCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ActionSheet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterClose afterClose} event of this `sap.m.ActionSheet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ActionSheet` itself.
     *
     * This event will be fired after the ActionSheet is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ActionSheet$AfterCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ActionSheet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterOpen afterOpen} event of this `sap.m.ActionSheet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ActionSheet` itself.
     *
     * This event will be fired after the ActionSheet is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ActionSheet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterOpen afterOpen} event of this `sap.m.ActionSheet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ActionSheet` itself.
     *
     * This event will be fired after the ActionSheet is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ActionSheet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.ActionSheet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ActionSheet` itself.
     *
     * This event will be fired before the ActionSheet is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ActionSheet$BeforeCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ActionSheet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.ActionSheet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ActionSheet` itself.
     *
     * This event will be fired before the ActionSheet is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ActionSheet$BeforeCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ActionSheet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.ActionSheet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ActionSheet` itself.
     *
     * This event will be fired before the ActionSheet is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ActionSheet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.ActionSheet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ActionSheet` itself.
     *
     * This event will be fired before the ActionSheet is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ActionSheet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cancelButtonPress cancelButtonPress} event of
     * this `sap.m.ActionSheet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ActionSheet` itself.
     *
     * This event is fired when the cancelButton is clicked.
     *
     * **Note: ** For any device other than phones, this event would be fired always when the Popover closes.
     * To prevent this behavior, the `showCancelButton` property needs to be set to `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCancelButtonPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ActionSheet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cancelButtonPress cancelButtonPress} event of
     * this `sap.m.ActionSheet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ActionSheet` itself.
     *
     * This event is fired when the cancelButton is clicked.
     *
     * **Note: ** For any device other than phones, this event would be fired always when the Popover closes.
     * To prevent this behavior, the `showCancelButton` property needs to be set to `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCancelButtonPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ActionSheet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cancelButtonTap cancelButtonTap} event of this
     * `sap.m.ActionSheet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ActionSheet` itself.
     *
     * This event is fired when the cancelButton is tapped. For iPad, this event is also fired when showCancelButton
     * is set to true, and Popover is closed by tapping outside.
     *
     * @deprecated As of version 1.20.0. This event is deprecated, use the cancelButtonPress event instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCancelButtonTap(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ActionSheet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cancelButtonTap cancelButtonTap} event of this
     * `sap.m.ActionSheet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ActionSheet` itself.
     *
     * This event is fired when the cancelButton is tapped. For iPad, this event is also fired when showCancelButton
     * is set to true, and Popover is closed by tapping outside.
     *
     * @deprecated As of version 1.20.0. This event is deprecated, use the cancelButtonPress event instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCancelButtonTap(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ActionSheet` itself
       */
      oListener?: object
    ): this;
    /**
     * Calling this method will make the ActionSheet disappear from the screen.
     */
    close(): void;
    /**
     * Destroys all the buttons in the aggregation {@link #getButtons buttons}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyButtons(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterClose afterClose} event of this `sap.m.ActionSheet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ActionSheet$AfterCloseEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterOpen afterOpen} event of this `sap.m.ActionSheet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeClose beforeClose} event of this `sap.m.ActionSheet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ActionSheet$BeforeCloseEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeOpen beforeOpen} event of this `sap.m.ActionSheet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:cancelButtonPress cancelButtonPress} event
     * of this `sap.m.ActionSheet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachCancelButtonPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:cancelButtonTap cancelButtonTap} event of
     * this `sap.m.ActionSheet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @deprecated As of version 1.20.0. This event is deprecated, use the cancelButtonPress event instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachCancelButtonTap(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:afterClose afterClose} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ActionSheet$AfterCloseEventParameters
    ): this;
    /**
     * Fires event {@link #event:afterOpen afterOpen} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:beforeClose beforeClose} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforeClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ActionSheet$BeforeCloseEventParameters
    ): this;
    /**
     * Fires event {@link #event:beforeOpen beforeOpen} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforeOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:cancelButtonPress cancelButtonPress} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireCancelButtonPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:cancelButtonTap cancelButtonTap} to attached listeners.
     *
     * @deprecated As of version 1.20.0. This event is deprecated, use the cancelButtonPress event instead.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireCancelButtonTap(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets content of aggregation {@link #getButtons buttons}.
     *
     * These buttons are added to the content area in ActionSheet control. When button is tapped, the ActionSheet
     * is closed before the tap event listener is called.
     */
    getButtons(): Button[];
    /**
     * Gets current value of property {@link #getCancelButtonText cancelButtonText}.
     *
     * This is the text displayed in the cancelButton. Default value is "Cancel", and it's translated according
     * to the current locale setting. This property will be ignored when running either in iPad or showCancelButton
     * is set to false.
     *
     *
     * @returns Value of property `cancelButtonText`
     */
    getCancelButtonText(): string;
    /**
     * Gets current value of property {@link #getPlacement placement}.
     *
     * The ActionSheet behaves as an sap.m.Popover in iPad and this property is the information about on which
     * side will the popover be placed at.
     *
     * Possible values are sap.m.PlacementType.Left, sap.m.PlacementType.Right, sap.m.PlacementType.Top, sap.m.PlacementType.Bottom,
     * sap.m.PlacementType.Horizontal, sap.m.PlacementType.HorizontalPreferredLeft, sap.m.PlacementType.HorizontalPreferredRight,
     * sap.m.PlacementType.Vertical, sap.m.PlacementType.VerticalPreferredTop, sap.m.PlacementType.VerticalPreferredBottom.
     * The default value is sap.m.PlacementType.Bottom.
     *
     * Default value is `Bottom`.
     *
     *
     * @returns Value of property `placement`
     */
    getPlacement(): PlacementType;
    /**
     * Gets the ID of the hidden label
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns ID of hidden text
     */
    getPopupHiddenLabelId(): string;
    /**
     * Gets current value of property {@link #getShowCancelButton showCancelButton}.
     *
     * If this is set to true, there will be a cancel button shown below the action buttons. There won't be
     * any cancel button shown in iPad regardless of this property. The default value is set to true.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showCancelButton`
     */
    getShowCancelButton(): boolean;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Title will be shown in the header area in iPhone and every Android devices. This property will be ignored
     * in tablets and desktop browser.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Checks for the provided `sap.m.Button` in the aggregation {@link #getButtons buttons}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfButton(
      /**
       * The button whose index is looked for
       */
      oButton: Button
    ): int;
    /**
     * Inserts a button into the aggregation {@link #getButtons buttons}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertButton(
      /**
       * The button to insert; if empty, nothing is inserted
       */
      oButton: Button,
      /**
       * The `0`-based index the button should be inserted at; for a negative value of `iIndex`, the button is
       * inserted at position 0; for a value greater than the current size of the aggregation, the button is inserted
       * at the last position
       */
      iIndex: int
    ): this;
    /**
     * The method checks if the ActionSheet is open. It returns true when the ActionSheet is currently open
     * (this includes opening and closing animations), otherwise it returns false.
     *
     *
     * @returns Whether the ActionSheet is open.
     */
    isOpen(): boolean;
    /**
     * Calling this method will make the ActionSheet visible on the screen. The control parameter is the object
     * to which the ActionSheet will be placed. It can be not only a UI5 control, but also an existing DOM reference.
     * The side of the placement depends on the `placement` property set in the Popover (on tablet and desktop).
     * On other platforms, ActionSheet behaves as a standard dialog and this parameter is ignored because dialog
     * is aligned to the screen.
     */
    openBy(
      /**
       * The control to which the ActionSheet is opened
       */
      oControl: Control | HTMLElement
    ): void;
    /**
     * Removes all the controls from the aggregation {@link #getButtons buttons}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllButtons(): Button[];
    /**
     * Removes a button from the aggregation {@link #getButtons buttons}.
     *
     *
     * @returns The removed button or `null`
     */
    removeButton(
      /**
       * The button to remove or its index or id
       */
      vButton: int | string | Button
    ): Button | null;
    /**
     * Sets a new value for property {@link #getCancelButtonText cancelButtonText}.
     *
     * This is the text displayed in the cancelButton. Default value is "Cancel", and it's translated according
     * to the current locale setting. This property will be ignored when running either in iPad or showCancelButton
     * is set to false.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCancelButtonText(
      /**
       * New value for property `cancelButtonText`
       */
      sCancelButtonText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getPlacement placement}.
     *
     * The ActionSheet behaves as an sap.m.Popover in iPad and this property is the information about on which
     * side will the popover be placed at.
     *
     * Possible values are sap.m.PlacementType.Left, sap.m.PlacementType.Right, sap.m.PlacementType.Top, sap.m.PlacementType.Bottom,
     * sap.m.PlacementType.Horizontal, sap.m.PlacementType.HorizontalPreferredLeft, sap.m.PlacementType.HorizontalPreferredRight,
     * sap.m.PlacementType.Vertical, sap.m.PlacementType.VerticalPreferredTop, sap.m.PlacementType.VerticalPreferredBottom.
     * The default value is sap.m.PlacementType.Bottom.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Bottom`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPlacement(
      /**
       * New value for property `placement`
       */
      sPlacement?: PlacementType | keyof typeof PlacementType
    ): this;
    /**
     * Sets a new value for property {@link #getShowCancelButton showCancelButton}.
     *
     * If this is set to true, there will be a cancel button shown below the action buttons. There won't be
     * any cancel button shown in iPad regardless of this property. The default value is set to true.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowCancelButton(
      /**
       * New value for property `showCancelButton`
       */
      bShowCancelButton?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Title will be shown in the header area in iPhone and every Android devices. This property will be ignored
     * in tablets and desktop browser.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ActionSheet constructor.
   */
  export interface $ActionSheetSettings extends $ControlSettings {
    /**
     * The ActionSheet behaves as an sap.m.Popover in iPad and this property is the information about on which
     * side will the popover be placed at.
     *
     * Possible values are sap.m.PlacementType.Left, sap.m.PlacementType.Right, sap.m.PlacementType.Top, sap.m.PlacementType.Bottom,
     * sap.m.PlacementType.Horizontal, sap.m.PlacementType.HorizontalPreferredLeft, sap.m.PlacementType.HorizontalPreferredRight,
     * sap.m.PlacementType.Vertical, sap.m.PlacementType.VerticalPreferredTop, sap.m.PlacementType.VerticalPreferredBottom.
     * The default value is sap.m.PlacementType.Bottom.
     */
    placement?:
      | (PlacementType | keyof typeof PlacementType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * If this is set to true, there will be a cancel button shown below the action buttons. There won't be
     * any cancel button shown in iPad regardless of this property. The default value is set to true.
     */
    showCancelButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This is the text displayed in the cancelButton. Default value is "Cancel", and it's translated according
     * to the current locale setting. This property will be ignored when running either in iPad or showCancelButton
     * is set to false.
     */
    cancelButtonText?: string | PropertyBindingInfo;

    /**
     * Title will be shown in the header area in iPhone and every Android devices. This property will be ignored
     * in tablets and desktop browser.
     */
    title?: string | PropertyBindingInfo;

    /**
     * These buttons are added to the content area in ActionSheet control. When button is tapped, the ActionSheet
     * is closed before the tap event listener is called.
     */
    buttons?: Button[] | Button | AggregationBindingInfo | `{${string}}`;

    /**
     * This event is fired when the cancelButton is tapped. For iPad, this event is also fired when showCancelButton
     * is set to true, and Popover is closed by tapping outside.
     *
     * @deprecated As of version 1.20.0. This event is deprecated, use the cancelButtonPress event instead.
     */
    cancelButtonTap?: (oEvent: Event) => void;

    /**
     * This event will be fired before the ActionSheet is opened.
     */
    beforeOpen?: (oEvent: Event) => void;

    /**
     * This event will be fired after the ActionSheet is opened.
     */
    afterOpen?: (oEvent: Event) => void;

    /**
     * This event will be fired before the ActionSheet is closed.
     */
    beforeClose?: (oEvent: ActionSheet$BeforeCloseEvent) => void;

    /**
     * This event will be fired after the ActionSheet is closed.
     */
    afterClose?: (oEvent: ActionSheet$AfterCloseEvent) => void;

    /**
     * This event is fired when the cancelButton is clicked.
     *
     * **Note: ** For any device other than phones, this event would be fired always when the Popover closes.
     * To prevent this behavior, the `showCancelButton` property needs to be set to `false`.
     */
    cancelButtonPress?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the ActionSheet#afterClose event.
   */
  export interface ActionSheet$AfterCloseEventParameters {
    /**
     * This indicates the trigger of closing the control. If dialog is closed by either selection or closeButton
     * (on mobile device), the button that closes the dialog is set to this parameter. Otherwise this parameter
     * is set to null.
     */
    origin?: Button;
  }

  /**
   * Event object of the ActionSheet#afterClose event.
   */
  export type ActionSheet$AfterCloseEvent = Event<
    ActionSheet$AfterCloseEventParameters,
    ActionSheet
  >;

  /**
   * Parameters of the ActionSheet#afterOpen event.
   */
  export interface ActionSheet$AfterOpenEventParameters {}

  /**
   * Event object of the ActionSheet#afterOpen event.
   */
  export type ActionSheet$AfterOpenEvent = Event<
    ActionSheet$AfterOpenEventParameters,
    ActionSheet
  >;

  /**
   * Parameters of the ActionSheet#beforeClose event.
   */
  export interface ActionSheet$BeforeCloseEventParameters {
    /**
     * This indicates the trigger of closing the dialog. If dialog is closed by either leftButton or rightButton,
     * the button that closes the dialog is set to this parameter. Otherwise this parameter is set to null.
     * This is valid only for Phone mode of the ActionSheet
     */
    origin?: Button;
  }

  /**
   * Event object of the ActionSheet#beforeClose event.
   */
  export type ActionSheet$BeforeCloseEvent = Event<
    ActionSheet$BeforeCloseEventParameters,
    ActionSheet
  >;

  /**
   * Parameters of the ActionSheet#beforeOpen event.
   */
  export interface ActionSheet$BeforeOpenEventParameters {}

  /**
   * Event object of the ActionSheet#beforeOpen event.
   */
  export type ActionSheet$BeforeOpenEvent = Event<
    ActionSheet$BeforeOpenEventParameters,
    ActionSheet
  >;

  /**
   * Parameters of the ActionSheet#cancelButtonPress event.
   */
  export interface ActionSheet$CancelButtonPressEventParameters {}

  /**
   * Event object of the ActionSheet#cancelButtonPress event.
   */
  export type ActionSheet$CancelButtonPressEvent = Event<
    ActionSheet$CancelButtonPressEventParameters,
    ActionSheet
  >;

  /**
   * Parameters of the ActionSheet#cancelButtonTap event.
   *
   * @deprecated As of version 1.20.0. This event is deprecated, use the cancelButtonPress event instead.
   */
  export interface ActionSheet$CancelButtonTapEventParameters {}

  /**
   * Event object of the ActionSheet#cancelButtonTap event.
   *
   * @deprecated As of version 1.20.0. This event is deprecated, use the cancelButtonPress event instead.
   */
  export type ActionSheet$CancelButtonTapEvent = Event<
    ActionSheet$CancelButtonTapEventParameters,
    ActionSheet
  >;
}

declare module "sap/m/ActionTile" {
  import {
    default as GenericTile,
    $GenericTileSettings,
  } from "sap/m/GenericTile";

  import { URI, ValueState } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { Priority } from "sap/m/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Used to create a customizable tile for your todos and situations within the new My Home in SAP S/4HANA
   * cloud
   *
   * @since 1.122
   */
  export default class ActionTile extends GenericTile {
    /**
     * Constructor for a new sap.m.ActionTile control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $ActionTileSettings
    );
    /**
     * Constructor for a new sap.m.ActionTile control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $ActionTileSettings
    );

    /**
     * Creates a new subclass of class sap.m.ActionTile with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.GenericTile.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ActionTile>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ActionTile.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getBadgeIcon badgeIcon}.
     *
     * Defines what type of icon is displayed as visual affordance for the icon frame badge.
     *
     * Default value is `empty string`.
     *
     * @since 1.124
     *
     * @returns Value of property `badgeIcon`
     */
    getBadgeIcon(): URI;
    /**
     * Gets current value of property {@link #getBadgeValueState badgeValueState}.
     *
     * Visualizes the validation state of the icon frame badge, e.g. `Error`, `Warning`, `Success`, `Information`.
     *
     * Default value is `None`.
     *
     * @since 1.124
     *
     * @returns Value of property `badgeValueState`
     */
    getBadgeValueState(): ValueState;
    /**
     * Gets current value of property {@link #getEnableDynamicHeight enableDynamicHeight}.
     *
     * The height of the tile changes dynamically to accommodate the content inside it
     *
     * Default value is `false`.
     *
     * @since 1.124
     *
     * @returns Value of property `enableDynamicHeight`
     */
    getEnableDynamicHeight(): boolean;
    /**
     * Gets current value of property {@link #getEnableIconFrame enableIconFrame}.
     *
     * Decides whether the headerImage should have a frame or not.
     *
     * Default value is `false`.
     *
     * @since 1.124
     *
     * @returns Value of property `enableIconFrame`
     */
    getEnableIconFrame(): boolean;
    /**
     * Gets current value of property {@link #getPriority priority}.
     *
     * Adds a priority indicator for the Action Tile.
     *
     * Default value is `None`.
     *
     * @since 1.124
     *
     * @returns Value of property `priority`
     */
    getPriority(): Priority;
    /**
     * Gets current value of property {@link #getPriorityText priorityText}.
     *
     * Sets the text inside the priority indicator for the Action Tile.
     *
     * @since 1.124
     *
     * @returns Value of property `priorityText`
     */
    getPriorityText(): string;
    /**
     * Sets the badgeIcon property of the ActionTile.
     *
     *
     * @returns The reference to the ActionTile instance.
     */
    setBadgeIcon(
      /**
       * The URI of the icon to be displayed as a badge.
       */
      sIcon: string
    ): ActionTile;
    /**
     * Sets the badgeValueState property of the ActionTile.
     *
     *
     * @returns The reference to the ActionTile instance.
     */
    setBadgeValueState(
      /**
       * The value state of the badge.
       */
      sValueState: ValueState | keyof typeof ValueState
    ): ActionTile;
    /**
     * Sets a new value for property {@link #getEnableDynamicHeight enableDynamicHeight}.
     *
     * The height of the tile changes dynamically to accommodate the content inside it
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.124
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableDynamicHeight(
      /**
       * New value for property `enableDynamicHeight`
       */
      bEnableDynamicHeight?: boolean
    ): this;
    /**
     * Sets the enableIconFrame property of the ActionTile.
     *
     *
     * @returns The reference to the ActionTile instance.
     */
    setEnableIconFrame(
      /**
       * Determines whether the icon frame should be enabled or not.
       */
      bValue: boolean
    ): ActionTile;
    /**
     * Sets a new value for property {@link #getPriority priority}.
     *
     * Adds a priority indicator for the Action Tile.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     * @since 1.124
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPriority(
      /**
       * New value for property `priority`
       */
      sPriority?: Priority | keyof typeof Priority
    ): this;
    /**
     * Sets a new value for property {@link #getPriorityText priorityText}.
     *
     * Sets the text inside the priority indicator for the Action Tile.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.124
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPriorityText(
      /**
       * New value for property `priorityText`
       */
      sPriorityText?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ActionTile constructor.
   */
  export interface $ActionTileSettings extends $GenericTileSettings {
    /**
     * The height of the tile changes dynamically to accommodate the content inside it
     *
     * @since 1.124
     */
    enableDynamicHeight?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Decides whether the headerImage should have a frame or not.
     *
     * @since 1.124
     */
    enableIconFrame?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Adds a priority indicator for the Action Tile.
     *
     * @since 1.124
     */
    priority?:
      | (Priority | keyof typeof Priority)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Sets the text inside the priority indicator for the Action Tile.
     *
     * @since 1.124
     */
    priorityText?: string | PropertyBindingInfo;

    /**
     * Defines what type of icon is displayed as visual affordance for the icon frame badge.
     *
     * @since 1.124
     */
    badgeIcon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Visualizes the validation state of the icon frame badge, e.g. `Error`, `Warning`, `Success`, `Information`.
     *
     * @since 1.124
     */
    badgeValueState?:
      | (ValueState | keyof typeof ValueState)
      | PropertyBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/ActionTileContent" {
  import {
    default as TileContent,
    $TileContentSettings,
  } from "sap/m/TileContent";

  import TileAttribute from "sap/m/TileAttribute";

  import Link from "sap/m/Link";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { AggregationBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * This control is used within the ActionTile control and it renders the values from the custom attribute
   *
   * @since 1.122
   */
  export default class ActionTileContent extends TileContent {
    /**
     * Constructor for a new sap.m.ActionTileContent control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $ActionTileContentSettings
    );
    /**
     * Constructor for a new sap.m.ActionTileContent control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $ActionTileContentSettings
    );

    /**
     * Creates a new subclass of class sap.m.ActionTileContent with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.TileContent.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ActionTileContent>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ActionTileContent.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some attribute to the aggregation {@link #getAttributes attributes}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAttribute(
      /**
       * The attribute to add; if empty, nothing is inserted
       */
      oAttribute: TileAttribute
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:linkPress linkPress} event of this `sap.m.ActionTileContent`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ActionTileContent` itself.
     *
     * The event is triggered when the user clicks on the link
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLinkPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ActionTileContent$LinkPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ActionTileContent` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:linkPress linkPress} event of this `sap.m.ActionTileContent`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ActionTileContent` itself.
     *
     * The event is triggered when the user clicks on the link
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLinkPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ActionTileContent$LinkPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ActionTileContent` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the attributes in the aggregation {@link #getAttributes attributes}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyAttributes(): this;
    /**
     * Destroys the headerLink in the aggregation {@link #getHeaderLink headerLink}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyHeaderLink(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:linkPress linkPress} event of this `sap.m.ActionTileContent`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLinkPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ActionTileContent$LinkPressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:linkPress linkPress} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireLinkPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ActionTileContent$LinkPressEventParameters
    ): boolean;
    /**
     * Gets content of aggregation {@link #getAttributes attributes}.
     *
     * Holds detail of an attribute used in the ActionTile.
     */
    getAttributes(): TileAttribute[];
    /**
     * Gets content of aggregation {@link #getHeaderLink headerLink}.
     *
     * Adds header link for the tile content.
     */
    getHeaderLink(): Link;
    /**
     * Checks for the provided `sap.m.TileAttribute` in the aggregation {@link #getAttributes attributes}. and
     * returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfAttribute(
      /**
       * The attribute whose index is looked for
       */
      oAttribute: TileAttribute
    ): int;
    /**
     * Inserts a attribute into the aggregation {@link #getAttributes attributes}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertAttribute(
      /**
       * The attribute to insert; if empty, nothing is inserted
       */
      oAttribute: TileAttribute,
      /**
       * The `0`-based index the attribute should be inserted at; for a negative value of `iIndex`, the attribute
       * is inserted at position 0; for a value greater than the current size of the aggregation, the attribute
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getAttributes attributes}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAttributes(): TileAttribute[];
    /**
     * Removes a attribute from the aggregation {@link #getAttributes attributes}.
     *
     *
     * @returns The removed attribute or `null`
     */
    removeAttribute(
      /**
       * The attribute to remove or its index or id
       */
      vAttribute: int | string | TileAttribute
    ): TileAttribute | null;
    /**
     * Sets the aggregated {@link #getHeaderLink headerLink}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeaderLink(
      /**
       * The headerLink to set
       */
      oHeaderLink: Link
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ActionTileContent constructor.
   */
  export interface $ActionTileContentSettings extends $TileContentSettings {
    /**
     * Adds header link for the tile content.
     */
    headerLink?: Link;

    /**
     * Holds detail of an attribute used in the ActionTile.
     */
    attributes?:
      | TileAttribute[]
      | TileAttribute
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * The event is triggered when the user clicks on the link
     */
    linkPress?: (oEvent: ActionTileContent$LinkPressEvent) => void;
  }

  /**
   * Parameters of the ActionTileContent#linkPress event.
   */
  export interface ActionTileContent$LinkPressEventParameters {
    /**
     * Indicates whether the CTRL key was pressed when the link was selected.
     */
    ctrlKey?: boolean;

    /**
     * Indicates whether the "meta" key was pressed when the link was selected.
     *
     * On Macintosh keyboards, this is the command key (⌘). On Windows keyboards, this is the windows key (⊞).
     */
    metaKey?: boolean;

    /**
     * Returns the TileAttribute instance of the clicked link
     */
    attribute?: TileAttribute;

    /**
     * Returns the link instance
     */
    link?: Link;
  }

  /**
   * Event object of the ActionTileContent#linkPress event.
   */
  export type ActionTileContent$LinkPressEvent = Event<
    ActionTileContent$LinkPressEventParameters,
    ActionTileContent
  >;
}

declare module "sap/m/App" {
  import {
    default as NavContainer,
    $NavContainerSettings,
  } from "sap/m/NavContainer";

  import { URI } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * The root element of a UI5 mobile app.
   *
   * Overview:
   *
   * The `App` inherits from {@link sap.m.NavContainer} and thus provides its navigation capabilities. It
   * adds certain header tags to the HTML page which are considered useful for mobile apps.
   *
   * Usage:
   *
   * You can configure the home icon of the `App`. For more information, see the `homeIcon` property.
   *
   * There are options for setting the background color and a background image with the use of the `backgroundColor`
   * and `backgroundImage` properties.
   *
   * **Note**: Keep in mind that by default (`isTopLevel` is set to `true`) `sap.m.App` traverses its parent
   * elements and automatically sets their height to 100%.
   */
  export default class App extends NavContainer {
    /**
     * Constructor for a new `App`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/a4afb138acf64a61a038aa5b91a4f082 App}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $AppSettings
    );
    /**
     * Constructor for a new `App`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/a4afb138acf64a61a038aa5b91a4f082 App}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $AppSettings
    );

    /**
     * Creates a new subclass of class sap.m.App with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.NavContainer.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, App>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.App.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:orientationChange orientationChange} event of
     * this `sap.m.App`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.App` itself.
     *
     * Fired when the orientation (portrait/landscape) of the device is changed.
     *
     * @deprecated As of version 1.20.0. use {@link sap.ui.Device.orientation.attachHandler} instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachOrientationChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: App$OrientationChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.App` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:orientationChange orientationChange} event of
     * this `sap.m.App`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.App` itself.
     *
     * Fired when the orientation (portrait/landscape) of the device is changed.
     *
     * @deprecated As of version 1.20.0. use {@link sap.ui.Device.orientation.attachHandler} instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachOrientationChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: App$OrientationChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.App` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:orientationChange orientationChange} event
     * of this `sap.m.App`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @deprecated As of version 1.20.0. use {@link sap.ui.Device.orientation.attachHandler} instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachOrientationChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: App$OrientationChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:orientationChange orientationChange} to attached listeners.
     *
     * @deprecated As of version 1.20.0. use {@link sap.ui.Device.orientation.attachHandler} instead.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireOrientationChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: App$OrientationChangeEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getBackgroundColor backgroundColor}.
     *
     * Background color of the App. If set, this color will override the default background defined by the theme.
     * So this should only be set when really required. Any configured background image will be placed above
     * this colored background. But any theme adaptation in the Theme Designer will override this setting. Use
     * the "backgroundRepeat" property to define whether this image should be stretched to cover the complete
     * App or whether it should be tiled.
     *
     * @since 1.11.2
     *
     * @returns Value of property `backgroundColor`
     */
    getBackgroundColor(): string;
    /**
     * Gets current value of property {@link #getBackgroundImage backgroundImage}.
     *
     * Background image of the App. If set, this image will override the default background defined by the theme.
     * So this should only be set when really required. This background image will be placed above any color
     * set for the background. But any theme adaptation in the Theme Designer will override this image setting.
     * Use the "backgroundRepeat" property to define whether this image should be stretched to cover the complete
     * App or whether it should be tiled.
     *
     * @since 1.11.2
     *
     * @returns Value of property `backgroundImage`
     */
    getBackgroundImage(): URI;
    /**
     * Gets current value of property {@link #getBackgroundOpacity backgroundOpacity}.
     *
     * Opacity of the background image. The opacity can be set between 0 (fully transparent) and 1 fully opaque).
     * This can be used to make the application content better readable by making the background image partly
     * transparent.
     *
     * Default value is `1`.
     *
     * @since 1.11.2
     *
     * @returns Value of property `backgroundOpacity`
     */
    getBackgroundOpacity(): float;
    /**
     * Gets current value of property {@link #getBackgroundRepeat backgroundRepeat}.
     *
     * Whether the background image (if configured) should be proportionally stretched to cover the whole App
     * (false) or whether it should be tiled (true).
     *
     * Default value is `false`.
     *
     * @since 1.11.2
     *
     * @returns Value of property `backgroundRepeat`
     */
    getBackgroundRepeat(): boolean;
    /**
     * Gets current value of property {@link #getHomeIcon homeIcon}.
     *
     * The icon to be displayed on the home screen of iOS devices after the user does "add to home screen".
     *
     * Note that only the first attempt to set the homeIcon will be executed, subsequent settings are ignored.
     *
     * This icon must be in PNG format. The property can either hold the URL of one single icon which is used
     * for all devices (and possibly scaled, which looks not perfect), or an object holding icon URLs for the
     * different required sizes.
     *
     * A desktop icon (used for bookmarks and overriding the favicon) can also be configured. This requires
     * an object to be given and the "icon" property of this object then defines the desktop bookmark icon.
     * The ICO format is supported by all browsers. ICO is also preferred for this desktop icon setting because
     * the file can contain different images for different resolutions.
     *
     * One example is:
     *
     * app.setHomeIcon({ 'phone':'phone-icon.png', 'phone@2':'phone-retina.png', 'tablet':'tablet-icon.png',
     * 'tablet@2':'tablet-retina.png', 'icon':'desktop.ico' });
     *
     * The respective image sizes are 57/114 px for the phone and 72/144 px for the tablet. If an object is
     * given but one of the sizes is not given, the largest given icon will be used for this size.
     *
     * On Android these icons may or may not be used by the device. Apparently chances can be improved by adding
     * glare effect and rounded corners, setting the file name so it ends with "-precomposed.png" and setting
     * the "homeIconPrecomposed" property to "true".
     *
     *
     * @returns Value of property `homeIcon`
     */
    getHomeIcon(): any;
    /**
     * Gets current value of property {@link #getIsTopLevel isTopLevel}.
     *
     * Determines whether `sap.m.App` is used as a top level control.
     *
     * **Note**: When the `isTopLevel` property set to `true`, `sap.m.App` traverses its parent DOM elements
     * and sets their height to 100%.
     *
     * Default value is `true`.
     *
     * @since 1.91
     *
     * @returns Value of property `isTopLevel`
     */
    getIsTopLevel(): boolean;
    /**
     * Gets current value of property {@link #getMobileWebAppCapable mobileWebAppCapable}.
     *
     * Determines whether the `App` is displayed without address bar when opened from an exported home screen
     * icon on a mobile device.
     *
     * Keep in mind that if enabled, there is no back button provided by the browser and the app must provide
     * own navigation on all displayed pages to avoid dead ends.
     *
     * **Note** The property can be toggled, but it doesn't take effect in real time. It takes the set value
     * at the moment when the home screen icon is exported by the user. For example, if the icon is exported
     * while the property is set to `true`, the `App` will have no address bar when opened from that same icon
     * regardless of a changed property value to `false` at a later time.
     *
     * Default value is `true`.
     *
     * @since 1.58.0
     *
     * @returns Value of property `mobileWebAppCapable`
     */
    getMobileWebAppCapable(): boolean;
    /**
     * Sets a new value for property {@link #getBackgroundColor backgroundColor}.
     *
     * Background color of the App. If set, this color will override the default background defined by the theme.
     * So this should only be set when really required. Any configured background image will be placed above
     * this colored background. But any theme adaptation in the Theme Designer will override this setting. Use
     * the "backgroundRepeat" property to define whether this image should be stretched to cover the complete
     * App or whether it should be tiled.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.11.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundColor(
      /**
       * New value for property `backgroundColor`
       */
      sBackgroundColor?: string
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundImage backgroundImage}.
     *
     * Background image of the App. If set, this image will override the default background defined by the theme.
     * So this should only be set when really required. This background image will be placed above any color
     * set for the background. But any theme adaptation in the Theme Designer will override this image setting.
     * Use the "backgroundRepeat" property to define whether this image should be stretched to cover the complete
     * App or whether it should be tiled.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.11.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundImage(
      /**
       * New value for property `backgroundImage`
       */
      sBackgroundImage?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundOpacity backgroundOpacity}.
     *
     * Opacity of the background image. The opacity can be set between 0 (fully transparent) and 1 fully opaque).
     * This can be used to make the application content better readable by making the background image partly
     * transparent.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `1`.
     *
     * @since 1.11.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundOpacity(
      /**
       * New value for property `backgroundOpacity`
       */
      fBackgroundOpacity?: float
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundRepeat backgroundRepeat}.
     *
     * Whether the background image (if configured) should be proportionally stretched to cover the whole App
     * (false) or whether it should be tiled (true).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.11.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundRepeat(
      /**
       * New value for property `backgroundRepeat`
       */
      bBackgroundRepeat?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getHomeIcon homeIcon}.
     *
     * The icon to be displayed on the home screen of iOS devices after the user does "add to home screen".
     *
     * Note that only the first attempt to set the homeIcon will be executed, subsequent settings are ignored.
     *
     * This icon must be in PNG format. The property can either hold the URL of one single icon which is used
     * for all devices (and possibly scaled, which looks not perfect), or an object holding icon URLs for the
     * different required sizes.
     *
     * A desktop icon (used for bookmarks and overriding the favicon) can also be configured. This requires
     * an object to be given and the "icon" property of this object then defines the desktop bookmark icon.
     * The ICO format is supported by all browsers. ICO is also preferred for this desktop icon setting because
     * the file can contain different images for different resolutions.
     *
     * One example is:
     *
     * app.setHomeIcon({ 'phone':'phone-icon.png', 'phone@2':'phone-retina.png', 'tablet':'tablet-icon.png',
     * 'tablet@2':'tablet-retina.png', 'icon':'desktop.ico' });
     *
     * The respective image sizes are 57/114 px for the phone and 72/144 px for the tablet. If an object is
     * given but one of the sizes is not given, the largest given icon will be used for this size.
     *
     * On Android these icons may or may not be used by the device. Apparently chances can be improved by adding
     * glare effect and rounded corners, setting the file name so it ends with "-precomposed.png" and setting
     * the "homeIconPrecomposed" property to "true".
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHomeIcon(
      /**
       * New value for property `homeIcon`
       */
      oHomeIcon?: any
    ): this;
    /**
     * Sets a new value for property {@link #getIsTopLevel isTopLevel}.
     *
     * Determines whether `sap.m.App` is used as a top level control.
     *
     * **Note**: When the `isTopLevel` property set to `true`, `sap.m.App` traverses its parent DOM elements
     * and sets their height to 100%.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.91
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIsTopLevel(
      /**
       * New value for property `isTopLevel`
       */
      bIsTopLevel?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getMobileWebAppCapable mobileWebAppCapable}.
     *
     * Determines whether the `App` is displayed without address bar when opened from an exported home screen
     * icon on a mobile device.
     *
     * Keep in mind that if enabled, there is no back button provided by the browser and the app must provide
     * own navigation on all displayed pages to avoid dead ends.
     *
     * **Note** The property can be toggled, but it doesn't take effect in real time. It takes the set value
     * at the moment when the home screen icon is exported by the user. For example, if the icon is exported
     * while the property is set to `true`, the `App` will have no address bar when opened from that same icon
     * regardless of a changed property value to `false` at a later time.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.58.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMobileWebAppCapable(
      /**
       * New value for property `mobileWebAppCapable`
       */
      bMobileWebAppCapable?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the App constructor.
   */
  export interface $AppSettings extends $NavContainerSettings {
    /**
     * The icon to be displayed on the home screen of iOS devices after the user does "add to home screen".
     *
     * Note that only the first attempt to set the homeIcon will be executed, subsequent settings are ignored.
     *
     * This icon must be in PNG format. The property can either hold the URL of one single icon which is used
     * for all devices (and possibly scaled, which looks not perfect), or an object holding icon URLs for the
     * different required sizes.
     *
     * A desktop icon (used for bookmarks and overriding the favicon) can also be configured. This requires
     * an object to be given and the "icon" property of this object then defines the desktop bookmark icon.
     * The ICO format is supported by all browsers. ICO is also preferred for this desktop icon setting because
     * the file can contain different images for different resolutions.
     *
     * One example is:
     *
     * app.setHomeIcon({ 'phone':'phone-icon.png', 'phone@2':'phone-retina.png', 'tablet':'tablet-icon.png',
     * 'tablet@2':'tablet-retina.png', 'icon':'desktop.ico' });
     *
     * The respective image sizes are 57/114 px for the phone and 72/144 px for the tablet. If an object is
     * given but one of the sizes is not given, the largest given icon will be used for this size.
     *
     * On Android these icons may or may not be used by the device. Apparently chances can be improved by adding
     * glare effect and rounded corners, setting the file name so it ends with "-precomposed.png" and setting
     * the "homeIconPrecomposed" property to "true".
     */
    homeIcon?: any | PropertyBindingInfo | `{${string}}`;

    /**
     * Background color of the App. If set, this color will override the default background defined by the theme.
     * So this should only be set when really required. Any configured background image will be placed above
     * this colored background. But any theme adaptation in the Theme Designer will override this setting. Use
     * the "backgroundRepeat" property to define whether this image should be stretched to cover the complete
     * App or whether it should be tiled.
     *
     * @since 1.11.2
     */
    backgroundColor?: string | PropertyBindingInfo;

    /**
     * Background image of the App. If set, this image will override the default background defined by the theme.
     * So this should only be set when really required. This background image will be placed above any color
     * set for the background. But any theme adaptation in the Theme Designer will override this image setting.
     * Use the "backgroundRepeat" property to define whether this image should be stretched to cover the complete
     * App or whether it should be tiled.
     *
     * @since 1.11.2
     */
    backgroundImage?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Whether the background image (if configured) should be proportionally stretched to cover the whole App
     * (false) or whether it should be tiled (true).
     *
     * @since 1.11.2
     */
    backgroundRepeat?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Opacity of the background image. The opacity can be set between 0 (fully transparent) and 1 fully opaque).
     * This can be used to make the application content better readable by making the background image partly
     * transparent.
     *
     * @since 1.11.2
     */
    backgroundOpacity?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the `App` is displayed without address bar when opened from an exported home screen
     * icon on a mobile device.
     *
     * Keep in mind that if enabled, there is no back button provided by the browser and the app must provide
     * own navigation on all displayed pages to avoid dead ends.
     *
     * **Note** The property can be toggled, but it doesn't take effect in real time. It takes the set value
     * at the moment when the home screen icon is exported by the user. For example, if the icon is exported
     * while the property is set to `true`, the `App` will have no address bar when opened from that same icon
     * regardless of a changed property value to `false` at a later time.
     *
     * @since 1.58.0
     */
    mobileWebAppCapable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether `sap.m.App` is used as a top level control.
     *
     * **Note**: When the `isTopLevel` property set to `true`, `sap.m.App` traverses its parent DOM elements
     * and sets their height to 100%.
     *
     * @since 1.91
     */
    isTopLevel?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Fired when the orientation (portrait/landscape) of the device is changed.
     *
     * @deprecated As of version 1.20.0. use {@link sap.ui.Device.orientation.attachHandler} instead.
     */
    orientationChange?: (oEvent: App$OrientationChangeEvent) => void;
  }

  /**
   * Parameters of the App#orientationChange event.
   *
   * @deprecated As of version 1.20.0. use {@link sap.ui.Device.orientation.attachHandler} instead.
   */
  export interface App$OrientationChangeEventParameters {
    /**
     * Whether the device is in landscape orientation.
     */
    landscape?: boolean;
  }

  /**
   * Event object of the App#orientationChange event.
   *
   * @deprecated As of version 1.20.0. use {@link sap.ui.Device.orientation.attachHandler} instead.
   */
  export type App$OrientationChangeEvent = Event<
    App$OrientationChangeEventParameters,
    App
  >;
}

declare module "sap/m/Avatar" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { ID, aria, URI, ValueState, CSSSize } from "sap/ui/core/library";

  import Event from "sap/ui/base/Event";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import AvatarColor from "sap/m/AvatarColor";

  import AvatarBadgeColor from "sap/m/AvatarBadgeColor";

  import LightBox from "sap/m/LightBox";

  import AvatarShape from "sap/m/AvatarShape";

  import AvatarSize from "sap/m/AvatarSize";

  import AvatarImageFitType from "sap/m/AvatarImageFitType";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * An image-like control that has different display options for representing images, initials, and icons.
   *
   * Overview:
   *
   * The `Avatar` control allows the usage of different content, shapes, and sizes depending on the use case.
   *
   * The content types that can be displayed are either images, icons, or initials. The shape can be circular
   * or square. There are several predefined sizes, as well as an option to set a custom size.
   *
   * Usage:
   *
   * Up to three Latin letters can be displayed as initials in an `Avatar`. If there are more than three letters,
   * or if there's a non-Latin character present, a default image placeholder will be created.
   *
   * There are two options for how the displayed image can fit inside the available area:
   * 	 - Cover - the image is scaled to cover all of the available area
   * 	 - Contain - the image is scaled as large as possible while both its height and width fit inside the
   *     avalable area  **Note:** To set a custom size for the `Avatar`, you have to choose the `Custom`
   *     value for the `displaySize` property. Then, you have to set both the `customDisplaySize` and `customFontSize`
   *     properties.
   *
   * @since 1.73
   */
  export default class Avatar extends Control {
    /**
     * Constructor for a new `Avatar`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/avatar/ Avatar}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $AvatarSettings
    );
    /**
     * Constructor for a new `Avatar`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/avatar/ Avatar}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $AvatarSettings
    );

    /**
     * Creates a new subclass of class sap.m.Avatar with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Avatar>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Avatar.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.Avatar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Avatar` itself.
     *
     * Fired when the user selects the control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Avatar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.Avatar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Avatar` itself.
     *
     * Fired when the user selects the control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Avatar` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getDetailBox detailBox} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindDetailBox(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys the `detailBox` aggregation.
     *
     *
     * @returns `this` for chaining
     */
    destroyDetailBox(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.Avatar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getActive active}.
     *
     * Determines whether the `Avatar` is active/toggled (default is set to `false`). Active state is meant
     * to be toggled when user clicks on the `Avatar`. The Active state is only applied, when the `Avatar` has
     * `press` listeners.
     *
     * Default value is `false`.
     *
     * @since 1.120.0
     *
     * @returns Value of property `active`
     */
    getActive(): boolean;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Gets current value of property {@link #getAriaHasPopup ariaHasPopup}.
     *
     * Specifies the value of the `aria-haspopup` attribute
     *
     * If the value is `None`, the attribute will not be rendered. Otherwise it will be rendered with the selected
     * value.
     *
     * NOTE: Use this property only when an avatar is related to a popover/popup. The value needs to be equal
     * to the main/root role of the popup - e.g. dialog, menu or list (examples: if you have dialog -> dialog,
     * if you have menu -> menu; if you have list -> list; if you have dialog containing a list -> dialog).
     * Do not use it, if you open a standard sap.m.Dialog, MessageBox or other type of dialogs displayed as
     * on overlay over the application.
     *
     * Default value is `None`.
     *
     * @since 1.99.0
     *
     * @returns Value of property `ariaHasPopup`
     */
    getAriaHasPopup(): aria.HasPopup;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getBackgroundColor backgroundColor}.
     *
     * Determines the background color of the control.
     *
     * Default value is `Accent6`.
     *
     *
     * @returns Value of property `backgroundColor`
     */
    getBackgroundColor(): AvatarColor;
    /**
     * Gets current value of property {@link #getBadgeIcon badgeIcon}.
     *
     * Defines what type of icon is displayed as visual affordance. It can be predefined or custom.
     *
     * The predefined icons are recommended for:
     * 	 - Suggesting a zooming action: `sap-icon://zoom-in`
     * 	 - Suggesting an image change: `sap-icon://camera`
     * 	 - Suggesting an editing action: `sap-icon://edit`  **Notes:**
     * 	 - Use `sap-icon://avatar-icon-none` to show the badge without an icon.
     * 	 - When using avatar-icon-none, the badge remains visible and can display background color or tooltip.
     *
     *
     * Default value is `empty string`.
     *
     * @since 1.77
     *
     * @returns Value of property `badgeIcon`
     */
    getBadgeIcon(): URI;
    /**
     * Gets current value of property {@link #getBadgeIconColor badgeIconColor}.
     *
     * Defines the color of the badge icon. This color is used to style the badge, indicating different statuses
     * or categories. Acceptable values include predefined `sap.m.AvatarBadgeColor` options.
     *
     * Default value is `Accent6`.
     *
     * @since 1.132.0
     *
     * @returns Value of property `badgeIconColor`
     */
    getBadgeIconColor(): AvatarBadgeColor;
    /**
     * Gets current value of property {@link #getBadgeTooltip badgeTooltip}.
     *
     * Defines a custom tooltip for the `badgeIcon`. If set, it overrides the available default values.
     *
     * If not set, default tooltips are used as follows:
     * 	 - Specific default tooltips are displayed for each of the predefined `badgeIcons`.
     * 	 - For any other icons, the displayed tooltip is the same as the main control tooltip.
     *
     * @since 1.77
     *
     * @returns Value of property `badgeTooltip`
     */
    getBadgeTooltip(): string;
    /**
     * Gets current value of property {@link #getBadgeValueState badgeValueState}.
     *
     * Visualizes the validation state of the badge, e.g. `Error`, `Warning`, `Success`, `Information`.
     *
     * Default value is `None`.
     *
     * @since 1.116.0
     *
     * @returns Value of property `badgeValueState`
     */
    getBadgeValueState(): ValueState;
    /**
     * Gets current value of property {@link #getCustomDisplaySize customDisplaySize}.
     *
     * Specifies custom display size of the `Avatar`.
     *
     * **Note:** It takes effect if the `displaySize` property is set to `Custom`.
     *
     * Default value is `"3rem"`.
     *
     *
     * @returns Value of property `customDisplaySize`
     */
    getCustomDisplaySize(): CSSSize;
    /**
     * Gets current value of property {@link #getCustomFontSize customFontSize}.
     *
     * Specifies custom font size of the `Avatar`.
     *
     * **Note:** It takes effect if the `displaySize` property is set to `Custom`.
     *
     * Default value is `"1.125rem"`.
     *
     *
     * @returns Value of property `customFontSize`
     */
    getCustomFontSize(): CSSSize;
    /**
     * Gets current value of property {@link #getDecorative decorative}.
     *
     * Defines whether the `sap.m.Avatar` is used for decorative purposes and is ignored by accessibility tools.
     *
     * **Note:** This property doesn't take effect if `sap.m.Avatar` has a `press` handler.
     *
     * Default value is `false`.
     *
     * @since 1.97
     *
     * @returns Value of property `decorative`
     */
    getDecorative(): boolean;
    /**
     * Gets content of aggregation {@link #getDetailBox detailBox}.
     *
     * A `sap.m.LightBox` instance, that will be opened automatically when the user interacts with the `Avatar`
     * control.
     *
     * The `press` event will still be fired.
     */
    getDetailBox(): LightBox;
    /**
     * Gets current value of property {@link #getDisplayShape displayShape}.
     *
     * Defines the shape of the `Avatar`.
     *
     * Default value is `Circle`.
     *
     *
     * @returns Value of property `displayShape`
     */
    getDisplayShape(): AvatarShape;
    /**
     * Gets current value of property {@link #getDisplaySize displaySize}.
     *
     * Sets a predefined display size of the `Avatar`.
     *
     * Default value is `S`.
     *
     *
     * @returns Value of property `displaySize`
     */
    getDisplaySize(): AvatarSize;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Determines whether the `Avatar` is enabled (default is set to `true`). A disabled `Button` has different
     * colors depending on the {@link sap.m.AvatarColor AvatarColor}.
     *
     * Default value is `true`.
     *
     * @since 1.117.0
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets current value of property {@link #getFallbackIcon fallbackIcon}.
     *
     * Defines the fallback icon displayed in case of wrong image src and no initials set.
     *
     * **Notes:**
     * 	 - If not set, a default fallback icon is displayed depending on the set `displayShape` property.
     * 	 - Accepted values are only icons from the SAP icon font.
     *
     *
     * @returns Value of property `fallbackIcon`
     */
    getFallbackIcon(): string;
    /**
     * Gets current value of property {@link #getImageFitType imageFitType}.
     *
     * Specifies how an image would fit in the `Avatar`.
     *
     * Default value is `Cover`.
     *
     *
     * @returns Value of property `imageFitType`
     */
    getImageFitType(): AvatarImageFitType;
    /**
     * Gets current value of property {@link #getInitials initials}.
     *
     * Defines the displayed initials. They should consist of only 1,2 or 3 latin letters.
     *
     *
     * @returns Value of property `initials`
     */
    getInitials(): string;
    /**
     * Gets current value of property {@link #getShowBorder showBorder}.
     *
     * Determines whether the control is displayed with border.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showBorder`
     */
    getShowBorder(): boolean;
    /**
     * Gets current value of property {@link #getSrc src}.
     *
     * Determines the path to the desired image or icon.
     *
     *
     * @returns Value of property `src`
     */
    getSrc(): URI;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getActive active}.
     *
     * Determines whether the `Avatar` is active/toggled (default is set to `false`). Active state is meant
     * to be toggled when user clicks on the `Avatar`. The Active state is only applied, when the `Avatar` has
     * `press` listeners.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.120.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setActive(
      /**
       * New value for property `active`
       */
      bActive?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getAriaHasPopup ariaHasPopup}.
     *
     * Specifies the value of the `aria-haspopup` attribute
     *
     * If the value is `None`, the attribute will not be rendered. Otherwise it will be rendered with the selected
     * value.
     *
     * NOTE: Use this property only when an avatar is related to a popover/popup. The value needs to be equal
     * to the main/root role of the popup - e.g. dialog, menu or list (examples: if you have dialog -> dialog,
     * if you have menu -> menu; if you have list -> list; if you have dialog containing a list -> dialog).
     * Do not use it, if you open a standard sap.m.Dialog, MessageBox or other type of dialogs displayed as
     * on overlay over the application.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     * @since 1.99.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAriaHasPopup(
      /**
       * New value for property `ariaHasPopup`
       */
      sAriaHasPopup?: aria.HasPopup | keyof typeof aria.HasPopup
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundColor backgroundColor}.
     *
     * Determines the background color of the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Accent6`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundColor(
      /**
       * New value for property `backgroundColor`
       */
      sBackgroundColor?: AvatarColor | keyof typeof AvatarColor
    ): this;
    /**
     * Sets a new value for property {@link #getBadgeIcon badgeIcon}.
     *
     * Defines what type of icon is displayed as visual affordance. It can be predefined or custom.
     *
     * The predefined icons are recommended for:
     * 	 - Suggesting a zooming action: `sap-icon://zoom-in`
     * 	 - Suggesting an image change: `sap-icon://camera`
     * 	 - Suggesting an editing action: `sap-icon://edit`  **Notes:**
     * 	 - Use `sap-icon://avatar-icon-none` to show the badge without an icon.
     * 	 - When using avatar-icon-none, the badge remains visible and can display background color or tooltip.
     *
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.77
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBadgeIcon(
      /**
       * New value for property `badgeIcon`
       */
      sBadgeIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getBadgeIconColor badgeIconColor}.
     *
     * Defines the color of the badge icon. This color is used to style the badge, indicating different statuses
     * or categories. Acceptable values include predefined `sap.m.AvatarBadgeColor` options.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Accent6`.
     *
     * @since 1.132.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBadgeIconColor(
      /**
       * New value for property `badgeIconColor`
       */
      sBadgeIconColor?: AvatarBadgeColor | keyof typeof AvatarBadgeColor
    ): this;
    /**
     * Sets a new value for property {@link #getBadgeTooltip badgeTooltip}.
     *
     * Defines a custom tooltip for the `badgeIcon`. If set, it overrides the available default values.
     *
     * If not set, default tooltips are used as follows:
     * 	 - Specific default tooltips are displayed for each of the predefined `badgeIcons`.
     * 	 - For any other icons, the displayed tooltip is the same as the main control tooltip.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.77
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBadgeTooltip(
      /**
       * New value for property `badgeTooltip`
       */
      sBadgeTooltip?: string
    ): this;
    /**
     * Sets a new value for property {@link #getBadgeValueState badgeValueState}.
     *
     * Visualizes the validation state of the badge, e.g. `Error`, `Warning`, `Success`, `Information`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     * @since 1.116.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBadgeValueState(
      /**
       * New value for property `badgeValueState`
       */
      sBadgeValueState?: ValueState | keyof typeof ValueState
    ): this;
    /**
     * Sets a new value for property {@link #getCustomDisplaySize customDisplaySize}.
     *
     * Specifies custom display size of the `Avatar`.
     *
     * **Note:** It takes effect if the `displaySize` property is set to `Custom`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"3rem"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomDisplaySize(
      /**
       * New value for property `customDisplaySize`
       */
      sCustomDisplaySize?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getCustomFontSize customFontSize}.
     *
     * Specifies custom font size of the `Avatar`.
     *
     * **Note:** It takes effect if the `displaySize` property is set to `Custom`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"1.125rem"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomFontSize(
      /**
       * New value for property `customFontSize`
       */
      sCustomFontSize?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getDecorative decorative}.
     *
     * Defines whether the `sap.m.Avatar` is used for decorative purposes and is ignored by accessibility tools.
     *
     * **Note:** This property doesn't take effect if `sap.m.Avatar` has a `press` handler.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.97
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDecorative(
      /**
       * New value for property `decorative`
       */
      bDecorative?: boolean
    ): this;
    /**
     * Sets the `detailBox` aggregation.
     *
     *
     * @returns `this` for chaining
     */
    setDetailBox(
      /**
       * Instance of the `LightBox` control or undefined
       */
      oLightBox: LightBox | undefined
    ): this;
    /**
     * Sets a new value for property {@link #getDisplayShape displayShape}.
     *
     * Defines the shape of the `Avatar`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Circle`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisplayShape(
      /**
       * New value for property `displayShape`
       */
      sDisplayShape?: AvatarShape | keyof typeof AvatarShape
    ): this;
    /**
     * Sets a new value for property {@link #getDisplaySize displaySize}.
     *
     * Sets a predefined display size of the `Avatar`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `S`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisplaySize(
      /**
       * New value for property `displaySize`
       */
      sDisplaySize?: AvatarSize | keyof typeof AvatarSize
    ): this;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Determines whether the `Avatar` is enabled (default is set to `true`). A disabled `Button` has different
     * colors depending on the {@link sap.m.AvatarColor AvatarColor}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.117.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getFallbackIcon fallbackIcon}.
     *
     * Defines the fallback icon displayed in case of wrong image src and no initials set.
     *
     * **Notes:**
     * 	 - If not set, a default fallback icon is displayed depending on the set `displayShape` property.
     * 	 - Accepted values are only icons from the SAP icon font.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFallbackIcon(
      /**
       * New value for property `fallbackIcon`
       */
      sFallbackIcon?: string
    ): this;
    /**
     * Sets a new value for property {@link #getImageFitType imageFitType}.
     *
     * Specifies how an image would fit in the `Avatar`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Cover`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setImageFitType(
      /**
       * New value for property `imageFitType`
       */
      sImageFitType?: AvatarImageFitType | keyof typeof AvatarImageFitType
    ): this;
    /**
     * Sets a new value for property {@link #getInitials initials}.
     *
     * Defines the displayed initials. They should consist of only 1,2 or 3 latin letters.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInitials(
      /**
       * New value for property `initials`
       */
      sInitials?: string
    ): this;
    /**
     * Sets a new value for property {@link #getShowBorder showBorder}.
     *
     * Determines whether the control is displayed with border.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowBorder(
      /**
       * New value for property `showBorder`
       */
      bShowBorder?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getSrc src}.
     *
     * Determines the path to the desired image or icon.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSrc(
      /**
       * New value for property `src`
       */
      sSrc?: URI
    ): this;
    /**
     * Unbinds aggregation {@link #getDetailBox detailBox} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindDetailBox(): this;
  }
  /**
   * Describes the settings that can be provided to the Avatar constructor.
   */
  export interface $AvatarSettings extends $ControlSettings {
    /**
     * Determines the path to the desired image or icon.
     */
    src?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the displayed initials. They should consist of only 1,2 or 3 latin letters.
     */
    initials?: string | PropertyBindingInfo;

    /**
     * Defines the shape of the `Avatar`.
     */
    displayShape?:
      | (AvatarShape | keyof typeof AvatarShape)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Sets a predefined display size of the `Avatar`.
     */
    displaySize?:
      | (AvatarSize | keyof typeof AvatarSize)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies custom display size of the `Avatar`.
     *
     * **Note:** It takes effect if the `displaySize` property is set to `Custom`.
     */
    customDisplaySize?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies custom font size of the `Avatar`.
     *
     * **Note:** It takes effect if the `displaySize` property is set to `Custom`.
     */
    customFontSize?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies how an image would fit in the `Avatar`.
     */
    imageFitType?:
      | (AvatarImageFitType | keyof typeof AvatarImageFitType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the fallback icon displayed in case of wrong image src and no initials set.
     *
     * **Notes:**
     * 	 - If not set, a default fallback icon is displayed depending on the set `displayShape` property.
     * 	 - Accepted values are only icons from the SAP icon font.
     */
    fallbackIcon?: string | PropertyBindingInfo;

    /**
     * Determines the background color of the control.
     */
    backgroundColor?:
      | (AvatarColor | keyof typeof AvatarColor)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines whether the control is displayed with border.
     */
    showBorder?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines what type of icon is displayed as visual affordance. It can be predefined or custom.
     *
     * The predefined icons are recommended for:
     * 	 - Suggesting a zooming action: `sap-icon://zoom-in`
     * 	 - Suggesting an image change: `sap-icon://camera`
     * 	 - Suggesting an editing action: `sap-icon://edit`  **Notes:**
     * 	 - Use `sap-icon://avatar-icon-none` to show the badge without an icon.
     * 	 - When using avatar-icon-none, the badge remains visible and can display background color or tooltip.
     *
     *
     * @since 1.77
     */
    badgeIcon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines a custom tooltip for the `badgeIcon`. If set, it overrides the available default values.
     *
     * If not set, default tooltips are used as follows:
     * 	 - Specific default tooltips are displayed for each of the predefined `badgeIcons`.
     * 	 - For any other icons, the displayed tooltip is the same as the main control tooltip.
     *
     * @since 1.77
     */
    badgeTooltip?: string | PropertyBindingInfo;

    /**
     * Defines whether the `sap.m.Avatar` is used for decorative purposes and is ignored by accessibility tools.
     *
     * **Note:** This property doesn't take effect if `sap.m.Avatar` has a `press` handler.
     *
     * @since 1.97
     */
    decorative?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the value of the `aria-haspopup` attribute
     *
     * If the value is `None`, the attribute will not be rendered. Otherwise it will be rendered with the selected
     * value.
     *
     * NOTE: Use this property only when an avatar is related to a popover/popup. The value needs to be equal
     * to the main/root role of the popup - e.g. dialog, menu or list (examples: if you have dialog -> dialog,
     * if you have menu -> menu; if you have list -> list; if you have dialog containing a list -> dialog).
     * Do not use it, if you open a standard sap.m.Dialog, MessageBox or other type of dialogs displayed as
     * on overlay over the application.
     *
     * @since 1.99.0
     */
    ariaHasPopup?:
      | (aria.HasPopup | keyof typeof aria.HasPopup)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Visualizes the validation state of the badge, e.g. `Error`, `Warning`, `Success`, `Information`.
     *
     * @since 1.116.0
     */
    badgeValueState?:
      | (ValueState | keyof typeof ValueState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the color of the badge icon. This color is used to style the badge, indicating different statuses
     * or categories. Acceptable values include predefined `sap.m.AvatarBadgeColor` options.
     *
     * @since 1.132.0
     */
    badgeIconColor?:
      | (AvatarBadgeColor | keyof typeof AvatarBadgeColor)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines whether the `Avatar` is enabled (default is set to `true`). A disabled `Button` has different
     * colors depending on the {@link sap.m.AvatarColor AvatarColor}.
     *
     * @since 1.117.0
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the `Avatar` is active/toggled (default is set to `false`). Active state is meant
     * to be toggled when user clicks on the `Avatar`. The Active state is only applied, when the `Avatar` has
     * `press` listeners.
     *
     * @since 1.120.0
     */
    active?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * A `sap.m.LightBox` instance, that will be opened automatically when the user interacts with the `Avatar`
     * control.
     *
     * The `press` event will still be fired.
     */
    detailBox?: LightBox;

    /**
     * Association to controls / ids which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledBy).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Fired when the user selects the control.
     */
    press?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the Avatar#press event.
   */
  export interface Avatar$PressEventParameters {}

  /**
   * Event object of the Avatar#press event.
   */
  export type Avatar$PressEvent = Event<Avatar$PressEventParameters, Avatar>;
}

declare module "sap/m/AvatarBadgeColor" {
  /**
   * Possible badge color options for the {@link sap.m.Avatar} control.
   *
   * **Notes:**
   * 	 - Keep in mind that the colors are theme-dependent and can differ based on the currently used theme.
   *
   *
   * @since 1.132.0
   */
  enum AvatarBadgeColor {
    /**
     * Accent 1
     */
    Accent1 = "Accent1",
    /**
     * Accent 10
     */
    Accent10 = "Accent10",
    /**
     * Accent 2
     */
    Accent2 = "Accent2",
    /**
     * Accent 3
     */
    Accent3 = "Accent3",
    /**
     * Accent 4
     */
    Accent4 = "Accent4",
    /**
     * Accent 5
     */
    Accent5 = "Accent5",
    /**
     * Accent 6
     */
    Accent6 = "Accent6",
    /**
     * Accent 7
     */
    Accent7 = "Accent7",
    /**
     * Accent 8
     */
    Accent8 = "Accent8",
    /**
     * Accent 9
     */
    Accent9 = "Accent9",
  }
  export default AvatarBadgeColor;
}

declare module "sap/m/AvatarColor" {
  /**
   * Possible background color options for the {@link sap.m.Avatar} control.
   *
   * **Notes:**
   * 	 - Keep in mind that the colors are theme-dependent and can differ based on the currently used theme.
   *
   * 	 -  If the `Random` value is assigned, a random color is chosen from the accent options (Accent1 to
   *     Accent10).
   *
   * @since 1.73
   */
  enum AvatarColor {
    /**
     * Accent 1
     */
    Accent1 = "Accent1",
    /**
     * Accent 10
     */
    Accent10 = "Accent10",
    /**
     * Accent 2
     */
    Accent2 = "Accent2",
    /**
     * Accent 3
     */
    Accent3 = "Accent3",
    /**
     * Accent 4
     */
    Accent4 = "Accent4",
    /**
     * Accent 5
     */
    Accent5 = "Accent5",
    /**
     * Accent 6
     */
    Accent6 = "Accent6",
    /**
     * Accent 7
     */
    Accent7 = "Accent7",
    /**
     * Accent 8
     */
    Accent8 = "Accent8",
    /**
     * Accent 9
     */
    Accent9 = "Accent9",
    /**
     * Recommended when used as a placeholder (no image or initials are provided).
     */
    Placeholder = "Placeholder",
    /**
     * Random color, chosen from the accent options (Accent1 to Accent10)
     */
    Random = "Random",
    /**
     * Recommended when used as an icon in a tile.
     */
    TileIcon = "TileIcon",
    /**
     * Transparent
     */
    Transparent = "Transparent",
  }
  export default AvatarColor;
}

declare module "sap/m/AvatarImageFitType" {
  /**
   * Types of image size and position that determine how an image fits in the {@link sap.m.Avatar} control
   * area.
   *
   * @since 1.73
   */
  enum AvatarImageFitType {
    /**
     * The image is scaled to the largest size so that both its width and height can fit in the control area.
     */
    Contain = "Contain",
    /**
     * The image is scaled to be large enough so that the control area is completely covered.
     */
    Cover = "Cover",
  }
  export default AvatarImageFitType;
}

declare module "sap/m/AvatarShape" {
  /**
   * Types of shape for the {@link sap.m.Avatar} control.
   *
   * @since 1.73
   */
  enum AvatarShape {
    /**
     * Circular shape.
     */
    Circle = "Circle",
    /**
     * Square shape.
     */
    Square = "Square",
  }
  export default AvatarShape;
}

declare module "sap/m/AvatarSize" {
  /**
   * Predefined sizes for the {@link sap.m.Avatar} control.
   *
   * @since 1.73
   */
  enum AvatarSize {
    /**
     * Custom size
     */
    Custom = "Custom",
    /**
     * Control size - 5rem Font size - 2rem
     */
    L = "L",
    /**
     * Control size - 4rem Font size - 1.625rem
     */
    M = "M",
    /**
     * Control size - 3rem Font size - 1.125rem
     */
    S = "S",
    /**
     * Control size - 7rem Font size - 2.75rem
     */
    XL = "XL",
    /**
     * Control size - 2rem Font size - 0.75rem
     */
    XS = "XS",
  }
  export default AvatarSize;
}

declare module "sap/m/AvatarType" {
  /**
   * Types of {@link sap.m.Avatar} based on the displayed content.
   *
   * @since 1.73
   */
  enum AvatarType {
    /**
     * The displayed content is an icon.
     */
    Icon = "Icon",
    /**
     * The displayed content is an image.
     */
    Image = "Image",
    /**
     * The displayed content is initials.
     */
    Initials = "Initials",
  }
  export default AvatarType;
}

declare module "sap/m/BadgeCustomData" {
  import {
    default as CustomData,
    $CustomDataSettings,
  } from "sap/ui/core/CustomData";

  import { BadgeAnimationType } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Contains a single key/value pair of custom data attached to an `Element`.
   *
   * For more information, see {@link sap.ui.core.Element#data Element.prototype.data} and {@link https://ui5.sap.com/#/topic/91f0c3ee6f4d1014b6dd926db0e91070 Custom Data - Attaching Data Objects to Controls}.
   *
   * @since 1.80
   */
  export default class BadgeCustomData extends CustomData {
    /**
     * Constructor for a new `BadgeCustomData` element.
     */
    constructor(
      /**
       * Initial settings for the new element
       */
      mSettings?: $BadgeCustomDataSettings
    );
    /**
     * Constructor for a new `BadgeCustomData` element.
     */
    constructor(
      /**
       * ID for the new element, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new element
       */
      mSettings?: $BadgeCustomDataSettings
    );

    /**
     * Creates a new subclass of class sap.m.BadgeCustomData with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.CustomData.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, BadgeCustomData>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.BadgeCustomData.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getAnimation animation}.
     *
     * Determines the type of animation to be performed by the Badge DOM element.
     *
     * Default value is `Full`.
     *
     * @since 1.87
     *
     * @returns Value of property `animation`
     */
    getAnimation(): BadgeAnimationType;
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Sets a new value for property {@link #getAnimation animation}.
     *
     * Determines the type of animation to be performed by the Badge DOM element.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Full`.
     *
     * @since 1.87
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAnimation(
      /**
       * New value for property `animation`
       */
      sAnimation?: BadgeAnimationType | keyof typeof BadgeAnimationType
    ): this;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the BadgeCustomData constructor.
   */
  export interface $BadgeCustomDataSettings extends $CustomDataSettings {
    visible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the type of animation to be performed by the Badge DOM element.
     *
     * @since 1.87
     */
    animation?:
      | (BadgeAnimationType | keyof typeof BadgeAnimationType)
      | PropertyBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/BadgeEnabler" {
  /**
   * A helper class for implementing the {@link sap.m.IBadge} interface.
   *
   * The class represents a utility for visualising and updating the `badge` indicator for `sap.ui.core.Control`
   * instances. It should be created once per `IBadge` instance.
   *
   * On its initialization,  can accept a settings object. The settings object contains
   * the following properties:
   *
   *
   * 	 - `position` - accepts three predefined string values which add relative CSS classes to the badge element
   *     and position it accordingly: `topLeft`, `topRight` and `inline`
   *
   *
   * 	 - `accentColor` - accepts string values equal to theme-specific accent colors. For more information,
   *     see the {@link https://experience.sap.com/fiori-design-web/quartz-light-colors/#accent-colors SAP Fiori Design Guidelines}.
   *
   *
   * 	 - `selector` - accepts Object, containing one property which is named either `selector` or `suffix`.
   *     If no selector is passed, the main ID of the control is automatically set as selector value.
   *
   * @since 1.80
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export default class BadgeEnabler {
    /**
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    protected constructor();
  }
}

declare module "sap/m/Bar" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { IBar, BarDesign, IBarHTMLTag, TitleAlignment } from "sap/m/library";

  import { ID } from "sap/ui/core/library";

  import { BarContexts } from "sap/m/BarInPageEnabler";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * Used as a header, sub-header and a footer of a page.
   *
   * Overview:
   *
   * The `Bar` control consists of three areas to hold its content. It has the capability to center content,
   * such as a title, while having other controls on the left and right side.
   *
   * Usage:
   *
   * With the use of the `design` property, you can set the style of the `Bar` to appear as a header, sub-header
   * and footer.
   *
   * **Note:** Do not place a `sap.m.Bar` inside another `sap.m.Bar` or inside any bar-like control. Doing
   * so causes unpredictable behavior.
   *
   * Responsive Behavior:
   *
   * The content in the middle area is centrally positioned if there is enough space. If the right or left
   * content overlaps the middle content, the middle content will be centered in the space between.
   */
  export default class Bar extends Control implements IBar {
    __implements__sap_m_IBar: boolean;
    /**
     * Constructor for a new `Bar`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $BarSettings
    );
    /**
     * Constructor for a new `Bar`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $BarSettings
    );

    /**
     * Creates a new subclass of class sap.m.Bar with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Bar>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Bar.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Sets classes according to the context of the page. Possible contexts are header, footer and subheader.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns `this` for chaining
     */
    _applyContextClassFor(): IBar;
    /**
     * Sets HTML tag according to the context of the page. Possible contexts are header, footer and subheader.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns `this` for chaining
     */
    _applyTag(): IBar;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds some contentLeft to the aggregation {@link #getContentLeft contentLeft}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContentLeft(
      /**
       * The contentLeft to add; if empty, nothing is inserted
       */
      oContentLeft: Control
    ): this;
    /**
     * Adds some contentMiddle to the aggregation {@link #getContentMiddle contentMiddle}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContentMiddle(
      /**
       * The contentMiddle to add; if empty, nothing is inserted
       */
      oContentMiddle: Control
    ): this;
    /**
     * Adds some contentRight to the aggregation {@link #getContentRight contentRight}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContentRight(
      /**
       * The contentRight to add; if empty, nothing is inserted
       */
      oContentRight: Control
    ): this;
    /**
     * Sets classes and HTML tag according to the context of the page. Possible contexts are header, footer
     * and subheader.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns `this` for chaining
     */
    applyTagAndContextClassFor(): IBar;
    /**
     * Destroys all the contentLeft in the aggregation {@link #getContentLeft contentLeft}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContentLeft(): this;
    /**
     * Destroys all the contentMiddle in the aggregation {@link #getContentMiddle contentMiddle}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContentMiddle(): this;
    /**
     * Destroys all the contentRight in the aggregation {@link #getContentRight contentRight}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContentRight(): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets content of aggregation {@link #getContentLeft contentLeft}.
     *
     * Represents the left content area, usually containing a button or an app icon. If it is overlapped by
     * the right content, its content will disappear and the text will show an ellipsis.
     */
    getContentLeft(): Control[];
    /**
     * Gets content of aggregation {@link #getContentMiddle contentMiddle}.
     *
     * Represents the middle content area. Controls such as label, segmented buttons or select can be placed
     * here. The content is centrally positioned if there is enough space. If the right or left content overlaps
     * the middle content, the middle content will be centered in the space between the left and the right content.
     */
    getContentMiddle(): Control[];
    /**
     * Gets content of aggregation {@link #getContentRight contentRight}.
     *
     * Represents the right content area. Controls such as action buttons or search field can be placed here.
     */
    getContentRight(): Control[];
    /**
     * Gets the available Bar contexts.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns with all available contexts
     */
    getContext(): BarContexts;
    /**
     * Gets current value of property {@link #getDesign design}.
     *
     * Determines the design of the bar. If set to auto, it becomes dependent on the place where the bar is
     * placed.
     *
     * Default value is `Auto`.
     *
     * @since 1.22
     *
     * @returns Value of property `design`
     */
    getDesign(): BarDesign;
    /**
     * Gets current value of property {@link #getEnableFlexBox enableFlexBox}.
     *
     * If this flag is set to true, contentMiddle will be rendered as a HBox and layoutData can be used to allocate
     * available space.
     *
     * Default value is `false`.
     *
     * @deprecated As of version 1.16. replaced by `contentMiddle` aggregation. `contentMiddle` will always
     * occupy of the 100% width when no `contentLeft` and `contentRight` are being set.
     *
     * @returns Value of property `enableFlexBox`
     */
    getEnableFlexBox(): boolean;
    /**
     * Gets the HTML tag of the root element.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The HTML-tag
     */
    getHTMLTag(): IBarHTMLTag;
    /**
     * Gets current value of property {@link #getTitleAlignment titleAlignment}.
     *
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.None`, the automatic title
     * alignment depending on the theme settings will be disabled. If set to `TitleAlignment.Auto`, the Title
     * will be aligned as it is set in the theme (if not set, the default value is `center`); Other possible
     * values are `TitleAlignment.Start` (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * Default value is `None`.
     *
     * @since 1.85
     *
     * @returns Value of property `titleAlignment`
     */
    getTitleAlignment(): TitleAlignment;
    /**
     * Gets current value of property {@link #getTranslucent translucent}.
     *
     * Indicates whether the Bar is partially translucent. It is only applied for touch devices.
     *
     * Default value is `false`.
     *
     * @since 1.12
     * @deprecated As of version 1.18.6. This property has no effect since release 1.18.6 and should not be
     * used. Translucent bar may overlay an input and make it difficult to edit.
     *
     * @returns Value of property `translucent`
     */
    getTranslucent(): boolean;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContentLeft contentLeft}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContentLeft(
      /**
       * The contentLeft whose index is looked for
       */
      oContentLeft: Control
    ): int;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContentMiddle contentMiddle}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContentMiddle(
      /**
       * The contentMiddle whose index is looked for
       */
      oContentMiddle: Control
    ): int;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContentRight contentRight}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContentRight(
      /**
       * The contentRight whose index is looked for
       */
      oContentRight: Control
    ): int;
    /**
     * Inserts a contentLeft into the aggregation {@link #getContentLeft contentLeft}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContentLeft(
      /**
       * The contentLeft to insert; if empty, nothing is inserted
       */
      oContentLeft: Control,
      /**
       * The `0`-based index the contentLeft should be inserted at; for a negative value of `iIndex`, the contentLeft
       * is inserted at position 0; for a value greater than the current size of the aggregation, the contentLeft
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a contentMiddle into the aggregation {@link #getContentMiddle contentMiddle}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContentMiddle(
      /**
       * The contentMiddle to insert; if empty, nothing is inserted
       */
      oContentMiddle: Control,
      /**
       * The `0`-based index the contentMiddle should be inserted at; for a negative value of `iIndex`, the contentMiddle
       * is inserted at position 0; for a value greater than the current size of the aggregation, the contentMiddle
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a contentRight into the aggregation {@link #getContentRight contentRight}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContentRight(
      /**
       * The contentRight to insert; if empty, nothing is inserted
       */
      oContentRight: Control,
      /**
       * The `0`-based index the contentRight should be inserted at; for a negative value of `iIndex`, the contentRight
       * is inserted at position 0; for a value greater than the current size of the aggregation, the contentRight
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Determines whether the Bar is sensitive to the container context.
     *
     * Implementation of the IBar interface.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns isContextSensitive
     */
    isContextSensitive(): boolean;
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all the controls from the aggregation {@link #getContentLeft contentLeft}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContentLeft(): Control[];
    /**
     * Removes all the controls from the aggregation {@link #getContentMiddle contentMiddle}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContentMiddle(): Control[];
    /**
     * Removes all the controls from the aggregation {@link #getContentRight contentRight}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContentRight(): Control[];
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes a contentLeft from the aggregation {@link #getContentLeft contentLeft}.
     *
     *
     * @returns The removed contentLeft or `null`
     */
    removeContentLeft(
      /**
       * The contentLeft to remove or its index or id
       */
      vContentLeft: int | string | Control
    ): Control | null;
    /**
     * Removes a contentMiddle from the aggregation {@link #getContentMiddle contentMiddle}.
     *
     *
     * @returns The removed contentMiddle or `null`
     */
    removeContentMiddle(
      /**
       * The contentMiddle to remove or its index or id
       */
      vContentMiddle: int | string | Control
    ): Control | null;
    /**
     * Removes a contentRight from the aggregation {@link #getContentRight contentRight}.
     *
     *
     * @returns The removed contentRight or `null`
     */
    removeContentRight(
      /**
       * The contentRight to remove or its index or id
       */
      vContentRight: int | string | Control
    ): Control | null;
    /**
     * Sets a new value for property {@link #getDesign design}.
     *
     * Determines the design of the bar. If set to auto, it becomes dependent on the place where the bar is
     * placed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     * @since 1.22
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDesign(
      /**
       * New value for property `design`
       */
      sDesign?: BarDesign | keyof typeof BarDesign
    ): this;
    /**
     * Sets a new value for property {@link #getEnableFlexBox enableFlexBox}.
     *
     * If this flag is set to true, contentMiddle will be rendered as a HBox and layoutData can be used to allocate
     * available space.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @deprecated As of version 1.16. replaced by `contentMiddle` aggregation. `contentMiddle` will always
     * occupy of the 100% width when no `contentLeft` and `contentRight` are being set.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableFlexBox(
      /**
       * New value for property `enableFlexBox`
       */
      bEnableFlexBox?: boolean
    ): this;
    /**
     * Sets the HTML tag of the root element.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns this for chaining
     */
    setHTMLTag(
      /**
       * The HTML tag of the root element
       */
      sTag: IBarHTMLTag | keyof typeof IBarHTMLTag
    ): IBar;
    /**
     * Sets a new value for property {@link #getTitleAlignment titleAlignment}.
     *
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.None`, the automatic title
     * alignment depending on the theme settings will be disabled. If set to `TitleAlignment.Auto`, the Title
     * will be aligned as it is set in the theme (if not set, the default value is `center`); Other possible
     * values are `TitleAlignment.Start` (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     * @since 1.85
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleAlignment(
      /**
       * New value for property `titleAlignment`
       */
      sTitleAlignment?: TitleAlignment | keyof typeof TitleAlignment
    ): this;
    /**
     * Sets a new value for property {@link #getTranslucent translucent}.
     *
     * Indicates whether the Bar is partially translucent. It is only applied for touch devices.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.12
     * @deprecated As of version 1.18.6. This property has no effect since release 1.18.6 and should not be
     * used. Translucent bar may overlay an input and make it difficult to edit.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTranslucent(
      /**
       * New value for property `translucent`
       */
      bTranslucent?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Bar constructor.
   */
  export interface $BarSettings extends $ControlSettings {
    /**
     * If this flag is set to true, contentMiddle will be rendered as a HBox and layoutData can be used to allocate
     * available space.
     *
     * @deprecated As of version 1.16. replaced by `contentMiddle` aggregation. `contentMiddle` will always
     * occupy of the 100% width when no `contentLeft` and `contentRight` are being set.
     */
    enableFlexBox?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether the Bar is partially translucent. It is only applied for touch devices.
     *
     * @since 1.12
     * @deprecated As of version 1.18.6. This property has no effect since release 1.18.6 and should not be
     * used. Translucent bar may overlay an input and make it difficult to edit.
     */
    translucent?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the design of the bar. If set to auto, it becomes dependent on the place where the bar is
     * placed.
     *
     * @since 1.22
     */
    design?:
      | (BarDesign | keyof typeof BarDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.None`, the automatic title
     * alignment depending on the theme settings will be disabled. If set to `TitleAlignment.Auto`, the Title
     * will be aligned as it is set in the theme (if not set, the default value is `center`); Other possible
     * values are `TitleAlignment.Start` (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * @since 1.85
     */
    titleAlignment?:
      | (TitleAlignment | keyof typeof TitleAlignment)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Represents the left content area, usually containing a button or an app icon. If it is overlapped by
     * the right content, its content will disappear and the text will show an ellipsis.
     */
    contentLeft?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * Represents the middle content area. Controls such as label, segmented buttons or select can be placed
     * here. The content is centrally positioned if there is enough space. If the right or left content overlaps
     * the middle content, the middle content will be centered in the space between the left and the right content.
     */
    contentMiddle?:
      | Control[]
      | Control
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Represents the right content area. Controls such as action buttons or search field can be placed here.
     */
    contentRight?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledby).
     *
     * **Note:**The aria-labelledby attribute will not be rendered when there are less than two interactive
     * elements inside the Bar (for example, one Button).
     */
    ariaLabelledBy?: Array<Control | string>;
  }
}

declare module "sap/m/BarInPageEnabler" {
  import BaseObject from "sap/ui/base/Object";

  import Control from "sap/ui/core/Control";

  import { IBar } from "sap/m/library";

  import Metadata from "sap/ui/base/Metadata";

  import RenderManager from "sap/ui/core/RenderManager";

  /**
   * The object contains the available parameters for Bar`s context (footer, header or subheader).
   *
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export type BarContext = {
    contextClass?: string;

    internalAriaLabel?: string;

    tag?: string;
  };

  /**
   * The object contains the Bar contexts inside page.
   *
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export type BarContexts = {
    footer?: BarContext;

    header?: BarContext;

    subheader?: BarContext;
  };

  /**
   * Helper Class for implementing the IBar interface. Should be created once per IBar instance.
   *
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export default class BarInPageEnabler extends BaseObject {
    /**
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    protected constructor();

    /**
     * Adds the sapMBarChildClass to a control.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    static addChildClassTo(
      /**
       * The sap.ui.core.Control to which the sapMBarChildClass will be added
       */
      oControl: Control
    ): void;
    /**
     * Creates a new subclass of class sap.m.BarInPageEnabler with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.base.Object.extend}.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, BarInPageEnabler>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.BarInPageEnabler.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): Metadata;
    /**
     * Renders the tooltip for the given control
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    static renderTooltip(
      /**
       * the RenderManager that can be used for writing to the render output buffer.
       */
      oRM: RenderManager,
      /**
       * an object representation of the control that should be rendered.
       */
      oControl: Control
    ): void;
    /**
     * Sets classes and HTML tag according to the context of the page.
     *
     * Possible contexts are header, footer, subheader.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns `this` for chaining
     */
    applyTagAndContextClassFor(
      /**
       * allowed values are header, footer, subheader.
       */
      sContext: string
    ): IBar;
    /**
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns with all available contexts.
     */
    getContext(): BarContexts;
    /**
     * Gets the HTML tag of the root domref.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns the HTML-tag
     */
    getHTMLTag(): string;
    /**
     * Determines whether the bar is sensitive to the container context.
     *
     * Implementation of the IBar interface.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns isContextSensitive
     */
    isContextSensitive(): boolean;
    /**
     * Renders the HTML for the given control, using the provided {@link sap.ui.core.RenderManager}.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    render(
      /**
       * the RenderManager that can be used for writing to the render output buffer.
       */
      oRM: RenderManager,
      /**
       * an object representation of the control that should be rendered.
       */
      oControl: Control
    ): void;
    /**
     * Sets the HTML tag of the root element.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns `this` to allow method chaining
     */
    setHTMLTag(
      /**
       * The new root element
       */
      sNewTag: string
    ): IBar;
  }
}

declare module "sap/m/Breadcrumbs" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IBreadcrumbs,
    IOverflowToolbarContent,
    IToolbarInteractiveControl,
    BreadcrumbsSeparatorStyle,
  } from "sap/m/library";

  import { IShrinkable, ID } from "sap/ui/core/library";

  import Link from "sap/m/Link";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * Enables users to navigate between items by providing a list of links to previous steps in the user's
   * navigation path. The last three steps can be accessed as links directly, while the remaining links prior
   * to them are available in a drop-down menu.
   *
   * @since 1.34
   */
  export default class Breadcrumbs
    extends Control
    implements
      IBreadcrumbs,
      IOverflowToolbarContent,
      IShrinkable,
      IToolbarInteractiveControl
  {
    __implements__sap_m_IBreadcrumbs: boolean;
    __implements__sap_m_IOverflowToolbarContent: boolean;
    __implements__sap_ui_core_IShrinkable: boolean;
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new `Breadcrumbs`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/breadcrumb/ Breadcrumbs}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $BreadcrumbsSettings
    );
    /**
     * Constructor for a new `Breadcrumbs`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/breadcrumb/ Breadcrumbs}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $BreadcrumbsSettings
    );

    /**
     * Creates a new subclass of class sap.m.Breadcrumbs with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Breadcrumbs>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Breadcrumbs.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.92
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds some link to the aggregation {@link #getLinks links}.
     *
     * @since 1.34
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addLink(
      /**
       * The link to add; if empty, nothing is inserted
       */
      oLink: Link
    ): this;
    /**
     * Destroys the currentLocation in the aggregation {@link #getCurrentLocation currentLocation}.
     *
     * @since 1.123
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCurrentLocation(): this;
    /**
     * Destroys all the links in the aggregation {@link #getLinks links}.
     *
     * @since 1.34
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyLinks(): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.92
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets content of aggregation {@link #getCurrentLocation currentLocation}.
     *
     * Link determing the current/last element in the Breadcrumbs path.
     *
     * @since 1.123
     */
    getCurrentLocation(): Link;
    /**
     * Gets current value of property {@link #getCurrentLocationText currentLocationText}.
     *
     * Determines the text of current/last element in the Breadcrumbs path.
     *
     * @since 1.34
     *
     * @returns Value of property `currentLocationText`
     */
    getCurrentLocationText(): string;
    /**
     * Gets content of aggregation {@link #getLinks links}.
     *
     * A list of all the active link elements in the Breadcrumbs control. **Note:** Enabling the property `wrapping`
     * of the link will not work since it's incompatible with the concept of the control. The other properties
     * will work, but their effect may be undesirable.
     *
     * @since 1.34
     */
    getLinks(): Link[];
    /**
     * Gets current value of property {@link #getSeparatorStyle separatorStyle}.
     *
     * Determines the visual style of the separator between the `Breadcrumbs` elements.
     *
     * Default value is `Slash`.
     *
     * @since 1.69
     *
     * @returns Value of property `separatorStyle`
     */
    getSeparatorStyle(): BreadcrumbsSeparatorStyle;
    /**
     * Checks for the provided `sap.m.Link` in the aggregation {@link #getLinks links}. and returns its index
     * if found or -1 otherwise.
     *
     * @since 1.34
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfLink(
      /**
       * The link whose index is looked for
       */
      oLink: Link
    ): int;
    /**
     * Inserts a link into the aggregation {@link #getLinks links}.
     *
     * @since 1.34
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertLink(
      /**
       * The link to insert; if empty, nothing is inserted
       */
      oLink: Link,
      /**
       * The `0`-based index the link should be inserted at; for a negative value of `iIndex`, the link is inserted
       * at position 0; for a value greater than the current size of the aggregation, the link is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.92
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all the controls from the aggregation {@link #getLinks links}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.34
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllLinks(): Link[];
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.92
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes a link from the aggregation {@link #getLinks links}.
     *
     * @since 1.34
     *
     * @returns The removed link or `null`
     */
    removeLink(
      /**
       * The link to remove or its index or id
       */
      vLink: int | string | Link
    ): Link | null;
    /**
     * Sets the aggregated {@link #getCurrentLocation currentLocation}.
     *
     * @since 1.123
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCurrentLocation(
      /**
       * The currentLocation to set
       */
      oCurrentLocation: Link
    ): this;
    /**
     * Sets a new value for property {@link #getCurrentLocationText currentLocationText}.
     *
     * Determines the text of current/last element in the Breadcrumbs path.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.34
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCurrentLocationText(
      /**
       * New value for property `currentLocationText`
       */
      sCurrentLocationText?: string
    ): this;
    /**
     * Custom setter for the `Breadcrumbs` separator style.
     *
     * @since 1.71
     *
     * @returns this
     */
    setSeparatorStyle(
      sSeparatorStyle:
        | BreadcrumbsSeparatorStyle
        | keyof typeof BreadcrumbsSeparatorStyle
    ): Breadcrumbs;
  }
  /**
   * Describes the settings that can be provided to the Breadcrumbs constructor.
   */
  export interface $BreadcrumbsSettings extends $ControlSettings {
    /**
     * Determines the text of current/last element in the Breadcrumbs path.
     *
     * @since 1.34
     */
    currentLocationText?: string | PropertyBindingInfo;

    /**
     * Determines the visual style of the separator between the `Breadcrumbs` elements.
     *
     * @since 1.69
     */
    separatorStyle?:
      | (BreadcrumbsSeparatorStyle | keyof typeof BreadcrumbsSeparatorStyle)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Link determing the current/last element in the Breadcrumbs path.
     *
     * @since 1.123
     */
    currentLocation?: Link;

    /**
     * A list of all the active link elements in the Breadcrumbs control. **Note:** Enabling the property `wrapping`
     * of the link will not work since it's incompatible with the concept of the control. The other properties
     * will work, but their effect may be undesirable.
     *
     * @since 1.34
     */
    links?: Link[] | Link | AggregationBindingInfo | `{${string}}`;

    /**
     * Association to controls / IDs which label this control (see WAI-ARIA attribute `aria-labelledby`).
     *
     * @since 1.92
     */
    ariaLabelledBy?: Array<Control | string>;
  }
}

declare module "sap/m/BusyDialog" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { ID, URI, CSSSize } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { TitleAlignment } from "sap/m/library";

  import TooltipBase from "sap/ui/core/TooltipBase";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * BusyDialog is used to indicate that the system is busy. Overview: When the busy dialog is displayed,
   * the whole application is blocked. Structure: The busy dialog can hold several elements, most of which
   * are optional.
   * 	 - `title` - A title for the dialog. By default, there is no title.
   * 	 - `text` - A text displayed above the busy animation.
   * 	 - `showCancelButton` - An optional Cancel button to stop the execution.
   * 	 - `customIcon` - An optional alternative icon to use as a busy animation.  Usage: When to use:
   *
   * 	 - The operation lasts more than one second.
   * 	 - You want to indicate loading in a page-to-page navigation (lightweight version).
   * 	 - Offer a Cancel button if you expect the process to run more than 10 seconds.
   * 	 -  If you do not show a title or text, use the {@link sap.ui.core.InvisibleText invisible text} control
   *     to provide the reason for users with assistive technologies.  When not to use:
   * 	 - The screen is not supposed to be blocked. Use a {@link sap.m.BusyIndicator} for the specific application
   *     part.
   * 	 - Do not use the title of the busy dialog. Provide a precise text describing the operation in `text`.
   */
  export default class BusyDialog extends Control {
    /**
     * Constructor for a new BusyDialog.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/busydialog Busy Dialog}
     */
    constructor(
      /**
       * Initial settings for the new control.
       */
      mSettings?: $BusyDialogSettings
    );
    /**
     * Constructor for a new BusyDialog.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/busydialog Busy Dialog}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given.
       */
      sId?: string,
      /**
       * Initial settings for the new control.
       */
      mSettings?: $BusyDialogSettings
    );

    /**
     * Creates a new subclass of class sap.m.BusyDialog with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, BusyDialog>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.BusyDialog.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:close close} event of this `sap.m.BusyDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.BusyDialog` itself.
     *
     * Fires when the busy dialog is closed. Note: the BusyDialog will not be closed by the InstanceManager.closeAllDialogs
     * method
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: BusyDialog$CloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.BusyDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:close close} event of this `sap.m.BusyDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.BusyDialog` itself.
     *
     * Fires when the busy dialog is closed. Note: the BusyDialog will not be closed by the InstanceManager.closeAllDialogs
     * method
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: BusyDialog$CloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.BusyDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Closes the BusyDialog.
     *
     *
     * @returns The modified BusyDialog.
     */
    close(
      /**
       * Indicates if the BusyDialog is closed from a user interaction.
       */
      isClosedFromUserInteraction?: boolean
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:close close} event of this `sap.m.BusyDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: BusyDialog$CloseEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:close close} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: BusyDialog$CloseEventParameters
    ): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getCancelButtonText cancelButtonText}.
     *
     * The text of the cancel button. The default text is "Cancel" (translated to the respective language).
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `cancelButtonText`
     */
    getCancelButtonText(): string;
    /**
     * Gets current value of property {@link #getCustomIcon customIcon}.
     *
     * Icon, used from the BusyIndicator. This icon is invisible in iOS platform and it is density aware. You
     * can use the density convention (@2, @1.5, etc.) to provide higher resolution image for higher density
     * screens.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `customIcon`
     */
    getCustomIcon(): URI;
    /**
     * Gets current value of property {@link #getCustomIconDensityAware customIconDensityAware}.
     *
     * If this is set to `false`, the source image will be loaded directly without attempting to fetch the density
     * perfect image for high density devices. By default, this is set to `true` but then one or more requests
     * are sent trying to get the density perfect version of the image.
     *
     * If bandwidth is the key for the application, set this value to `false`.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `customIconDensityAware`
     */
    getCustomIconDensityAware(): boolean;
    /**
     * Gets current value of property {@link #getCustomIconHeight customIconHeight}.
     *
     * Height of the provided icon with default value "44px".
     *
     * Default value is `"44px"`.
     *
     *
     * @returns Value of property `customIconHeight`
     */
    getCustomIconHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getCustomIconRotationSpeed customIconRotationSpeed}.
     *
     * Defines the rotation speed of the given image. If GIF file is used, the speed has to be set to 0. The
     * value is in milliseconds.
     *
     * Default value is `1000`.
     *
     *
     * @returns Value of property `customIconRotationSpeed`
     */
    getCustomIconRotationSpeed(): int;
    /**
     * Gets current value of property {@link #getCustomIconWidth customIconWidth}.
     *
     * Width of the provided icon with default value "44px".
     *
     * Default value is `"44px"`.
     *
     *
     * @returns Value of property `customIconWidth`
     */
    getCustomIconWidth(): CSSSize;
    /**
     * Gets the DOM reference for the BusyDialog.
     *
     *
     * @returns Dom reference.
     */
    getDomRef(): Element;
    /**
     * Gets current value of property {@link #getShowCancelButton showCancelButton}.
     *
     * Indicates if the cancel button will be rendered inside the busy dialog. The default value is set to `false`.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showCancelButton`
     */
    getShowCancelButton(): boolean;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Optional text displayed inside the dialog.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Sets the title of the BusyDialog. The default value is an empty string.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getTitleAlignment titleAlignment}.
     *
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * Default value is `Auto`.
     *
     * @since 1.72
     *
     * @returns Value of property `titleAlignment`
     */
    getTitleAlignment(): TitleAlignment;
    /**
     * Gets the tooltip of the BusyDialog.
     *
     *
     * @returns The tooltip of the BusyDialog.
     */
    getTooltip(): string | TooltipBase;
    /**
     * Opens the BusyDialog.
     *
     *
     * @returns BusyDialog reference for chaining.
     */
    open(): this;
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Shows the text for the cancel button.
     *
     *
     * @returns The modified BusyDialog.
     */
    setCancelButtonText(
      /**
       * Text for the cancel button.
       */
      sText: string
    ): this;
    /**
     * Sets custom icon.
     *
     *
     * @returns BusyDialog reference for chaining.
     */
    setCustomIcon(
      /**
       * Icon to use as a busy animation.
       */
      sIcon: URI
    ): this;
    /**
     * Sets the density of the custom icon.
     *
     *
     * @returns BusyDialog reference for chaining.
     */
    setCustomIconDensityAware(
      /**
       * Determines if the source image will be loaded directly without attempting to fetch the density for high
       * density devices.
       */
      bIsDensityAware: boolean
    ): this;
    /**
     * Sets the height of the custom icon.
     *
     *
     * @returns BusyDialog reference for chaining.
     */
    setCustomIconHeight(
      /**
       * Height of the provided icon in CSSSize.
       */
      sHeight: CSSSize
    ): this;
    /**
     * Sets the rotation speed of the custom icon.
     *
     *
     * @returns BusyDialog reference for chaining.
     */
    setCustomIconRotationSpeed(
      /**
       * Defines the rotation speed of the given image.
       */
      iSpeed: int
    ): this;
    /**
     * Sets the width of the custom icon.
     *
     *
     * @returns BusyDialog reference for chaining.
     */
    setCustomIconWidth(
      /**
       * Width of the provided icon in CSSSize.
       */
      sWidth: CSSSize
    ): this;
    /**
     * Shows the cancel button.
     *
     *
     * @returns BusyDialog reference for chaining.
     */
    setShowCancelButton(
      /**
       * Determines if the Cancel button is shown.
       */
      bIsCancelButtonShown: boolean
    ): this;
    /**
     * Sets the text for the BusyDialog.
     *
     *
     * @returns BusyDialog reference for chaining.
     */
    setText(
      /**
       * The text for the BusyDialog.
       */
      sText: string
    ): this;
    /**
     * Sets the title for the BusyDialog.
     *
     *
     * @returns BusyDialog reference for chaining.
     */
    setTitle(
      /**
       * The title for the BusyDialog.
       */
      sTitle: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitleAlignment titleAlignment}.
     *
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     * @since 1.72
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleAlignment(
      /**
       * New value for property `titleAlignment`
       */
      sTitleAlignment?: TitleAlignment | keyof typeof TitleAlignment
    ): this;
    /**
     * Sets the tooltip for the BusyDialog.
     *
     *
     * @returns BusyDialog reference for chaining.
     */
    setTooltip(
      /**
       * The tooltip for the BusyDialog.
       */
      sTooltip: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the BusyDialog constructor.
   */
  export interface $BusyDialogSettings extends $ControlSettings {
    /**
     * Optional text displayed inside the dialog.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Sets the title of the BusyDialog. The default value is an empty string.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Icon, used from the BusyIndicator. This icon is invisible in iOS platform and it is density aware. You
     * can use the density convention (@2, @1.5, etc.) to provide higher resolution image for higher density
     * screens.
     */
    customIcon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the rotation speed of the given image. If GIF file is used, the speed has to be set to 0. The
     * value is in milliseconds.
     */
    customIconRotationSpeed?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * If this is set to `false`, the source image will be loaded directly without attempting to fetch the density
     * perfect image for high density devices. By default, this is set to `true` but then one or more requests
     * are sent trying to get the density perfect version of the image.
     *
     * If bandwidth is the key for the application, set this value to `false`.
     */
    customIconDensityAware?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Width of the provided icon with default value "44px".
     */
    customIconWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Height of the provided icon with default value "44px".
     */
    customIconHeight?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * The text of the cancel button. The default text is "Cancel" (translated to the respective language).
     */
    cancelButtonText?: string | PropertyBindingInfo;

    /**
     * Indicates if the cancel button will be rendered inside the busy dialog. The default value is set to `false`.
     */
    showCancelButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * @since 1.72
     */
    titleAlignment?:
      | (TitleAlignment | keyof typeof TitleAlignment)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Association to controls / IDs which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Fires when the busy dialog is closed. Note: the BusyDialog will not be closed by the InstanceManager.closeAllDialogs
     * method
     */
    close?: (oEvent: BusyDialog$CloseEvent) => void;
  }

  /**
   * Parameters of the BusyDialog#close event.
   */
  export interface BusyDialog$CloseEventParameters {
    /**
     * Indicates if the close events are triggered by a user, pressing a cancel button or because the operation
     * was terminated. This parameter is set to true if the close event is fired by user interaction.
     */
    cancelPressed?: boolean;
  }

  /**
   * Event object of the BusyDialog#close event.
   */
  export type BusyDialog$CloseEvent = Event<
    BusyDialog$CloseEventParameters,
    BusyDialog
  >;
}

declare module "sap/m/BusyIndicator" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { ID, URI, CSSSize, TextDirection } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Informs the user about an ongoing operation. Overview: The busy indicator implies that an action is taking
   * place within a single control. You can set the size of the icon, the text, but also define a custom icon
   * to be used instead. Usage: When to use:
   * 	 - The user needs to be able to cancel the operation.
   * 	 - Only part of the application or a particular control is affected.  When not to use:
   * 	 - The operation takes less than one second.
   * 	 - You need to block the screen and prevent the user from starting another activity. In this case, use
   *     the {@link sap.m.BusyDialog busy dialog}.
   * 	 - Do not change the mouse cursor to indicate the ongoing operation.
   * 	 - Do not show multiple busy indicators at once
   */
  export default class BusyIndicator extends Control {
    /**
     * Constructor for a new BusyIndicator.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/busy-indicator/ Busy Indicator}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $BusyIndicatorSettings
    );
    /**
     * Constructor for a new BusyIndicator.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/busy-indicator/ Busy Indicator}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $BusyIndicatorSettings
    );

    /**
     * Creates a new subclass of class sap.m.BusyIndicator with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, BusyIndicator>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.BusyIndicator.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getCustomIcon customIcon}.
     *
     * Icon URL if an icon is used as the busy indicator.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `customIcon`
     */
    getCustomIcon(): URI;
    /**
     * Gets current value of property {@link #getCustomIconDensityAware customIconDensityAware}.
     *
     * If this is set to false, the src image will be loaded directly without attempting to fetch the density
     * perfect image for high density device. By default, this is set to true but then one or more requests
     * are sent to the server, trying to get the density perfect version of the specified image. If bandwidth
     * is the key for the application, set this value to false.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `customIconDensityAware`
     */
    getCustomIconDensityAware(): boolean;
    /**
     * Gets current value of property {@link #getCustomIconHeight customIconHeight}.
     *
     * Height of the provided icon. By default 44px are used.
     *
     * Default value is `"44px"`.
     *
     *
     * @returns Value of property `customIconHeight`
     */
    getCustomIconHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getCustomIconRotationSpeed customIconRotationSpeed}.
     *
     * Defines the rotation speed of the given image. If a .gif is used, the speed has to be set to 0. The unit
     * is in ms. **Note:** Values are considered valid when greater than or equal to 0. If invalid value is
     * provided the speed defaults to 0.
     *
     * Default value is `1000`.
     *
     *
     * @returns Value of property `customIconRotationSpeed`
     */
    getCustomIconRotationSpeed(): int;
    /**
     * Gets current value of property {@link #getCustomIconWidth customIconWidth}.
     *
     * Width of the provided icon. By default 44px are used.
     *
     * Default value is `"44px"`.
     *
     *
     * @returns Value of property `customIconWidth`
     */
    getCustomIconWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getDesign design}.
     *
     * Setting this property will not have any effect on the appearance of the BusyIndicator in versions greater
     * than or equal to 1.32.1
     *
     * Default value is `"auto"`.
     *
     * @deprecated As of version 1.32.1. the concept has been discarded.
     *
     * @returns Value of property `design`
     */
    getDesign(): string;
    /**
     * Gets current value of property {@link #getSize size}.
     *
     * Defines the size of the busy indicator. The animation consists of three circles, each of which will be
     * this size. Therefore the total width of the control amounts to three times the given size.
     *
     * Default value is `"1rem"`.
     *
     *
     * @returns Value of property `size`
     */
    getSize(): CSSSize;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Defines text to be displayed below the busy indicator. It can be used to inform the user of the current
     * operation.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * Options for the text direction are RTL and LTR. Alternatively, the control can inherit the text direction
     * from its parent container.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getCustomIcon customIcon}.
     *
     * Icon URL if an icon is used as the busy indicator.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomIcon(
      /**
       * New value for property `customIcon`
       */
      sCustomIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getCustomIconDensityAware customIconDensityAware}.
     *
     * If this is set to false, the src image will be loaded directly without attempting to fetch the density
     * perfect image for high density device. By default, this is set to true but then one or more requests
     * are sent to the server, trying to get the density perfect version of the specified image. If bandwidth
     * is the key for the application, set this value to false.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomIconDensityAware(
      /**
       * New value for property `customIconDensityAware`
       */
      bCustomIconDensityAware?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getCustomIconHeight customIconHeight}.
     *
     * Height of the provided icon. By default 44px are used.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"44px"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomIconHeight(
      /**
       * New value for property `customIconHeight`
       */
      sCustomIconHeight?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getCustomIconRotationSpeed customIconRotationSpeed}.
     *
     * Defines the rotation speed of the given image. If a .gif is used, the speed has to be set to 0. The unit
     * is in ms. **Note:** Values are considered valid when greater than or equal to 0. If invalid value is
     * provided the speed defaults to 0.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `1000`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomIconRotationSpeed(
      /**
       * New value for property `customIconRotationSpeed`
       */
      iCustomIconRotationSpeed?: int
    ): this;
    /**
     * Sets a new value for property {@link #getCustomIconWidth customIconWidth}.
     *
     * Width of the provided icon. By default 44px are used.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"44px"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomIconWidth(
      /**
       * New value for property `customIconWidth`
       */
      sCustomIconWidth?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getDesign design}.
     *
     * Setting this property will not have any effect on the appearance of the BusyIndicator in versions greater
     * than or equal to 1.32.1
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"auto"`.
     *
     * @deprecated As of version 1.32.1. the concept has been discarded.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDesign(
      /**
       * New value for property `design`
       */
      sDesign?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSize size}.
     *
     * Defines the size of the busy indicator. The animation consists of three circles, each of which will be
     * this size. Therefore the total width of the control amounts to three times the given size.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"1rem"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSize(
      /**
       * New value for property `size`
       */
      sSize?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Defines text to be displayed below the busy indicator. It can be used to inform the user of the current
     * operation.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * Options for the text direction are RTL and LTR. Alternatively, the control can inherit the text direction
     * from its parent container.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
  }
  /**
   * Describes the settings that can be provided to the BusyIndicator constructor.
   */
  export interface $BusyIndicatorSettings extends $ControlSettings {
    /**
     * Defines text to be displayed below the busy indicator. It can be used to inform the user of the current
     * operation.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Options for the text direction are RTL and LTR. Alternatively, the control can inherit the text direction
     * from its parent container.
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Icon URL if an icon is used as the busy indicator.
     */
    customIcon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the rotation speed of the given image. If a .gif is used, the speed has to be set to 0. The unit
     * is in ms. **Note:** Values are considered valid when greater than or equal to 0. If invalid value is
     * provided the speed defaults to 0.
     */
    customIconRotationSpeed?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * If this is set to false, the src image will be loaded directly without attempting to fetch the density
     * perfect image for high density device. By default, this is set to true but then one or more requests
     * are sent to the server, trying to get the density perfect version of the specified image. If bandwidth
     * is the key for the application, set this value to false.
     */
    customIconDensityAware?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Width of the provided icon. By default 44px are used.
     */
    customIconWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Height of the provided icon. By default 44px are used.
     */
    customIconHeight?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the size of the busy indicator. The animation consists of three circles, each of which will be
     * this size. Therefore the total width of the control amounts to three times the given size.
     */
    size?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Setting this property will not have any effect on the appearance of the BusyIndicator in versions greater
     * than or equal to 1.32.1
     *
     * @deprecated As of version 1.32.1. the concept has been discarded.
     */
    design?: string | PropertyBindingInfo;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledby).
     *
     * @since 1.27.0
     */
    ariaLabelledBy?: Array<Control | string>;
  }
}

declare module "sap/m/Button" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IFormContent,
    IAccessKeySupport,
    ID,
    AccessibilityInfo,
    URI,
    aria,
    TextDirection,
    CSSSize,
  } from "sap/ui/core/library";

  import {
    IToolbarInteractiveControl,
    ButtonAccessibleRole,
    BadgeStyle,
    ButtonType,
  } from "sap/m/library";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Enables users to trigger actions.
   *
   * Overview:
   *
   * The user triggers an action by clicking or tapping the `Button` or by pressing certain keyboard keys,
   * such as Enter.
   *
   * Usage:
   *
   * For the `Button` UI, you can define text, icon, or both. You can also specify whether the text or the
   * icon is displayed first.
   *
   * You can choose from a set of predefined {@link sap.m.ButtonType ButtonTypes} that offer different styling
   * to correspond to the triggered action.
   *
   * You can set the `Button` as enabled or disabled. An enabled `Button` can be pressed by clicking or tapping
   * it and it changes its style to provide visual feedback to the user that it is pressed or hovered over
   * with the mouse cursor. A disabled `Button` appears inactive and cannot be pressed.
   */
  export default class Button
    extends Control
    implements IFormContent, IAccessKeySupport, IToolbarInteractiveControl
  {
    __implements__sap_ui_core_IFormContent: boolean;
    __implements__sap_ui_core_IAccessKeySupport: boolean;
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new `Button`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/button/ Button}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ButtonSettings
    );
    /**
     * Constructor for a new `Button`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/button/ Button}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ButtonSettings
    );

    /**
     * Creates a new subclass of class sap.m.Button with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Button>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Button.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.Button`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Button` itself.
     *
     * Fired when the user clicks or taps on the control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Button` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.Button`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Button` itself.
     *
     * Fired when the user clicks or taps on the control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Button` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tap tap} event of this `sap.m.Button`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Button` itself.
     *
     * Fired when the user taps the control.
     *
     * @deprecated As of version 1.20. replaced by `press` event
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTap(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Button` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tap tap} event of this `sap.m.Button`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Button` itself.
     *
     * Fired when the user taps the control.
     *
     * @deprecated As of version 1.20. replaced by `press` event
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTap(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Button` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.Button`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:tap tap} event of this `sap.m.Button`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @deprecated As of version 1.20. replaced by `press` event
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachTap(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:tap tap} to attached listeners.
     *
     * @deprecated As of version 1.20. replaced by `press` event
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireTap(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Current accessibility state of the control
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Gets current value of property {@link #getAccessibleRole accessibleRole}.
     *
     * Describes the accessibility role of the button:
     * 	`ButtonAccessibleRole.Default` - The accessibility semantics is derived from the button tag and no role
     * attribute is rendered. `ButtonAccessibleRole.Link` - The accessibility semantics is derived from
     * a custom role attribute with "link" value.
     *
     * NOTE: Use link role only with a press handler, which performs a navigation. In all other scenarios the
     * default button semantics is recommended.
     *
     * Default value is `Default`.
     *
     * @since 1.114.0
     *
     * @returns Value of property `accessibleRole`
     */
    getAccessibleRole(): ButtonAccessibleRole;
    /**
     * Gets current value of property {@link #getActiveIcon activeIcon}.
     *
     * The source property of an alternative icon for the active (depressed) state of the button. Both active
     * and default icon properties should be defined and have the same type: image or icon font. If the `icon`
     * property is not set or has a different type, the active icon is not displayed.
     *
     *
     * @returns Value of property `activeIcon`
     */
    getActiveIcon(): URI;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Gets current value of property {@link #getAriaHasPopup ariaHasPopup}.
     *
     * Specifies the value of the `aria-haspopup` attribute
     *
     * If the value is `None`, the attribute will not be rendered. Otherwise it will be rendered with the selected
     * value.
     *
     * NOTE: Use this property only when a button is related to a popover/popup. The value needs to be equal
     * to the main/root role of the popup - e.g. dialog, menu or list (examples: if you have dialog -> dialog,
     * if you have menu -> menu; if you have list -> list; if you have dialog containing a list -> dialog).
     * Do not use it, if you open a standard sap.m.Dialog, MessageBox or other type of dialogs displayed as
     * on overlay over the application.
     *
     * Default value is `None`.
     *
     * @since 1.84.0
     *
     * @returns Value of property `ariaHasPopup`
     */
    getAriaHasPopup(): aria.HasPopup;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getBadgeStyle badgeStyle}.
     *
     * Determines the style in which the badge notification will be represented:
     * 	 - `BadgeStyle.Default` Use for badges that contain numbers
     * 	 - `BadgeStyle.Attention` This badge is rendered as a single dot designed to capture user attention
     *
     *
     * Default value is `Default`.
     *
     * @since 1.132.0
     *
     * @returns Value of property `badgeStyle`
     */
    getBadgeStyle(): BadgeStyle;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Determines whether the `Button` is enabled (default is set to `true`). A disabled `Button` has different
     * colors depending on the {@link sap.m.ButtonType ButtonType}.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Defines the icon to be displayed as graphical element within the `Button`. It can be an image or an icon
     * from the icon font.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getIconDensityAware iconDensityAware}.
     *
     * By default, this is set to true but then one or more requests are sent trying to get the density perfect
     * version of image if this version of image doesn't exist on the server.
     *
     * If only one version of image is provided, set this value to false to avoid the attempt of fetching density
     * perfect image.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `iconDensityAware`
     */
    getIconDensityAware(): boolean;
    /**
     * Gets current value of property {@link #getIconFirst iconFirst}.
     *
     * Determines whether the icon is displayed before the text.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `iconFirst`
     */
    getIconFirst(): boolean;
    /**
     * Defines to which DOM reference the Popup should be docked
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns the DOM reference that Popup should dock to
     */
    getPopupAnchorDomRef(): Element;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Determines the text of the `Button`.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * Specifies the element's text directionality with enumerated options. By default, the control inherits
     * text direction from the DOM.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getType type}.
     *
     * Defines the `Button` type.
     *
     * Default value is `Default`.
     *
     *
     * @returns Value of property `type`
     */
    getType(): ButtonType;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Defines the `Button` width.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getAccessibleRole accessibleRole}.
     *
     * Describes the accessibility role of the button:
     * 	`ButtonAccessibleRole.Default` - The accessibility semantics is derived from the button tag and no role
     * attribute is rendered. `ButtonAccessibleRole.Link` - The accessibility semantics is derived from
     * a custom role attribute with "link" value.
     *
     * NOTE: Use link role only with a press handler, which performs a navigation. In all other scenarios the
     * default button semantics is recommended.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Default`.
     *
     * @since 1.114.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAccessibleRole(
      /**
       * New value for property `accessibleRole`
       */
      sAccessibleRole?: ButtonAccessibleRole | keyof typeof ButtonAccessibleRole
    ): this;
    /**
     * Sets a new value for property {@link #getActiveIcon activeIcon}.
     *
     * The source property of an alternative icon for the active (depressed) state of the button. Both active
     * and default icon properties should be defined and have the same type: image or icon font. If the `icon`
     * property is not set or has a different type, the active icon is not displayed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setActiveIcon(
      /**
       * New value for property `activeIcon`
       */
      sActiveIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getAriaHasPopup ariaHasPopup}.
     *
     * Specifies the value of the `aria-haspopup` attribute
     *
     * If the value is `None`, the attribute will not be rendered. Otherwise it will be rendered with the selected
     * value.
     *
     * NOTE: Use this property only when a button is related to a popover/popup. The value needs to be equal
     * to the main/root role of the popup - e.g. dialog, menu or list (examples: if you have dialog -> dialog,
     * if you have menu -> menu; if you have list -> list; if you have dialog containing a list -> dialog).
     * Do not use it, if you open a standard sap.m.Dialog, MessageBox or other type of dialogs displayed as
     * on overlay over the application.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     * @since 1.84.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAriaHasPopup(
      /**
       * New value for property `ariaHasPopup`
       */
      sAriaHasPopup?: aria.HasPopup | keyof typeof aria.HasPopup
    ): this;
    /**
     * Badge maximum value setter - called when someone wants to change the value above which the badge value
     * is displayed with + after the value (ex. 999+)
     *
     *
     * @returns this to allow method chaining
     */
    setBadgeMaxValue(
      /**
       * maximum visible value of the badge (not greater than maximum Badge value - 9999)
       */
      iMax: number
    ): this;
    /**
     * Badge minimum value setter - called when someone wants to change the value below which the badge is hidden.
     *
     *
     * @returns this to allow method chaining
     */
    setBadgeMinValue(
      /**
       * minimum visible value of the badge (not less than minimum Badge value - 1)
       */
      iMin: number
    ): this;
    /**
     * Sets a new value for property {@link #getBadgeStyle badgeStyle}.
     *
     * Determines the style in which the badge notification will be represented:
     * 	 - `BadgeStyle.Default` Use for badges that contain numbers
     * 	 - `BadgeStyle.Attention` This badge is rendered as a single dot designed to capture user attention
     *
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Default`.
     *
     * @since 1.132.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBadgeStyle(
      /**
       * New value for property `badgeStyle`
       */
      sBadgeStyle?: BadgeStyle | keyof typeof BadgeStyle
    ): this;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Determines whether the `Button` is enabled (default is set to `true`). A disabled `Button` has different
     * colors depending on the {@link sap.m.ButtonType ButtonType}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Defines the icon to be displayed as graphical element within the `Button`. It can be an image or an icon
     * from the icon font.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getIconDensityAware iconDensityAware}.
     *
     * By default, this is set to true but then one or more requests are sent trying to get the density perfect
     * version of image if this version of image doesn't exist on the server.
     *
     * If only one version of image is provided, set this value to false to avoid the attempt of fetching density
     * perfect image.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconDensityAware(
      /**
       * New value for property `iconDensityAware`
       */
      bIconDensityAware?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIconFirst iconFirst}.
     *
     * Determines whether the icon is displayed before the text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconFirst(
      /**
       * New value for property `iconFirst`
       */
      bIconFirst?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Determines the text of the `Button`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * Specifies the element's text directionality with enumerated options. By default, the control inherits
     * text direction from the DOM.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getType type}.
     *
     * Defines the `Button` type.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Default`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setType(
      /**
       * New value for property `type`
       */
      sType?: ButtonType | keyof typeof ButtonType
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Defines the `Button` width.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Button constructor.
   */
  export interface $ButtonSettings extends $ControlSettings {
    /**
     * Determines the text of the `Button`.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Defines the `Button` type.
     */
    type?:
      | (ButtonType | keyof typeof ButtonType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the `Button` width.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the `Button` is enabled (default is set to `true`). A disabled `Button` has different
     * colors depending on the {@link sap.m.ButtonType ButtonType}.
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the icon to be displayed as graphical element within the `Button`. It can be an image or an icon
     * from the icon font.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the icon is displayed before the text.
     */
    iconFirst?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The source property of an alternative icon for the active (depressed) state of the button. Both active
     * and default icon properties should be defined and have the same type: image or icon font. If the `icon`
     * property is not set or has a different type, the active icon is not displayed.
     */
    activeIcon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * By default, this is set to true but then one or more requests are sent trying to get the density perfect
     * version of image if this version of image doesn't exist on the server.
     *
     * If only one version of image is provided, set this value to false to avoid the attempt of fetching density
     * perfect image.
     */
    iconDensityAware?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the element's text directionality with enumerated options. By default, the control inherits
     * text direction from the DOM.
     *
     * @since 1.28.0
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies the value of the `aria-haspopup` attribute
     *
     * If the value is `None`, the attribute will not be rendered. Otherwise it will be rendered with the selected
     * value.
     *
     * NOTE: Use this property only when a button is related to a popover/popup. The value needs to be equal
     * to the main/root role of the popup - e.g. dialog, menu or list (examples: if you have dialog -> dialog,
     * if you have menu -> menu; if you have list -> list; if you have dialog containing a list -> dialog).
     * Do not use it, if you open a standard sap.m.Dialog, MessageBox or other type of dialogs displayed as
     * on overlay over the application.
     *
     * @since 1.84.0
     */
    ariaHasPopup?:
      | (aria.HasPopup | keyof typeof aria.HasPopup)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Describes the accessibility role of the button:
     * 	`ButtonAccessibleRole.Default` - The accessibility semantics is derived from the button tag and no role
     * attribute is rendered. `ButtonAccessibleRole.Link` - The accessibility semantics is derived from
     * a custom role attribute with "link" value.
     *
     * NOTE: Use link role only with a press handler, which performs a navigation. In all other scenarios the
     * default button semantics is recommended.
     *
     * @since 1.114.0
     */
    accessibleRole?:
      | (ButtonAccessibleRole | keyof typeof ButtonAccessibleRole)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the style in which the badge notification will be represented:
     * 	 - `BadgeStyle.Default` Use for badges that contain numbers
     * 	 - `BadgeStyle.Attention` This badge is rendered as a single dot designed to capture user attention
     *
     *
     * @since 1.132.0
     */
    badgeStyle?:
      | (BadgeStyle | keyof typeof BadgeStyle)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Association to controls / ids which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Fired when the user taps the control.
     *
     * @deprecated As of version 1.20. replaced by `press` event
     */
    tap?: (oEvent: Event) => void;

    /**
     * Fired when the user clicks or taps on the control.
     */
    press?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the Button#press event.
   */
  export interface Button$PressEventParameters {}

  /**
   * Event object of the Button#press event.
   */
  export type Button$PressEvent = Event<Button$PressEventParameters, Button>;

  /**
   * Parameters of the Button#tap event.
   *
   * @deprecated As of version 1.20. replaced by `press` event
   */
  export interface Button$TapEventParameters {}

  /**
   * Event object of the Button#tap event.
   *
   * @deprecated As of version 1.20. replaced by `press` event
   */
  export type Button$TapEvent = Event<Button$TapEventParameters, Button>;
}

declare module "sap/m/Carousel" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { ID, CSSSize } from "sap/ui/core/library";

  import {
    CarouselArrowsPlacement,
    BackgroundDesign,
    BorderDesign,
    CarouselPageIndicatorPlacementType,
  } from "sap/m/library";

  import CarouselLayout from "sap/m/CarouselLayout";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * The carousel allows the user to browse through a set of items by swiping right or left. Overview: The
   * control is mostly used for showing a gallery of images, but can hold any sap.m control. Structure: The
   * carousel consists of a the following elements:
   * 	 - Content area - displays the different items.
   * 	 - Navigation - arrows to the left and right for switching between items.
   * 	 - (optional) Paging - indicator at the bottom to show the current position in the set.  The paging
   *     indicator can be configured as follows:
   * 	 - `showPageIndicator` - determines if the indicator is displayed.
   * 	 - If the pages are less than 9, the page indicator is represented with bullets.
   * 	 - If the pages are 9 or more, the page indicator is numeric.
   * 	 - `pageIndicatorPlacement` - determines where the indicator is located. Default (`sap.m.CarouselPageIndicatorPlacementType.Bottom`)
   *     - below the content.  Additionally, you can also change the location of the navigation arrows. By
   *     setting `arrowsPlacement` to `sap.m.CarouselArrowsPlacement.PageIndicator`, the arrows will be located
   *     at the bottom by the paging indicator. Note: When the content is of type `sap.m.Image` add "Image" text
   *     at the end of the `"alt"` description in order to provide accessibility info for the UI element. Usage:
   *      When to use:
   * 	 - The items you want to display are very different from each other.
   * 	 - You want to display the items one after the other.   When not to use:
   * 	 - The items you want to display need to be visible at the same time.
   * 	 - The items you want to display are uniform and very similar  Responsive Behavior:
   * 	 - On touch devices, navigation is performed with swipe gestures (swipe right or swipe left) or with
   *     the navigation arrows.
   * 	 - On desktop, navigation is done with the navigation arrows.
   * 	 - The paging indicator (when activated) is visible on each form factor.
   */
  export default class Carousel extends Control {
    /**
     * Constructor for a new Carousel.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/carousel/ Carousel}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $CarouselSettings
    );
    /**
     * Constructor for a new Carousel.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/carousel/ Carousel}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $CarouselSettings
    );

    /**
     * Creates a new subclass of class sap.m.Carousel with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Carousel>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Carousel.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.125
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds some page to the aggregation {@link #getPages pages}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addPage(
      /**
       * The page to add; if empty, nothing is inserted
       */
      oPage: Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforePageChanged beforePageChanged} event of
     * this `sap.m.Carousel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Carousel` itself.
     *
     * This event is fired before a carousel swipe has been completed. It is triggered both by physical swipe
     * events and through API carousel manipulations such as calling 'next', 'previous' or 'setActivePage' functions.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforePageChanged(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Carousel$BeforePageChangedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Carousel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforePageChanged beforePageChanged} event of
     * this `sap.m.Carousel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Carousel` itself.
     *
     * This event is fired before a carousel swipe has been completed. It is triggered both by physical swipe
     * events and through API carousel manipulations such as calling 'next', 'previous' or 'setActivePage' functions.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforePageChanged(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Carousel$BeforePageChangedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Carousel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:loadPage loadPage} event of this `sap.m.Carousel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Carousel` itself.
     *
     * Carousel requires a new page to be loaded. This event may be used to fill the content of that page
     *
     * @deprecated As of version 1.18.7. Since 1.18.7 pages are no longer loaded or unloaded
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLoadPage(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Carousel$LoadPageEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Carousel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:loadPage loadPage} event of this `sap.m.Carousel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Carousel` itself.
     *
     * Carousel requires a new page to be loaded. This event may be used to fill the content of that page
     *
     * @deprecated As of version 1.18.7. Since 1.18.7 pages are no longer loaded or unloaded
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLoadPage(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Carousel$LoadPageEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Carousel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:pageChanged pageChanged} event of this `sap.m.Carousel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Carousel` itself.
     *
     * This event is fired after a carousel swipe has been completed. It is triggered both by physical swipe
     * events and through API carousel manipulations such as calling 'next', 'previous' or 'setActivePage' functions.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPageChanged(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Carousel$PageChangedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Carousel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:pageChanged pageChanged} event of this `sap.m.Carousel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Carousel` itself.
     *
     * This event is fired after a carousel swipe has been completed. It is triggered both by physical swipe
     * events and through API carousel manipulations such as calling 'next', 'previous' or 'setActivePage' functions.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPageChanged(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Carousel$PageChangedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Carousel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:unloadPage unloadPage} event of this `sap.m.Carousel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Carousel` itself.
     *
     * Carousel does not display a page any longer and unloads it. This event may be used to clean up the content
     * of that page.
     *
     * @deprecated As of version 1.18.7. Since 1.18.7 pages are no longer loaded or unloaded
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUnloadPage(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Carousel$UnloadPageEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Carousel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:unloadPage unloadPage} event of this `sap.m.Carousel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Carousel` itself.
     *
     * Carousel does not display a page any longer and unloads it. This event may be used to clean up the content
     * of that page.
     *
     * @deprecated As of version 1.18.7. Since 1.18.7 pages are no longer loaded or unloaded
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUnloadPage(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Carousel$UnloadPageEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Carousel` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys the customLayout in the aggregation {@link #getCustomLayout customLayout}.
     *
     * @since 1.62
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCustomLayout(): this;
    /**
     * Destroys all the pages in the aggregation {@link #getPages pages}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyPages(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforePageChanged beforePageChanged} event
     * of this `sap.m.Carousel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforePageChanged(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Carousel$BeforePageChangedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:loadPage loadPage} event of this `sap.m.Carousel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @deprecated As of version 1.18.7. Since 1.18.7 pages are no longer loaded or unloaded
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLoadPage(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Carousel$LoadPageEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:pageChanged pageChanged} event of this `sap.m.Carousel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPageChanged(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Carousel$PageChangedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:unloadPage unloadPage} event of this `sap.m.Carousel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @deprecated As of version 1.18.7. Since 1.18.7 pages are no longer loaded or unloaded
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUnloadPage(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Carousel$UnloadPageEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:beforePageChanged beforePageChanged} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforePageChanged(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Carousel$BeforePageChangedEventParameters
    ): this;
    /**
     * Fires event {@link #event:loadPage loadPage} to attached listeners.
     *
     * @deprecated As of version 1.18.7. Since 1.18.7 pages are no longer loaded or unloaded
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLoadPage(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Carousel$LoadPageEventParameters
    ): this;
    /**
     * Fires event {@link #event:pageChanged pageChanged} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePageChanged(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Carousel$PageChangedEventParameters
    ): this;
    /**
     * Fires event {@link #event:unloadPage unloadPage} to attached listeners.
     *
     * @deprecated As of version 1.18.7. Since 1.18.7 pages are no longer loaded or unloaded
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUnloadPage(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Carousel$UnloadPageEventParameters
    ): this;
    /**
     * ID of the element which is the current target of the association {@link #getActivePage activePage}, or
     * `null`.
     */
    getActivePage(): ID | null;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.125
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getArrowsPlacement arrowsPlacement}.
     *
     * Defines where the carousel's arrows are placed. Default is `sap.m.CarouselArrowsPlacement.Content` used
     * to place the arrows on the sides of the carousel. Alternatively `sap.m.CarouselArrowsPlacement.PageIndicator`
     * can be used to place the arrows on the sides of the page indicator.
     *
     * Default value is `Content`.
     *
     *
     * @returns Value of property `arrowsPlacement`
     */
    getArrowsPlacement(): CarouselArrowsPlacement;
    /**
     * Gets current value of property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Defines the carousel's background design. Default is `sap.m.BackgroundDesign.Translucent`.
     *
     * Default value is `Translucent`.
     *
     * @since 1.110
     *
     * @returns Value of property `backgroundDesign`
     */
    getBackgroundDesign(): BackgroundDesign;
    /**
     * Gets content of aggregation {@link #getCustomLayout customLayout}.
     *
     * Defines how many pages are displayed in the visible area of the `Carousel` control.
     *
     * **Note:** When this property is used, the `loop` property is ignored.
     *
     * @since 1.62
     */
    getCustomLayout(): CarouselLayout;
    /**
     * Gets current value of property {@link #getHeight height}.
     *
     * The height of the carousel. Note that when a percentage value is used, the height of the surrounding
     * container must be defined.
     *
     * Default value is `'100%'`.
     *
     *
     * @returns Value of property `height`
     */
    getHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getLoop loop}.
     *
     * Defines whether the carousel should loop, i.e show the first page after the last page is reached and
     * vice versa.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `loop`
     */
    getLoop(): boolean;
    /**
     * Gets current value of property {@link #getPageIndicatorBackgroundDesign pageIndicatorBackgroundDesign}.
     *
     * Defines the carousel page indicator background design. Default is `sap.m.BackgroundDesign.Solid`.
     *
     * Default value is `Solid`.
     *
     * @since 1.115
     *
     * @returns Value of property `pageIndicatorBackgroundDesign`
     */
    getPageIndicatorBackgroundDesign(): BackgroundDesign;
    /**
     * Gets current value of property {@link #getPageIndicatorBorderDesign pageIndicatorBorderDesign}.
     *
     * Defines the carousel page indicator border design. Default is `sap.m.BorderDesign.Solid`.
     *
     * Default value is `Solid`.
     *
     * @since 1.115
     *
     * @returns Value of property `pageIndicatorBorderDesign`
     */
    getPageIndicatorBorderDesign(): BorderDesign;
    /**
     * Gets current value of property {@link #getPageIndicatorPlacement pageIndicatorPlacement}.
     *
     * Defines where the carousel's page indicator is displayed. Possible values are sap.m.CarouselPageIndicatorPlacementType.Top,
     * sap.m.CarouselPageIndicatorPlacementType.Bottom, CarouselPageIndicatorPlacementType.OverContentTop and
     * CarouselPageIndicatorPlacementType.OverContentBottom.
     *
     * **Note:** When the page indicator is placed over the carousel's content (values "OverContentBottom" and
     * "OverContentTop"), the properties `pageIndicatorBackgroundDesign` and `pageIndicatorBorderDesign` will
     * not take effect.
     *
     * **Note:** We recommend using a page indicator placed over the carousel's content (values "OverContentBottom"
     * and "OverContentTop") only if the content consists of images.
     *
     * Default value is `Bottom`.
     *
     *
     * @returns Value of property `pageIndicatorPlacement`
     */
    getPageIndicatorPlacement(): CarouselPageIndicatorPlacementType;
    /**
     * Gets content of aggregation {@link #getPages pages}.
     *
     * The content which the carousel displays.
     */
    getPages(): Control[];
    /**
     * Gets current value of property {@link #getShowBusyIndicator showBusyIndicator}.
     *
     * Show or hide busy indicator in the carousel when loading pages after swipe.
     *
     * Default value is `true`.
     *
     * @deprecated As of version 1.18.7. Since 1.18.7 pages are no longer loaded or unloaded. Therefore busy
     * indicator is not necessary any longer.
     *
     * @returns Value of property `showBusyIndicator`
     */
    getShowBusyIndicator(): boolean;
    /**
     * Gets current value of property {@link #getShowPageIndicator showPageIndicator}.
     *
     * Show or hide carousel's page indicator.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showPageIndicator`
     */
    getShowPageIndicator(): boolean;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * The width of the carousel. Note that when a percentage value is used, the height of the surrounding container
     * must be defined.
     *
     * Default value is `'100%'`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getPages pages}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfPage(
      /**
       * The page whose index is looked for
       */
      oPage: Control
    ): int;
    /**
     * Inserts a page into the aggregation {@link #getPages pages}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertPage(
      /**
       * The page to insert; if empty, nothing is inserted
       */
      oPage: Control,
      /**
       * The `0`-based index the page should be inserted at; for a negative value of `iIndex`, the page is inserted
       * at position 0; for a value greater than the current size of the aggregation, the page is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Call this method to display the next page (corresponds to a swipe right).
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    next(): this;
    /**
     * Call this method to display the previous page (corresponds to a swipe left).
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    previous(): this;
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.125
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all the controls from the aggregation {@link #getPages pages}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllPages(): Control[];
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.125
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes a page from the aggregation {@link #getPages pages}.
     *
     *
     * @returns The removed page or `null`
     */
    removePage(
      /**
       * The page to remove or its index or id
       */
      vPage: int | string | Control
    ): Control | null;
    /**
     * Sets the associated {@link #getActivePage activePage}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setActivePage(
      /**
       * ID of an element which becomes the new target of this activePage association; alternatively, an element
       * instance may be given
       */
      oActivePage: ID | Control
    ): this;
    /**
     * Sets a new value for property {@link #getArrowsPlacement arrowsPlacement}.
     *
     * Defines where the carousel's arrows are placed. Default is `sap.m.CarouselArrowsPlacement.Content` used
     * to place the arrows on the sides of the carousel. Alternatively `sap.m.CarouselArrowsPlacement.PageIndicator`
     * can be used to place the arrows on the sides of the page indicator.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Content`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setArrowsPlacement(
      /**
       * New value for property `arrowsPlacement`
       */
      sArrowsPlacement?:
        | CarouselArrowsPlacement
        | keyof typeof CarouselArrowsPlacement
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Defines the carousel's background design. Default is `sap.m.BackgroundDesign.Translucent`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Translucent`.
     *
     * @since 1.110
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundDesign(
      /**
       * New value for property `backgroundDesign`
       */
      sBackgroundDesign?: BackgroundDesign | keyof typeof BackgroundDesign
    ): this;
    /**
     * Sets the aggregated {@link #getCustomLayout customLayout}.
     *
     * @since 1.62
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomLayout(
      /**
       * The customLayout to set
       */
      oCustomLayout: CarouselLayout
    ): this;
    /**
     * Sets a new value for property {@link #getHeight height}.
     *
     * The height of the carousel. Note that when a percentage value is used, the height of the surrounding
     * container must be defined.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `'100%'`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeight(
      /**
       * New value for property `height`
       */
      sHeight?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getLoop loop}.
     *
     * Defines whether the carousel should loop, i.e show the first page after the last page is reached and
     * vice versa.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLoop(
      /**
       * New value for property `loop`
       */
      bLoop?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getPageIndicatorBackgroundDesign pageIndicatorBackgroundDesign}.
     *
     * Defines the carousel page indicator background design. Default is `sap.m.BackgroundDesign.Solid`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Solid`.
     *
     * @since 1.115
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPageIndicatorBackgroundDesign(
      /**
       * New value for property `pageIndicatorBackgroundDesign`
       */
      sPageIndicatorBackgroundDesign?:
        | BackgroundDesign
        | keyof typeof BackgroundDesign
    ): this;
    /**
     * Sets a new value for property {@link #getPageIndicatorBorderDesign pageIndicatorBorderDesign}.
     *
     * Defines the carousel page indicator border design. Default is `sap.m.BorderDesign.Solid`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Solid`.
     *
     * @since 1.115
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPageIndicatorBorderDesign(
      /**
       * New value for property `pageIndicatorBorderDesign`
       */
      sPageIndicatorBorderDesign?: BorderDesign | keyof typeof BorderDesign
    ): this;
    /**
     * Sets a new value for property {@link #getPageIndicatorPlacement pageIndicatorPlacement}.
     *
     * Defines where the carousel's page indicator is displayed. Possible values are sap.m.CarouselPageIndicatorPlacementType.Top,
     * sap.m.CarouselPageIndicatorPlacementType.Bottom, CarouselPageIndicatorPlacementType.OverContentTop and
     * CarouselPageIndicatorPlacementType.OverContentBottom.
     *
     * **Note:** When the page indicator is placed over the carousel's content (values "OverContentBottom" and
     * "OverContentTop"), the properties `pageIndicatorBackgroundDesign` and `pageIndicatorBorderDesign` will
     * not take effect.
     *
     * **Note:** We recommend using a page indicator placed over the carousel's content (values "OverContentBottom"
     * and "OverContentTop") only if the content consists of images.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Bottom`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPageIndicatorPlacement(
      /**
       * New value for property `pageIndicatorPlacement`
       */
      sPageIndicatorPlacement?:
        | CarouselPageIndicatorPlacementType
        | keyof typeof CarouselPageIndicatorPlacementType
    ): this;
    /**
     * Sets a new value for property {@link #getShowBusyIndicator showBusyIndicator}.
     *
     * Show or hide busy indicator in the carousel when loading pages after swipe.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @deprecated As of version 1.18.7. Since 1.18.7 pages are no longer loaded or unloaded. Therefore busy
     * indicator is not necessary any longer.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowBusyIndicator(
      /**
       * New value for property `showBusyIndicator`
       */
      bShowBusyIndicator?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowPageIndicator showPageIndicator}.
     *
     * Show or hide carousel's page indicator.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowPageIndicator(
      /**
       * New value for property `showPageIndicator`
       */
      bShowPageIndicator?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * The width of the carousel. Note that when a percentage value is used, the height of the surrounding container
     * must be defined.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `'100%'`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Carousel constructor.
   */
  export interface $CarouselSettings extends $ControlSettings {
    /**
     * The height of the carousel. Note that when a percentage value is used, the height of the surrounding
     * container must be defined.
     */
    height?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * The width of the carousel. Note that when a percentage value is used, the height of the surrounding container
     * must be defined.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether the carousel should loop, i.e show the first page after the last page is reached and
     * vice versa.
     */
    loop?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Show or hide carousel's page indicator.
     */
    showPageIndicator?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines where the carousel's page indicator is displayed. Possible values are sap.m.CarouselPageIndicatorPlacementType.Top,
     * sap.m.CarouselPageIndicatorPlacementType.Bottom, CarouselPageIndicatorPlacementType.OverContentTop and
     * CarouselPageIndicatorPlacementType.OverContentBottom.
     *
     * **Note:** When the page indicator is placed over the carousel's content (values "OverContentBottom" and
     * "OverContentTop"), the properties `pageIndicatorBackgroundDesign` and `pageIndicatorBorderDesign` will
     * not take effect.
     *
     * **Note:** We recommend using a page indicator placed over the carousel's content (values "OverContentBottom"
     * and "OverContentTop") only if the content consists of images.
     */
    pageIndicatorPlacement?:
      | (
          | CarouselPageIndicatorPlacementType
          | keyof typeof CarouselPageIndicatorPlacementType
        )
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Show or hide busy indicator in the carousel when loading pages after swipe.
     *
     * @deprecated As of version 1.18.7. Since 1.18.7 pages are no longer loaded or unloaded. Therefore busy
     * indicator is not necessary any longer.
     */
    showBusyIndicator?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines where the carousel's arrows are placed. Default is `sap.m.CarouselArrowsPlacement.Content` used
     * to place the arrows on the sides of the carousel. Alternatively `sap.m.CarouselArrowsPlacement.PageIndicator`
     * can be used to place the arrows on the sides of the page indicator.
     */
    arrowsPlacement?:
      | (CarouselArrowsPlacement | keyof typeof CarouselArrowsPlacement)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the carousel's background design. Default is `sap.m.BackgroundDesign.Translucent`.
     *
     * @since 1.110
     */
    backgroundDesign?:
      | (BackgroundDesign | keyof typeof BackgroundDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the carousel page indicator background design. Default is `sap.m.BackgroundDesign.Solid`.
     *
     * @since 1.115
     */
    pageIndicatorBackgroundDesign?:
      | (BackgroundDesign | keyof typeof BackgroundDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the carousel page indicator border design. Default is `sap.m.BorderDesign.Solid`.
     *
     * @since 1.115
     */
    pageIndicatorBorderDesign?:
      | (BorderDesign | keyof typeof BorderDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The content which the carousel displays.
     */
    pages?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * Defines how many pages are displayed in the visible area of the `Carousel` control.
     *
     * **Note:** When this property is used, the `loop` property is ignored.
     *
     * @since 1.62
     */
    customLayout?: CarouselLayout;

    /**
     * Provides getter and setter for the currently displayed page. For the setter, argument may be the control
     * itself, which must be member of the carousel's page list, or the control's id. The getter will return
     * the control id
     */
    activePage?: Control | string;

    /**
     * Association to controls / IDs which label this control (see WAI-ARIA attribute `aria-labelledby`).
     *
     * @since 1.125
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Carousel requires a new page to be loaded. This event may be used to fill the content of that page
     *
     * @deprecated As of version 1.18.7. Since 1.18.7 pages are no longer loaded or unloaded
     */
    loadPage?: (oEvent: Carousel$LoadPageEvent) => void;

    /**
     * Carousel does not display a page any longer and unloads it. This event may be used to clean up the content
     * of that page.
     *
     * @deprecated As of version 1.18.7. Since 1.18.7 pages are no longer loaded or unloaded
     */
    unloadPage?: (oEvent: Carousel$UnloadPageEvent) => void;

    /**
     * This event is fired after a carousel swipe has been completed. It is triggered both by physical swipe
     * events and through API carousel manipulations such as calling 'next', 'previous' or 'setActivePage' functions.
     */
    pageChanged?: (oEvent: Carousel$PageChangedEvent) => void;

    /**
     * This event is fired before a carousel swipe has been completed. It is triggered both by physical swipe
     * events and through API carousel manipulations such as calling 'next', 'previous' or 'setActivePage' functions.
     */
    beforePageChanged?: (oEvent: Carousel$BeforePageChangedEvent) => void;
  }

  /**
   * Parameters of the Carousel#beforePageChanged event.
   */
  export interface Carousel$BeforePageChangedEventParameters {
    /**
     * Indexes of all active pages after the page change.
     */
    activePages?: any[];
  }

  /**
   * Event object of the Carousel#beforePageChanged event.
   */
  export type Carousel$BeforePageChangedEvent = Event<
    Carousel$BeforePageChangedEventParameters,
    Carousel
  >;

  /**
   * Parameters of the Carousel#loadPage event.
   *
   * @deprecated As of version 1.18.7. Since 1.18.7 pages are no longer loaded or unloaded
   */
  export interface Carousel$LoadPageEventParameters {
    /**
     * Id of the page which will be loaded
     */
    pageId?: string;
  }

  /**
   * Event object of the Carousel#loadPage event.
   *
   * @deprecated As of version 1.18.7. Since 1.18.7 pages are no longer loaded or unloaded
   */
  export type Carousel$LoadPageEvent = Event<
    Carousel$LoadPageEventParameters,
    Carousel
  >;

  /**
   * Parameters of the Carousel#pageChanged event.
   */
  export interface Carousel$PageChangedEventParameters {
    /**
     * ID of the page which was active before the page change.
     */
    oldActivePageId?: string;

    /**
     * ID of the page which will be active after the page change.
     */
    newActivePageId?: string;

    /**
     * Indexes of all active pages after the page change.
     */
    activePages?: any[];
  }

  /**
   * Event object of the Carousel#pageChanged event.
   */
  export type Carousel$PageChangedEvent = Event<
    Carousel$PageChangedEventParameters,
    Carousel
  >;

  /**
   * Parameters of the Carousel#unloadPage event.
   *
   * @deprecated As of version 1.18.7. Since 1.18.7 pages are no longer loaded or unloaded
   */
  export interface Carousel$UnloadPageEventParameters {
    /**
     * Id of the page which will be unloaded
     */
    pageId?: string;
  }

  /**
   * Event object of the Carousel#unloadPage event.
   *
   * @deprecated As of version 1.18.7. Since 1.18.7 pages are no longer loaded or unloaded
   */
  export type Carousel$UnloadPageEvent = Event<
    Carousel$UnloadPageEventParameters,
    Carousel
  >;
}

declare module "sap/m/CarouselLayout" {
  import {
    default as ManagedObject,
    $ManagedObjectSettings,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ManagedObjectMetadata from "sap/ui/base/ManagedObjectMetadata";

  import { CarouselScrollMode } from "sap/m/library";

  /**
   * Applies a `sap.m.CarouselLayout` to a provided DOM element or Control.
   *
   * @since 1.62
   */
  export default class CarouselLayout extends ManagedObject {
    /**
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $CarouselLayoutSettings
    );
    /**
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $CarouselLayoutSettings
    );

    /**
     * Creates a new subclass of class sap.m.CarouselLayout with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.base.ManagedObject.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, CarouselLayout>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.CarouselLayout.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ManagedObjectMetadata;
    /**
     * Gets current value of property {@link #getScrollMode scrollMode}.
     *
     * Defines how the items will be scrolled through in `Carousel` control. One at a time or depending on the
     * `visiblePagesCount`
     *
     * NOTE: `visiblePagesCount` must be set a value larger than 1, to be able to use `scrollMode` with value
     * "VisiblePages"
     *
     * Default value is `SinglePage`.
     *
     * @since 1.121
     *
     * @returns Value of property `scrollMode`
     */
    getScrollMode(): CarouselScrollMode;
    /**
     * Gets current value of property {@link #getVisiblePagesCount visiblePagesCount}.
     *
     * Defines how many pages are displayed in the visible area of the `Carousel` control. Value should be a
     * positive number.
     *
     * **Note:** When this property is set to something different than the default value, the `loop` property
     * of `Carousel` is ignored.
     *
     * Default value is `1`.
     *
     *
     * @returns Value of property `visiblePagesCount`
     */
    getVisiblePagesCount(): int;
    /**
     * Sets a new value for property {@link #getScrollMode scrollMode}.
     *
     * Defines how the items will be scrolled through in `Carousel` control. One at a time or depending on the
     * `visiblePagesCount`
     *
     * NOTE: `visiblePagesCount` must be set a value larger than 1, to be able to use `scrollMode` with value
     * "VisiblePages"
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `SinglePage`.
     *
     * @since 1.121
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setScrollMode(
      /**
       * New value for property `scrollMode`
       */
      sScrollMode?: CarouselScrollMode | keyof typeof CarouselScrollMode
    ): this;
    /**
     * Sets a new value for property {@link #getVisiblePagesCount visiblePagesCount}.
     *
     * Defines how many pages are displayed in the visible area of the `Carousel` control. Value should be a
     * positive number.
     *
     * **Note:** When this property is set to something different than the default value, the `loop` property
     * of `Carousel` is ignored.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `1`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisiblePagesCount(
      /**
       * New value for property `visiblePagesCount`
       */
      iVisiblePagesCount?: int
    ): this;
  }
  /**
   * Describes the settings that can be provided to the CarouselLayout constructor.
   */
  export interface $CarouselLayoutSettings extends $ManagedObjectSettings {
    /**
     * Defines how many pages are displayed in the visible area of the `Carousel` control. Value should be a
     * positive number.
     *
     * **Note:** When this property is set to something different than the default value, the `loop` property
     * of `Carousel` is ignored.
     */
    visiblePagesCount?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines how the items will be scrolled through in `Carousel` control. One at a time or depending on the
     * `visiblePagesCount`
     *
     * NOTE: `visiblePagesCount` must be set a value larger than 1, to be able to use `scrollMode` with value
     * "VisiblePages"
     *
     * @since 1.121
     */
    scrollMode?:
      | (CarouselScrollMode | keyof typeof CarouselScrollMode)
      | PropertyBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/CheckBox" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IFormContent,
    ISemanticFormContent,
    IAccessKeySupport,
    ID,
    AccessibilityInfo,
    TextAlign,
    TextDirection,
    ValueState,
    CSSSize,
  } from "sap/ui/core/library";

  import { IToolbarInteractiveControl } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * Allows the user to set a binary value, such as true/false or yes/no for an item.
   *
   * Overview:
   *
   * The `CheckBox` control consists of a box and a label that describes its purpose. If it's checked, an
   * indicator is displayed inside the box.
   *
   * To select/deselect the `CheckBox`, the user has to click or tap the square box or its label. Clicking
   * or tapping toggles the `CheckBox` between checked and unchecked state. The `CheckBox` control only has
   * 3 states - checked, unchecked and partially selected.
   *
   * Usage:
   *
   * You can set the width of the element containing the box and the label manually with the use of the `width`
   * property. If the text exceeds the available width, it is truncated.
   *
   * **Note:** When `useEntireWidth` property is set to `true`, the value of the `width` property is applied
   * to the control as a whole (box and label). If `useEntireWidth` is set to `false`, the `width` is applied
   * to the label only.
   *
   * The touchable area for toggling the `CheckBox` ends where the text ends.
   *
   * If the width allows more space than the text requires, white space is added. The text can be positioned
   * manually in this space using the `textAlign` property.
   *
   * **Note:** Keep in mind that setting the `textAlign` property to `Right` can result in a large amount
   * of white space between the box and the text.
   *
   * You can disable the `CheckBox` by setting the `enabled` property to `false`, or use the `CheckBox` in
   * read-only mode by setting the `editable` property to false.
   *
   * **Note:** Disabled and read-only states shouldn't be used together.
   */
  export default class CheckBox
    extends Control
    implements
      IFormContent,
      ISemanticFormContent,
      IAccessKeySupport,
      IToolbarInteractiveControl
  {
    __implements__sap_ui_core_IFormContent: boolean;
    __implements__sap_ui_core_ISemanticFormContent: boolean;
    __implements__sap_ui_core_IAccessKeySupport: boolean;
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new `CheckBox`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/checkbox/ Check Box}
     */
    constructor(
      /**
       * The Initial settings for the new control
       */
      mSettings?: $CheckBoxSettings
    );
    /**
     * Constructor for a new `CheckBox`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/checkbox/ Check Box}
     */
    constructor(
      /**
       * The ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * The Initial settings for the new control
       */
      mSettings?: $CheckBoxSettings
    );

    /**
     * Creates a new subclass of class sap.m.CheckBox with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, CheckBox>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.CheckBox.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:select select} event of this `sap.m.CheckBox`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.CheckBox` itself.
     *
     * Event is triggered when the control status is changed by the user by selecting or deselecting the checkbox.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: CheckBox$SelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.CheckBox` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:select select} event of this `sap.m.CheckBox`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.CheckBox` itself.
     *
     * Event is triggered when the control status is changed by the user by selecting or deselecting the checkbox.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: CheckBox$SelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.CheckBox` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:select select} event of this `sap.m.CheckBox`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: CheckBox$SelectEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:select select} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: CheckBox$SelectEventParameters
    ): this;
    /**
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The object contains the accessibility information of `sap.m.CheckBox`
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Gets current value of property {@link #getActiveHandling activeHandling}.
     *
     * Flag to switch on activeHandling, when it is switched off, there will be no visual changes on active
     * state. Default value is 'true'
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `activeHandling`
     */
    getActiveHandling(): boolean;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getDisplayOnly displayOnly}.
     *
     * Determines whether the `CheckBox` is in display only state.
     *
     * When set to `true`, the `CheckBox` is not interactive, not editable, not focusable and not in the tab
     * chain. This setting is used for forms in review mode.
     *
     *  When the property `enabled` is set to `false` this property has no effect.
     *
     * Default value is `false`.
     *
     * @since 1.54
     *
     * @returns Value of property `displayOnly`
     */
    getDisplayOnly(): boolean;
    /**
     * Gets current value of property {@link #getEditable editable}.
     *
     * Specifies whether the user shall be allowed to edit the state of the checkbox
     *
     * Default value is `true`.
     *
     * @since 1.25
     *
     * @returns Value of property `editable`
     */
    getEditable(): boolean;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Whether the `CheckBox` is enabled.
     *
     * **Note:** Disabled `CheckBox` is not interactive and is rendered differently according to the theme.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets current value of property {@link #getName name}.
     *
     * The 'name' property to be used in the HTML code, for example for HTML forms that send data to the server
     * via submit.
     *
     *
     * @returns Value of property `name`
     */
    getName(): string;
    /**
     * Gets current value of property {@link #getPartiallySelected partiallySelected}.
     *
     * Determines whether the `CheckBox` is displayed as partially selected.
     *
     * **Note:** This property leads only to visual change of the checkbox and the state cannot be achieved
     * by user interaction. The visual state depends on the value of the `selected` property:
     * 	 - If `selected` = `true` and `partiallySelected` = `true`, the control is displayed as partially selected
     *
     * 	 - If `selected` = `true` and `partiallySelected` = `false`, the control is displayed as selected
     * 	 - If `selected` = `false`, the control is displayed as not selected regardless of what is set for `partiallySelected`
     *
     *
     * Default value is `false`.
     *
     * @since 1.58
     *
     * @returns Value of property `partiallySelected`
     */
    getPartiallySelected(): boolean;
    /**
     * Gets current value of property {@link #getRequired required}.
     *
     * Sets the `required` state of the `CheckBox`.
     *
     * **Note:** Use this property only when a single relationship between this field and a Label cannot be
     * established. For example, with the assistance of the `labelFor` property of `sap.m.Label`.
     *
     * **Note:** This property won't work as expected without setting a value to the `text` property of the
     * `CheckBox`. The `text` property acts as a label for the `CheckBox` and is crucial for assistive technologies,
     * like screen readers, to provide a meaningful context.
     *
     * Default value is `false`.
     *
     * @since 1.121
     *
     * @returns Value of property `required`
     */
    getRequired(): boolean;
    /**
     * Gets current value of property {@link #getSelected selected}.
     *
     * Determines whether the `CheckBox` is selected (checked).
     *
     * When this property is set to `true`, the control is displayed as selected, unless the value of the `partiallySelected`
     * property is also set to `true`. In this case, the control is displayed as partially selected.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `selected`
     */
    getSelected(): boolean;
    /**
     * Returns the CheckBox`s tab index.
     *
     * @since 1.22
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns iTabIndex for Checkbox
     */
    getTabIndex(): int;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Defines the text displayed next to the checkbox
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getTextAlign textAlign}.
     *
     * Aligns the text of the checkbox. Available alignment settings are "Begin", "Center", "End", "Left", and
     * "Right".
     *
     * Default value is `Begin`.
     *
     *
     * @returns Value of property `textAlign`
     */
    getTextAlign(): TextAlign;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * Options for the text direction are RTL and LTR. Alternatively, the control can inherit the text direction
     * from its parent container.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getUseEntireWidth useEntireWidth}.
     *
     * Indicates if the given width will be applied to the control as a whole or to its label only.
     *
     * **Note:** by default the width is set to the label
     *
     * Default value is `false`.
     *
     * @since 1.52
     *
     * @returns Value of property `useEntireWidth`
     */
    getUseEntireWidth(): boolean;
    /**
     * Gets current value of property {@link #getValueState valueState}.
     *
     * Accepts the core enumeration ValueState.type that supports 'None', 'Error', 'Warning', 'Success' and
     * 'Information'.
     *
     * Default value is `None`.
     *
     * @since 1.38
     *
     * @returns Value of property `valueState`
     */
    getValueState(): ValueState;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Determines the total width of the control or the width of its label only, depending on the value of `useEntireWidth`.
     *
     * **Note:** When `useEntireWidth` is set to `true`, `width` is applied to the control as a whole (checkbox
     * and label). Otherwise, `width` is applied to the label only.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getWrapping wrapping}.
     *
     * Determines whether the label's text is wrapped.
     *
     * When set to `false` (default), the label's text is truncated with ellipsis at the end.
     *
     * Default value is `false`.
     *
     * @since 1.54
     *
     * @returns Value of property `wrapping`
     */
    getWrapping(): boolean;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getActiveHandling activeHandling}.
     *
     * Flag to switch on activeHandling, when it is switched off, there will be no visual changes on active
     * state. Default value is 'true'
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setActiveHandling(
      /**
       * New value for property `activeHandling`
       */
      bActiveHandling?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getDisplayOnly displayOnly}.
     *
     * Determines whether the `CheckBox` is in display only state.
     *
     * When set to `true`, the `CheckBox` is not interactive, not editable, not focusable and not in the tab
     * chain. This setting is used for forms in review mode.
     *
     *  When the property `enabled` is set to `false` this property has no effect.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisplayOnly(
      /**
       * New value for property `displayOnly`
       */
      bDisplayOnly?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEditable editable}.
     *
     * Specifies whether the user shall be allowed to edit the state of the checkbox
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.25
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEditable(
      /**
       * New value for property `editable`
       */
      bEditable?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Whether the `CheckBox` is enabled.
     *
     * **Note:** Disabled `CheckBox` is not interactive and is rendered differently according to the theme.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getName name}.
     *
     * The 'name' property to be used in the HTML code, for example for HTML forms that send data to the server
     * via submit.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setName(
      /**
       * New value for property `name`
       */
      sName?: string
    ): this;
    /**
     * Sets a new value for property {@link #getPartiallySelected partiallySelected}.
     *
     * Determines whether the `CheckBox` is displayed as partially selected.
     *
     * **Note:** This property leads only to visual change of the checkbox and the state cannot be achieved
     * by user interaction. The visual state depends on the value of the `selected` property:
     * 	 - If `selected` = `true` and `partiallySelected` = `true`, the control is displayed as partially selected
     *
     * 	 - If `selected` = `true` and `partiallySelected` = `false`, the control is displayed as selected
     * 	 - If `selected` = `false`, the control is displayed as not selected regardless of what is set for `partiallySelected`
     *
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.58
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPartiallySelected(
      /**
       * New value for property `partiallySelected`
       */
      bPartiallySelected?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getRequired required}.
     *
     * Sets the `required` state of the `CheckBox`.
     *
     * **Note:** Use this property only when a single relationship between this field and a Label cannot be
     * established. For example, with the assistance of the `labelFor` property of `sap.m.Label`.
     *
     * **Note:** This property won't work as expected without setting a value to the `text` property of the
     * `CheckBox`. The `text` property acts as a label for the `CheckBox` and is crucial for assistive technologies,
     * like screen readers, to provide a meaningful context.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.121
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRequired(
      /**
       * New value for property `required`
       */
      bRequired?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getSelected selected}.
     *
     * Determines whether the `CheckBox` is selected (checked).
     *
     * When this property is set to `true`, the control is displayed as selected, unless the value of the `partiallySelected`
     * property is also set to `true`. In this case, the control is displayed as partially selected.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSelected(
      /**
       * New value for property `selected`
       */
      bSelected?: boolean
    ): this;
    /**
     * Sets the tab index of the control
     *
     * @since 1.16
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The `sap.m.CheckBox` instance
     */
    setTabIndex(
      /**
       * The tab index should be greater than or equal -1
       */
      iTabIndex: int
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Defines the text displayed next to the checkbox
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTextAlign textAlign}.
     *
     * Aligns the text of the checkbox. Available alignment settings are "Begin", "Center", "End", "Left", and
     * "Right".
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Begin`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextAlign(
      /**
       * New value for property `textAlign`
       */
      sTextAlign?: TextAlign | keyof typeof TextAlign
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * Options for the text direction are RTL and LTR. Alternatively, the control can inherit the text direction
     * from its parent container.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getUseEntireWidth useEntireWidth}.
     *
     * Indicates if the given width will be applied to the control as a whole or to its label only.
     *
     * **Note:** by default the width is set to the label
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.52
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUseEntireWidth(
      /**
       * New value for property `useEntireWidth`
       */
      bUseEntireWidth?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getValueState valueState}.
     *
     * Accepts the core enumeration ValueState.type that supports 'None', 'Error', 'Warning', 'Success' and
     * 'Information'.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     * @since 1.38
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueState(
      /**
       * New value for property `valueState`
       */
      sValueState?: ValueState | keyof typeof ValueState
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Determines the total width of the control or the width of its label only, depending on the value of `useEntireWidth`.
     *
     * **Note:** When `useEntireWidth` is set to `true`, `width` is applied to the control as a whole (checkbox
     * and label). Otherwise, `width` is applied to the label only.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getWrapping wrapping}.
     *
     * Determines whether the label's text is wrapped.
     *
     * When set to `false` (default), the label's text is truncated with ellipsis at the end.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWrapping(
      /**
       * New value for property `wrapping`
       */
      bWrapping?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the CheckBox constructor.
   */
  export interface $CheckBoxSettings extends $ControlSettings {
    /**
     * Determines whether the `CheckBox` is selected (checked).
     *
     * When this property is set to `true`, the control is displayed as selected, unless the value of the `partiallySelected`
     * property is also set to `true`. In this case, the control is displayed as partially selected.
     */
    selected?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the `CheckBox` is displayed as partially selected.
     *
     * **Note:** This property leads only to visual change of the checkbox and the state cannot be achieved
     * by user interaction. The visual state depends on the value of the `selected` property:
     * 	 - If `selected` = `true` and `partiallySelected` = `true`, the control is displayed as partially selected
     *
     * 	 - If `selected` = `true` and `partiallySelected` = `false`, the control is displayed as selected
     * 	 - If `selected` = `false`, the control is displayed as not selected regardless of what is set for `partiallySelected`
     *
     *
     * @since 1.58
     */
    partiallySelected?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Whether the `CheckBox` is enabled.
     *
     * **Note:** Disabled `CheckBox` is not interactive and is rendered differently according to the theme.
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the `required` state of the `CheckBox`.
     *
     * **Note:** Use this property only when a single relationship between this field and a Label cannot be
     * established. For example, with the assistance of the `labelFor` property of `sap.m.Label`.
     *
     * **Note:** This property won't work as expected without setting a value to the `text` property of the
     * `CheckBox`. The `text` property acts as a label for the `CheckBox` and is crucial for assistive technologies,
     * like screen readers, to provide a meaningful context.
     *
     * @since 1.121
     */
    required?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The 'name' property to be used in the HTML code, for example for HTML forms that send data to the server
     * via submit.
     */
    name?: string | PropertyBindingInfo;

    /**
     * Defines the text displayed next to the checkbox
     */
    text?: string | PropertyBindingInfo;

    /**
     * Options for the text direction are RTL and LTR. Alternatively, the control can inherit the text direction
     * from its parent container.
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Aligns the text of the checkbox. Available alignment settings are "Begin", "Center", "End", "Left", and
     * "Right".
     */
    textAlign?:
      | (TextAlign | keyof typeof TextAlign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the total width of the control or the width of its label only, depending on the value of `useEntireWidth`.
     *
     * **Note:** When `useEntireWidth` is set to `true`, `width` is applied to the control as a whole (checkbox
     * and label). Otherwise, `width` is applied to the label only.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates if the given width will be applied to the control as a whole or to its label only.
     *
     * **Note:** by default the width is set to the label
     *
     * @since 1.52
     */
    useEntireWidth?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Flag to switch on activeHandling, when it is switched off, there will be no visual changes on active
     * state. Default value is 'true'
     */
    activeHandling?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies whether the user shall be allowed to edit the state of the checkbox
     *
     * @since 1.25
     */
    editable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Accepts the core enumeration ValueState.type that supports 'None', 'Error', 'Warning', 'Success' and
     * 'Information'.
     *
     * @since 1.38
     */
    valueState?:
      | (ValueState | keyof typeof ValueState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines whether the `CheckBox` is in display only state.
     *
     * When set to `true`, the `CheckBox` is not interactive, not editable, not focusable and not in the tab
     * chain. This setting is used for forms in review mode.
     *
     *  When the property `enabled` is set to `false` this property has no effect.
     *
     * @since 1.54
     */
    displayOnly?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the label's text is wrapped.
     *
     * When set to `false` (default), the label's text is truncated with ellipsis at the end.
     *
     * @since 1.54
     */
    wrapping?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Association to controls / IDs which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Association to controls / IDs which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Event is triggered when the control status is changed by the user by selecting or deselecting the checkbox.
     */
    select?: (oEvent: CheckBox$SelectEvent) => void;
  }

  /**
   * Parameters of the CheckBox#select event.
   */
  export interface CheckBox$SelectEventParameters {
    /**
     * Checks whether the CheckBox is marked or not .
     */
    selected?: boolean;
  }

  /**
   * Event object of the CheckBox#select event.
   */
  export type CheckBox$SelectEvent = Event<
    CheckBox$SelectEventParameters,
    CheckBox
  >;
}

declare module "sap/m/ColorPalette" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { CSSColor } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * Represents a predefined range of colors for easier selection.
   *
   * Overview: The `ColorPalette` provides the users with a range of predefined colors.
   *
   * You can customize them with the use of the `colors` property. You can specify a `defaultColor` and display
   * a "Default color" button for the user to choose directly. You can display a "More colors..." button that
   * opens an additional color picker for the user to choose specific colors that are not present in the predefined
   * range.
   *
   * Usage:
   *
   * The palette is intended for users, who don't want to check and remember the different values of the colors
   * and spend large amount of time to configure the right color through the color picker.
   *
   * The control can be embedded in a form or can be opened as popover (by use of thin wrapper control `sap.m.ColorPalettePopover`).
   *
   * @since 1.54
   */
  export default class ColorPalette extends Control {
    /**
     * Constructor for a new `ColorPalette`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link sap.m.ColorPalettePopover}
     *
     * **Note:** The application developers should add dependency to `sap.ui.unified` library
     * on application level to ensure that the library is loaded before the module dependencies will be required.
     * The {@link sap.ui.unified.ColorPicker} is used internally only if the `ColorPicker`
     * is opened (not used for the initial rendering). If the `sap.ui.unified` library is not loaded
     * before the `ColorPicker` is opened, it will be loaded upon opening. This could lead to CSP compliance
     * issues and adds an additional waiting time when the `ColorPicker` is opened for the first time.
     * To prevent this, apps using the `ColorPalette` should also load the `sap.ui.unified` library in advance.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ColorPaletteSettings
    );
    /**
     * Constructor for a new `ColorPalette`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link sap.m.ColorPalettePopover}
     *
     * **Note:** The application developers should add dependency to `sap.ui.unified` library
     * on application level to ensure that the library is loaded before the module dependencies will be required.
     * The {@link sap.ui.unified.ColorPicker} is used internally only if the `ColorPicker`
     * is opened (not used for the initial rendering). If the `sap.ui.unified` library is not loaded
     * before the `ColorPicker` is opened, it will be loaded upon opening. This could lead to CSP compliance
     * issues and adds an additional waiting time when the `ColorPicker` is opened for the first time.
     * To prevent this, apps using the `ColorPalette` should also load the `sap.ui.unified` library in advance.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ColorPaletteSettings
    );

    /**
     * Creates a new subclass of class sap.m.ColorPalette with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ColorPalette>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ColorPalette.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:colorSelect colorSelect} event of this `sap.m.ColorPalette`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ColorPalette` itself.
     *
     * Fired when the user selects a color. Note: The `selectedColor` property is updated after the event is
     * fired. Use the event parameter `value` to retrieve the new value for `selectedColor`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachColorSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ColorPalette$ColorSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ColorPalette` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:colorSelect colorSelect} event of this `sap.m.ColorPalette`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ColorPalette` itself.
     *
     * Fired when the user selects a color. Note: The `selectedColor` property is updated after the event is
     * fired. Use the event parameter `value` to retrieve the new value for `selectedColor`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachColorSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ColorPalette$ColorSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ColorPalette` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.ColorPalette`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ColorPalette` itself.
     *
     * Fired when the value is changed by user interaction in the internal ColorPicker
     *
     * @since 1.85
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ColorPalette$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ColorPalette` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.ColorPalette`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ColorPalette` itself.
     *
     * Fired when the value is changed by user interaction in the internal ColorPicker
     *
     * @since 1.85
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ColorPalette$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ColorPalette` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:colorSelect colorSelect} event of this `sap.m.ColorPalette`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachColorSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ColorPalette$ColorSelectEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:liveChange liveChange} event of this `sap.m.ColorPalette`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.85
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLiveChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ColorPalette$LiveChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:colorSelect colorSelect} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireColorSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ColorPalette$ColorSelectEventParameters
    ): this;
    /**
     * Fires event {@link #event:liveChange liveChange} to attached listeners.
     *
     * @since 1.85
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLiveChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ColorPalette$LiveChangeEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getColors colors}.
     *
     * Defines the List of colors displayed in the palette. Minimum is 2 colors, maximum is 15 colors.
     *
     * Default value is `["gold", "darkorange", "indianred", "darkmagenta", "cornflowerblue", "deepskyblue",
     * "darkcyan", "olivedrab", "darkslategray", "azure", "white", "lightgray", "darkgray", "dimgray", "black"]`.
     *
     *
     * @returns Value of property `colors`
     */
    getColors(): CSSColor[];
    /**
     * Gets current value of property {@link #getSelectedColor selectedColor}.
     *
     * The last selected color in the ColorPalette.
     *
     * @since 1.122
     * @experimental As of version 1.122. this property is in a beta state.
     *
     * @returns Value of property `selectedColor`
     */
    getSelectedColor(): CSSColor;
    /**
     * Sets a selected color for the ColorPicker control.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setColorPickerSelectedColor(
      /**
       * the selected color
       */
      sColor: CSSColor
    ): this;
    /**
     * Sets a new value for property {@link #getColors colors}.
     *
     * Defines the List of colors displayed in the palette. Minimum is 2 colors, maximum is 15 colors.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `["gold", "darkorange", "indianred", "darkmagenta", "cornflowerblue", "deepskyblue",
     * "darkcyan", "olivedrab", "darkslategray", "azure", "white", "lightgray", "darkgray", "dimgray", "black"]`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setColors(
      /**
       * New value for property `colors`
       */
      sColors?: CSSColor[]
    ): this;
    /**
     * Sets a new value for property {@link #getSelectedColor selectedColor}.
     *
     * The last selected color in the ColorPalette.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.122
     * @experimental As of version 1.122. this property is in a beta state.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSelectedColor(
      /**
       * New value for property `selectedColor`
       */
      sSelectedColor?: CSSColor
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ColorPalette constructor.
   */
  export interface $ColorPaletteSettings extends $ControlSettings {
    /**
     * Defines the List of colors displayed in the palette. Minimum is 2 colors, maximum is 15 colors.
     */
    colors?: CSSColor[] | PropertyBindingInfo | `{${string}}`;

    /**
     * The last selected color in the ColorPalette.
     *
     * @since 1.122
     * @experimental As of version 1.122. this property is in a beta state.
     */
    selectedColor?: CSSColor | PropertyBindingInfo | `{${string}}`;

    /**
     * Fired when the user selects a color. Note: The `selectedColor` property is updated after the event is
     * fired. Use the event parameter `value` to retrieve the new value for `selectedColor`.
     */
    colorSelect?: (oEvent: ColorPalette$ColorSelectEvent) => void;

    /**
     * Fired when the value is changed by user interaction in the internal ColorPicker
     *
     * @since 1.85
     */
    liveChange?: (oEvent: ColorPalette$LiveChangeEvent) => void;
  }

  /**
   * Parameters of the ColorPalette#colorSelect event.
   */
  export interface ColorPalette$ColorSelectEventParameters {
    /**
     * The color that is returned when user chooses the "Default color" button.
     */
    value?: CSSColor;

    /**
     * Denotes if the color has been chosen by selecting the "Default Color" button (true or false)
     */
    defaultAction?: boolean;
  }

  /**
   * Event object of the ColorPalette#colorSelect event.
   */
  export type ColorPalette$ColorSelectEvent = Event<
    ColorPalette$ColorSelectEventParameters,
    ColorPalette
  >;

  /**
   * Parameters of the ColorPalette#liveChange event.
   */
  export interface ColorPalette$LiveChangeEventParameters {
    /**
     * Parameter containing the RED value (0-255).
     */
    r?: int;

    /**
     * Parameter containing the GREEN value (0-255).
     */
    g?: int;

    /**
     * Parameter containing the BLUE value (0-255).
     */
    b?: int;

    /**
     * Parameter containing the HUE value (0-360).
     */
    h?: int;

    /**
     * Parameter containing the SATURATION value (0-100).
     */
    s?: int;

    /**
     * Parameter containing the VALUE value (0-100).
     */
    v?: int;

    /**
     * Parameter containing the LIGHTNESS value (0-100).
     */
    l?: int;

    /**
     * Parameter containing the Hexadecimal string (#FFFFFF).
     */
    hex?: string;

    /**
     * Parameter containing the alpha value (transparency).
     */
    alpha?: string;
  }

  /**
   * Event object of the ColorPalette#liveChange event.
   */
  export type ColorPalette$LiveChangeEvent = Event<
    ColorPalette$LiveChangeEventParameters,
    ColorPalette
  >;
}

declare module "sap/m/ColorPalettePopover" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { CSSColor } from "sap/ui/core/library";

  import ColorPickerDisplayMode from "sap/ui/unified/ColorPickerDisplayMode";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * A thin wrapper over {@link sap.m.ColorPalette} allowing the latter to be used in a popover.
   *
   * @since 1.54
   */
  export default class ColorPalettePopover extends Control {
    /**
     * Constructor for a new `ColorPalettePopover`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ColorPalettePopoverSettings
    );
    /**
     * Constructor for a new `ColorPalettePopover`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ColorPalettePopoverSettings
    );

    /**
     * Creates a new subclass of class sap.m.ColorPalettePopover with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ColorPalettePopover>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ColorPalettePopover.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:colorSelect colorSelect} event of this `sap.m.ColorPalettePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ColorPalettePopover` itself.
     *
     * Fired when the user selects a color.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachColorSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ColorPalettePopover$ColorSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ColorPalettePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:colorSelect colorSelect} event of this `sap.m.ColorPalettePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ColorPalettePopover` itself.
     *
     * Fired when the user selects a color.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachColorSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ColorPalettePopover$ColorSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ColorPalettePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.ColorPalettePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ColorPalettePopover` itself.
     *
     * Fired when the value is changed by user interaction in the internal ColorPicker of the ColorPalette
     *
     * @since 1.85
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ColorPalettePopover$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ColorPalettePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.ColorPalettePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ColorPalettePopover` itself.
     *
     * Fired when the value is changed by user interaction in the internal ColorPicker of the ColorPalette
     *
     * @since 1.85
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ColorPalettePopover$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ColorPalettePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Closes the `ColorPalettePopover`.
     *
     *
     * @returns Reference to the closed control
     */
    close(): Control;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:colorSelect colorSelect} event of this `sap.m.ColorPalettePopover`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachColorSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ColorPalettePopover$ColorSelectEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:liveChange liveChange} event of this `sap.m.ColorPalettePopover`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.85
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLiveChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ColorPalettePopover$LiveChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:colorSelect colorSelect} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireColorSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ColorPalettePopover$ColorSelectEventParameters
    ): this;
    /**
     * Fires event {@link #event:liveChange liveChange} to attached listeners.
     *
     * @since 1.85
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLiveChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ColorPalettePopover$LiveChangeEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getColors colors}.
     *
     * Defines the list of colors displayed in the palette. Minimum is 2 colors, maximum is 15 colors.
     *
     * Default value is `["gold", "darkorange", "indianred", "darkmagenta", "cornflowerblue", "deepskyblue",
     * "darkcyan", "olivedrab", "darkslategray", "azure", "white", "lightgray", "darkgray", "dimgray", "black"]`.
     *
     *
     * @returns Value of property `colors`
     */
    getColors(): CSSColor[];
    /**
     * Gets current value of property {@link #getDefaultColor defaultColor}.
     *
     * The color, which the app developer will receive when end-user chooses the "Default color" button. See
     * event {@link #event:colorSelect colorSelect}.
     *
     *
     * @returns Value of property `defaultColor`
     */
    getDefaultColor(): CSSColor;
    /**
     * Gets current value of property {@link #getDisplayMode displayMode}.
     *
     * Determines the `displayMode` of the `ColorPicker` among three types - Default, Large and Simplified
     *
     * Default value is `Default`.
     *
     * @since 1.70
     *
     * @returns Value of property `displayMode`
     */
    getDisplayMode(): ColorPickerDisplayMode;
    /**
     * Gets current value of property {@link #getSelectedColor selectedColor}.
     *
     * The last selected color in the ColorPalette.
     *
     * @since 1.122
     * @experimental As of version 1.122. this property is in a beta state.
     *
     * @returns Value of property `selectedColor`
     */
    getSelectedColor(): CSSColor;
    /**
     * Gets current value of property {@link #getShowDefaultColorButton showDefaultColorButton}.
     *
     * Indicates if the button for default color selection is available.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showDefaultColorButton`
     */
    getShowDefaultColorButton(): boolean;
    /**
     * Gets current value of property {@link #getShowMoreColorsButton showMoreColorsButton}.
     *
     * Whether the popover shows a "More colors..." button that opens an additional color picker for the user
     * to choose specific colors, not present in the predefined range.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showMoreColorsButton`
     */
    getShowMoreColorsButton(): boolean;
    /**
     * Gets current value of property {@link #getShowRecentColorsSection showRecentColorsSection}.
     *
     * Indicates if the Recent Colors section is available
     *
     * Default value is `true`.
     *
     * @since 1.74
     *
     * @returns Value of property `showRecentColorsSection`
     */
    getShowRecentColorsSection(): boolean;
    /**
     * Opens the `ColorPalettePopover`.
     *
     * On table or desktop devices, the popover is positioned relative to the given `oControl` parameter. On
     * phones, it is shown full screen, the `oControl` parameter is ignored.
     *
     *
     * @returns Reference to the opened control
     */
    openBy(
      /**
       * When displayed on a tablet or desktop device, the `ColorPalettePopover` is positioned relative to this
       * control
       */
      oControl: Control
    ): Control;
    /**
     * Sets a selected color for the ColorPicker control.
     *
     *
     * @returns `this` for method chaining
     */
    setColorPickerSelectedColor(
      /**
       * the selected color
       */
      color: CSSColor
    ): this;
    /**
     * Sets a new value for property {@link #getColors colors}.
     *
     * Defines the list of colors displayed in the palette. Minimum is 2 colors, maximum is 15 colors.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `["gold", "darkorange", "indianred", "darkmagenta", "cornflowerblue", "deepskyblue",
     * "darkcyan", "olivedrab", "darkslategray", "azure", "white", "lightgray", "darkgray", "dimgray", "black"]`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setColors(
      /**
       * New value for property `colors`
       */
      sColors?: CSSColor[]
    ): this;
    /**
     * Sets a new value for property {@link #getDefaultColor defaultColor}.
     *
     * The color, which the app developer will receive when end-user chooses the "Default color" button. See
     * event {@link #event:colorSelect colorSelect}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDefaultColor(
      /**
       * New value for property `defaultColor`
       */
      sDefaultColor?: CSSColor
    ): this;
    /**
     * Sets a new value for property {@link #getDisplayMode displayMode}.
     *
     * Determines the `displayMode` of the `ColorPicker` among three types - Default, Large and Simplified
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Default`.
     *
     * @since 1.70
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisplayMode(
      /**
       * New value for property `displayMode`
       */
      sDisplayMode?:
        | ColorPickerDisplayMode
        | keyof typeof ColorPickerDisplayMode
    ): this;
    /**
     * Sets a new value for property {@link #getSelectedColor selectedColor}.
     *
     * The last selected color in the ColorPalette.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.122
     * @experimental As of version 1.122. this property is in a beta state.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSelectedColor(
      /**
       * New value for property `selectedColor`
       */
      sSelectedColor?: CSSColor
    ): this;
    /**
     * Sets a new value for property {@link #getShowDefaultColorButton showDefaultColorButton}.
     *
     * Indicates if the button for default color selection is available.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowDefaultColorButton(
      /**
       * New value for property `showDefaultColorButton`
       */
      bShowDefaultColorButton?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowMoreColorsButton showMoreColorsButton}.
     *
     * Whether the popover shows a "More colors..." button that opens an additional color picker for the user
     * to choose specific colors, not present in the predefined range.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowMoreColorsButton(
      /**
       * New value for property `showMoreColorsButton`
       */
      bShowMoreColorsButton?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowRecentColorsSection showRecentColorsSection}.
     *
     * Indicates if the Recent Colors section is available
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.74
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowRecentColorsSection(
      /**
       * New value for property `showRecentColorsSection`
       */
      bShowRecentColorsSection?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ColorPalettePopover constructor.
   */
  export interface $ColorPalettePopoverSettings extends $ControlSettings {
    /**
     * The color, which the app developer will receive when end-user chooses the "Default color" button. See
     * event {@link #event:colorSelect colorSelect}.
     */
    defaultColor?: CSSColor | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the list of colors displayed in the palette. Minimum is 2 colors, maximum is 15 colors.
     */
    colors?: CSSColor[] | PropertyBindingInfo | `{${string}}`;

    /**
     * The last selected color in the ColorPalette.
     *
     * @since 1.122
     * @experimental As of version 1.122. this property is in a beta state.
     */
    selectedColor?: CSSColor | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates if the button for default color selection is available.
     */
    showDefaultColorButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Whether the popover shows a "More colors..." button that opens an additional color picker for the user
     * to choose specific colors, not present in the predefined range.
     */
    showMoreColorsButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates if the Recent Colors section is available
     *
     * @since 1.74
     */
    showRecentColorsSection?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the `displayMode` of the `ColorPicker` among three types - Default, Large and Simplified
     *
     * @since 1.70
     */
    displayMode?:
      | (ColorPickerDisplayMode | keyof typeof ColorPickerDisplayMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Fired when the user selects a color.
     */
    colorSelect?: (oEvent: ColorPalettePopover$ColorSelectEvent) => void;

    /**
     * Fired when the value is changed by user interaction in the internal ColorPicker of the ColorPalette
     *
     * @since 1.85
     */
    liveChange?: (oEvent: ColorPalettePopover$LiveChangeEvent) => void;
  }

  /**
   * Parameters of the ColorPalettePopover#colorSelect event.
   */
  export interface ColorPalettePopover$ColorSelectEventParameters {
    /**
     * The selected color value.
     */
    value?: CSSColor;

    /**
     * Denotes if the color has been chosen by selecting the "Default Color" button (true or false).
     */
    defaultAction?: boolean;
  }

  /**
   * Event object of the ColorPalettePopover#colorSelect event.
   */
  export type ColorPalettePopover$ColorSelectEvent = Event<
    ColorPalettePopover$ColorSelectEventParameters,
    ColorPalettePopover
  >;

  /**
   * Parameters of the ColorPalettePopover#liveChange event.
   */
  export interface ColorPalettePopover$LiveChangeEventParameters {
    /**
     * Parameter containing the RED value (0-255).
     */
    r?: int;

    /**
     * Parameter containing the GREEN value (0-255).
     */
    g?: int;

    /**
     * Parameter containing the BLUE value (0-255).
     */
    b?: int;

    /**
     * Parameter containing the HUE value (0-360).
     */
    h?: int;

    /**
     * Parameter containing the SATURATION value (0-100).
     */
    s?: int;

    /**
     * Parameter containing the VALUE value (0-100).
     */
    v?: int;

    /**
     * Parameter containing the LIGHTNESS value (0-100).
     */
    l?: int;

    /**
     * Parameter containing the Hexadecimal string (#FFFFFF).
     */
    hex?: string;

    /**
     * Parameter containing the alpha value (transparency).
     */
    alpha?: string;
  }

  /**
   * Event object of the ColorPalettePopover#liveChange event.
   */
  export type ColorPalettePopover$LiveChangeEvent = Event<
    ColorPalettePopover$LiveChangeEventParameters,
    ColorPalettePopover
  >;
}

declare module "sap/m/Column" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import Control from "sap/ui/core/Control";

  import {
    TextAlign,
    ID,
    Priority,
    SortOrder,
    VerticalAlign,
    CSSSize,
    IColumnHeaderMenu,
  } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PopinDisplay } from "sap/m/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The `sap.m.Column` allows to define column specific properties that will be applied when rendering the
   * `sap.m.Table`.
   *
   * See section "{@link https://ui5.sap.com/#/topic/6f778a805bc3453dbb66e246d8271839 Defining Column Width}"
   * in the documentation to understand how to define the `width` property of the `sap.m.Column` to render
   * a `sap.m.Table` control properly.
   *
   * @since 1.12
   */
  export default class Column extends UI5Element {
    /**
     * Constructor for a new Column.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $ColumnSettings
    );
    /**
     * Constructor for a new Column.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $ColumnSettings
    );

    /**
     * Creates a new subclass of class sap.m.Column with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Column>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Column.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Clears the last value of the column if mergeDuplicates property is true
     *
     * @since 1.20.4
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    clearLastValue(): this;
    /**
     * Destroys the footer in the aggregation {@link #getFooter footer}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyFooter(): this;
    /**
     * Destroys the header in the aggregation {@link #getHeader header}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyHeader(): this;
    /**
     * Gets current value of property {@link #getAutoPopinWidth autoPopinWidth}.
     *
     * Defines the auto pop-in width for the column.
     *
     * If the `sap.m.Table` control is configured with `autoPopinMode=true`, then the `autoPopinWidth` property
     * is used to calculate the `minScreenWidth` property of the column in case a fixed width is not set for
     * the column. See {@link sap.m.Column#getWidth} and {@link sap.m.Table#getAutoPopinMode}. **Note:** A float
     * value is set for the `autoPopinWidth` property which is internally treated as a rem value.
     *
     * Default value is `8`.
     *
     * @since 1.76
     *
     * @returns Value of property `autoPopinWidth`
     */
    getAutoPopinWidth(): float;
    /**
     * Returns CSS alignment according to column hAlign setting or given parameter for Begin/End values checks
     * the locale settings
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns left|center|right
     */
    getCssAlign(
      /**
       * TextAlign enumeration
       */
      sAlign?: string
    ): string;
    /**
     * Gets current value of property {@link #getDemandPopin demandPopin}.
     *
     * According to your minScreenWidth settings, the column can be hidden in different screen sizes. Setting
     * this property to true, shows this column as pop-in instead of hiding it. **Note:** This property gets
     * overwritten if the `sap.m.Table` control is configured with `autoPopinMode=true`. See {@link sap.m.Table#getAutoPopinMode}
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `demandPopin`
     */
    getDemandPopin(): boolean;
    /**
     * Gets content of aggregation {@link #getFooter footer}.
     *
     * Control to be displayed in the column footer.
     */
    getFooter(): Control;
    /**
     * Gets current value of property {@link #getHAlign hAlign}.
     *
     * Defines the horizontal alignment of the column content.
     *
     * **Note:** Text controls with a `textAlign` property inherits the horizontal alignment.
     *
     * Default value is `Begin`.
     *
     *
     * @returns Value of property `hAlign`
     */
    getHAlign(): TextAlign;
    /**
     * Gets content of aggregation {@link #getHeader header}.
     *
     * Control to be displayed in the column header.
     */
    getHeader(): Control;
    /**
     * ID of the element which is the current target of the association {@link #getHeaderMenu headerMenu}, or
     * `null`.
     *
     * @since 1.98.0
     */
    getHeaderMenu(): ID | null;
    /**
     * Gets current value of property {@link #getImportance importance}.
     *
     * Defines the column importance.
     *
     * If the `sap.m.Table` control is configured with `autoPopinMode=true`, then the column importance is taken
     * into consideration for calculating the `minScreenWidth` property and for setting the `demandPopin` property
     * of the column. See {@link sap.m.Table#getAutoPopinMode}
     *
     * Default value is `"None"`.
     *
     * @since 1.76
     *
     * @returns Value of property `importance`
     */
    getImportance(): Priority;
    /**
     * Gets the rendering index of the column
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    getIndex(): void;
    /**
     * Gets the initial order of the column
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns initial order of the column
     */
    getInitialOrder(): int;
    /**
     * Gets the last value of the column
     *
     * @since 1.16
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    getLastValue(): void;
    /**
     * Gets current value of property {@link #getMergeDuplicates mergeDuplicates}.
     *
     * Set `true` to merge repeating/duplicate cells into one cell block. See `mergeFunctionName` property to
     * customize.
     *
     * **Note:** Merging only happens when rendering the `sap.m.Table` control, subsequent changes on the cell
     * or item do not have any effect on the merged state of the cells, therefore this feature should not be
     * used together with two-way binding. This property is ignored if any column is configured to be shown
     * as a pop-in. Don't set this property for cells for which the content provides a user interaction, such
     * as `sap.m.Link`.
     *
     * Default value is `false`.
     *
     * @since 1.16
     *
     * @returns Value of property `mergeDuplicates`
     */
    getMergeDuplicates(): boolean;
    /**
     * Gets current value of property {@link #getMergeFunctionName mergeFunctionName}.
     *
     * Defines the control serialization function if `mergeDuplicates` property is set to `true`. The control
     * itself uses this function to compare values of two repeating cells. Default value "getText" is suitable
     * for `sap.m.Label` and `sap.m.Text` controls but for the `sap.ui.core.Icon` control "getSrc" function
     * should be used to merge icons. **Note:** You can pass one string parameter to given function after "#"
     * sign. e.g. "data#myparameter"
     *
     * Default value is `'getText'`.
     *
     * @since 1.16
     *
     * @returns Value of property `mergeFunctionName`
     */
    getMergeFunctionName(): string;
    /**
     * Gets current value of property {@link #getMinScreenWidth minScreenWidth}.
     *
     * Defines the minimum screen width to show or hide this column. By default column is always shown. The
     * responsive behavior of the `sap.m.Table` is determined by this property. As an example by setting `minScreenWidth`
     * property to "40em" (or "640px" or "Tablet") shows this column on tablet (and desktop) but hides on mobile.
     * As you can give specific CSS sizes (e.g: "480px" or "40em"), you can also use the {@link sap.m.ScreenSize }
     * enumeration (e.g: "Phone", "Tablet", "Desktop", "Small", "Medium", "Large", ....). Please also see `demandPopin`
     * property for further responsive design options. **Note:** This property gets overwritten if the `sap.m.Table`
     * control is configured with `autoPopinMode=true`. See {@link sap.m.Table#getAutoPopinMode}
     *
     *
     * @returns Value of property `minScreenWidth`
     */
    getMinScreenWidth(): string;
    /**
     * Gets the order of the column
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns nOrder order of the column
     */
    getOrder(): int;
    /**
     * Gets current value of property {@link #getPopinDisplay popinDisplay}.
     *
     * Defines enumerated display options for the pop-in.
     *
     * Default value is `Block`.
     *
     * @since 1.13.2
     *
     * @returns Value of property `popinDisplay`
     */
    getPopinDisplay(): PopinDisplay;
    /**
     * Gets current value of property {@link #getPopinHAlign popinHAlign}.
     *
     * Horizontal alignment of the pop-in content. Available alignment settings are "Begin", "Center", "End",
     * "Left", and "Right".
     *
     * **Note:** Controls with a text align do not inherit the horizontal alignment.
     *
     * Default value is `Begin`.
     *
     * @deprecated As of version 1.14. Use popinDisplay property instead.
     *
     * @returns Value of property `popinHAlign`
     */
    getPopinHAlign(): TextAlign;
    /**
     * Gets current value of property {@link #getSortIndicator sortIndicator}.
     *
     * Defines if a column is sorted by setting the sort indicator for this column.
     *
     * **Note:** Defining this property does not trigger the sorting.
     *
     * Default value is `None`.
     *
     * @since 1.61
     *
     * @returns Value of property `sortIndicator`
     */
    getSortIndicator(): SortOrder;
    /**
     * Gets current value of property {@link #getStyleClass styleClass}.
     *
     * CSS class name for column contents(header, cells and footer of column). This property can be used for
     * different column styling. If column is shown as pop-in then this class name is applied to related pop-in
     * row.
     *
     *
     * @returns Value of property `styleClass`
     */
    getStyleClass(): string;
    /**
     * Gets current value of property {@link #getVAlign vAlign}.
     *
     * Defines the vertical alignment of the cells in a column. This property does not affect the vertical alignment
     * of header and footer.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Value of property `vAlign`
     */
    getVAlign(): VerticalAlign;
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * Specifies whether or not the column is visible. Invisible columns are not rendered.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Defines the width of the column. If you leave it empty then this column covers the remaining space. **Note:**
     * When setting `autoPopinMode=true` on the table, the columns with a fixed width must either be in px,
     * rem, or em as the table internally calculates the `minScreenWidth` property for the column. If a column
     * has a fixed width, then this width is used to calculate the `minScreenWidth` for the `autoPopinMode`.
     * If a column has a flexible width, such as % or auto, the `autoPopinWidth` property is used to calculate
     * the `minScreenWidth`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Determines whether the column is hidden without being in the popin area
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    isHidden(): void;
    /**
     * Determines whether the column is shown as pop-in or not
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    isPopin(): void;
    /**
     * Gets called from the Table when the all items are removed
     *
     * @since 1.16
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onItemsRemoved(): void;
    /**
     * Sets a new value for property {@link #getAutoPopinWidth autoPopinWidth}.
     *
     * Defines the auto pop-in width for the column.
     *
     * If the `sap.m.Table` control is configured with `autoPopinMode=true`, then the `autoPopinWidth` property
     * is used to calculate the `minScreenWidth` property of the column in case a fixed width is not set for
     * the column. See {@link sap.m.Column#getWidth} and {@link sap.m.Table#getAutoPopinMode}. **Note:** A float
     * value is set for the `autoPopinWidth` property which is internally treated as a rem value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `8`.
     *
     * @since 1.76
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAutoPopinWidth(
      /**
       * New value for property `autoPopinWidth`
       */
      fAutoPopinWidth?: float
    ): this;
    /**
     * Sets a new value for property {@link #getDemandPopin demandPopin}.
     *
     * According to your minScreenWidth settings, the column can be hidden in different screen sizes. Setting
     * this property to true, shows this column as pop-in instead of hiding it. **Note:** This property gets
     * overwritten if the `sap.m.Table` control is configured with `autoPopinMode=true`. See {@link sap.m.Table#getAutoPopinMode}
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDemandPopin(
      /**
       * New value for property `demandPopin`
       */
      bDemandPopin?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getFooter footer}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFooter(
      /**
       * The footer to set
       */
      oFooter: Control
    ): this;
    /**
     * Sets a new value for property {@link #getHAlign hAlign}.
     *
     * Defines the horizontal alignment of the column content.
     *
     * **Note:** Text controls with a `textAlign` property inherits the horizontal alignment.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Begin`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHAlign(
      /**
       * New value for property `hAlign`
       */
      sHAlign?: TextAlign | keyof typeof TextAlign
    ): this;
    /**
     * Sets the aggregated {@link #getHeader header}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeader(
      /**
       * The header to set
       */
      oHeader: Control
    ): this;
    /**
     * Sets the associated {@link #getHeaderMenu headerMenu}.
     *
     * @since 1.98.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeaderMenu(
      /**
       * ID of an element which becomes the new target of this headerMenu association; alternatively, an element
       * instance may be given
       */
      oHeaderMenu: ID | IColumnHeaderMenu
    ): this;
    /**
     * Sets a new value for property {@link #getImportance importance}.
     *
     * Defines the column importance.
     *
     * If the `sap.m.Table` control is configured with `autoPopinMode=true`, then the column importance is taken
     * into consideration for calculating the `minScreenWidth` property and for setting the `demandPopin` property
     * of the column. See {@link sap.m.Table#getAutoPopinMode}
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"None"`.
     *
     * @since 1.76
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setImportance(
      /**
       * New value for property `importance`
       */
      sImportance?: Priority | keyof typeof Priority
    ): this;
    /**
     * Sets the visible column index Negative index values can be used to clear
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    setIndex(
      /**
       * index of the visible column
       */
      nIndex: int
    ): void;
    /**
     * Sets the initial order of the column
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    setInitialOrder(
      /**
       * initial order of the column
       */
      nOrder: int
    ): void;
    /**
     * Sets the last value of the column if mergeDuplicates property is true
     *
     * @since 1.16
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    setLastValue(
      /**
       * Any Value
       */
      value: any
    ): this;
    /**
     * Sets a new value for property {@link #getMergeDuplicates mergeDuplicates}.
     *
     * Set `true` to merge repeating/duplicate cells into one cell block. See `mergeFunctionName` property to
     * customize.
     *
     * **Note:** Merging only happens when rendering the `sap.m.Table` control, subsequent changes on the cell
     * or item do not have any effect on the merged state of the cells, therefore this feature should not be
     * used together with two-way binding. This property is ignored if any column is configured to be shown
     * as a pop-in. Don't set this property for cells for which the content provides a user interaction, such
     * as `sap.m.Link`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMergeDuplicates(
      /**
       * New value for property `mergeDuplicates`
       */
      bMergeDuplicates?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getMergeFunctionName mergeFunctionName}.
     *
     * Defines the control serialization function if `mergeDuplicates` property is set to `true`. The control
     * itself uses this function to compare values of two repeating cells. Default value "getText" is suitable
     * for `sap.m.Label` and `sap.m.Text` controls but for the `sap.ui.core.Icon` control "getSrc" function
     * should be used to merge icons. **Note:** You can pass one string parameter to given function after "#"
     * sign. e.g. "data#myparameter"
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `'getText'`.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMergeFunctionName(
      /**
       * New value for property `mergeFunctionName`
       */
      sMergeFunctionName?: string
    ): this;
    /**
     * Sets a new value for property {@link #getMinScreenWidth minScreenWidth}.
     *
     * Defines the minimum screen width to show or hide this column. By default column is always shown. The
     * responsive behavior of the `sap.m.Table` is determined by this property. As an example by setting `minScreenWidth`
     * property to "40em" (or "640px" or "Tablet") shows this column on tablet (and desktop) but hides on mobile.
     * As you can give specific CSS sizes (e.g: "480px" or "40em"), you can also use the {@link sap.m.ScreenSize }
     * enumeration (e.g: "Phone", "Tablet", "Desktop", "Small", "Medium", "Large", ....). Please also see `demandPopin`
     * property for further responsive design options. **Note:** This property gets overwritten if the `sap.m.Table`
     * control is configured with `autoPopinMode=true`. See {@link sap.m.Table#getAutoPopinMode}
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMinScreenWidth(
      /**
       * New value for property `minScreenWidth`
       */
      sMinScreenWidth?: string
    ): this;
    /**
     * Sets the order of the column Does not do the visual effect Table should be invalidate to re-render
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    setOrder(
      /**
       * order of the column
       */
      nOrder: int
    ): void;
    /**
     * Sets a new value for property {@link #getPopinDisplay popinDisplay}.
     *
     * Defines enumerated display options for the pop-in.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Block`.
     *
     * @since 1.13.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPopinDisplay(
      /**
       * New value for property `popinDisplay`
       */
      sPopinDisplay?: PopinDisplay | keyof typeof PopinDisplay
    ): this;
    /**
     * Sets a new value for property {@link #getPopinHAlign popinHAlign}.
     *
     * Horizontal alignment of the pop-in content. Available alignment settings are "Begin", "Center", "End",
     * "Left", and "Right".
     *
     * **Note:** Controls with a text align do not inherit the horizontal alignment.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Begin`.
     *
     * @deprecated As of version 1.14. Use popinDisplay property instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPopinHAlign(
      /**
       * New value for property `popinHAlign`
       */
      sPopinHAlign?: TextAlign | keyof typeof TextAlign
    ): this;
    /**
     * Sets a new value for property {@link #getSortIndicator sortIndicator}.
     *
     * Defines if a column is sorted by setting the sort indicator for this column.
     *
     * **Note:** Defining this property does not trigger the sorting.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     * @since 1.61
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSortIndicator(
      /**
       * New value for property `sortIndicator`
       */
      sSortIndicator?: SortOrder | keyof typeof SortOrder
    ): this;
    /**
     * Sets a new value for property {@link #getStyleClass styleClass}.
     *
     * CSS class name for column contents(header, cells and footer of column). This property can be used for
     * different column styling. If column is shown as pop-in then this class name is applied to related pop-in
     * row.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setStyleClass(
      /**
       * New value for property `styleClass`
       */
      sStyleClass?: string
    ): this;
    /**
     * Sets a new value for property {@link #getVAlign vAlign}.
     *
     * Defines the vertical alignment of the cells in a column. This property does not affect the vertical alignment
     * of header and footer.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVAlign(
      /**
       * New value for property `vAlign`
       */
      sVAlign?: VerticalAlign | keyof typeof VerticalAlign
    ): this;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * Specifies whether or not the column is visible. Invisible columns are not rendered.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Defines the width of the column. If you leave it empty then this column covers the remaining space. **Note:**
     * When setting `autoPopinMode=true` on the table, the columns with a fixed width must either be in px,
     * rem, or em as the table internally calculates the `minScreenWidth` property for the column. If a column
     * has a fixed width, then this width is used to calculate the `minScreenWidth` for the `autoPopinMode`.
     * If a column has a flexible width, such as % or auto, the `autoPopinWidth` property is used to calculate
     * the `minScreenWidth`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Column constructor.
   */
  export interface $ColumnSettings extends $ElementSettings {
    /**
     * Defines the width of the column. If you leave it empty then this column covers the remaining space. **Note:**
     * When setting `autoPopinMode=true` on the table, the columns with a fixed width must either be in px,
     * rem, or em as the table internally calculates the `minScreenWidth` property for the column. If a column
     * has a fixed width, then this width is used to calculate the `minScreenWidth` for the `autoPopinMode`.
     * If a column has a flexible width, such as % or auto, the `autoPopinWidth` property is used to calculate
     * the `minScreenWidth`.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the horizontal alignment of the column content.
     *
     * **Note:** Text controls with a `textAlign` property inherits the horizontal alignment.
     */
    hAlign?:
      | (TextAlign | keyof typeof TextAlign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the vertical alignment of the cells in a column. This property does not affect the vertical alignment
     * of header and footer.
     */
    vAlign?:
      | (VerticalAlign | keyof typeof VerticalAlign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * CSS class name for column contents(header, cells and footer of column). This property can be used for
     * different column styling. If column is shown as pop-in then this class name is applied to related pop-in
     * row.
     */
    styleClass?: string | PropertyBindingInfo;

    /**
     * Specifies whether or not the column is visible. Invisible columns are not rendered.
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the minimum screen width to show or hide this column. By default column is always shown. The
     * responsive behavior of the `sap.m.Table` is determined by this property. As an example by setting `minScreenWidth`
     * property to "40em" (or "640px" or "Tablet") shows this column on tablet (and desktop) but hides on mobile.
     * As you can give specific CSS sizes (e.g: "480px" or "40em"), you can also use the {@link sap.m.ScreenSize }
     * enumeration (e.g: "Phone", "Tablet", "Desktop", "Small", "Medium", "Large", ....). Please also see `demandPopin`
     * property for further responsive design options. **Note:** This property gets overwritten if the `sap.m.Table`
     * control is configured with `autoPopinMode=true`. See {@link sap.m.Table#getAutoPopinMode}
     */
    minScreenWidth?: string | PropertyBindingInfo;

    /**
     * According to your minScreenWidth settings, the column can be hidden in different screen sizes. Setting
     * this property to true, shows this column as pop-in instead of hiding it. **Note:** This property gets
     * overwritten if the `sap.m.Table` control is configured with `autoPopinMode=true`. See {@link sap.m.Table#getAutoPopinMode}
     */
    demandPopin?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Horizontal alignment of the pop-in content. Available alignment settings are "Begin", "Center", "End",
     * "Left", and "Right".
     *
     * **Note:** Controls with a text align do not inherit the horizontal alignment.
     *
     * @deprecated As of version 1.14. Use popinDisplay property instead.
     */
    popinHAlign?:
      | (TextAlign | keyof typeof TextAlign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines enumerated display options for the pop-in.
     *
     * @since 1.13.2
     */
    popinDisplay?:
      | (PopinDisplay | keyof typeof PopinDisplay)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Set `true` to merge repeating/duplicate cells into one cell block. See `mergeFunctionName` property to
     * customize.
     *
     * **Note:** Merging only happens when rendering the `sap.m.Table` control, subsequent changes on the cell
     * or item do not have any effect on the merged state of the cells, therefore this feature should not be
     * used together with two-way binding. This property is ignored if any column is configured to be shown
     * as a pop-in. Don't set this property for cells for which the content provides a user interaction, such
     * as `sap.m.Link`.
     *
     * @since 1.16
     */
    mergeDuplicates?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the control serialization function if `mergeDuplicates` property is set to `true`. The control
     * itself uses this function to compare values of two repeating cells. Default value "getText" is suitable
     * for `sap.m.Label` and `sap.m.Text` controls but for the `sap.ui.core.Icon` control "getSrc" function
     * should be used to merge icons. **Note:** You can pass one string parameter to given function after "#"
     * sign. e.g. "data#myparameter"
     *
     * @since 1.16
     */
    mergeFunctionName?: string | PropertyBindingInfo;

    /**
     * Defines if a column is sorted by setting the sort indicator for this column.
     *
     * **Note:** Defining this property does not trigger the sorting.
     *
     * @since 1.61
     */
    sortIndicator?:
      | (SortOrder | keyof typeof SortOrder)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the column importance.
     *
     * If the `sap.m.Table` control is configured with `autoPopinMode=true`, then the column importance is taken
     * into consideration for calculating the `minScreenWidth` property and for setting the `demandPopin` property
     * of the column. See {@link sap.m.Table#getAutoPopinMode}
     *
     * @since 1.76
     */
    importance?:
      | (Priority | keyof typeof Priority)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the auto pop-in width for the column.
     *
     * If the `sap.m.Table` control is configured with `autoPopinMode=true`, then the `autoPopinWidth` property
     * is used to calculate the `minScreenWidth` property of the column in case a fixed width is not set for
     * the column. See {@link sap.m.Column#getWidth} and {@link sap.m.Table#getAutoPopinMode}. **Note:** A float
     * value is set for the `autoPopinWidth` property which is internally treated as a rem value.
     *
     * @since 1.76
     */
    autoPopinWidth?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * Control to be displayed in the column header.
     */
    header?: Control;

    /**
     * Control to be displayed in the column footer.
     */
    footer?: Control;

    /**
     * Provides a menu that is used by the column. The given menu has to follow the same pattern as the `sap.ui.core.IColumnHeaderMenu`
     * interface.
     *
     * @since 1.98.0
     */
    headerMenu?: IColumnHeaderMenu | string;
  }
}

declare module "sap/m/ColumnListItem" {
  import {
    default as ListItemBase,
    $ListItemBaseSettings,
  } from "sap/m/ListItemBase";

  import { ITableItem } from "sap/m/library";

  import Control from "sap/ui/core/Control";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { VerticalAlign } from "sap/ui/core/library";

  /**
   * `sap.m.ColumnListItem` can be used with the `cells` aggregation to create rows for the `sap.m.Table`
   * control. The `columns` aggregation of the `sap.m.Table` should match with the cells aggregation.
   *
   * **Note:** This control should only be used within the `sap.m.Table` control. The inherited `counter`
   * property of `sap.m.ListItemBase` is not supported.
   *
   * @since 1.12
   */
  export default class ColumnListItem
    extends ListItemBase
    implements ITableItem
  {
    __implements__sap_m_ITableItem: boolean;
    /**
     * Constructor for a new ColumnListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ColumnListItemSettings
    );
    /**
     * Constructor for a new ColumnListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ColumnListItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.ColumnListItem with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ListItemBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ColumnListItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ColumnListItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Returns pop-in DOMRef as a jQuery Object
     *
     * @since 1.26
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    $Popin(): void;
    /**
     * Adds some cell to the aggregation {@link #getCells cells}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addCell(
      /**
       * The cell to add; if empty, nothing is inserted
       */
      oCell: Control
    ): this;
    /**
     * Binds aggregation {@link #getCells cells} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindCells(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the cells in the aggregation {@link #getCells cells}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCells(): this;
    /**
     * Gets content of aggregation {@link #getCells cells}.
     *
     * Every `control` inside the `cells` aggregation defines one cell of the row. **Note:** The order of the
     * `cells` aggregation must match the order of the `columns` aggregation of `sap.m.Table`.
     */
    getCells(): Control[];
    /**
     * Returns the pop-in element.
     *
     * @since 1.30.9
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    getPopin(): void;
    /**
     * Returns the tabbable DOM elements as a jQuery collection When popin is available this separated dom should
     * also be included
     *
     * @since 1.26
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns jQuery object
     */
    getTabbables(
      /**
       * Whether only tabbables of data cells
       */
      bContentOnly?: undefined
    ): jQuery;
    /**
     * Gets current value of property {@link #getVAlign vAlign}.
     *
     * Sets the vertical alignment of all the cells within the table row (including selection and navigation).
     * **Note:** `vAlign` property of `sap.m.Column` overrides the property for cell vertical alignment if both
     * are set.
     *
     * Default value is `Inherit`.
     *
     * @since 1.20
     *
     * @returns Value of property `vAlign`
     */
    getVAlign(): VerticalAlign;
    /**
     * Determines whether control has pop-in or not.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    hasPopin(): void;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getCells cells}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfCell(
      /**
       * The cell whose index is looked for
       */
      oCell: Control
    ): int;
    /**
     * Inserts a cell into the aggregation {@link #getCells cells}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertCell(
      /**
       * The cell to insert; if empty, nothing is inserted
       */
      oCell: Control,
      /**
       * The `0`-based index the cell should be inserted at; for a negative value of `iIndex`, the cell is inserted
       * at position 0; for a value greater than the current size of the aggregation, the cell is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getCells cells}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllCells(): Control[];
    /**
     * Removes a cell from the aggregation {@link #getCells cells}.
     *
     *
     * @returns The removed cell or `null`
     */
    removeCell(
      /**
       * The cell to remove or its index or id
       */
      vCell: int | string | Control
    ): Control | null;
    /**
     * Pemove pop-in from DOM
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    removePopin(): void;
    /**
     * Sets a new value for property {@link #getVAlign vAlign}.
     *
     * Sets the vertical alignment of all the cells within the table row (including selection and navigation).
     * **Note:** `vAlign` property of `sap.m.Column` overrides the property for cell vertical alignment if both
     * are set.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.20
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVAlign(
      /**
       * New value for property `vAlign`
       */
      sVAlign?: VerticalAlign | keyof typeof VerticalAlign
    ): this;
    /**
     * Unbinds aggregation {@link #getCells cells} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindCells(): this;
  }
  /**
   * Describes the settings that can be provided to the ColumnListItem constructor.
   */
  export interface $ColumnListItemSettings extends $ListItemBaseSettings {
    /**
     * Sets the vertical alignment of all the cells within the table row (including selection and navigation).
     * **Note:** `vAlign` property of `sap.m.Column` overrides the property for cell vertical alignment if both
     * are set.
     *
     * @since 1.20
     */
    vAlign?:
      | (VerticalAlign | keyof typeof VerticalAlign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Every `control` inside the `cells` aggregation defines one cell of the row. **Note:** The order of the
     * `cells` aggregation must match the order of the `columns` aggregation of `sap.m.Table`.
     */
    cells?: Control[] | Control | AggregationBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/ComboBox" {
  import {
    default as ComboBoxBase,
    $ComboBoxBaseSettings,
  } from "sap/m/ComboBoxBase";

  import { IToolbarInteractiveControl } from "sap/m/library";

  import List from "sap/m/List";

  import Popover from "sap/m/Popover";

  import Dialog from "sap/m/Dialog";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Item from "sap/ui/core/Item";

  import { ID } from "sap/ui/core/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import { InputBase$ChangeEventParameters } from "sap/m/InputBase";

  import Event from "sap/ui/base/Event";

  /**
   * A drop-down list for selecting and filtering values. Overview: The control represents a drop-down menu
   * with a list of the available options and a text input field to narrow down the options. Structure: The
   * combo-box consists of the following elements:
   * 	 -  Input field - displays the selected option or a custom user entry. Users can type to narrow down
   *     the list or enter their own value.
   * 	 -  Drop-down arrow - expands\collapses the option list.
   * 	 -  Option list - the list of available options. **Note:** Disabled items are not visualized in the
   *     list with the available options, however they can still be accessed through the `items` aggregation.
   *      By setting the `showSecondaryValues` property, the combo box can display an additional value for
   *     each option (if there is one). **Note:** The typeahead feature is not available on Android devices due
   *     to a OS specific issue. Usage: When to use::
   * 	 - You need to select only one item in a long list of options (between 13 and 200) or your custom user
   *     input.  When not to use::
   * 	 - You need to select between only two options. Use a {@link sap.m.Switch switch} control instead.
   * 	 - You need to select between up to 12 options. Use a {@link sap.m.Select select} control instead.
   * 	 - You need to select between more than 200 options. Use a {@link sap.m.Input input} control with value
   *     help instead.
   *
   * Note:: The control has the following behavior regarding the `selectedKey` and `value` properties:
   *
   * 	 -  On initial loading, if the control has a `selectedKey` set which corresponds to a matching item,
   *     and a set `value`, the `value` will be updated to the matching item's text.
   * 	 -  If a `selectedKey` is set and the user types an input which corresponds to an item's text, the `selectedKey`
   *     will be updated with the matching item's key.
   * 	 -  If a `selectedKey` is set and the user types an input which does not correspond to any item's text,
   *     the `selectedKey` will be set to an empty string ("")
   * 	 -  If a `selectedKey` is set and the user selects an item, the `selectedKey` will be updated to match
   *     the selected item's key.
   * 	 -  If a `selectedKey` is bound and the user types before the data is loaded, the user's input will
   *     be overwritten by the binding update.
   *
   * Responsive Behavior:
   * 	 - As the `sap.m.ComboBox` control allows free text, as well as has `selectedKey` / `selectedItem` properties,
   *     here is brief explanation of how they are updated during model change:
   * 	 - If the ComboBox has `selectedKey` and `selectedItem` set, the model changes and the item key is no
   *     longer amongst the newly added items, the value of the ComboBox will remain the same and the `selectedKey`
   *     and `selectedItem` properties **will not** be changed.
   * 	 - If the ComboBox has `selectedKey` and `selectedItem` set, the model changes and the item key corresponds
   *     to newly added item, with different text, the value of the ComboBox **will** be updated with the text
   *     of the newly corresponding item.
   * 	 - If the ComboBox has only value, but no `selectedKey` and `selectedItem` set, the model changes, the
   *     value **will** remain the same and the `selectedKey` and `selectedItem` properties **will not** be changed.
   *
   * 	 - The width of the option list adapts to its content. The minimum width is the input field plus the
   *     drop-down arrow.
   * 	 - There is no horizontal scrolling in the option list. Entries in the list that are too long will be
   *     truncated.
   * 	 - On phone devices the combo box option list opens a dialog.
   *
   * @since 1.22
   */
  export default class ComboBox
    extends ComboBoxBase
    implements IToolbarInteractiveControl
  {
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new ComboBox.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/combo-box/ Combo Box}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ComboBoxSettings
    );
    /**
     * Constructor for a new ComboBox.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/combo-box/ Combo Box}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ComboBoxSettings
    );

    /**
     * Creates a new subclass of class sap.m.ComboBox with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ComboBoxBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ComboBox>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ComboBox.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Configures the SuggestionsPopover's list.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    _configureList(
      /**
       * The list instance to be configured
       */
      oList: List
    ): void;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.ComboBox`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ComboBox` itself.
     *
     * This event is fired when the value in the text input field is changed in combination with one of the
     * following actions:
     *
     *
     * 	 - The focus leaves the text input field
     * 	 - The Enter key is pressed
     * 	 - An item in the list is selected
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ComboBox$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ComboBox` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.ComboBox`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ComboBox` itself.
     *
     * This event is fired when the value in the text input field is changed in combination with one of the
     * following actions:
     *
     *
     * 	 - The focus leaves the text input field
     * 	 - The Enter key is pressed
     * 	 - An item in the list is selected
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ComboBox$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ComboBox` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionChange selectionChange} event of this
     * `sap.m.ComboBox`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ComboBox` itself.
     *
     * This event is fired when the user types something that matches with an item in the list; it is also fired
     * when the user presses on a list item, or when navigating via keyboard.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ComboBox$SelectionChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ComboBox` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionChange selectionChange} event of this
     * `sap.m.ComboBox`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ComboBox` itself.
     *
     * This event is fired when the user types something that matches with an item in the list; it is also fired
     * when the user presses on a list item, or when navigating via keyboard.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ComboBox$SelectionChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ComboBox` itself
       */
      oListener?: object
    ): this;
    /**
     * Clears the selection.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    clearSelection(): void;
    /**
     * Clones the `sap.m.ComboBox` control.
     *
     * @since 1.22.1
     *
     * @returns The cloned `sap.m.ComboBox` control.
     */
    clone(
      /**
       * Suffix to be added to the IDs of the new control and its internal objects.
       */
      sIdSuffix?: string
    ): this;
    /**
     * `ComboBox` picker configuration
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    configPicker(
      /**
       * Picker instance
       */
      oPicker: Popover | Dialog
    ): void;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:change change} event of this `sap.m.ComboBox`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ComboBox$ChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:selectionChange selectionChange} event of
     * this `sap.m.ComboBox`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelectionChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ComboBox$SelectionChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * This method will be called when the ComboBox is being destroyed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    exit(): void;
    /**
     * Fires event {@link #event:change change} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ComboBox$ChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:selectionChange selectionChange} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelectionChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ComboBox$SelectionChangeEventParameters
    ): this;
    /**
     * Gets the default selected item from the aggregation named `items`.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Null, as there is no default selected item
     */
    getDefaultSelectedItem(): null;
    /**
     * Gets current value of property {@link #getFilterSecondaryValues filterSecondaryValues}.
     *
     * Indicates whether the filter should check in both the `text` and the `additionalText` property of the
     * {@link sap.ui.core.ListItem} for the suggestion.
     *
     * Default value is `false`.
     *
     * @since 1.46
     *
     * @returns Value of property `filterSecondaryValues`
     */
    getFilterSecondaryValues(): boolean;
    /**
     * Gets the selected item object from the aggregation named `items`.
     *
     *
     * @returns The current target of the `selectedItem` association, or `null`.
     */
    getSelectedItem(): Item | null;
    /**
     * Gets current value of property {@link #getSelectedItemId selectedItemId}.
     *
     * ID of the selected item.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `selectedItemId`
     */
    getSelectedItemId(): string;
    /**
     * Gets current value of property {@link #getSelectedKey selectedKey}.
     *
     * Key of the selected item.
     *
     * **Note:** If duplicate keys exist, the first item matching the key is used.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `selectedKey`
     */
    getSelectedKey(): string;
    /**
     * This method will be called when the ComboBox is initially created.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    init(): void;
    /**
     * This event handler will be called after the ComboBox Picker's List is rendered.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onAfterRenderingList(): void;
    /**
     * This event handler will be called after the ComboBox's Picker is rendered.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onAfterRenderingPicker(): void;
    /**
     * This event handler is called before the picker popup is opened.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onBeforeOpen(): void;
    /**
     * This event handler will be called before the ComboBox is rendered.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onBeforeRendering(): void;
    /**
     * This event handler will be called before the ComboBox' Picker of type `sap.m.Popover` is rendered.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onBeforeRenderingDropdown(): void;
    /**
     * This event handler will be called before the ComboBox Picker's List is rendered.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onBeforeRenderingList(): void;
    /**
     * This event handler will be called before the ComboBox's Picker is rendered.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onBeforeRenderingPicker(): void;
    /**
     * Called when the `ComboBox` is clicked or tapped.
     */
    ontap(
      /**
       * The event object.
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * Opens the control's picker popup.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns `this` to allow method chaining.
     */
    open(): this;
    /**
     * Sets the start and end positions of the current text selection.
     *
     * @since 1.22.1
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns `this` to allow method chaining
     */
    selectText(
      /**
       * The index of the first selected character.
       */
      iSelectionStart: int,
      /**
       * The index of the character after the last selected character.
       */
      iSelectionEnd: int
    ): this;
    /**
     * Sets a new value for property {@link #getFilterSecondaryValues filterSecondaryValues}.
     *
     * Indicates whether the filter should check in both the `text` and the `additionalText` property of the
     * {@link sap.ui.core.ListItem} for the suggestion.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.46
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFilterSecondaryValues(
      /**
       * New value for property `filterSecondaryValues`
       */
      bFilterSecondaryValues?: boolean
    ): this;
    /**
     * Sets the `selectedItem` association.
     *
     * Default value is `null`.
     *
     *
     * @returns `this` to allow method chaining.
     */
    setSelectedItem(
      /**
       * New value for the `selectedItem` association. If an ID of a `sap.ui.core.Item` is given, the item with
       * this ID becomes the `selectedItem` association. Alternatively, a `sap.ui.core.Item` instance may be given
       * or `null` to clear the selection.
       */
      vItem: ID | Item | null
    ): this;
    /**
     * Sets the `selectedItemId` property.
     *
     * Default value is an empty string `""` or `undefined`.
     *
     *
     * @returns `this` to allow method chaining.
     */
    setSelectedItemId(
      /**
       * New value for property `selectedItemId`. If the provided `vItem` is an empty string `""` or `undefined`,
       * the selection is cleared. If the ID has no corresponding aggregated item, the selected item is not changed.
       */
      vItem: string | undefined
    ): this;
    /**
     * Sets the `selectedKey` property.
     *
     * Default value is an empty string `""` or `undefined`.
     *
     *
     * @returns `this` to allow method chaining.
     */
    setSelectedKey(
      /**
       * New value for property `selectedKey`. If the provided `sKey` is an empty string `""` or `undefined`,
       * the selection is cleared. If duplicate keys exist, the first item matching the key is selected. If a
       * key is set and no item exists with that key, the visual selection remains the same.
       */
      sKey: string
    ): this;
    /**
     * Synchronizes the `selectedItem` association and the `selectedItemId` property.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    synchronizeSelection(): void;
    /**
     * Creates picker if doesn't exist yet and sync with Control items
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    syncPickerContent(): Dialog | Popover;
  }
  /**
   * Describes the settings that can be provided to the ComboBox constructor.
   */
  export interface $ComboBoxSettings extends $ComboBoxBaseSettings {
    /**
     * Key of the selected item.
     *
     * **Note:** If duplicate keys exist, the first item matching the key is used.
     */
    selectedKey?: string | PropertyBindingInfo;

    /**
     * ID of the selected item.
     */
    selectedItemId?: string | PropertyBindingInfo;

    /**
     * Indicates whether the filter should check in both the `text` and the `additionalText` property of the
     * {@link sap.ui.core.ListItem} for the suggestion.
     *
     * @since 1.46
     */
    filterSecondaryValues?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets or retrieves the selected item from the aggregation named items.
     */
    selectedItem?: Item | string;

    /**
     * This event is fired when the value in the text input field is changed in combination with one of the
     * following actions:
     *
     *
     * 	 - The focus leaves the text input field
     * 	 - The Enter key is pressed
     * 	 - An item in the list is selected
     */
    change?: (oEvent: ComboBox$ChangeEvent) => void;

    /**
     * This event is fired when the user types something that matches with an item in the list; it is also fired
     * when the user presses on a list item, or when navigating via keyboard.
     */
    selectionChange?: (oEvent: ComboBox$SelectionChangeEvent) => void;
  }

  /**
   * Parameters of the ComboBox#change event.
   */
  export interface ComboBox$ChangeEventParameters
    extends InputBase$ChangeEventParameters {
    /**
     * Indicates whether the change event was caused by selecting an item in the list
     */
    itemPressed?: boolean;
  }

  /**
   * Event object of the ComboBox#change event.
   */
  export type ComboBox$ChangeEvent = Event<
    ComboBox$ChangeEventParameters,
    ComboBox
  >;

  /**
   * Parameters of the ComboBox#selectionChange event.
   */
  export interface ComboBox$SelectionChangeEventParameters {
    /**
     * The selected item.
     */
    selectedItem?: Item;
  }

  /**
   * Event object of the ComboBox#selectionChange event.
   */
  export type ComboBox$SelectionChangeEvent = Event<
    ComboBox$SelectionChangeEventParameters,
    ComboBox
  >;
}

declare module "sap/m/ComboBoxBase" {
  import {
    default as ComboBoxTextField,
    $ComboBoxTextFieldSettings,
  } from "sap/m/ComboBoxTextField";

  import Item from "sap/ui/core/Item";

  import Event from "sap/ui/base/Event";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Popover from "sap/m/Popover";

  import Dialog from "sap/m/Dialog";

  import List from "sap/m/List";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Input from "sap/m/Input";

  import Control from "sap/ui/core/Control";

  /**
   * An abstract class for combo boxes.
   *
   * @since 1.22.0
   */
  export default abstract class ComboBoxBase extends ComboBoxTextField {
    /**
     * Constructor for a new `sap.m.ComboBoxBase`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control.
       */
      mSettings?: $ComboBoxBaseSettings
    );
    /**
     * Constructor for a new `sap.m.ComboBoxBase`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given.
       */
      sId?: string,
      /**
       * Initial settings for the new control.
       */
      mSettings?: $ComboBoxBaseSettings
    );

    /**
     * Creates a new subclass of class sap.m.ComboBoxBase with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ComboBoxTextField.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ComboBoxBase>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ComboBoxBase.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets the ID of the hidden label for the group header items
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Id of hidden text
     */
    _getGroupHeaderInvisibleText(): string;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: Item
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:loadItems loadItems} event of this `sap.m.ComboBoxBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ComboBoxBase` itself.
     *
     * This event is fired when the end user clicks the combo box button to open the dropdown list and the data
     * used to display items is not already loaded. Alternatively, it is fired after the user moves the cursor
     * to the combo box text field and perform an action that requires data to be loaded. For example, pressing
     * F4 to open the dropdown list or typing something in the text field fires the event.
     *
     * **Note:** Use this feature in performance critical scenarios only. Loading the data lazily (on demand)
     * to defer initialization has several implications for the end user experience. For example, the busy indicator
     * has to be shown while the items are being loaded and assistive technology software also has to announce
     * the state changes (which may be confusing for some screen reader users).
     *
     * **Note**: Currently the `sap.m.MultiComboBox` does not support this event.
     *
     * @since 1.38
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLoadItems(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ComboBoxBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:loadItems loadItems} event of this `sap.m.ComboBoxBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ComboBoxBase` itself.
     *
     * This event is fired when the end user clicks the combo box button to open the dropdown list and the data
     * used to display items is not already loaded. Alternatively, it is fired after the user moves the cursor
     * to the combo box text field and perform an action that requires data to be loaded. For example, pressing
     * F4 to open the dropdown list or typing something in the text field fires the event.
     *
     * **Note:** Use this feature in performance critical scenarios only. Loading the data lazily (on demand)
     * to defer initialization has several implications for the end user experience. For example, the busy indicator
     * has to be shown while the items are being loaded and assistive technology software also has to announce
     * the state changes (which may be confusing for some screen reader users).
     *
     * **Note**: Currently the `sap.m.MultiComboBox` does not support this event.
     *
     * @since 1.38
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLoadItems(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ComboBoxBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getItems items} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Clears the selection. To be overwritten by subclasses.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    clearSelection(): void;
    /**
     * Closes the control's picker popup.
     *
     *
     * @returns `this` to allow method chaining.
     */
    close(): this;
    /**
     * Base method for picker configuration
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    configPicker(
      /**
       * Picker instance
       */
      oPicker: Popover | Dialog
    ): void;
    /**
     * Creates a picker popup container where the selection should take place. To be overwritten by subclasses.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The picker popup to be used.
     */
    createPicker(
      /**
       * The picker type
       */
      sPickerType: string
    ): Popover | Dialog;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:loadItems loadItems} event of this `sap.m.ComboBoxBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.38
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLoadItems(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:loadItems loadItems} to attached listeners.
     *
     * @since 1.38
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLoadItems(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets the enabled items from the aggregation named `items`.
     *
     * @deprecated As of version 1.86. The enabled items should be managed by the application.
     *
     * @returns An array containing the enabled items.
     */
    getEnabledItems(
      /**
       * Items to filter.
       */
      aItems?: Item[]
    ): Item[];
    /**
     * Gets the first item from the aggregation named `items`.
     *
     *
     * @returns The first item, or `null` if there are no items.
     */
    getFirstItem(): Item | null;
    /**
     * Gets the input properties, which should be forwarded from the combobox text field to the picker text
     * field
     *
     * @since 1.66
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Array of the forwardable properties
     */
    getInputForwardableProperties(): any[];
    /**
     * Gets the item from the aggregation named `items` at the given 0-based index.
     *
     *
     * @returns Item at the given index, or `null` if none.
     */
    getItemAt(
      /**
       * Index of the item to return.
       */
      iIndex: int
    ): Item | null;
    /**
     * Gets the item with the given key from the aggregation named `items`.
     *  **Note:** If duplicate keys exist, the first item matching the key is returned.
     *
     *
     * @returns The matching item
     */
    getItemByKey(
      /**
       * An item key that specifies the item to retrieve.
       */
      sKey: string
    ): Item;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * Defines the items contained within this control. **Note:** Disabled items are not visualized in the list
     * with the available options, however they can still be accessed through the aggregation.
     */
    getItems(): Item[];
    /**
     * Gets the last item from the aggregation named `items`.
     *
     *
     * @returns The last item, or `null` if there are no items.
     */
    getLastItem(): Item | null;
    /**
     * Gets the `list`.
     *
     * @deprecated As of version 1.62. The list structure should not be used as per SAP note: 2746748.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The list instance object or `null`.
     */
    getList(): List | null;
    /**
     * Gets the control's picker popup.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The picker instance the `createPicker()` method.
     */
    getPicker(): Dialog | Popover | null;
    /**
     * Gets the ID of the hidden label
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Id of hidden text
     */
    getPickerInvisibleTextId(): string;
    /**
     * Gets the control's input from the picker.
     *
     * @since 1.42
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Picker's input for filtering the list
     */
    getPickerTextField(): ComboBoxTextField | Input | null;
    /**
     * Gets the property `_sPickerType`
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The picker type
     */
    getPickerType(): string;
    /**
     * Gets the flag indicating whether the list items should be recreated
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns True if the list items should be recreated
     */
    getRecreateItems(): boolean;
    /**
     * Gets current value of property {@link #getShowClearIcon showClearIcon}.
     *
     * Specifies whether clear icon is shown. Pressing the icon will clear input's value.
     *
     * Default value is `false`.
     *
     * @since 1.96
     *
     * @returns Value of property `showClearIcon`
     */
    getShowClearIcon(): boolean;
    /**
     * Gets current value of property {@link #getShowSecondaryValues showSecondaryValues}.
     *
     * Indicates whether the text values of the `additionalText` property of a {@link sap.ui.core.ListItem }
     * are shown.
     *
     * Default value is `false`.
     *
     * @since 1.60
     *
     * @returns Value of property `showSecondaryValues`
     */
    getShowSecondaryValues(): boolean;
    /**
     * Fires when an object gets inserted in the items aggregation.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    handleItemInsertion(
      /**
       * The item that should be inserted
       */
      oItem: Item
    ): void;
    /**
     * Fires when an object gets removed from the items aggregation.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    handleItemRemoval(
      /**
       * The item that should be removed
       */
      oItem: Item
    ): void;
    /**
     * Determines whether the control has content or not.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns True if the control has content
     */
    hasContent(): boolean;
    /**
     * Handles highlighting of items after filtering.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    highlightList(
      /**
       * The value of the item
       */
      sValue: string
    ): void;
    /**
     * Checks for the provided `sap.ui.core.Item` in the aggregation {@link #getItems items}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: Item
    ): int;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: Item,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Finds the common items of two arrays
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Array of unique items from both arrays
     */
    intersectItems(
      /**
       * Array of Items
       */
      aItems: Item[],
      /**
       * Second array of items
       */
      aOtherItems: Item[]
    ): Item[];
    /**
     * Indicates whether the control's picker popup is open.
     *
     *
     * @returns Determines whether the control's picker popup is currently open (this includes opening and closing
     * animations).
     */
    isOpen(): boolean;
    /**
     * Called when the composition of a passage of text has been completed or cancelled.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    oncompositionend(
      /**
       * The event object.
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * Handles properties' changes of items in the aggregation named `items`.
     *
     * @since 1.90
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onItemChange(
      /**
       * The change event
       */
      oControlEvent: Event,
      /**
       * Indicates whether second values should be shown
       */
      bShowSecondaryValues: boolean
    ): void;
    /**
     * Opens the control's picker popup.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns `this` to allow method chaining.
     */
    open(): this;
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): Item[];
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | Item
    ): Item | null;
    /**
     * Sets a custom filter function for items. The function accepts two parameters: - currenly typed value
     * in the input field - item to be matched The function should return a Boolean value (true or false) which
     * represents whether an item will be shown in the dropdown or not. If no callback is provided, the control
     * fallbacks to default filtering.
     *
     * @since 1.58
     *
     * @returns `this` to allow method chaining.
     */
    setFilterFunction(
      /**
       * A callback function called when typing in a ComboBoxBase control or ancestor.
       */
      fnFilter?: (p1?: string, p2?: Item) => boolean
    ): this;
    /**
     * Sets the property `_sPickerType`.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    setPickerType(
      /**
       * The picker type
       */
      sPickerType: string
    ): void;
    /**
     * Sets whether the list items should be recreated.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    setRecreateItems(
      /**
       * True if the list items should be recreated
       */
      bRecreate: boolean
    ): void;
    /**
     * Sets the selectable property of `sap.ui.core.Item`
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    setSelectable(
      /**
       * The item to set the property
       */
      oItem: Item,
      /**
       * The selectable value
       */
      bSelectable: boolean
    ): void;
    /**
     * Sets a new value for property {@link #getShowClearIcon showClearIcon}.
     *
     * Specifies whether clear icon is shown. Pressing the icon will clear input's value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.96
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowClearIcon(
      /**
       * New value for property `showClearIcon`
       */
      bShowClearIcon?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowSecondaryValues showSecondaryValues}.
     *
     * Indicates whether the text values of the `additionalText` property of a {@link sap.ui.core.ListItem }
     * are shown.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.60
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowSecondaryValues(
      /**
       * New value for property `showSecondaryValues`
       */
      bShowSecondaryValues?: boolean
    ): this;
    /**
     * Sets the TextField handler
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    setTextFieldHandler(
      /**
       * Text field instance
       */
      oTextField: ComboBoxTextField | Input
    ): void;
    /**
     * Sets the value property of the control.
     *
     *
     * @returns this instance for method chaining
     */
    setValue(
      /**
       * The new value
       */
      sValue: string
    ): this;
    /**
     * Opens the `SuggestionsPopover` with the available items.
     *
     * @since 1.64
     */
    showItems(
      /**
       * Function to filter the items shown in the SuggestionsPopover
       */
      fnFilter: Function | undefined
    ): void;
    /**
     * Creates picker if doesn't exist yet and sync with Control items To be overwritten by subclasses.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    syncPickerContent(): Control;
    /**
     * Unbinds aggregation {@link #getItems items} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindItems(): this;
  }
  /**
   * Describes the settings that can be provided to the ComboBoxBase constructor.
   */
  export interface $ComboBoxBaseSettings extends $ComboBoxTextFieldSettings {
    /**
     * Indicates whether the text values of the `additionalText` property of a {@link sap.ui.core.ListItem }
     * are shown.
     *
     * @since 1.60
     */
    showSecondaryValues?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies whether clear icon is shown. Pressing the icon will clear input's value.
     *
     * @since 1.96
     */
    showClearIcon?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the items contained within this control. **Note:** Disabled items are not visualized in the list
     * with the available options, however they can still be accessed through the aggregation.
     */
    items?: Item[] | Item | AggregationBindingInfo | `{${string}}`;

    /**
     * This event is fired when the end user clicks the combo box button to open the dropdown list and the data
     * used to display items is not already loaded. Alternatively, it is fired after the user moves the cursor
     * to the combo box text field and perform an action that requires data to be loaded. For example, pressing
     * F4 to open the dropdown list or typing something in the text field fires the event.
     *
     * **Note:** Use this feature in performance critical scenarios only. Loading the data lazily (on demand)
     * to defer initialization has several implications for the end user experience. For example, the busy indicator
     * has to be shown while the items are being loaded and assistive technology software also has to announce
     * the state changes (which may be confusing for some screen reader users).
     *
     * **Note**: Currently the `sap.m.MultiComboBox` does not support this event.
     *
     * @since 1.38
     */
    loadItems?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the ComboBoxBase#loadItems event.
   */
  export interface ComboBoxBase$LoadItemsEventParameters {}

  /**
   * Event object of the ComboBoxBase#loadItems event.
   */
  export type ComboBoxBase$LoadItemsEvent = Event<
    ComboBoxBase$LoadItemsEventParameters,
    ComboBoxBase
  >;
}

declare module "sap/m/ComboBoxTextField" {
  import { default as InputBase, $InputBaseSettings } from "sap/m/InputBase";

  import { CSSSize } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The `sap.m.ComboBoxTextField`.
   *
   * @since 1.34
   */
  export default class ComboBoxTextField extends InputBase {
    /**
     * Constructor for a new `sap.m.ComboBoxTextField`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control.
       */
      mSettings?: $ComboBoxTextFieldSettings
    );
    /**
     * Constructor for a new `sap.m.ComboBoxTextField`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given.
       */
      sId?: string,
      /**
       * Initial settings for the new control.
       */
      mSettings?: $ComboBoxTextFieldSettings
    );
    /**
     * Returns the arrow icon
     *
     * Left for backward compatibility.
     *
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    getIcon: undefined;

    /**
     * Creates a new subclass of class sap.m.ComboBoxTextField with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.InputBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ComboBoxTextField>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ComboBoxTextField.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getMaxWidth maxWidth}.
     *
     * Sets the maximum width of the text field.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Value of property `maxWidth`
     */
    getMaxWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getShowButton showButton}.
     *
     * Indicates whether the dropdown downward-facing arrow button is shown.
     *
     * Default value is `true`.
     *
     * @since 1.38
     *
     * @returns Value of property `showButton`
     */
    getShowButton(): boolean;
    /**
     * Gets the `value`.
     *
     * Default value is an empty string.
     *
     *
     * @returns The value of property `value`
     */
    getValue(): string;
    /**
     * Sets a new value for property {@link #getMaxWidth maxWidth}.
     *
     * Sets the maximum width of the text field.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxWidth(
      /**
       * New value for property `maxWidth`
       */
      sMaxWidth?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getShowButton showButton}.
     *
     * Indicates whether the dropdown downward-facing arrow button is shown.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.38
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowButton(
      /**
       * New value for property `showButton`
       */
      bShowButton?: boolean
    ): this;
    /**
     * Toggles the icon pressed style on or off.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    toggleIconPressedStyle(
      /**
       * True if the icon pressed class should be applied.
       */
      bState?: boolean
    ): void;
  }
  /**
   * Describes the settings that can be provided to the ComboBoxTextField constructor.
   */
  export interface $ComboBoxTextFieldSettings extends $InputBaseSettings {
    /**
     * Sets the maximum width of the text field.
     */
    maxWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether the dropdown downward-facing arrow button is shown.
     *
     * @since 1.38
     */
    showButton?: boolean | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/ContentConfig" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import { LinkAccessibleRole, ContentConfigType } from "sap/m/library";

  import { URI } from "sap/ui/core/library";

  import Link from "sap/m/Link";

  import Text from "sap/m/Text";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * This element is used within the TileAttribute control that generates either a link or text
   *
   * @since 1.122
   * @experimental As of version 1.122.
   */
  export default class ContentConfig extends UI5Element {
    /**
     * Constructor for a new ContentConfig.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control.
       */
      mSettings?: $ContentConfigSettings
    );
    /**
     * Constructor for a new ContentConfig.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, it is generated automatically if an ID is not provided.
       */
      sId?: string,
      /**
       * Initial settings for the new control.
       */
      mSettings?: $ContentConfigSettings
    );

    /**
     * Creates a new subclass of class sap.m.ContentConfig with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ContentConfig>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ContentConfig.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getAccessibleRole accessibleRole}.
     *
     * Describes the accessibility role of the link:
     * 	 - `LinkAccessibleRole.Default` - a navigation is expected to the location given in `href` property
     *
     * 	 - `LinkAccessibleRole.Button` - there will be `role` attribute with value "Button" rendered. In this
     *     scenario the `href` property value shouldn't be set as navigation isn't expected to occur.
     *
     * Default value is `Default`.
     *
     *
     * @returns Value of property `accessibleRole`
     */
    getAccessibleRole(): LinkAccessibleRole;
    /**
     * Gets current value of property {@link #getHref href}.
     *
     * Defines the link target URI. Supports standard hyperlink behavior. **Note:** Don't set `href` property
     * if an action should be triggered by the link. Instead set `accessibleRole` property to `LinkAccessibleRole.Button`
     * and register a `press` event handler.
     *
     *
     * @returns Value of property `href`
     */
    getHref(): URI;
    /**
     * Returns the current element instance
     */
    getInnerControl(): Record<string, Link> | Record<string, Text>;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Defines the displayed text.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getType type}.
     *
     * The type of the ContentConfig.
     *
     * Default value is `Text`.
     *
     *
     * @returns Value of property `type`
     */
    getType(): ContentConfigType;
    /**
     * Sets a new value for property {@link #getAccessibleRole accessibleRole}.
     *
     * Describes the accessibility role of the link:
     * 	 - `LinkAccessibleRole.Default` - a navigation is expected to the location given in `href` property
     *
     * 	 - `LinkAccessibleRole.Button` - there will be `role` attribute with value "Button" rendered. In this
     *     scenario the `href` property value shouldn't be set as navigation isn't expected to occur.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Default`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAccessibleRole(
      /**
       * New value for property `accessibleRole`
       */
      sAccessibleRole?: LinkAccessibleRole | keyof typeof LinkAccessibleRole
    ): this;
    /**
     * Sets a new value for property {@link #getHref href}.
     *
     * Defines the link target URI. Supports standard hyperlink behavior. **Note:** Don't set `href` property
     * if an action should be triggered by the link. Instead set `accessibleRole` property to `LinkAccessibleRole.Button`
     * and register a `press` event handler.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHref(
      /**
       * New value for property `href`
       */
      sHref?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Defines the displayed text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getType type}.
     *
     * The type of the ContentConfig.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Text`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setType(
      /**
       * New value for property `type`
       */
      sType?: ContentConfigType | keyof typeof ContentConfigType
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ContentConfig constructor.
   *
   * @experimental As of version 1.122.
   */
  export interface $ContentConfigSettings extends $ElementSettings {
    /**
     * The type of the ContentConfig.
     */
    type?:
      | (ContentConfigType | keyof typeof ContentConfigType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the displayed text.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Defines the link target URI. Supports standard hyperlink behavior. **Note:** Don't set `href` property
     * if an action should be triggered by the link. Instead set `accessibleRole` property to `LinkAccessibleRole.Button`
     * and register a `press` event handler.
     */
    href?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Describes the accessibility role of the link:
     * 	 - `LinkAccessibleRole.Default` - a navigation is expected to the location given in `href` property
     *
     * 	 - `LinkAccessibleRole.Button` - there will be `role` attribute with value "Button" rendered. In this
     *     scenario the `href` property value shouldn't be set as navigation isn't expected to occur.
     */
    accessibleRole?:
      | (LinkAccessibleRole | keyof typeof LinkAccessibleRole)
      | PropertyBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/CustomListItem" {
  import {
    default as ListItemBase,
    $ListItemBaseSettings,
  } from "sap/m/ListItemBase";

  import Control from "sap/ui/core/Control";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * This control with a content aggregation can be used to customize standard list items that we don't provide.
   * List mode and ListItem type are applied to CustomListItems as well. **Note:** Even though the content
   * aggregation allows any control, complex responsive layout controls (e.g. `Table, Form`) should not be
   * aggregated as content.
   */
  export default class CustomListItem extends ListItemBase {
    /**
     * Constructor for a new CustomListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $CustomListItemSettings
    );
    /**
     * Constructor for a new CustomListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $CustomListItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.CustomListItem with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ListItemBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, CustomListItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.CustomListItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some content to the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContent(
      /**
       * The content to add; if empty, nothing is inserted
       */
      oContent: Control
    ): this;
    /**
     * Binds aggregation {@link #getContent content} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindContent(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Gets current value of property {@link #getAccDescription accDescription}.
     *
     * Defines the custom accessibility announcement.
     *
     * **Note:** If defined, then only the provided custom accessibility description is announced when there
     * is a focus on the list item.
     *
     * @since 1.84
     *
     * @returns Value of property `accDescription`
     */
    getAccDescription(): string;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * The content of this list item
     */
    getContent(): Control[];
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContent content}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContent(
      /**
       * The content whose index is looked for
       */
      oContent: Control
    ): int;
    /**
     * Inserts a content into the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContent(
      /**
       * The content to insert; if empty, nothing is inserted
       */
      oContent: Control,
      /**
       * The `0`-based index the content should be inserted at; for a negative value of `iIndex`, the content
       * is inserted at position 0; for a value greater than the current size of the aggregation, the content
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getContent content}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContent(): Control[];
    /**
     * Removes a content from the aggregation {@link #getContent content}.
     *
     *
     * @returns The removed content or `null`
     */
    removeContent(
      /**
       * The content to remove or its index or id
       */
      vContent: int | string | Control
    ): Control | null;
    /**
     * Sets a new value for property {@link #getAccDescription accDescription}.
     *
     * Defines the custom accessibility announcement.
     *
     * **Note:** If defined, then only the provided custom accessibility description is announced when there
     * is a focus on the list item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.84
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAccDescription(
      /**
       * New value for property `accDescription`
       */
      sAccDescription: string
    ): this;
    /**
     * Unbinds aggregation {@link #getContent content} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindContent(): this;
  }
  /**
   * Describes the settings that can be provided to the CustomListItem constructor.
   */
  export interface $CustomListItemSettings extends $ListItemBaseSettings {
    /**
     * Defines the custom accessibility announcement.
     *
     * **Note:** If defined, then only the provided custom accessibility description is announced when there
     * is a focus on the list item.
     *
     * @since 1.84
     */
    accDescription?: string | PropertyBindingInfo;

    /**
     * The content of this list item
     */
    content?: Control[] | Control | AggregationBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/CustomTile" {
  import { default as Tile, $TileSettings } from "sap/m/Tile";

  import Control from "sap/ui/core/Control";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * Use the CustomTile control to display application specific content in the Tile control. The tile width
   * is 8.5em and height is 10em.
   *
   * @since 1.12
   * @deprecated As of version 1.50. use {@link sap.m.GenericTile} instead
   */
  export default class CustomTile extends Tile {
    /**
     * Constructor for a new CustomTile.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $CustomTileSettings
    );
    /**
     * Constructor for a new CustomTile.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $CustomTileSettings
    );

    /**
     * Creates a new subclass of class sap.m.CustomTile with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.Tile.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, CustomTile>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.CustomTile.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Destroys the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * Defines the content of the CustomTile.
     */
    getContent(): Control;
    /**
     * Sets the aggregated {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContent(
      /**
       * The content to set
       */
      oContent: Control
    ): this;
  }
  /**
   * Describes the settings that can be provided to the CustomTile constructor.
   *
   * @deprecated As of version 1.50. use {@link sap.m.GenericTile} instead
   */
  export interface $CustomTileSettings extends $TileSettings {
    /**
     * Defines the content of the CustomTile.
     */
    content?: Control;
  }
}

declare module "sap/m/CustomTreeItem" {
  import {
    default as TreeItemBase,
    $TreeItemBaseSettings,
  } from "sap/m/TreeItemBase";

  import Control from "sap/ui/core/Control";

  import { AggregationBindingInfo } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * The `CustomTreeItem` control with a content aggregation is used to customize the tree items within the
   * `Tree` control.
   * **Note:** Even though the content aggregation can be used for any control, complex responsive layout
   * controls, such as `Table, Form` etc, should not be aggregated as content.
   *
   * @since 1.48.0
   */
  export default class CustomTreeItem extends TreeItemBase {
    /**
     * Constructor for a new CustomTreeItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $CustomTreeItemSettings
    );
    /**
     * Constructor for a new CustomTreeItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $CustomTreeItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.CustomTreeItem with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.TreeItemBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, CustomTreeItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.CustomTreeItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some content to the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContent(
      /**
       * The content to add; if empty, nothing is inserted
       */
      oContent: Control
    ): this;
    /**
     * Binds aggregation {@link #getContent content} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindContent(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * The content of this tree item.
     */
    getContent(): Control[];
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContent content}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContent(
      /**
       * The content whose index is looked for
       */
      oContent: Control
    ): int;
    /**
     * Inserts a content into the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContent(
      /**
       * The content to insert; if empty, nothing is inserted
       */
      oContent: Control,
      /**
       * The `0`-based index the content should be inserted at; for a negative value of `iIndex`, the content
       * is inserted at position 0; for a value greater than the current size of the aggregation, the content
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getContent content}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContent(): Control[];
    /**
     * Removes a content from the aggregation {@link #getContent content}.
     *
     *
     * @returns The removed content or `null`
     */
    removeContent(
      /**
       * The content to remove or its index or id
       */
      vContent: int | string | Control
    ): Control | null;
    /**
     * Unbinds aggregation {@link #getContent content} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindContent(): this;
  }
  /**
   * Describes the settings that can be provided to the CustomTreeItem constructor.
   */
  export interface $CustomTreeItemSettings extends $TreeItemBaseSettings {
    /**
     * The content of this tree item.
     */
    content?: Control[] | Control | AggregationBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/DatePicker" {
  import {
    default as DateTimeField,
    $DateTimeFieldSettings,
  } from "sap/m/DateTimeField";

  import DateTypeRange from "sap/ui/unified/DateTypeRange";

  import Event from "sap/ui/base/Event";

  import { AccessibilityInfo, ID } from "sap/ui/core/library";

  import CalendarWeekNumbering from "sap/base/i18n/date/CalendarWeekNumbering";

  import UI5Date from "sap/ui/core/date/UI5Date";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import CalendarType from "sap/base/i18n/date/CalendarType";

  import UI5Element from "sap/ui/core/Element";

  import CalendarLegend from "sap/ui/unified/CalendarLegend";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Control from "sap/ui/core/Control";

  import { InputBase$ChangeEventParameters } from "sap/m/InputBase";

  import DateRange from "sap/ui/unified/DateRange";

  /**
   * Enables the users to select a localized date between 0001-01-01 and 9999-12-31.
   *
   * Overview:
   *
   * The `DatePicker` lets the users select a localized date using touch, mouse, or keyboard input. It consists
   * of two parts: the date input field and the date picker.
   *
   * **Note:** The application developer should add dependency to `sap.ui.unified` library on application
   * level to ensure that the library is loaded before the module dependencies will be required. The {@link sap.ui.unified.Calendar }
   * is used internally only if the `DatePicker` is opened (not used for the initial rendering). If the `sap.ui.unified`
   * library is not loaded before the `DatePicker` is opened, it will be loaded upon opening. This could lead
   * to CSP compliance issues and adds an additional waiting time when the `DatePicker` is opened for the
   * first time. To prevent this, apps using the `DatePicker` should also load the `sap.ui.unified` library
   * in advance.
   *
   * Usage:
   *
   * The user can enter a date by:
   * 	 - Using the calendar that opens in a popup
   * 	 - Typing it directly in the input field
   *
   * On app level, there are two options to provide a date for the `DatePicker` - as a string to the `value`
   * property or as a UI5Date or JavaScript Date object to the `dateValue` property (only one of these properties
   * should be used at a time):
   *
   *
   * 	 - Use the `value` property if you want to bind the `DatePicker` to a model using the `sap.ui.model.type.Date`
   *      binding the `value` property by using types
   * ```javascript
   *
   * new sap.ui.model.json.JSONModel({
   *     date: sap.ui.core.date.UI5Date.getInstance(2022,10,10,10,10,10)
   * });
   *
   * new sap.m.DatePicker({
   *     value:{path:"/date",type:"sap.ui.model.type.Date"}
   * });
   * ```
   *
   * 	 - Use the `value` property if the date is provided as a string from the backend or inside the app (for
   *     example, as ABAP type DATS field)  binding the `value` property by using types
   * ```javascript
   *
   * new sap.ui.model.json.JSONModel({date:'2022-11-10');
   *
   * new sap.m.DatePicker({
   *     value:{
   *         path:"/date",
   *         type:"sap.ui.model.type.Date",
   *         formatOptions:{
   *             source:{
   *                 pattern:"yyyy-MM-dd"
   *             }
   *         }
   *     }
   * });
   * ```
   *  **Note:** There are multiple binding type choices, such as: sap.ui.model.type.Date sap.ui.model.odata.type.DateTime
   * sap.ui.model.odata.type.DateTimeOffset See {@link sap.ui.model.type.Date}, {@link sap.ui.model.odata.type.DateTime }
   * or {@link sap.ui.model.odata.type.DateTimeOffset}
   *
   *
   * 	 - Use the `dateValue` property if the date is already provided as a UI5Date or JavaScript Date object
   *     or you want to work with a UI5Date or JavaScript Date object. Use `dateValue` as a helper property to
   *     easily obtain the day, month and year of the chosen date. Although it's possible to bind it, it's not
   *     recommended to do so. When binding is needed, use `value` property instead
   *
   * Formatting:
   *
   * All formatting and parsing of dates from and to strings is done using the {@link sap.ui.core.format.DateFormat}.
   * If a date is entered by typing it into the input field, it must fit to the used date format and locale.
   *
   * Supported format options are pattern-based on Unicode LDML Date Format notation. See {@link http://unicode.org/reports/tr35/#Date_Field_Symbol_Table}
   *
   * For example, if the `valueFormat` is "yyyy-MM-dd", the `displayFormat` is "MMM d, y", and the used locale
   * is English, a valid value string is "2015-07-30", which leads to an output of "Jul 30, 2015".
   *
   * If no placeholder is set to the `DatePicker`, the used `displayFormat` is displayed as a placeholder.
   * If another placeholder is needed, it must be set.
   *
   * **Note:** If the string does NOT match the `displayFormat` (from user input) or the `valueFormat` (on
   * app level), the {@link sap.ui.core.format.DateFormat} makes an attempt to parse it based on the locale
   * settings. For more information, see the respective documentation in the API Reference.
   *
   * Responsive behavior:
   *
   * The `DatePicker` is smaller in compact mode and provides a touch-friendly size in cozy mode.
   *
   * On mobile devices, one tap on the input field opens the `DatePicker` in full screen. To close the window,
   * the user can select a date (which triggers the close event), or select Cancel.
   *
   * @since 1.22.0
   */
  export default class DatePicker extends DateTimeField {
    /**
     * Constructor for a new `DatePicker`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/date-picker/ Date Picker}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $DatePickerSettings
    );
    /**
     * Constructor for a new `DatePicker`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/date-picker/ Date Picker}
     */
    constructor(
      /**
       * Id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $DatePickerSettings
    );

    /**
     * Creates a new subclass of class sap.m.DatePicker with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.DateTimeField.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, DatePicker>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.DatePicker.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some `specialDate` to the aggregation `specialDates`.
     *
     * @since 1.38.5
     *
     * @returns Reference to `this` for method chaining
     */
    addSpecialDate(
      /**
       * the specialDate to add; if empty, nothing is added
       */
      oSpecialDate: DateTypeRange
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterValueHelpClose afterValueHelpClose} event
     * of this `sap.m.DatePicker`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.DatePicker` itself.
     *
     * Fired when `value help` dialog closes.
     *
     * @since 1.102.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterValueHelpClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.DatePicker` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterValueHelpClose afterValueHelpClose} event
     * of this `sap.m.DatePicker`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.DatePicker` itself.
     *
     * Fired when `value help` dialog closes.
     *
     * @since 1.102.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterValueHelpClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.DatePicker` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterValueHelpOpen afterValueHelpOpen} event
     * of this `sap.m.DatePicker`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.DatePicker` itself.
     *
     * Fired when `value help` dialog opens.
     *
     * @since 1.102.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterValueHelpOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.DatePicker` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterValueHelpOpen afterValueHelpOpen} event
     * of this `sap.m.DatePicker`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.DatePicker` itself.
     *
     * Fired when `value help` dialog opens.
     *
     * @since 1.102.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterValueHelpOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.DatePicker` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navigate navigate} event of this `sap.m.DatePicker`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.DatePicker` itself.
     *
     * Fired when navigating in `Calendar` popup.
     *
     * @since 1.46.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavigate(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: DatePicker$NavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.DatePicker` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navigate navigate} event of this `sap.m.DatePicker`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.DatePicker` itself.
     *
     * Fired when navigating in `Calendar` popup.
     *
     * @since 1.46.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavigate(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: DatePicker$NavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.DatePicker` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the specialDates in the aggregation {@link #getSpecialDates specialDates}.
     *
     * @since 1.38.5
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySpecialDates(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterValueHelpClose afterValueHelpClose} event
     * of this `sap.m.DatePicker`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.102.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterValueHelpClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterValueHelpOpen afterValueHelpOpen} event
     * of this `sap.m.DatePicker`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.102.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterValueHelpOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:navigate navigate} event of this `sap.m.DatePicker`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.46.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachNavigate(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: DatePicker$NavigateEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:afterValueHelpClose afterValueHelpClose} to attached listeners.
     *
     * @since 1.102.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterValueHelpClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:afterValueHelpOpen afterValueHelpOpen} to attached listeners.
     *
     * @since 1.102.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterValueHelpOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fire event change to attached listeners.
     *
     * Expects following event parameters:
     * 	 - 'value' of type `string` The new value of the `sap.m.DatePicker`.
     * 	 - 'valid' of type `boolean` Indicator for a valid date.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` for method chaining
     */
    fireChange(
      /**
       * the arguments to pass along with the event.
       */
      mArguments?: object
    ): this;
    /**
     * Fires event {@link #event:navigate navigate} to attached listeners.
     *
     * @since 1.46.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireNavigate(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: DatePicker$NavigateEventParameters
    ): this;
    /**
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Current accessibility state of the control.
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Gets current value of property {@link #getCalendarWeekNumbering calendarWeekNumbering}.
     *
     * If set, the calendar week numbering is used for display. If not set, the calendar week numbering of the
     * global configuration is used.
     *
     * @since 1.108.0
     *
     * @returns Value of property `calendarWeekNumbering`
     */
    getCalendarWeekNumbering(): CalendarWeekNumbering;
    /**
     * The date instance. This is independent from any formatter.
     *
     * **Note:** If this property is used, the `value` property should not be changed from the caller.
     *
     *
     * @returns the value of property `dateValue`
     */
    getDateValue(): Date | UI5Date | null;
    /**
     * The date is displayed in the input field using this format. By default, the medium format of the used
     * locale is used.
     *
     * Supported format options are pattern-based on Unicode LDML Date Format notation. {@link http://unicode.org/reports/tr35/#Date_Field_Symbol_Table }
     * **Note:** If you use data binding on the `value` property with type `sap.ui.model.type.Date` this property
     * will be ignored. The format defined in the binding will be used.
     *
     *
     * @returns the value of property `displayFormat`
     */
    getDisplayFormat(): string;
    /**
     * Gets current value of property {@link #getDisplayFormatType displayFormatType}.
     *
     * Displays date in this given type in input field. Default value is taken from locale settings. Accepted
     * are values of {@link module:sap/base/i18n/date/CalendarType} or an empty string. If no type is set, the
     * default type of the configuration is used. **Note:** If data binding on `value` property with type `sap.ui.model.type.Date`
     * is used, this property will be ignored.
     *
     * Default value is `empty string`.
     *
     * @since 1.28.6
     *
     * @returns Value of property `displayFormatType`
     */
    getDisplayFormatType(): string;
    /**
     * Gets current value of property {@link #getHideInput hideInput}.
     *
     * Determines whether the input field of the picker is hidden or visible. When set to `true`, the input
     * field becomes invisible and there is no way to open the picker popover. In that case it can be opened
     * by another control through calling of picker's `openBy` method, and the opening control's DOM reference
     * must be provided as parameter.
     *
     * Note: Since the picker is not responsible for accessibility attributes of the control which opens its
     * popover, those attributes should be added by the application developer. The following is recommended
     * to be added to the opening control: a text or tooltip that describes the action (example: "Open Date
     * Picker"), and also aria-haspopup attribute with value of `sap.ui.core.aria.HasPopup.Dialog`.
     *
     * Default value is `false`.
     *
     * @since 1.97
     *
     * @returns Value of property `hideInput`
     */
    getHideInput(): boolean;
    /**
     * ID of the element which is the current target of the association {@link #getLegend legend}, or `null`.
     *
     * @since 1.38.5
     */
    getLegend(): ID | null;
    /**
     * Gets current value of property {@link #getMaxDate maxDate}.
     *
     * Maximum date that can be shown and selected in the `DatePicker`. This must be a UI5Date or JavaScript
     * Date object.
     *
     * **Note:** If the `maxDate` is set to be before the `minDate`, the `maxDate` and the `minDate` are switched
     * before rendering.
     *
     * @since 1.38.0
     *
     * @returns Value of property `maxDate`
     */
    getMaxDate(): object;
    /**
     * Gets current value of property {@link #getMinDate minDate}.
     *
     * Minimum date that can be shown and selected in the `DatePicker`. This must be a UI5Date or JavaScript
     * Date object.
     *
     * **Note:** If the `minDate` is set to be after the `maxDate`, the `maxDate` and the `minDate` are switched
     * before rendering.
     *
     * @since 1.38.0
     *
     * @returns Value of property `minDate`
     */
    getMinDate(): object;
    /**
     * Gets current value of property {@link #getSecondaryCalendarType secondaryCalendarType}.
     *
     * If set, the days in the calendar popup are also displayed in this calendar type If not set, the dates
     * are only displayed in the primary calendar type
     *
     * @since 1.34.1
     *
     * @returns Value of property `secondaryCalendarType`
     */
    getSecondaryCalendarType(): CalendarType;
    /**
     * Gets current value of property {@link #getShowCurrentDateButton showCurrentDateButton}.
     *
     * Determines whether there is a shortcut navigation to Today. When used in Month, Year or Year-range picker
     * view, the calendar navigates to Day picker view.
     *
     * Note: The Current date button appears if the `displayFormat` property allows entering day.
     *
     * Default value is `false`.
     *
     * @since 1.95
     *
     * @returns Value of property `showCurrentDateButton`
     */
    getShowCurrentDateButton(): boolean;
    /**
     * Gets current value of property {@link #getShowFooter showFooter}.
     *
     * Hides or shows the popover's footer.
     *
     * Default value is `false`.
     *
     * @since 1.70
     *
     * @returns Value of property `showFooter`
     */
    getShowFooter(): boolean;
    /**
     * Gets content of aggregation {@link #getSpecialDates specialDates}.
     *
     * Date Range with type to visualize special days in the Calendar. If one day is assigned to more than one
     * Type, only the first one will be used.
     *
     * To set a single date (instead of a range), set only the startDate property of the sap.ui.unified.DateRange
     * class.
     *
     * **Note:** Since 1.48 you could set a non-working day via the sap.ui.unified.CalendarDayType.NonWorking
     * enum type just as any other special date type using sap.ui.unified.DateRangeType.
     *
     * @since 1.38.5
     */
    getSpecialDates(): UI5Element[];
    /**
     * Getter for property `value`.
     *
     * Returns a date as a string in the format defined in property `valueFormat`.
     *
     * **Note:** If there is no data binding, the value is expected and updated in Gregorian calendar type.
     * (Otherwise, the type of the binding is used.)
     *
     * If this property is used, the `dateValue` property should not be changed from the caller.
     *
     *
     * @returns the value of property `value`
     */
    getValue(): string;
    /**
     * The date string expected and returned in the `value` property uses this format. By default the medium
     * format of the used locale is used.
     *
     * Supported format options are pattern-based on Unicode LDML Date Format notation. {@link http://unicode.org/reports/tr35/#Date_Field_Symbol_Table}
     *
     * For example, if the date string represents an ABAP DATS type, the format should be "yyyyMMdd".
     *
     * **Note:** If data binding on `value` property with type `sap.ui.model.type.Date` is used, this property
     * will be ignored. The format defined in the binding will be used.
     *
     *
     * @returns the value of property `valueFormat`
     */
    getValueFormat(): string;
    /**
     * Checks for the provided `sap.ui.core.Element` in the aggregation {@link #getSpecialDates specialDates}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.38.5
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfSpecialDate(
      /**
       * The specialDate whose index is looked for
       */
      oSpecialDate: UI5Element
    ): int;
    /**
     * Inserts a `specialDate` to the aggregation `specialDates`.
     *
     * @since 1.38.5
     *
     * @returns Reference to `this` for method chaining
     */
    insertSpecialDate(
      /**
       * the specialDate to insert; if empty, nothing is inserted
       */
      oSpecialDate: DateTypeRange,
      /**
       * the 0-based index the `specialDate` should be inserted at; for a negative value of `iIndex`, the `specialDate`
       * is inserted at position 0; for a value greater than the current size of the aggregation, the `specialDate`
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Checks if the picker is open
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    isOpen(): boolean;
    /**
     * Returns if the last entered value is valid.
     *
     * @since 1.64
     */
    isValidValue(): boolean;
    /**
     * Opens the picker popover. The popover is positioned relatively to the control given as `oDomRef` parameter
     * on tablet or desktop and is full screen on phone. Therefore the control parameter is only used on tablet
     * or desktop and is ignored on phone.
     *
     * Note: use this method to open the picker popover only when the `hideInput` property is set to `true`.
     * Please consider opening of the picker popover by another control only in scenarios that comply with Fiori
     * guidelines. For example, opening the picker popover by another popover is not recommended. The application
     * developer should implement the following accessibility attributes to the opening control: a text or tooltip
     * that describes the action (example: "Open Date Picker"), and aria-haspopup attribute with value of `sap.ui.core.aria.HasPopup.Dialog`.
     *
     * @since 1.97
     */
    openBy(
      /**
       * DOM reference of the opening control. On tablet or desktop, the popover is positioned relatively to this
       * control.
       */
      oDomRef: HTMLElement
    ): void;
    /**
     * Removes all the controls from the aggregation {@link #getSpecialDates specialDates}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.38.5
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllSpecialDates(): UI5Element[];
    /**
     * Removes a `specialDate` from the aggregation `specialDates`.
     *
     * @since 1.38.5
     *
     * @returns The removed `specialDate`
     */
    removeSpecialDate(
      /**
       * The `specialDate` to remove or its index or ID
       */
      oSpecialDate: DateTypeRange
    ): int | string | DateTypeRange;
    /**
     * Sets a new value for property {@link #getCalendarWeekNumbering calendarWeekNumbering}.
     *
     * If set, the calendar week numbering is used for display. If not set, the calendar week numbering of the
     * global configuration is used.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.108.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCalendarWeekNumbering(
      /**
       * New value for property `calendarWeekNumbering`
       */
      sCalendarWeekNumbering?:
        | CalendarWeekNumbering
        | keyof typeof CalendarWeekNumbering
    ): this;
    /**
     * Sets the displayFormat of the DatePicker.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setDisplayFormat(
      /**
       * new value for `displayFormat`
       */
      sDisplayFormat: string
    ): this;
    /**
     * Sets a new value for property {@link #getDisplayFormatType displayFormatType}.
     *
     * Displays date in this given type in input field. Default value is taken from locale settings. Accepted
     * are values of {@link module:sap/base/i18n/date/CalendarType} or an empty string. If no type is set, the
     * default type of the configuration is used. **Note:** If data binding on `value` property with type `sap.ui.model.type.Date`
     * is used, this property will be ignored.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.28.6
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisplayFormatType(
      /**
       * New value for property `displayFormatType`
       */
      sDisplayFormatType?: string
    ): this;
    /**
     * Sets a new value for property {@link #getHideInput hideInput}.
     *
     * Determines whether the input field of the picker is hidden or visible. When set to `true`, the input
     * field becomes invisible and there is no way to open the picker popover. In that case it can be opened
     * by another control through calling of picker's `openBy` method, and the opening control's DOM reference
     * must be provided as parameter.
     *
     * Note: Since the picker is not responsible for accessibility attributes of the control which opens its
     * popover, those attributes should be added by the application developer. The following is recommended
     * to be added to the opening control: a text or tooltip that describes the action (example: "Open Date
     * Picker"), and also aria-haspopup attribute with value of `sap.ui.core.aria.HasPopup.Dialog`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.97
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHideInput(
      /**
       * New value for property `hideInput`
       */
      bHideInput?: boolean
    ): this;
    /**
     * Sets the associated legend.
     *
     * @since 1.38.5
     *
     * @returns Reference to `this` for method chaining
     */
    setLegend(
      /**
       * ID of an element which becomes the new target of this `legend` association; alternatively, an element
       * instance may be given
       */
      oLegend: ID | CalendarLegend
    ): this;
    /**
     * Set maximum date that can be shown and selected in the `DatePicker`. This must be a date instance.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setMaxDate(
      /**
       * A date instance
       */
      oDate: Date | UI5Date
    ): this;
    /**
     * Set minimum date that can be shown and selected in the `DatePicker`. This must be a date instance.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setMinDate(
      /**
       * A date instance
       */
      oDate: Date | UI5Date
    ): this;
    /**
     * Sets a new value for property {@link #getSecondaryCalendarType secondaryCalendarType}.
     *
     * If set, the days in the calendar popup are also displayed in this calendar type If not set, the dates
     * are only displayed in the primary calendar type
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.34.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSecondaryCalendarType(
      /**
       * New value for property `secondaryCalendarType`
       */
      sSecondaryCalendarType: CalendarType | keyof typeof CalendarType
    ): this;
    /**
     * Sets a new value for property {@link #getShowCurrentDateButton showCurrentDateButton}.
     *
     * Determines whether there is a shortcut navigation to Today. When used in Month, Year or Year-range picker
     * view, the calendar navigates to Day picker view.
     *
     * Note: The Current date button appears if the `displayFormat` property allows entering day.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.95
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowCurrentDateButton(
      /**
       * New value for property `showCurrentDateButton`
       */
      bShowCurrentDateButton?: boolean
    ): this;
    /**
     * Sets `showFooter` property to the given boolean value
     *
     * @since 1.70
     */
    setShowFooter(
      /**
       * when true footer is displayed
       */
      bFlag: boolean
    ): void;
    /**
     * Setter for property `value`.
     *
     * Expects a date as a string in the format defined in property `valueFormat`.
     *
     * **Note:** If there is no data binding, the value is expected and updated in Gregorian calendar type.
     * (Otherwise, the type of the binding is used.)
     *
     * If this property is used, the `dateValue` property should not be changed from the caller.
     *
     * If Data binding using a `sap.ui.model.type.Date` is used, please set the `formatOption` `stricktParsing`
     * to `true`. This prevents unwanted automatic corrections of wrong input.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setValue(
      /**
       * The new value of the input.
       */
      sValue: string
    ): this;
    /**
     * Defines the width of the DatePicker. Default value is 100%
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setWidth(
      /**
       * new value for `width`
       */
      sWidth: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the DatePicker constructor.
   */
  export interface $DatePickerSettings extends $DateTimeFieldSettings {
    /**
     * Displays date in this given type in input field. Default value is taken from locale settings. Accepted
     * are values of {@link module:sap/base/i18n/date/CalendarType} or an empty string. If no type is set, the
     * default type of the configuration is used. **Note:** If data binding on `value` property with type `sap.ui.model.type.Date`
     * is used, this property will be ignored.
     *
     * @since 1.28.6
     */
    displayFormatType?: string | PropertyBindingInfo;

    /**
     * If set, the days in the calendar popup are also displayed in this calendar type If not set, the dates
     * are only displayed in the primary calendar type
     *
     * @since 1.34.1
     */
    secondaryCalendarType?:
      | (CalendarType | keyof typeof CalendarType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Minimum date that can be shown and selected in the `DatePicker`. This must be a UI5Date or JavaScript
     * Date object.
     *
     * **Note:** If the `minDate` is set to be after the `maxDate`, the `maxDate` and the `minDate` are switched
     * before rendering.
     *
     * @since 1.38.0
     */
    minDate?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Maximum date that can be shown and selected in the `DatePicker`. This must be a UI5Date or JavaScript
     * Date object.
     *
     * **Note:** If the `maxDate` is set to be before the `minDate`, the `maxDate` and the `minDate` are switched
     * before rendering.
     *
     * @since 1.38.0
     */
    maxDate?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Hides or shows the popover's footer.
     *
     * @since 1.70
     */
    showFooter?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether there is a shortcut navigation to Today. When used in Month, Year or Year-range picker
     * view, the calendar navigates to Day picker view.
     *
     * Note: The Current date button appears if the `displayFormat` property allows entering day.
     *
     * @since 1.95
     */
    showCurrentDateButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the input field of the picker is hidden or visible. When set to `true`, the input
     * field becomes invisible and there is no way to open the picker popover. In that case it can be opened
     * by another control through calling of picker's `openBy` method, and the opening control's DOM reference
     * must be provided as parameter.
     *
     * Note: Since the picker is not responsible for accessibility attributes of the control which opens its
     * popover, those attributes should be added by the application developer. The following is recommended
     * to be added to the opening control: a text or tooltip that describes the action (example: "Open Date
     * Picker"), and also aria-haspopup attribute with value of `sap.ui.core.aria.HasPopup.Dialog`.
     *
     * @since 1.97
     */
    hideInput?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * If set, the calendar week numbering is used for display. If not set, the calendar week numbering of the
     * global configuration is used.
     *
     * @since 1.108.0
     */
    calendarWeekNumbering?:
      | (CalendarWeekNumbering | keyof typeof CalendarWeekNumbering)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Date Range with type to visualize special days in the Calendar. If one day is assigned to more than one
     * Type, only the first one will be used.
     *
     * To set a single date (instead of a range), set only the startDate property of the sap.ui.unified.DateRange
     * class.
     *
     * **Note:** Since 1.48 you could set a non-working day via the sap.ui.unified.CalendarDayType.NonWorking
     * enum type just as any other special date type using sap.ui.unified.DateRangeType.
     *
     * @since 1.38.5
     */
    specialDates?:
      | UI5Element[]
      | UI5Element
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Association to the `CalendarLegend` explaining the colors of the `specialDates`.
     *
     * **Note** The legend does not have to be rendered but must exist, and all required types must be assigned.
     *
     * @since 1.38.5
     */
    legend?: Control | string;

    /**
     * Fired when navigating in `Calendar` popup.
     *
     * @since 1.46.0
     */
    navigate?: (oEvent: DatePicker$NavigateEvent) => void;

    /**
     * Fired when `value help` dialog opens.
     *
     * @since 1.102.0
     */
    afterValueHelpOpen?: (oEvent: Event) => void;

    /**
     * Fired when `value help` dialog closes.
     *
     * @since 1.102.0
     */
    afterValueHelpClose?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the DatePicker#afterValueHelpClose event.
   */
  export interface DatePicker$AfterValueHelpCloseEventParameters {}

  /**
   * Event object of the DatePicker#afterValueHelpClose event.
   */
  export type DatePicker$AfterValueHelpCloseEvent = Event<
    DatePicker$AfterValueHelpCloseEventParameters,
    DatePicker
  >;

  /**
   * Parameters of the DatePicker#afterValueHelpOpen event.
   */
  export interface DatePicker$AfterValueHelpOpenEventParameters {}

  /**
   * Event object of the DatePicker#afterValueHelpOpen event.
   */
  export type DatePicker$AfterValueHelpOpenEvent = Event<
    DatePicker$AfterValueHelpOpenEventParameters,
    DatePicker
  >;

  /**
   * Parameters of the DatePicker#change event.
   */
  export interface DatePicker$ChangeEventParameters
    extends InputBase$ChangeEventParameters {
    /**
     * Indicator for a valid date.
     */
    valid?: boolean;
  }

  /**
   * Event object of the DatePicker#change event.
   */
  export type DatePicker$ChangeEvent = Event<
    DatePicker$ChangeEventParameters,
    DatePicker
  >;

  /**
   * Parameters of the DatePicker#navigate event.
   */
  export interface DatePicker$NavigateEventParameters {
    /**
     * Date range containing the start and end date displayed in the `Calendar` popup.
     */
    dateRange?: DateRange;

    /**
     * Indicates if the event is fired, due to popup being opened.
     */
    afterPopupOpened?: boolean;
  }

  /**
   * Event object of the DatePicker#navigate event.
   */
  export type DatePicker$NavigateEvent = Event<
    DatePicker$NavigateEventParameters,
    DatePicker
  >;
}

declare module "sap/m/DateRangeSelection" {
  import {
    default as DatePicker,
    $DatePickerSettings,
    DatePicker$ChangeEventParameters,
  } from "sap/m/DatePicker";

  import { AccessibilityInfo } from "sap/ui/core/library";

  import UI5Date from "sap/ui/core/date/UI5Date";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * A single-field input control that enables the users to enter a localized date range (between 0001-01-01
   * and 9999-12-31).
   *
   * Overview:
   *
   * The `DateRangeSelection` enables the users to enter a localized date range using touch, mouse, keyboard
   * input, or by selecting a date range in the calendar. They can also navigate directly from one month or
   * year to another.
   *
   * **Note:** The control is not UTC aware and the selected date range starts from 00:00:00:000 of the first
   * date and ends in 23:59:59:999 on the second date.
   *
   * The application developer should add dependency to `sap.ui.unified` library on application level to ensure
   * that the library is loaded before the module dependencies will be required. The {@link sap.ui.unified.Calendar }
   * is used internally only if the `DateRangeSelection` is opened (not used for the initial rendering). If
   * the `sap.ui.unified` library is not loaded before the `DateRangeSelection` is opened, it will be loaded
   * upon opening. This could lead to CSP compliance issues and adds an additional waiting time when the `DateRangeSelection`
   * is opened for the first time. To prevent this, apps using the `DateRangeSelection` should also load the
   * `sap.ui.unified` library in advance.
   *
   * Usage:
   *
   * When to use?
   *
   * If you need a date range and know that your user is a power user who has to input lots of data. If the
   * keyboard is the primary device used for navigating the app, use two input fields. This allows the user
   * to quickly jump from field to field. By selecting a date in one of the fields, the other field should
   * recognize the information and jump to the same selection.
   *
   * When not to use?
   *
   * If the user's primary goal is not to select ranges or if you just want to enter a date and a time. For
   * such cases, use the {@link sap.m.DatePicker} or {@link sap.m.TimePicker}.
   *
   * The user can enter a date by:
   * 	 - Using the calendar that opens in a popup
   * 	 - Typing it directly in the input field
   *
   * On app level, there are two options to provide a date for the `DateRangeSelection` - date range as a
   * string to the `value` property or UI5Date/JavaScript Date objects to the `dateValue` and `secondDateValue`
   * properties (only one of these options should be used at a time):
   *
   *
   * 	 - Use the `value` property if the date range is already provided as a formatted string  binding
   *     the `value` property by using types
   * ```javascript
   *
   * new sap.ui.model.json.JSONModel({start:'2022-11-10', end:'2022-11-15'});
   *
   * new sap.m.DateRangeSelection({
   *     value: {
   *         type: "sap.ui.model.type.DateInterval",
   *         parts: [{
   *             type: "sap.ui.model.type.Date",
   *             path: "/start",
   *             formatOptions: {
   *                 source: {
   *                     pattern: "yyyy-MM-dd"
   *                 }
   *             }
   *         },
   *         {
   *             type: "sap.ui.model.type.Date",
   *             path:"/end",
   *             formatOptions: {
   *             source: {
   *                 pattern: "yyyy-MM-dd"
   *             }
   *         }}]
   *     }
   * });
   * ```
   *  **Note:** There are multiple binding type choices, such as: sap.ui.model.type.Date sap.ui.model.odata.type.DateTime
   * sap.ui.model.odata.type.DateTimeOffset See {@link sap.ui.model.type.Date}, {@link sap.ui.model.odata.type.DateTime }
   * or {@link sap.ui.model.odata.type.DateTimeOffset}
   *
   *
   * 	 - Use the `dateValue` and `secondDateValue` properties if the date range is already provided as UI5Date
   *     or JavaScript Date objects or you want to work with UI5Date or JavaScript Date objects
   *
   * Formatting:
   *
   * All formatting and parsing of dates from and to strings is done using the {@link sap.ui.core.format.DateFormat}.
   * If a date is entered by typing it into the input field, it must fit to the used date format and locale.
   *
   * Supported format options are pattern-based on Unicode LDML Date Format notation. See {@link http://unicode.org/reports/tr35/#Date_Field_Symbol_Table}
   *
   * For example, if the `displayFormat` is "MMM d, y", delimiter is "-", and the used locale is English,
   * a valid value string is "Jul 29, 2015 - Jul 31, 2015" and it is displayed in the same way in the input
   * field.
   *
   * If no placeholder is set to the `DateRangeSelection`, the used `displayFormat` is displayed as a placeholder.
   * If another placeholder is needed, it must be set.
   *
   * **Note:** If the string does NOT match the `displayFormat` (from user input) or the `valueFormat` (on
   * app level), the {@link sap.ui.core.format.DateFormat} makes an attempt to parse it based on the locale
   * settings. For more information, see the respective documentation in the API Reference.
   *
   * Responsive behavior:
   *
   * The `DateRangeSelection` is fully responsive. It is smaller in compact mode and provides a touch-friendly
   * size in cozy mode.
   *
   * @since 1.22.0
   */
  export default class DateRangeSelection extends DatePicker {
    /**
     * Constructor for a new `DateRangeSelection`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $DateRangeSelectionSettings
    );
    /**
     * Constructor for a new `DateRangeSelection`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $DateRangeSelectionSettings
    );

    /**
     * Creates a new subclass of class sap.m.DateRangeSelection with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.DatePicker.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, DateRangeSelection>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.DateRangeSelection.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Fire event change to attached listeners.
     *
     * Expects following event parameters:
     * 	 - 'value' of type `string` The new value of the `sap.m.DateRangeSelection`.
     * 	 - 'valid' of type `boolean` Indicator for a valid date.
     * 	 - 'from' of type `object` Current start date after change.
     * 	 - 'to' of type `object` Current end date after change.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` for method chaining
     */
    fireChange(
      /**
       * The arguments to pass along with the event.
       */
      mArguments?: object
    ): this;
    /**
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Current accessibility state of the control
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Getter for property `dateValue`.
     *
     * The start date of the range as UI5Date or JavaScript Date object. This is independent from any formatter.
     *
     * **Note:** If this property is used, the `value` property should not be changed from the caller.
     *
     *
     * @returns the value of property `dateValue`
     */
    getDateValue(): Date | UI5Date | null;
    /**
     * Gets current value of property {@link #getDelimiter delimiter}.
     *
     * Delimiter between start and end date. Default value is "-". If no delimiter is given, the one defined
     * for the used locale is used.
     *
     * Default value is `'-'`.
     *
     *
     * @returns Value of property `delimiter`
     */
    getDelimiter(): string;
    /**
     * Get the start date of the range.
     *
     * @deprecated As of version 1.22.0. replaced by `dateValue` property of the {@link sap.m.DateTimeField}
     *
     * @returns the start date of the date range
     */
    getFrom(): Date | UI5Date | null;
    /**
     * Getter for property `secondDateValue`.
     *
     * The end date of the range as UI5Date or JavaScript Date object. This is independent from any formatter.
     *
     * **Note:** If this property is used, the `value` property should not be changed from the caller.
     *
     *
     * @returns the value of property `secondDateValue`
     */
    getSecondDateValue(): Date | UI5Date | null;
    /**
     * Get the end date of the range.
     *
     * @deprecated As of version 1.22.0. replaced by `secondDateValue` property
     *
     * @returns the end date of the date range
     */
    getTo(): Date | UI5Date | null;
    /**
     * Getter for property `value`.
     *
     * Returns a date as a string in the format defined in property `displayFormat`.
     *
     * **Note:** As the value string always used the `displayFormat`, it is both locale-dependent and calendar-type-dependent.
     *
     * If this property is used, the `dateValue` property should not be changed from the caller.
     *
     *
     * @returns the value of property `value`
     */
    getValue(): string;
    /**
     * Getter for property `valueFormat`.
     *
     * **Note:** Property `valueFormat` is not supported in the `sap.m.DateRangeSelection` control.
     *
     *
     * @returns the value of property valueFormat
     */
    getValueFormat(): string;
    /**
     * Setter for property `dateValue`.
     *
     * The start date of the range as UI5Date or JavaScript Date object. This is independent from any formatter.
     *
     * **Note:** If this property is used, the `value` property should not be changed from the caller.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setDateValue(
      /**
       * New value for property `dateValue`
       */
      oDateValue: Date | UI5Date | null
    ): this;
    /**
     * Sets a new value for property {@link #getDelimiter delimiter}.
     *
     * Delimiter between start and end date. Default value is "-". If no delimiter is given, the one defined
     * for the used locale is used.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `'-'`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDelimiter(
      /**
       * New value for property `delimiter`
       */
      sDelimiter?: string
    ): this;
    /**
     * Sets the displayFormat of the DatePicker.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setDisplayFormat(
      /**
       * new value for `displayFormat`
       */
      sDisplayFormat: string
    ): this;
    /**
     * Set the start date of the range.
     *
     * @deprecated As of version 1.22.0. replaced by `dateValue` property of the {@link sap.m.DateTimeField}
     *
     * @returns Reference to `this` for method chaining
     */
    setFrom(
      /**
       * A date instance
       */
      oFrom: Date | UI5Date | null
    ): this;
    /**
     * Set maximum date that can be shown and selected in the `DatePicker`. This must be a UI5Date or JavaScript
     * Date object.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setMaxDate(
      /**
       * A date instance
       */
      oDate: Date | UI5Date
    ): this;
    /**
     * Set minimum date that can be shown and selected in the `DatePicker`. This must be a UI5Date or JavaScript
     * Date object.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setMinDate(
      /**
       * A date instance
       */
      oDate: Date | UI5Date
    ): this;
    /**
     * Setter for property `secondDateValue`.
     *
     * The start date of the range as UI5Date or JavaScript Date object. This is independent from any formatter.
     *
     * **Note:** If this property is used, the `value` property should not be changed from the caller.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setSecondDateValue(
      /**
       * New value for property `dateValue`
       */
      oSecondDateValue: Date | UI5Date | null
    ): this;
    /**
     * Set the end date of the range.
     *
     * @deprecated As of version 1.22.0. replaced by `secondDateValue` property
     *
     * @returns Reference to `this` for method chaining
     */
    setTo(
      /**
       * A date instance
       */
      oTo: Date | UI5Date | null
    ): this;
    /**
     * Setter for property `value`.
     *
     * Expects a date as a string in the format defined in property `displayFormat`.
     *
     * **Note:** As the value string always used the `displayFormat`, it is both locale-dependent and calendar-type-dependent.
     *
     * If this property is used, the `dateValue` property should not be changed from the caller.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setValue(
      /**
       * The new value of the input.
       */
      sValue: string
    ): this;
    /**
     * Setter for property `valueFormat`.
     *
     * **Note:** Property `valueFormat` is not supported in the `sap.m.DateRangeSelection` control.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setValueFormat(
      /**
       * New value for property valueFormat
       */
      sValueFormat: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the DateRangeSelection constructor.
   */
  export interface $DateRangeSelectionSettings extends $DatePickerSettings {
    /**
     * Delimiter between start and end date. Default value is "-". If no delimiter is given, the one defined
     * for the used locale is used.
     */
    delimiter?: string | PropertyBindingInfo;

    /**
     * The end date of the range as UI5Date or JavaScript Date object. This is independent from any formatter.
     *
     * **Note:** If this property is used, the `value` property should not be changed from the caller.
     */
    secondDateValue?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Start date of the range.
     *
     * @deprecated As of version 1.22.0. replaced by `dateValue` property of the {@link sap.m.DateTimeField}
     */
    from?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * End date of the range.
     *
     * @deprecated As of version 1.22.0. replaced by `secondDateValue` property
     */
    to?: object | PropertyBindingInfo | `{${string}}`;
  }

  /**
   * Parameters of the DateRangeSelection#change event.
   */
  export interface DateRangeSelection$ChangeEventParameters
    extends DatePicker$ChangeEventParameters {
    /**
     * Current start date after change.
     */
    from?: object;

    /**
     * Current end date after change.
     */
    to?: object;
  }

  /**
   * Event object of the DateRangeSelection#change event.
   */
  export type DateRangeSelection$ChangeEvent = Event<
    DateRangeSelection$ChangeEventParameters,
    DateRangeSelection
  >;
}

declare module "sap/m/DateTimeField" {
  import { default as InputBase, $InputBaseSettings } from "sap/m/InputBase";

  import UI5Date from "sap/ui/core/date/UI5Date";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * The `sap.m.DateTimeField` control provides a basic functionality for date/time input controls.
   *
   * To be extended by date and time picker controls. For internal use only.
   *
   * @since 1.50.0
   */
  export default abstract class DateTimeField extends InputBase {
    /**
     * Constructor for a new `sap.m.DateTimeField`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $DateTimeFieldSettings
    );
    /**
     * Constructor for a new `sap.m.DateTimeField`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $DateTimeFieldSettings
    );

    /**
     * Creates a new subclass of class sap.m.DateTimeField with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.InputBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, DateTimeField>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.DateTimeField.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.DateTimeField`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.DateTimeField` itself.
     *
     * Fired when the value of the `DateTimeField` is changed by user interaction - each keystroke, delete,
     * paste, etc.
     *
     * **Note:** Browsing autocomplete suggestions doesn't fire the event.
     *
     * @since 1.104.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: DateTimeField$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.DateTimeField` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.DateTimeField`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.DateTimeField` itself.
     *
     * Fired when the value of the `DateTimeField` is changed by user interaction - each keystroke, delete,
     * paste, etc.
     *
     * **Note:** Browsing autocomplete suggestions doesn't fire the event.
     *
     * @since 1.104.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: DateTimeField$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.DateTimeField` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:liveChange liveChange} event of this `sap.m.DateTimeField`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.104.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLiveChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: DateTimeField$LiveChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:liveChange liveChange} to attached listeners.
     *
     * @since 1.104.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLiveChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: DateTimeField$LiveChangeEventParameters
    ): this;
    /**
     * Getter for property `dateValue`.
     *
     * The date and time in DateTimeField as UI5Date or JavaScript Date object.
     *
     * **Note:** If this property is used, the `value` property should not be changed from the caller.
     *
     *
     * @returns the value of property `dateValue`
     */
    getDateValue(): Date | UI5Date | null;
    /**
     * Gets current value of property {@link #getDisplayFormat displayFormat}.
     *
     * Determines the format, displayed in the input field.
     *
     *
     * @returns Value of property `displayFormat`
     */
    getDisplayFormat(): string;
    /**
     * Gets the inner input DOM value.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The value of the input.
     */
    getDOMValue(): any;
    /**
     * Gets current value of property {@link #getInitialFocusedDateValue initialFocusedDateValue}.
     *
     * Holds a reference to a UI5Date or JavaScript Date object to define the initially focused date/time when
     * the picker popup is opened.
     *
     * **Notes:**
     * 	 - Setting this property does not change the `value` property.
     * 	 - Depending on the context this property is used in ({@link sap.m.TimePicker}, {@link sap.m.DatePicker }
     *     or {@link sap.m.DateTimePicker}), it takes into account only the time part, only the date part or both
     *     parts of the UI5Date or JavaScript Date object.
     *
     * @since 1.54
     *
     * @returns Value of property `initialFocusedDateValue`
     */
    getInitialFocusedDateValue(): object;
    /**
     * Gets current value of property {@link #getValueFormat valueFormat}.
     *
     * Determines the format of the value property.
     *
     *
     * @returns Value of property `valueFormat`
     */
    getValueFormat(): string;
    /**
     * Event handler for user input.
     */
    oninput(
      /**
       * User input.
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * Setter for property `dateValue`.
     *
     * The date and time in DateTimeField as UI5Date or JavaScript Date object.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setDateValue(
      /**
       * A date instance
       */
      oDate: Date | UI5Date | null
    ): this;
    /**
     * Sets a new value for property {@link #getDisplayFormat displayFormat}.
     *
     * Determines the format, displayed in the input field.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisplayFormat(
      /**
       * New value for property `displayFormat`
       */
      sDisplayFormat?: string
    ): this;
    /**
     * Sets a new value for property {@link #getInitialFocusedDateValue initialFocusedDateValue}.
     *
     * Holds a reference to a UI5Date or JavaScript Date object to define the initially focused date/time when
     * the picker popup is opened.
     *
     * **Notes:**
     * 	 - Setting this property does not change the `value` property.
     * 	 - Depending on the context this property is used in ({@link sap.m.TimePicker}, {@link sap.m.DatePicker }
     *     or {@link sap.m.DateTimePicker}), it takes into account only the time part, only the date part or both
     *     parts of the UI5Date or JavaScript Date object.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInitialFocusedDateValue(
      /**
       * New value for property `initialFocusedDateValue`
       */
      oInitialFocusedDateValue?: object
    ): this;
    /**
     * Sets a new value for property {@link #getValueFormat valueFormat}.
     *
     * Determines the format of the value property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueFormat(
      /**
       * New value for property `valueFormat`
       */
      sValueFormat?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the DateTimeField constructor.
   */
  export interface $DateTimeFieldSettings extends $InputBaseSettings {
    /**
     * Determines the format, displayed in the input field.
     */
    displayFormat?: string | PropertyBindingInfo;

    /**
     * Determines the format of the value property.
     */
    valueFormat?: string | PropertyBindingInfo;

    /**
     * Holds a reference to a UI5Date or JavaScript Date object. The `value` (string) property will be set according
     * to it. Alternatively, if the `value` and `valueFormat` pair properties are supplied instead, the `dateValue`
     * will be instantiated according to the parsed `value`. Use `dateValue` as a helper property to easily
     * obtain the day, month, year, hours, minutes and seconds of the chosen date and time. Although possible
     * to bind it, the recommendation is not to do it. When binding is needed, use `value` property instead.
     */
    dateValue?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Holds a reference to a UI5Date or JavaScript Date object to define the initially focused date/time when
     * the picker popup is opened.
     *
     * **Notes:**
     * 	 - Setting this property does not change the `value` property.
     * 	 - Depending on the context this property is used in ({@link sap.m.TimePicker}, {@link sap.m.DatePicker }
     *     or {@link sap.m.DateTimePicker}), it takes into account only the time part, only the date part or both
     *     parts of the UI5Date or JavaScript Date object.
     *
     * @since 1.54
     */
    initialFocusedDateValue?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Fired when the value of the `DateTimeField` is changed by user interaction - each keystroke, delete,
     * paste, etc.
     *
     * **Note:** Browsing autocomplete suggestions doesn't fire the event.
     *
     * @since 1.104.0
     */
    liveChange?: (oEvent: DateTimeField$LiveChangeEvent) => void;
  }

  /**
   * Parameters of the DateTimeField#liveChange event.
   */
  export interface DateTimeField$LiveChangeEventParameters {
    /**
     * The current value of the input, after a live change event.
     */
    value?: string;

    /**
     * The previous value of the input, before the last user interaction.
     */
    previousValue?: string;
  }

  /**
   * Event object of the DateTimeField#liveChange event.
   */
  export type DateTimeField$LiveChangeEvent = Event<
    DateTimeField$LiveChangeEventParameters,
    DateTimeField
  >;
}

declare module "sap/m/DateTimeInput" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { IToolbarInteractiveControl, DateTimeInputType } from "sap/m/library";

  import {
    ID,
    AccessibilityInfo,
    TextAlign,
    TextDirection,
    ValueState,
    CSSSize,
  } from "sap/ui/core/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Event from "sap/ui/base/Event";

  /**
   * Allows end users to interact with date (between 0001-01-01 and 9999-12-31) and/or time and select from
   * a date and/or time pad.
   *
   * **Note:** This control should not be used any longer, instead please use the dedicated `sap.m.DatePicker`,
   * `sap.m.TimePicker` or `sap.m.DateTimePicker` control.
   *
   * @since 1.9.1
   * @deprecated As of version 1.32.8. replaced by {@link sap.m.DatePicker}, {@link sap.m.TimePicker} or {@link sap.m.DateTimePicker}
   */
  export default class DateTimeInput
    extends Control
    implements IToolbarInteractiveControl
  {
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new DateTimeInput.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $DateTimeInputSettings
    );
    /**
     * Constructor for a new DateTimeInput.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $DateTimeInputSettings
    );

    /**
     * Creates a new subclass of class sap.m.DateTimeInput with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, DateTimeInput>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.DateTimeInput.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.DateTimeInput`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.DateTimeInput` itself.
     *
     * This event gets fired when the selection has finished and the value has changed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: DateTimeInput$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.DateTimeInput` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.DateTimeInput`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.DateTimeInput` itself.
     *
     * This event gets fired when the selection has finished and the value has changed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: DateTimeInput$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.DateTimeInput` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds property {@link #getValue value} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindProperty ManagedObject.bindProperty} for a detailed description
     * of the possible properties of `oBindingInfo`
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindValue(
      /**
       * The binding information
       */
      oBindingInfo: PropertyBindingInfo
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:change change} event of this `sap.m.DateTimeInput`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: DateTimeInput$ChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:change change} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: DateTimeInput$ChangeEventParameters
    ): this;
    /**
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Current accessibility state of the control
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getDateValue dateValue}.
     *
     * This property as JavaScript Date Object can be used to assign a new value which is independent from valueFormat.
     *
     *
     * @returns Value of property `dateValue`
     */
    getDateValue(): object;
    /**
     * Gets current value of property {@link #getDisplayFormat displayFormat}.
     *
     * Displays date value in this given format in text field. Default value is taken from locale settings.
     * If you use data-binding on value property with type sap.ui.model.type.Date then you can ignore this property
     * or the latter wins. If the user's browser supports native picker then this property is overwritten by
     * browser with locale settings.
     *
     *
     * @returns Value of property `displayFormat`
     */
    getDisplayFormat(): string;
    /**
     * Gets current value of property {@link #getEditable editable}.
     *
     * Defines whether the control can be modified by the user or not. **Note:** A user can tab to non-editable
     * control, highlight it, and copy the text from it.
     *
     * Default value is `true`.
     *
     * @since 1.12.0
     *
     * @returns Value of property `editable`
     */
    getEditable(): boolean;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Indicates whether the user can interact with the control or not. **Note:** Disabled controls cannot be
     * focused and they are out of the tab-chain.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets current value of property {@link #getName name}.
     *
     * Defines the name of the control for the purposes of form submission.
     *
     *
     * @returns Value of property `name`
     */
    getName(): string;
    /**
     * Gets current value of property {@link #getPlaceholder placeholder}.
     *
     * Defines a short hint intended to aid the user with data entry when the control has no value.
     *
     *
     * @returns Value of property `placeholder`
     */
    getPlaceholder(): string;
    /**
     * Gets current value of property {@link #getShowValueStateMessage showValueStateMessage}.
     *
     * Indicates whether the value state message should be shown or not.
     *
     * Default value is `true`.
     *
     * @since 1.26.0
     *
     * @returns Value of property `showValueStateMessage`
     */
    getShowValueStateMessage(): boolean;
    /**
     * Gets current value of property {@link #getTextAlign textAlign}.
     *
     * Defines the horizontal alignment of the text that is shown inside the input field.
     *
     * Default value is `Initial`.
     *
     * @since 1.26.0
     *
     * @returns Value of property `textAlign`
     */
    getTextAlign(): TextAlign;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * Defines the text directionality of the input field, e.g. `RTL`, `LTR`
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getType type}.
     *
     * Type of DateTimeInput (e.g. Date, Time, DateTime)
     *
     * Default value is `Date`.
     *
     *
     * @returns Value of property `type`
     */
    getType(): DateTimeInputType;
    /**
     * Gets current value of property {@link #getValue value}.
     *
     * Defines the value of the control.
     *
     * The new value must be in the format set by `valueFormat`.
     *
     * The "Now" literal can also be assigned as a parameter to show the current date and/or time.
     *
     *
     * @returns Value of property `value`
     */
    getValue(): string;
    /**
     * Gets current value of property {@link #getValueFormat valueFormat}.
     *
     * Given value property should match with valueFormat to parse date. Default value is taken from locale
     * settings. You can only set and get value in this format. If you use data-binding on value property with
     * type sap.ui.model.type.Date you can ignore this property or the latter wins.
     *
     *
     * @returns Value of property `valueFormat`
     */
    getValueFormat(): string;
    /**
     * Gets current value of property {@link #getValueState valueState}.
     *
     * Visualizes the validation state of the control, e.g. `Error`, `Warning`, `Success`.
     *
     * Default value is `None`.
     *
     *
     * @returns Value of property `valueState`
     */
    getValueState(): ValueState;
    /**
     * Gets current value of property {@link #getValueStateText valueStateText}.
     *
     * Defines the text that appears in the value state message pop-up. If this is not specified, a default
     * text is shown from the resource bundle.
     *
     * @since 1.26.0
     *
     * @returns Value of property `valueStateText`
     */
    getValueStateText(): string;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Defines the width of the control.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Setter for property `dateValue`.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setDateValue(
      /**
       * A JavaScript Date
       */
      oDate: Date
    ): this;
    /**
     * Sets a new value for property {@link #getDisplayFormat displayFormat}.
     *
     * Displays date value in this given format in text field. Default value is taken from locale settings.
     * If you use data-binding on value property with type sap.ui.model.type.Date then you can ignore this property
     * or the latter wins. If the user's browser supports native picker then this property is overwritten by
     * browser with locale settings.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisplayFormat(
      /**
       * New value for property `displayFormat`
       */
      sDisplayFormat?: string
    ): this;
    /**
     * Sets a new value for property {@link #getEditable editable}.
     *
     * Defines whether the control can be modified by the user or not. **Note:** A user can tab to non-editable
     * control, highlight it, and copy the text from it.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.12.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEditable(
      /**
       * New value for property `editable`
       */
      bEditable?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Indicates whether the user can interact with the control or not. **Note:** Disabled controls cannot be
     * focused and they are out of the tab-chain.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getName name}.
     *
     * Defines the name of the control for the purposes of form submission.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setName(
      /**
       * New value for property `name`
       */
      sName?: string
    ): this;
    /**
     * Sets a new value for property {@link #getPlaceholder placeholder}.
     *
     * Defines a short hint intended to aid the user with data entry when the control has no value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPlaceholder(
      /**
       * New value for property `placeholder`
       */
      sPlaceholder?: string
    ): this;
    /**
     * Sets a new value for property {@link #getShowValueStateMessage showValueStateMessage}.
     *
     * Indicates whether the value state message should be shown or not.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.26.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowValueStateMessage(
      /**
       * New value for property `showValueStateMessage`
       */
      bShowValueStateMessage?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getTextAlign textAlign}.
     *
     * Defines the horizontal alignment of the text that is shown inside the input field.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Initial`.
     *
     * @since 1.26.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextAlign(
      /**
       * New value for property `textAlign`
       */
      sTextAlign?: TextAlign | keyof typeof TextAlign
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * Defines the text directionality of the input field, e.g. `RTL`, `LTR`
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getType type}.
     *
     * Type of DateTimeInput (e.g. Date, Time, DateTime)
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Date`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setType(
      /**
       * New value for property `type`
       */
      sType?: DateTimeInputType | keyof typeof DateTimeInputType
    ): this;
    /**
     * Sets a new value for property {@link #getValue value}.
     *
     * Defines the value of the control.
     *
     * The new value must be in the format set by `valueFormat`.
     *
     * The "Now" literal can also be assigned as a parameter to show the current date and/or time.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValue(
      /**
       * New value for property `value`
       */
      sValue?: string
    ): this;
    /**
     * Sets a new value for property {@link #getValueFormat valueFormat}.
     *
     * Given value property should match with valueFormat to parse date. Default value is taken from locale
     * settings. You can only set and get value in this format. If you use data-binding on value property with
     * type sap.ui.model.type.Date you can ignore this property or the latter wins.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueFormat(
      /**
       * New value for property `valueFormat`
       */
      sValueFormat?: string
    ): this;
    /**
     * Sets a new value for property {@link #getValueState valueState}.
     *
     * Visualizes the validation state of the control, e.g. `Error`, `Warning`, `Success`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueState(
      /**
       * New value for property `valueState`
       */
      sValueState?: ValueState | keyof typeof ValueState
    ): this;
    /**
     * Sets a new value for property {@link #getValueStateText valueStateText}.
     *
     * Defines the text that appears in the value state message pop-up. If this is not specified, a default
     * text is shown from the resource bundle.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.26.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueStateText(
      /**
       * New value for property `valueStateText`
       */
      sValueStateText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Defines the width of the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Unbinds property {@link #getValue value} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindValue(): this;
  }
  /**
   * Describes the settings that can be provided to the DateTimeInput constructor.
   *
   * @deprecated As of version 1.32.8. replaced by {@link sap.m.DatePicker}, {@link sap.m.TimePicker} or {@link sap.m.DateTimePicker}
   */
  export interface $DateTimeInputSettings extends $ControlSettings {
    /**
     * Defines the value of the control.
     *
     * The new value must be in the format set by `valueFormat`.
     *
     * The "Now" literal can also be assigned as a parameter to show the current date and/or time.
     */
    value?: string | PropertyBindingInfo;

    /**
     * Defines the width of the control.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether the user can interact with the control or not. **Note:** Disabled controls cannot be
     * focused and they are out of the tab-chain.
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether the control can be modified by the user or not. **Note:** A user can tab to non-editable
     * control, highlight it, and copy the text from it.
     *
     * @since 1.12.0
     */
    editable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Visualizes the validation state of the control, e.g. `Error`, `Warning`, `Success`.
     */
    valueState?:
      | (ValueState | keyof typeof ValueState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the text that appears in the value state message pop-up. If this is not specified, a default
     * text is shown from the resource bundle.
     *
     * @since 1.26.0
     */
    valueStateText?: string | PropertyBindingInfo;

    /**
     * Indicates whether the value state message should be shown or not.
     *
     * @since 1.26.0
     */
    showValueStateMessage?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the name of the control for the purposes of form submission.
     */
    name?: string | PropertyBindingInfo;

    /**
     * Defines a short hint intended to aid the user with data entry when the control has no value.
     */
    placeholder?: string | PropertyBindingInfo;

    /**
     * Defines the horizontal alignment of the text that is shown inside the input field.
     *
     * @since 1.26.0
     */
    textAlign?:
      | (TextAlign | keyof typeof TextAlign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the text directionality of the input field, e.g. `RTL`, `LTR`
     *
     * @since 1.28.0
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Type of DateTimeInput (e.g. Date, Time, DateTime)
     */
    type?:
      | (DateTimeInputType | keyof typeof DateTimeInputType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Displays date value in this given format in text field. Default value is taken from locale settings.
     * If you use data-binding on value property with type sap.ui.model.type.Date then you can ignore this property
     * or the latter wins. If the user's browser supports native picker then this property is overwritten by
     * browser with locale settings.
     */
    displayFormat?: string | PropertyBindingInfo;

    /**
     * Given value property should match with valueFormat to parse date. Default value is taken from locale
     * settings. You can only set and get value in this format. If you use data-binding on value property with
     * type sap.ui.model.type.Date you can ignore this property or the latter wins.
     */
    valueFormat?: string | PropertyBindingInfo;

    /**
     * This property as JavaScript Date Object can be used to assign a new value which is independent from valueFormat.
     */
    dateValue?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Association to controls / IDs that label this control (see WAI-ARIA attribute aria-labelledby).
     *
     * @since 1.27.0
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * This event gets fired when the selection has finished and the value has changed.
     */
    change?: (oEvent: DateTimeInput$ChangeEvent) => void;
  }

  /**
   * Parameters of the DateTimeInput#change event.
   */
  export interface DateTimeInput$ChangeEventParameters {
    /**
     * The string value of the control in given valueFormat (or locale format).
     */
    value?: string;

    /**
     * The value of control as JavaScript Date Object or null if value is empty.
     */
    dateValue?: object;

    /**
     * if set, the entered value is a valid date. If not set the entered value cannot be converted to a date.
     */
    valid?: boolean;
  }

  /**
   * Event object of the DateTimeInput#change event.
   */
  export type DateTimeInput$ChangeEvent = Event<
    DateTimeInput$ChangeEventParameters,
    DateTimeInput
  >;
}

declare module "sap/m/DateTimePicker" {
  import { default as DatePicker, $DatePickerSettings } from "sap/m/DatePicker";

  import { AccessibilityInfo } from "sap/ui/core/library";

  import UI5Date from "sap/ui/core/date/UI5Date";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Enables the users to select date (between 0001-01-01 and 9999-12-31) and time values in a combined input.
   *
   * Overview:
   *
   * The `DateTimePicker` control consists of two parts: the input field and the date/time picker.
   *
   * **Note:** The application developer should add dependency to `sap.ui.unified` library on application
   * level to ensure that the library is loaded before the module dependencies will be required. The {@link sap.ui.unified.Calendar }
   * is used internally only if the `DateTimePicker` is opened (not used for the initial rendering). If the
   * `sap.ui.unified` library is not loaded before the `DateTimePicker` is opened, it will be loaded upon
   * opening. This could lead to CSP compliance issues and adds an additional waiting time when the `DateTimePicker`
   * is opened for the first time. To prevent this, apps using the `DateTimePicker` should also load the `sap.ui.unified`
   * library in advance.
   *
   * Usage:
   *
   * Use this control if you need a combined date and time input control.
   *
   * Don't use it if you want to use either a date or a time value. In this case, use the {@link sap.m.DatePicker }
   * or the {@link sap.m.TimePicker} controls instead.
   *
   * The user can enter a date by:
   * 	 - Using the calendar or a time selector that opens in a popup
   * 	 - Typing it in directly in the input field
   *
   * On app level, there are two options to provide a date for the `DateTimePicker` - as a string to the `value`
   * property or as a UI5Date or JavaScript Date object to the `dateValue` property (only one of these properties
   * should be used at a time):
   *
   *
   * 	 - Use the `value` property if you want to bind the `DateTimePicker` to a model using the `sap.ui.model.type.DateTime`
   *      binding the `value` property by using types
   * ```javascript
   *
   * new sap.ui.model.json.JSONModel({date: sap.ui.core.date.UI5Date.getInstance(2022,10,10,12,10,10)});
   *
   * new sap.m.DateTimePicker({
   *     value: {
   *         type: "sap.ui.model.type.DateTime",
   *         path: "/date"
   *     }
   * });
   * ```
   *
   * 	 - Use the `value` property if the date is provided as a string from the backend or inside the app (for
   *     example, as ABAP type DATS field)  binding the `value` property by using types
   * ```javascript
   *
   * new sap.ui.model.json.JSONModel({date:"2022-11-10-12-10-10"});
   *
   * new sap.m.DateTimePicker({
   *     value: {
   *         type: "sap.ui.model.type.DateTime",
   *         path: "/date",
   *         formatOptions: {
   *             source: {
   *                 pattern: "yyyy-MM-dd-HH-mm-ss"
   *             }
   *          }
   *     }
   * });
   * ```
   *  **Note:** There are multiple binding type choices, such as: sap.ui.model.type.Date sap.ui.model.odata.type.DateTime
   * sap.ui.model.odata.type.DateTimeOffset sap.ui.model.odata.type.DateTimeWithTimezone See {@link sap.ui.model.type.Date},
   * {@link sap.ui.model.odata.type.DateTime}, {@link sap.ui.model.odata.type.DateTimeOffset} or {@link sap.ui.model.odata.type.DateTimeWithTimezone}
   *
   *
   * 	 - Use the `dateValue` property if the date is already provided as a UI5Date or JavaScript Date object
   *     or you want to work with a UI5Date or JavaScript Date object. Use `dateValue` as a helper property to
   *     easily obtain the day, month, year, hours, minutes and seconds of the chosen date and time. Although
   *     it's possible to bind it, it's not recommended to do so. When binding is needed, use `value` property
   *     instead
   *
   * Formatting:
   *
   * All formatting and parsing of dates from and to strings is done using the {@link sap.ui.core.format.DateFormat}.
   * If a date is entered by typing it into the input field, it must fit to the used date format and locale.
   *
   * Supported format options are pattern-based on Unicode LDML Date Format notation. See {@link http://unicode.org/reports/tr35/#Date_Field_Symbol_Table}
   *
   * For example, if the `valueFormat` is "yyyy-MM-dd-HH-mm-ss", the `displayFormat` is "MMM d, y, HH:mm:ss",
   * and the used locale is English, a valid value string is "2015-07-30-10-30-15", which leads to an output
   * of "Jul 30, 2015, 10:30:15".
   *
   * If no placeholder is set to the `DateTimePicker`, the used `displayFormat` is displayed as a placeholder.
   * If another placeholder is needed, it must be set.
   *
   * **Note:** If the string does NOT match the `displayFormat` (from user input) or the `valueFormat` (on
   * app level), the {@link sap.ui.core.format.DateFormat} makes an attempt to parse it based on the locale
   * settings. For more information, see the respective documentation in the API Reference.
   *
   * Responsive behavior:
   *
   * The `DateTimePicker` is responsive and fully adapts to all devices. For larger screens, such as tablet
   * or desktop, it opens as a popover. For mobile devices, it opens in full screen.
   *
   * @since 1.38.0
   */
  export default class DateTimePicker extends DatePicker {
    /**
     * Constructor for a new `DateTimePicker`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/datetime-picker/ Date/Time Picker}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $DateTimePickerSettings
    );
    /**
     * Constructor for a new `DateTimePicker`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/datetime-picker/ Date/Time Picker}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $DateTimePickerSettings
    );

    /**
     * Creates a new subclass of class sap.m.DateTimePicker with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.DatePicker.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, DateTimePicker>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.DateTimePicker.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Current accessibility state of the control
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * This method should not be used because it could produce unpredictable results. Use `getValue()` instead.
     *
     * @since 1.102
     *
     * @returns date instance
     */
    getDateValue(): Date | UI5Date;
    /**
     * Apply the correct icon to the used Date control
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    getIconSrc(): void;
    /**
     * Gets current value of property {@link #getMinutesStep minutesStep}.
     *
     * Sets the minutes step. If the step is less than 1, it will be automatically converted back to 1. The
     * minutes clock is populated only by multiples of the step.
     *
     * Default value is `1`.
     *
     * @since 1.56
     *
     * @returns Value of property `minutesStep`
     */
    getMinutesStep(): int;
    /**
     * Gets current value of property {@link #getSecondsStep secondsStep}.
     *
     * Sets the seconds step. If the step is less than 1, it will be automatically converted back to 1. The
     * seconds clock is populated only by multiples of the step.
     *
     * Default value is `1`.
     *
     * @since 1.56
     *
     * @returns Value of property `secondsStep`
     */
    getSecondsStep(): int;
    /**
     * Gets current value of property {@link #getShowCurrentTimeButton showCurrentTimeButton}.
     *
     * Determines whether there is a shortcut navigation to current time.
     *
     * Default value is `false`.
     *
     * @since 1.98
     *
     * @returns Value of property `showCurrentTimeButton`
     */
    getShowCurrentTimeButton(): boolean;
    /**
     * Gets current value of property {@link #getShowFooter showFooter}.
     *
     * This property is inherited from `DatePicker` but its usage makes no sense in `DateTimePicker` because
     * `DateTimePicker` always have footer with buttons. Additionally, the setter for this property is overriden
     * to deny changing its value.
     *
     * Default value is `false`.
     *
     * @since 1.70
     *
     * @returns Value of property `showFooter`
     */
    getShowFooter(): boolean;
    /**
     * Gets current value of property {@link #getShowTimezone showTimezone}.
     *
     * Determines whether to show the timezone or not.
     *
     * @since 1.99
     *
     * @returns Value of property `showTimezone`
     */
    getShowTimezone(): boolean;
    /**
     * Gets current value of property {@link #getTimezone timezone}.
     *
     * The IANA timezone ID, e.g `"Europe/Berlin"`. For display purposes only in combination with `showTimezone`
     * property. The `value` property is a string representation of a date and time and is not related to the
     * displayed time zone. The `dateValue` property should not be used as this could lead to unpredictable
     * results. Use `getValue()` instead.
     *
     * @since 1.99
     *
     * @returns Value of property `timezone`
     */
    getTimezone(): string;
    /**
     * Set maximum date that can be shown and selected in the `DateTimePicker`. This must be a UI5Date or JavaScript
     * Date object.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setMaxDate(
      /**
       * A date instance
       */
      oDate: Date | UI5Date
    ): this;
    /**
     * Set minimum date that can be shown and selected in the `DateTimePicker`. This must be a UI5Date or JavaScript
     * Date object.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setMinDate(
      /**
       * A date instance
       */
      oDate: Date | UI5Date
    ): this;
    /**
     * Sets a new value for property {@link #getMinutesStep minutesStep}.
     *
     * Sets the minutes step. If the step is less than 1, it will be automatically converted back to 1. The
     * minutes clock is populated only by multiples of the step.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `1`.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMinutesStep(
      /**
       * New value for property `minutesStep`
       */
      iMinutesStep?: int
    ): this;
    /**
     * Sets a new value for property {@link #getSecondsStep secondsStep}.
     *
     * Sets the seconds step. If the step is less than 1, it will be automatically converted back to 1. The
     * seconds clock is populated only by multiples of the step.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `1`.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSecondsStep(
      /**
       * New value for property `secondsStep`
       */
      iSecondsStep?: int
    ): this;
    /**
     * Sets a new value for property {@link #getShowCurrentTimeButton showCurrentTimeButton}.
     *
     * Determines whether there is a shortcut navigation to current time.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.98
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowCurrentTimeButton(
      /**
       * New value for property `showCurrentTimeButton`
       */
      bShowCurrentTimeButton?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowTimezone showTimezone}.
     *
     * Determines whether to show the timezone or not.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.99
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowTimezone(
      /**
       * New value for property `showTimezone`
       */
      bShowTimezone: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getTimezone timezone}.
     *
     * The IANA timezone ID, e.g `"Europe/Berlin"`. For display purposes only in combination with `showTimezone`
     * property. The `value` property is a string representation of a date and time and is not related to the
     * displayed time zone. The `dateValue` property should not be used as this could lead to unpredictable
     * results. Use `getValue()` instead.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.99
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTimezone(
      /**
       * New value for property `timezone`
       */
      sTimezone: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the DateTimePicker constructor.
   */
  export interface $DateTimePickerSettings extends $DatePickerSettings {
    /**
     * Sets the minutes step. If the step is less than 1, it will be automatically converted back to 1. The
     * minutes clock is populated only by multiples of the step.
     *
     * @since 1.56
     */
    minutesStep?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the seconds step. If the step is less than 1, it will be automatically converted back to 1. The
     * seconds clock is populated only by multiples of the step.
     *
     * @since 1.56
     */
    secondsStep?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether there is a shortcut navigation to current time.
     *
     * @since 1.98
     */
    showCurrentTimeButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether to show the timezone or not.
     *
     * @since 1.99
     */
    showTimezone?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The IANA timezone ID, e.g `"Europe/Berlin"`. For display purposes only in combination with `showTimezone`
     * property. The `value` property is a string representation of a date and time and is not related to the
     * displayed time zone. The `dateValue` property should not be used as this could lead to unpredictable
     * results. Use `getValue()` instead.
     *
     * @since 1.99
     */
    timezone?: string | PropertyBindingInfo;

    /**
     * This property is inherited from `DatePicker` but its usage makes no sense in `DateTimePicker` because
     * `DateTimePicker` always have footer with buttons. Additionally, the setter for this property is overriden
     * to deny changing its value.
     *
     * @since 1.70
     */
    showFooter?: boolean | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/Dialog" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    PopupInterface,
    ID,
    CSSSize,
    URI,
    ValueState,
  } from "sap/ui/core/library";

  import Button from "sap/m/Button";

  import Event from "sap/ui/base/Event";

  import { IBar, TitleAlignment, DialogType } from "sap/m/library";

  import Toolbar from "sap/m/Toolbar";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * A popup that interrupts the current processing and prompts the user for an action or an input in a modal
   * mode. Overview: The Dialog control is used to prompt the user for an action or a confirmation. It interrupts
   * the current app processing as it is the only focused UI element and the main screen is dimmed/blocked.
   * The content of the Dialog is fully customizable. Structure: A Dialog consists of a title, optional subtitle,
   * content area and a footer for action buttons. The Dialog is usually displayed at the center of the screen.
   * Its size and position can be changed by the user. To enable this, you need to set the properties `resizable`
   * and `draggable` accordingly. In that case the dialog title bar can be focused. While the keyboard focus
   * is located on the title bar, the dialog can be moved with the arrow keys and resized with shift+arrow
   * keys.
   *
   * There are other specialized types of dialogs:
   * 	 - {@link sap.m.P13nDialog Personalization Dialog} - used for personalizing sorting, filtering and grouping
   *     in tables
   * 	 - {@link sap.m.SelectDialog Select Dialog} - used to select one or more items from a comprehensive
   *     list
   * 	 - {@link sap.m.TableSelectDialog Table Select Dialog} - used to make a selection from a comprehensive
   *     table containing multiple attributes or values
   * 	 - {@link sap.ui.comp.valuehelpdialog.ValueHelpDialog Value Help Dialog} - used to help the user find
   *     and select single and multiple values
   * 	 - {@link sap.m.ViewSettingsDialog View Settings Dialog} - used to sort, filter, or group data within
   *     a (master) list or a table
   * 	 - {@link sap.m.BusyDialog Busy Dialog} - used to block the screen and inform the user about an ongoing
   *     operation  Usage: When to use::
   * 	 - You want to display a system message.
   * 	 - You want to interrupt the user’s action.
   * 	 - You want to show a message with a short and a long description.  When not to use::
   * 	 - You just want to confirm a successful action.  Responsive Behavior:
   * 	 - If the `stretch` property is set to `true`, the Dialog displays on full screen.
   * 	 - If the `contentWidth` and/or `contentHeight` properties are set, the Dialog will try to fill those
   *     sizes.
   * 	 - If there is no specific sizing, the Dialog will try to adjust its size to its content.  When
   *     using the `sap.m.Dialog` in SAP Quartz and Horizon themes, the breakpoints and layout paddings could
   *     be determined by the Dialog's width. To enable this concept and add responsive paddings to an element
   *     of the Dialog control, you have to add the following classes depending on your use case: `sapUiResponsivePadding--header`,
   *     `sapUiResponsivePadding--subHeader`, `sapUiResponsivePadding--content`, `sapUiResponsivePadding--footer`.
   *     Smartphones: If the Dialog has one or two actions, they will cover the entire footer. If there are more
   *     actions, they will overflow. Tablets: The action buttons in the toolbar are **right-aligned**. Use **cozy**
   *     mode on tablet devices. Desktop: The action buttons in the toolbar are **right-aligned**. Use **compact**
   *     mode on desktop.
   */
  export default class Dialog extends Control implements PopupInterface {
    __implements__sap_ui_core_PopupInterface: boolean;
    /**
     * Constructor for a new Dialog.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/dialog/ Dialog}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $DialogSettings
    );
    /**
     * Constructor for a new Dialog.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/dialog/ Dialog}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $DialogSettings
    );

    /**
     * Creates a new subclass of class sap.m.Dialog with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Dialog>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Dialog.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Returns the custom header instance when the `customHeader` aggregation is set. Otherwise, it returns
     * the internal managed header instance. This method can be called within composite controls which use `sap.m.Dialog`
     * inside.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    _getAnyHeader(): void;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds some button to the aggregation {@link #getButtons buttons}.
     *
     * @since 1.21.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addButton(
      /**
       * The button to add; if empty, nothing is inserted
       */
      oButton: Button
    ): this;
    /**
     * Adds some content to the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContent(
      /**
       * The content to add; if empty, nothing is inserted
       */
      oContent: Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterClose afterClose} event of this `sap.m.Dialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Dialog` itself.
     *
     * This event will be fired after the Dialog is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Dialog$AfterCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Dialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterClose afterClose} event of this `sap.m.Dialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Dialog` itself.
     *
     * This event will be fired after the Dialog is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Dialog$AfterCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Dialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterOpen afterOpen} event of this `sap.m.Dialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Dialog` itself.
     *
     * This event will be fired after the Dialog is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Dialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterOpen afterOpen} event of this `sap.m.Dialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Dialog` itself.
     *
     * This event will be fired after the Dialog is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Dialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.Dialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Dialog` itself.
     *
     * This event will be fired before the Dialog is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Dialog$BeforeCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Dialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.Dialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Dialog` itself.
     *
     * This event will be fired before the Dialog is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Dialog$BeforeCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Dialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.Dialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Dialog` itself.
     *
     * This event will be fired before the Dialog is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Dialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.Dialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Dialog` itself.
     *
     * This event will be fired before the Dialog is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Dialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Close the dialog.
     *
     *
     * @returns `this` to allow method chaining
     */
    close(): this;
    /**
     * Destroys the beginButton in the aggregation {@link #getBeginButton beginButton}.
     *
     * @since 1.15.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyBeginButton(): this;
    /**
     * Destroys all the buttons in the aggregation {@link #getButtons buttons}.
     *
     * @since 1.21.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyButtons(): this;
    /**
     * Destroys all the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Destroys the customHeader in the aggregation {@link #getCustomHeader customHeader}.
     *
     * @since 1.15.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCustomHeader(): this;
    /**
     * Destroys the endButton in the aggregation {@link #getEndButton endButton}.
     *
     * @since 1.15.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyEndButton(): this;
    /**
     * Destroys the footer in the aggregation {@link #getFooter footer}.
     *
     * @since 1.110
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyFooter(): this;
    /**
     * Destroys the subHeader in the aggregation {@link #getSubHeader subHeader}.
     *
     * @since 1.12.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySubHeader(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterClose afterClose} event of this `sap.m.Dialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Dialog$AfterCloseEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterOpen afterOpen} event of this `sap.m.Dialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeClose beforeClose} event of this `sap.m.Dialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Dialog$BeforeCloseEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeOpen beforeOpen} event of this `sap.m.Dialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:afterClose afterClose} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Dialog$AfterCloseEventParameters
    ): this;
    /**
     * Fires event {@link #event:afterOpen afterOpen} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:beforeClose beforeClose} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireBeforeClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Dialog$BeforeCloseEventParameters
    ): boolean;
    /**
     * Fires event {@link #event:beforeOpen beforeOpen} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireBeforeOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): boolean;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets content of aggregation {@link #getBeginButton beginButton}.
     *
     * The button which is rendered to the left side (right side in RTL mode) of the `endButton` in the footer
     * area inside the Dialog. As of version 1.21.1, there's a new aggregation `buttons` created with which
     * more than 2 buttons can be added to the footer area of the Dialog. If the new `buttons` aggregation is
     * set, any change made to this aggregation has no effect anymore. With the Belize themes when running on
     * a phone, this `button` (and the `endButton` together when set) is (are) rendered at the center of the
     * footer area. While with the Quartz themes when running on a phone, this `button` (and the `endButton`
     * together when set) is (are) rendered on the right side of the footer area. When running on other platforms,
     * this `button` (and the `endButton` together when set) is (are) rendered at the right side (left side
     * in RTL mode) of the footer area.
     *
     * @since 1.15.1
     */
    getBeginButton(): Button;
    /**
     * Gets content of aggregation {@link #getButtons buttons}.
     *
     * Buttons can be added to the footer area of the Dialog through this aggregation. When this aggregation
     * is set, any change to the `beginButton` and `endButton` has no effect anymore. Buttons which are inside
     * this aggregation are aligned at the right side (left side in RTL mode) of the footer instead of in the
     * middle of the footer. The buttons aggregation can not be used together with the footer aggregation.
     *
     * @since 1.21.1
     */
    getButtons(): Button[];
    /**
     * Gets current value of property {@link #getCloseOnNavigation closeOnNavigation}.
     *
     * Indicates whether the Dialog will be closed automatically when a routing navigation occurs.
     *
     * Default value is `true`.
     *
     * @since 1.72
     *
     * @returns Value of property `closeOnNavigation`
     */
    getCloseOnNavigation(): boolean;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * The content inside the Dialog.
     * **Note:** When the content of the Dialog is comprised of controls that use `position: absolute`, such
     * as `SplitContainer`, the Dialog has to have either `stretch: true` or `contentHeight` set.
     */
    getContent(): Control[];
    /**
     * Gets current value of property {@link #getContentHeight contentHeight}.
     *
     * Preferred height of the content in the Dialog. If the preferred height is bigger than the available space
     * on a screen, it will be overwritten by the maximum available height on a screen in order to make sure
     * that the Dialog isn't cut off.
     *
     * @since 1.12.1
     *
     * @returns Value of property `contentHeight`
     */
    getContentHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getContentWidth contentWidth}.
     *
     * Preferred width of the content in the Dialog. This property affects the width of the Dialog on a phone
     * in landscape mode, a tablet or a desktop, because the Dialog has a fixed width on a phone in portrait
     * mode. If the preferred width is less than the minimum width of the Dialog or more than the available
     * width of the screen, it will be overwritten by the min or max value. The current mininum value of the
     * Dialog width on tablet is 400px.
     *
     * @since 1.12.1
     *
     * @returns Value of property `contentWidth`
     */
    getContentWidth(): CSSSize;
    /**
     * Gets content of aggregation {@link #getCustomHeader customHeader}.
     *
     * When it is set, the `icon`, `title` and `showHeader` properties are ignored. Only the `customHeader`
     * is shown as the header of the Dialog.
     * **Note:** To improve accessibility, titles with heading level `H1` should be used inside the custom header.
     *
     * @since 1.15.1
     */
    getCustomHeader(): IBar;
    /**
     * Gets current value of property {@link #getDraggable draggable}.
     *
     * Indicates whether the Dialog is draggable. If this property is set to `true`, the Dialog will be draggable
     * by its header. This property has a default value `false`. The Dialog can be draggable only in desktop
     * mode.
     *
     * Default value is `false`.
     *
     * @since 1.30
     *
     * @returns Value of property `draggable`
     */
    getDraggable(): boolean;
    /**
     * Gets content of aggregation {@link #getEndButton endButton}.
     *
     * The button which is rendered to the right side (left side in RTL mode) of the `beginButton` in the footer
     * area inside the Dialog. As of version 1.21.1, there's a new aggregation `buttons` created with which
     * more than 2 buttons can be added to the footer area of Dialog. If the new `buttons` aggregation is set,
     * any change made to this aggregation has no effect anymore. With the Belize themes when running on a phone,
     * this `button` (and the `beginButton` together when set) is (are) rendered at the center of the footer
     * area. While with the Quartz themes when running on a phone, this `button` (and the `beginButton` together
     * when set) is (are) rendered on the right side of the footer area. When running on other platforms, this
     * `button` (and the `beginButton` together when set) is (are) rendered at the right side (left side in
     * RTL mode) of the footer area.
     *
     * @since 1.15.1
     */
    getEndButton(): Button;
    /**
     * Gets current value of property {@link #getEscapeHandler escapeHandler}.
     *
     * This property allows to define custom behavior if the Escape key is pressed. By default, the Dialog is
     * closed.
     *  The property expects a function with one object parameter with `resolve` and `reject` properties. In
     * the function, either call `resolve` to close the dialog or call `reject` to prevent it from being closed.
     *
     * @since 1.44
     *
     * @returns Value of property `escapeHandler`
     */
    getEscapeHandler(): EscapeHandler;
    /**
     * Gets content of aggregation {@link #getFooter footer}.
     *
     * The footer of this dialog. It is always located at the bottom of the dialog. The footer aggregation can
     * not be used together with the buttons aggregation.
     *
     * @since 1.110
     */
    getFooter(): Toolbar;
    /**
     * Gets current value of property {@link #getHorizontalScrolling horizontalScrolling}.
     *
     * Indicates if the user can scroll horizontally inside the Dialog when the content is bigger than the content
     * area. The Dialog detects if there's `sap.m.NavContainer`, `sap.m.Page`, `sap.m.ScrollContainer` or `sap.m.SplitContainer`
     * as a direct child added to the Dialog. If there is, the Dialog will turn off `scrolling` by setting this
     * property to `false`, automatically ignoring the existing value of the property.
     *
     * Default value is `true`.
     *
     * @since 1.15.1
     *
     * @returns Value of property `horizontalScrolling`
     */
    getHorizontalScrolling(): boolean;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Icon displayed in the Dialog header. This `icon` is invisible on the iOS platform and it is density-aware.
     * You can use the density convention (@2, @1.5, etc.) to provide higher resolution image for higher density
     * screen.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * ID of the element which is the current target of the association {@link #getInitialFocus initialFocus},
     * or `null`.
     *
     * @since 1.15.0
     */
    getInitialFocus(): ID | null;
    /**
     * ID of the element which is the current target of the association {@link #getLeftButton leftButton}, or
     * `null`.
     *
     * @deprecated As of version 1.15.1. `LeftButton` has been deprecated since 1.15.1. Please use the `beginButton`
     * instead which is more RTL friendly.
     */
    getLeftButton(): ID | null;
    /**
     * Gets current value of property {@link #getResizable resizable}.
     *
     * Indicates whether the Dialog is resizable. If this property is set to `true`, the Dialog will have a
     * resize handler in its bottom right corner. This property has a default value `false`. The Dialog can
     * be resizable only in desktop mode.
     *
     * Default value is `false`.
     *
     * @since 1.30
     *
     * @returns Value of property `resizable`
     */
    getResizable(): boolean;
    /**
     * ID of the element which is the current target of the association {@link #getRightButton rightButton},
     * or `null`.
     *
     * @deprecated As of version 1.15.1. `RightButton` has been deprecated since 1.15.1. Please use the `endButton`
     * instead which is more RTL friendly.
     */
    getRightButton(): ID | null;
    /**
     * Gets current value of property {@link #getShowHeader showHeader}.
     *
     * Determines whether the header is shown inside the Dialog. If this property is set to `false`, the `text`
     * and `icon` properties are ignored. This property has a default value `true`.
     *
     * Default value is `true`.
     *
     * @since 1.15.1
     *
     * @returns Value of property `showHeader`
     */
    getShowHeader(): boolean;
    /**
     * Gets current value of property {@link #getState state}.
     *
     * Affects the `icon` and the `title` color.
     *
     * If a value other than `None` is set, a predefined icon will be added to the Dialog. Setting the `icon`
     * property will overwrite the predefined icon.
     *
     * Default value is `None`.
     *
     * @since 1.11.2
     *
     * @returns Value of property `state`
     */
    getState(): ValueState;
    /**
     * Gets current value of property {@link #getStretch stretch}.
     *
     * Determines if the Dialog will be stretched to full screen on mobile. On desktop, the Dialog will be stretched
     * to approximately 90% of the viewport. This property is only applicable to a Standard Dialog. Message-type
     * Dialog ignores it.
     *
     * Default value is `false`.
     *
     * @since 1.13.1
     *
     * @returns Value of property `stretch`
     */
    getStretch(): boolean;
    /**
     * Gets current value of property {@link #getStretchOnPhone stretchOnPhone}.
     *
     * Determines whether the Dialog will be displayed on full screen on a phone.
     *
     * Default value is `false`.
     *
     * @since 1.11.2
     * @deprecated As of version 1.13.1. Please use the new stretch property instead. This enables a stretched
     * Dialog even on tablet and desktop. If you want to achieve the same effect as `stretchOnPhone`, please
     * set the stretch with `Device.system.phone`, then the Dialog is only stretched when it runs on a phone.
     *
     * @returns Value of property `stretchOnPhone`
     */
    getStretchOnPhone(): boolean;
    /**
     * Gets content of aggregation {@link #getSubHeader subHeader}.
     *
     * When a `subHeader` is assigned to the Dialog, it's rendered directly after the main header in the Dialog.
     * The `subHeader` is out of the content area and won't be scrolled when the content size is bigger than
     * the content area size.
     *
     * @since 1.12.2
     */
    getSubHeader(): IBar;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Title text appears in the Dialog header.
     * **Note:** The heading level of the Dialog is `H1`. Headings in the Dialog content should start with `H2`
     * heading level.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getTitleAlignment titleAlignment}.
     *
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * Default value is `Auto`.
     *
     * @since 1.72
     *
     * @returns Value of property `titleAlignment`
     */
    getTitleAlignment(): TitleAlignment;
    /**
     * Gets current value of property {@link #getType type}.
     *
     * The `type` of the Dialog. In some themes, the type Message will limit the Dialog width within 480px on
     * tablet and desktop.
     *
     * Default value is `Standard`.
     *
     *
     * @returns Value of property `type`
     */
    getType(): DialogType;
    /**
     * Gets current value of property {@link #getVerticalScrolling verticalScrolling}.
     *
     * Indicates if the user can scroll vertically inside the Dialog when the content is bigger than the content
     * area. The Dialog detects if there's `sap.m.NavContainer`, `sap.m.Page`, `sap.m.ScrollContainer` or `sap.m.SplitContainer`
     * as a direct child added to the Dialog. If there is, the Dialog will turn off `scrolling` by setting this
     * property to `false`, automatically ignoring the existing value of this property.
     *
     * Default value is `true`.
     *
     * @since 1.15.1
     *
     * @returns Value of property `verticalScrolling`
     */
    getVerticalScrolling(): boolean;
    /**
     * Checks for the provided `sap.m.Button` in the aggregation {@link #getButtons buttons}. and returns its
     * index if found or -1 otherwise.
     *
     * @since 1.21.1
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfButton(
      /**
       * The button whose index is looked for
       */
      oButton: Button
    ): int;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContent content}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContent(
      /**
       * The content whose index is looked for
       */
      oContent: Control
    ): int;
    /**
     * Inserts a button into the aggregation {@link #getButtons buttons}.
     *
     * @since 1.21.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertButton(
      /**
       * The button to insert; if empty, nothing is inserted
       */
      oButton: Button,
      /**
       * The `0`-based index the button should be inserted at; for a negative value of `iIndex`, the button is
       * inserted at position 0; for a value greater than the current size of the aggregation, the button is inserted
       * at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a content into the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContent(
      /**
       * The content to insert; if empty, nothing is inserted
       */
      oContent: Control,
      /**
       * The `0`-based index the content should be inserted at; for a negative value of `iIndex`, the content
       * is inserted at position 0; for a value greater than the current size of the aggregation, the content
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * The method checks if the Dialog is open.
     *
     * It returns `true` when the Dialog is currently open (this includes opening and closing animations), otherwise
     * it returns `false`.
     *
     * @since 1.9.1
     *
     * @returns Whether the dialog is open.
     */
    isOpen(): boolean;
    /**
     * Open the dialog.
     *
     *
     * @returns `this` to allow method chaining
     */
    open(): this;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all the controls from the aggregation {@link #getButtons buttons}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.21.1
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllButtons(): Button[];
    /**
     * Removes all the controls from the aggregation {@link #getContent content}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContent(): Control[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes a button from the aggregation {@link #getButtons buttons}.
     *
     * @since 1.21.1
     *
     * @returns The removed button or `null`
     */
    removeButton(
      /**
       * The button to remove or its index or id
       */
      vButton: int | string | Button
    ): Button | null;
    /**
     * Removes a content from the aggregation {@link #getContent content}.
     *
     *
     * @returns The removed content or `null`
     */
    removeContent(
      /**
       * The content to remove or its index or id
       */
      vContent: int | string | Control
    ): Control | null;
    /**
     * Sets the aggregated {@link #getBeginButton beginButton}.
     *
     * @since 1.15.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBeginButton(
      /**
       * The beginButton to set
       */
      oBeginButton: Button
    ): this;
    /**
     * Sets a new value for property {@link #getCloseOnNavigation closeOnNavigation}.
     *
     * Indicates whether the Dialog will be closed automatically when a routing navigation occurs.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.72
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCloseOnNavigation(
      /**
       * New value for property `closeOnNavigation`
       */
      bCloseOnNavigation?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getContentHeight contentHeight}.
     *
     * Preferred height of the content in the Dialog. If the preferred height is bigger than the available space
     * on a screen, it will be overwritten by the maximum available height on a screen in order to make sure
     * that the Dialog isn't cut off.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.12.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContentHeight(
      /**
       * New value for property `contentHeight`
       */
      sContentHeight?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getContentWidth contentWidth}.
     *
     * Preferred width of the content in the Dialog. This property affects the width of the Dialog on a phone
     * in landscape mode, a tablet or a desktop, because the Dialog has a fixed width on a phone in portrait
     * mode. If the preferred width is less than the minimum width of the Dialog or more than the available
     * width of the screen, it will be overwritten by the min or max value. The current mininum value of the
     * Dialog width on tablet is 400px.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.12.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContentWidth(
      /**
       * New value for property `contentWidth`
       */
      sContentWidth?: CSSSize
    ): this;
    /**
     * Sets the aggregated {@link #getCustomHeader customHeader}.
     *
     * @since 1.15.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomHeader(
      /**
       * The customHeader to set
       */
      oCustomHeader: IBar
    ): this;
    /**
     * Sets a new value for property {@link #getDraggable draggable}.
     *
     * Indicates whether the Dialog is draggable. If this property is set to `true`, the Dialog will be draggable
     * by its header. This property has a default value `false`. The Dialog can be draggable only in desktop
     * mode.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.30
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDraggable(
      /**
       * New value for property `draggable`
       */
      bDraggable?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getEndButton endButton}.
     *
     * @since 1.15.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEndButton(
      /**
       * The endButton to set
       */
      oEndButton: Button
    ): this;
    /**
     * Sets a new value for property {@link #getEscapeHandler escapeHandler}.
     *
     * This property allows to define custom behavior if the Escape key is pressed. By default, the Dialog is
     * closed.
     *  The property expects a function with one object parameter with `resolve` and `reject` properties. In
     * the function, either call `resolve` to close the dialog or call `reject` to prevent it from being closed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.44
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEscapeHandler(
      /**
       * New value for property `escapeHandler`
       */
      sEscapeHandler?: EscapeHandler
    ): this;
    /**
     * Sets the aggregated {@link #getFooter footer}.
     *
     * @since 1.110
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFooter(
      /**
       * The footer to set
       */
      oFooter: Toolbar
    ): this;
    /**
     * Sets a new value for property {@link #getHorizontalScrolling horizontalScrolling}.
     *
     * Indicates if the user can scroll horizontally inside the Dialog when the content is bigger than the content
     * area. The Dialog detects if there's `sap.m.NavContainer`, `sap.m.Page`, `sap.m.ScrollContainer` or `sap.m.SplitContainer`
     * as a direct child added to the Dialog. If there is, the Dialog will turn off `scrolling` by setting this
     * property to `false`, automatically ignoring the existing value of the property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.15.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHorizontalScrolling(
      /**
       * New value for property `horizontalScrolling`
       */
      bHorizontalScrolling?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Icon displayed in the Dialog header. This `icon` is invisible on the iOS platform and it is density-aware.
     * You can use the density convention (@2, @1.5, etc.) to provide higher resolution image for higher density
     * screen.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets the associated {@link #getInitialFocus initialFocus}.
     *
     * @since 1.15.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInitialFocus(
      /**
       * ID of an element which becomes the new target of this initialFocus association; alternatively, an element
       * instance may be given
       */
      oInitialFocus: ID | Control
    ): this;
    /**
     * Sets the associated {@link #getLeftButton leftButton}.
     *
     * @deprecated As of version 1.15.1. `LeftButton` has been deprecated since 1.15.1. Please use the `beginButton`
     * instead which is more RTL friendly.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLeftButton(
      /**
       * ID of an element which becomes the new target of this leftButton association; alternatively, an element
       * instance may be given
       */
      oLeftButton: ID | Button
    ): this;
    /**
     * Sets a new value for property {@link #getResizable resizable}.
     *
     * Indicates whether the Dialog is resizable. If this property is set to `true`, the Dialog will have a
     * resize handler in its bottom right corner. This property has a default value `false`. The Dialog can
     * be resizable only in desktop mode.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.30
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setResizable(
      /**
       * New value for property `resizable`
       */
      bResizable?: boolean
    ): this;
    /**
     * Sets the associated {@link #getRightButton rightButton}.
     *
     * @deprecated As of version 1.15.1. `RightButton` has been deprecated since 1.15.1. Please use the `endButton`
     * instead which is more RTL friendly.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRightButton(
      /**
       * ID of an element which becomes the new target of this rightButton association; alternatively, an element
       * instance may be given
       */
      oRightButton: ID | Button
    ): this;
    /**
     * Sets a new value for property {@link #getShowHeader showHeader}.
     *
     * Determines whether the header is shown inside the Dialog. If this property is set to `false`, the `text`
     * and `icon` properties are ignored. This property has a default value `true`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.15.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowHeader(
      /**
       * New value for property `showHeader`
       */
      bShowHeader?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getState state}.
     *
     * Affects the `icon` and the `title` color.
     *
     * If a value other than `None` is set, a predefined icon will be added to the Dialog. Setting the `icon`
     * property will overwrite the predefined icon.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     * @since 1.11.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setState(
      /**
       * New value for property `state`
       */
      sState?: ValueState | keyof typeof ValueState
    ): this;
    /**
     * Sets a new value for property {@link #getStretch stretch}.
     *
     * Determines if the Dialog will be stretched to full screen on mobile. On desktop, the Dialog will be stretched
     * to approximately 90% of the viewport. This property is only applicable to a Standard Dialog. Message-type
     * Dialog ignores it.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.13.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setStretch(
      /**
       * New value for property `stretch`
       */
      bStretch?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getStretchOnPhone stretchOnPhone}.
     *
     * Determines whether the Dialog will be displayed on full screen on a phone.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.11.2
     * @deprecated As of version 1.13.1. Please use the new stretch property instead. This enables a stretched
     * Dialog even on tablet and desktop. If you want to achieve the same effect as `stretchOnPhone`, please
     * set the stretch with `Device.system.phone`, then the Dialog is only stretched when it runs on a phone.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setStretchOnPhone(
      /**
       * New value for property `stretchOnPhone`
       */
      bStretchOnPhone?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getSubHeader subHeader}.
     *
     * @since 1.12.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSubHeader(
      /**
       * The subHeader to set
       */
      oSubHeader: IBar
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Title text appears in the Dialog header.
     * **Note:** The heading level of the Dialog is `H1`. Headings in the Dialog content should start with `H2`
     * heading level.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitleAlignment titleAlignment}.
     *
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     * @since 1.72
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleAlignment(
      /**
       * New value for property `titleAlignment`
       */
      sTitleAlignment?: TitleAlignment | keyof typeof TitleAlignment
    ): this;
    /**
     * Sets a new value for property {@link #getType type}.
     *
     * The `type` of the Dialog. In some themes, the type Message will limit the Dialog width within 480px on
     * tablet and desktop.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Standard`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setType(
      /**
       * New value for property `type`
       */
      sType?: DialogType | keyof typeof DialogType
    ): this;
    /**
     * Sets a new value for property {@link #getVerticalScrolling verticalScrolling}.
     *
     * Indicates if the user can scroll vertically inside the Dialog when the content is bigger than the content
     * area. The Dialog detects if there's `sap.m.NavContainer`, `sap.m.Page`, `sap.m.ScrollContainer` or `sap.m.SplitContainer`
     * as a direct child added to the Dialog. If there is, the Dialog will turn off `scrolling` by setting this
     * property to `false`, automatically ignoring the existing value of this property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.15.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVerticalScrolling(
      /**
       * New value for property `verticalScrolling`
       */
      bVerticalScrolling?: boolean
    ): this;
  }
  /**
   * Escape handler for sap.m.Dialog control.
   */
  export type EscapeHandler = (oHandlers: object) => void;

  /**
   * Describes the settings that can be provided to the Dialog constructor.
   */
  export interface $DialogSettings extends $ControlSettings {
    /**
     * Icon displayed in the Dialog header. This `icon` is invisible on the iOS platform and it is density-aware.
     * You can use the density convention (@2, @1.5, etc.) to provide higher resolution image for higher density
     * screen.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Title text appears in the Dialog header.
     * **Note:** The heading level of the Dialog is `H1`. Headings in the Dialog content should start with `H2`
     * heading level.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Determines whether the header is shown inside the Dialog. If this property is set to `false`, the `text`
     * and `icon` properties are ignored. This property has a default value `true`.
     *
     * @since 1.15.1
     */
    showHeader?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The `type` of the Dialog. In some themes, the type Message will limit the Dialog width within 480px on
     * tablet and desktop.
     */
    type?:
      | (DialogType | keyof typeof DialogType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Affects the `icon` and the `title` color.
     *
     * If a value other than `None` is set, a predefined icon will be added to the Dialog. Setting the `icon`
     * property will overwrite the predefined icon.
     *
     * @since 1.11.2
     */
    state?:
      | (ValueState | keyof typeof ValueState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines whether the Dialog will be displayed on full screen on a phone.
     *
     * @since 1.11.2
     * @deprecated As of version 1.13.1. Please use the new stretch property instead. This enables a stretched
     * Dialog even on tablet and desktop. If you want to achieve the same effect as `stretchOnPhone`, please
     * set the stretch with `Device.system.phone`, then the Dialog is only stretched when it runs on a phone.
     */
    stretchOnPhone?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines if the Dialog will be stretched to full screen on mobile. On desktop, the Dialog will be stretched
     * to approximately 90% of the viewport. This property is only applicable to a Standard Dialog. Message-type
     * Dialog ignores it.
     *
     * @since 1.13.1
     */
    stretch?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Preferred width of the content in the Dialog. This property affects the width of the Dialog on a phone
     * in landscape mode, a tablet or a desktop, because the Dialog has a fixed width on a phone in portrait
     * mode. If the preferred width is less than the minimum width of the Dialog or more than the available
     * width of the screen, it will be overwritten by the min or max value. The current mininum value of the
     * Dialog width on tablet is 400px.
     *
     * @since 1.12.1
     */
    contentWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Preferred height of the content in the Dialog. If the preferred height is bigger than the available space
     * on a screen, it will be overwritten by the maximum available height on a screen in order to make sure
     * that the Dialog isn't cut off.
     *
     * @since 1.12.1
     */
    contentHeight?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates if the user can scroll horizontally inside the Dialog when the content is bigger than the content
     * area. The Dialog detects if there's `sap.m.NavContainer`, `sap.m.Page`, `sap.m.ScrollContainer` or `sap.m.SplitContainer`
     * as a direct child added to the Dialog. If there is, the Dialog will turn off `scrolling` by setting this
     * property to `false`, automatically ignoring the existing value of the property.
     *
     * @since 1.15.1
     */
    horizontalScrolling?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates if the user can scroll vertically inside the Dialog when the content is bigger than the content
     * area. The Dialog detects if there's `sap.m.NavContainer`, `sap.m.Page`, `sap.m.ScrollContainer` or `sap.m.SplitContainer`
     * as a direct child added to the Dialog. If there is, the Dialog will turn off `scrolling` by setting this
     * property to `false`, automatically ignoring the existing value of this property.
     *
     * @since 1.15.1
     */
    verticalScrolling?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether the Dialog is resizable. If this property is set to `true`, the Dialog will have a
     * resize handler in its bottom right corner. This property has a default value `false`. The Dialog can
     * be resizable only in desktop mode.
     *
     * @since 1.30
     */
    resizable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether the Dialog is draggable. If this property is set to `true`, the Dialog will be draggable
     * by its header. This property has a default value `false`. The Dialog can be draggable only in desktop
     * mode.
     *
     * @since 1.30
     */
    draggable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This property allows to define custom behavior if the Escape key is pressed. By default, the Dialog is
     * closed.
     *  The property expects a function with one object parameter with `resolve` and `reject` properties. In
     * the function, either call `resolve` to close the dialog or call `reject` to prevent it from being closed.
     *
     * @since 1.44
     */
    escapeHandler?: EscapeHandler | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether the Dialog will be closed automatically when a routing navigation occurs.
     *
     * @since 1.72
     */
    closeOnNavigation?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * @since 1.72
     */
    titleAlignment?:
      | (TitleAlignment | keyof typeof TitleAlignment)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The content inside the Dialog.
     * **Note:** When the content of the Dialog is comprised of controls that use `position: absolute`, such
     * as `SplitContainer`, the Dialog has to have either `stretch: true` or `contentHeight` set.
     */
    content?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * When a `subHeader` is assigned to the Dialog, it's rendered directly after the main header in the Dialog.
     * The `subHeader` is out of the content area and won't be scrolled when the content size is bigger than
     * the content area size.
     *
     * @since 1.12.2
     */
    subHeader?: IBar;

    /**
     * When it is set, the `icon`, `title` and `showHeader` properties are ignored. Only the `customHeader`
     * is shown as the header of the Dialog.
     * **Note:** To improve accessibility, titles with heading level `H1` should be used inside the custom header.
     *
     * @since 1.15.1
     */
    customHeader?: IBar;

    /**
     * The button which is rendered to the left side (right side in RTL mode) of the `endButton` in the footer
     * area inside the Dialog. As of version 1.21.1, there's a new aggregation `buttons` created with which
     * more than 2 buttons can be added to the footer area of the Dialog. If the new `buttons` aggregation is
     * set, any change made to this aggregation has no effect anymore. With the Belize themes when running on
     * a phone, this `button` (and the `endButton` together when set) is (are) rendered at the center of the
     * footer area. While with the Quartz themes when running on a phone, this `button` (and the `endButton`
     * together when set) is (are) rendered on the right side of the footer area. When running on other platforms,
     * this `button` (and the `endButton` together when set) is (are) rendered at the right side (left side
     * in RTL mode) of the footer area.
     *
     * @since 1.15.1
     */
    beginButton?: Button;

    /**
     * The button which is rendered to the right side (left side in RTL mode) of the `beginButton` in the footer
     * area inside the Dialog. As of version 1.21.1, there's a new aggregation `buttons` created with which
     * more than 2 buttons can be added to the footer area of Dialog. If the new `buttons` aggregation is set,
     * any change made to this aggregation has no effect anymore. With the Belize themes when running on a phone,
     * this `button` (and the `beginButton` together when set) is (are) rendered at the center of the footer
     * area. While with the Quartz themes when running on a phone, this `button` (and the `beginButton` together
     * when set) is (are) rendered on the right side of the footer area. When running on other platforms, this
     * `button` (and the `beginButton` together when set) is (are) rendered at the right side (left side in
     * RTL mode) of the footer area.
     *
     * @since 1.15.1
     */
    endButton?: Button;

    /**
     * Buttons can be added to the footer area of the Dialog through this aggregation. When this aggregation
     * is set, any change to the `beginButton` and `endButton` has no effect anymore. Buttons which are inside
     * this aggregation are aligned at the right side (left side in RTL mode) of the footer instead of in the
     * middle of the footer. The buttons aggregation can not be used together with the footer aggregation.
     *
     * @since 1.21.1
     */
    buttons?: Button[] | Button | AggregationBindingInfo | `{${string}}`;

    /**
     * The footer of this dialog. It is always located at the bottom of the dialog. The footer aggregation can
     * not be used together with the buttons aggregation.
     *
     * @since 1.110
     */
    footer?: Toolbar;

    /**
     * `LeftButton` is shown at the left edge of the bar in iOS, and at the right side of the bar for the other
     * platforms. Please set this to `null` if you want to remove the Left button from the bar. And the button
     * is only removed from the bar, not destroyed. When `showHeader` is set to `false`, this property will
     * be ignored. Setting `leftButton` will also set the `beginButton` internally.
     *
     * @deprecated As of version 1.15.1. `LeftButton` has been deprecated since 1.15.1. Please use the `beginButton`
     * instead which is more RTL friendly.
     */
    leftButton?: Button | string;

    /**
     * `RightButton` is always shown at the right edge of the bar. Please set this to null if you want to remove
     * the Right button from the bar. And the button is only removed from the bar, not destroyed. When `showHeader`
     * is set to false, this property will be ignored. Setting `rightButton` will also set the `endButton` internally.
     *
     * @deprecated As of version 1.15.1. `RightButton` has been deprecated since 1.15.1. Please use the `endButton`
     * instead which is more RTL friendly.
     */
    rightButton?: Button | string;

    /**
     * In the Dialog focus is set first on the `beginButton` and then on `endButton`, when available. If another
     * control needs to get the focus, set the `initialFocus` with the control which should be focused on. Setting
     * `initialFocus` to input controls doesn't open the On-Screen keyboard on mobile device as, due to browser
     * restriction, the On-Screen keyboard can't be opened with JavaScript code. The opening of On-Screen keyboard
     * must be triggered by real user action.
     *
     * @since 1.15.0
     */
    initialFocus?: Control | string;

    /**
     * Association to controls/IDs which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Association to controls/IDs which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * This event will be fired before the Dialog is opened.
     */
    beforeOpen?: (oEvent: Event) => void;

    /**
     * This event will be fired after the Dialog is opened.
     */
    afterOpen?: (oEvent: Event) => void;

    /**
     * This event will be fired before the Dialog is closed.
     */
    beforeClose?: (oEvent: Dialog$BeforeCloseEvent) => void;

    /**
     * This event will be fired after the Dialog is closed.
     */
    afterClose?: (oEvent: Dialog$AfterCloseEvent) => void;
  }

  /**
   * Parameters of the Dialog#afterClose event.
   */
  export interface Dialog$AfterCloseEventParameters {
    /**
     * This indicates the trigger of closing the Dialog. If the Dialog is closed by either the `beginButton`
     * or the `endButton`, the button that closes the Dialog is set to this parameter. Otherwise, the parameter
     * is set to `null`.
     */
    origin?: Button;
  }

  /**
   * Event object of the Dialog#afterClose event.
   */
  export type Dialog$AfterCloseEvent = Event<
    Dialog$AfterCloseEventParameters,
    Dialog
  >;

  /**
   * Parameters of the Dialog#afterOpen event.
   */
  export interface Dialog$AfterOpenEventParameters {}

  /**
   * Event object of the Dialog#afterOpen event.
   */
  export type Dialog$AfterOpenEvent = Event<
    Dialog$AfterOpenEventParameters,
    Dialog
  >;

  /**
   * Parameters of the Dialog#beforeClose event.
   */
  export interface Dialog$BeforeCloseEventParameters {
    /**
     * This indicates the trigger of closing the Dialog. If the Dialog is closed by either the `beginButton`
     * or the `endButton`, the button that closes the Dialog is set to this parameter. Otherwise, the parameter
     * is set to `null`.
     */
    origin?: Button;
  }

  /**
   * Event object of the Dialog#beforeClose event.
   */
  export type Dialog$BeforeCloseEvent = Event<
    Dialog$BeforeCloseEventParameters,
    Dialog
  >;

  /**
   * Parameters of the Dialog#beforeOpen event.
   */
  export interface Dialog$BeforeOpenEventParameters {}

  /**
   * Event object of the Dialog#beforeOpen event.
   */
  export type Dialog$BeforeOpenEvent = Event<
    Dialog$BeforeOpenEventParameters,
    Dialog
  >;
}

declare module "sap/m/DisplayListItem" {
  import {
    default as ListItemBase,
    $ListItemBaseSettings,
  } from "sap/m/ListItemBase";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { TextDirection } from "sap/ui/core/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * `sap.m.DisplayListItem` can be used to represent a label and a value.
   */
  export default class DisplayListItem extends ListItemBase {
    /**
     * Constructor for a new DisplayListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:/display-list-item/ Display List Item}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $DisplayListItemSettings
    );
    /**
     * Constructor for a new DisplayListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:/display-list-item/ Display List Item}
     */
    constructor(
      /**
       * Id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $DisplayListItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.DisplayListItem with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ListItemBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, DisplayListItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.DisplayListItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getLabel label}.
     *
     * Defines the label of the list item.
     *
     *
     * @returns Value of property `label`
     */
    getLabel(): string;
    /**
     * Gets current value of property {@link #getValue value}.
     *
     * Defines the value of the list item.
     *
     *
     * @returns Value of property `value`
     */
    getValue(): string;
    /**
     * Gets current value of property {@link #getValueTextDirection valueTextDirection}.
     *
     * Defines the `value` text directionality with enumerated options. By default, the control inherits text
     * direction from the DOM.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Value of property `valueTextDirection`
     */
    getValueTextDirection(): TextDirection;
    /**
     * Sets a new value for property {@link #getLabel label}.
     *
     * Defines the label of the list item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLabel(
      /**
       * New value for property `label`
       */
      sLabel?: string
    ): this;
    /**
     * Sets a new value for property {@link #getValue value}.
     *
     * Defines the value of the list item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValue(
      /**
       * New value for property `value`
       */
      sValue?: string
    ): this;
    /**
     * Sets a new value for property {@link #getValueTextDirection valueTextDirection}.
     *
     * Defines the `value` text directionality with enumerated options. By default, the control inherits text
     * direction from the DOM.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueTextDirection(
      /**
       * New value for property `valueTextDirection`
       */
      sValueTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
  }
  /**
   * Describes the settings that can be provided to the DisplayListItem constructor.
   */
  export interface $DisplayListItemSettings extends $ListItemBaseSettings {
    /**
     * Defines the label of the list item.
     */
    label?: string | PropertyBindingInfo;

    /**
     * Defines the value of the list item.
     */
    value?: string | PropertyBindingInfo;

    /**
     * Defines the `value` text directionality with enumerated options. By default, the control inherits text
     * direction from the DOM.
     *
     * @since 1.28.0
     */
    valueTextDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/DraftIndicator" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { DraftIndicatorState } from "sap/m/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * A draft indicator is {@link sap.m.Label}.
   *
   * @since 1.32.0
   */
  export default class DraftIndicator extends Control {
    /**
     * Constructor for a new DraftIndicator.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $DraftIndicatorSettings
    );
    /**
     * Constructor for a new DraftIndicator.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $DraftIndicatorSettings
    );

    /**
     * Creates a new subclass of class sap.m.DraftIndicator with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, DraftIndicator>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.DraftIndicator.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Clears the indicator state
     */
    clearDraftState(): void;
    /**
     * Gets current value of property {@link #getMinDisplayTime minDisplayTime}.
     *
     * Minimum time in milliseconds for showing the draft indicator
     *
     * Default value is `1500`.
     *
     *
     * @returns Value of property `minDisplayTime`
     */
    getMinDisplayTime(): int;
    /**
     * Gets current value of property {@link #getState state}.
     *
     * State of the indicator. Could be "Saving", "Saved" and "Clear".
     *
     * Default value is `Clear`.
     *
     *
     * @returns Value of property `state`
     */
    getState(): DraftIndicatorState;
    /**
     * Sets a new value for property {@link #getMinDisplayTime minDisplayTime}.
     *
     * Minimum time in milliseconds for showing the draft indicator
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `1500`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMinDisplayTime(
      /**
       * New value for property `minDisplayTime`
       */
      iMinDisplayTime?: int
    ): this;
    /**
     * Sets a new value for property {@link #getState state}.
     *
     * State of the indicator. Could be "Saving", "Saved" and "Clear".
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Clear`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setState(
      /**
       * New value for property `state`
       */
      sState?: DraftIndicatorState | keyof typeof DraftIndicatorState
    ): this;
    /**
     * Sets the indicator in "Saved" state
     */
    showDraftSaved(): void;
    /**
     * Sets the indicator in "Saving..." state
     */
    showDraftSaving(): void;
  }
  /**
   * Describes the settings that can be provided to the DraftIndicator constructor.
   */
  export interface $DraftIndicatorSettings extends $ControlSettings {
    /**
     * State of the indicator. Could be "Saving", "Saved" and "Clear".
     */
    state?:
      | (DraftIndicatorState | keyof typeof DraftIndicatorState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Minimum time in milliseconds for showing the draft indicator
     */
    minDisplayTime?: int | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/DynamicDate" {
  import SimpleType from "sap/ui/model/SimpleType";

  import Metadata from "sap/ui/base/Metadata";

  /**
   * This class represents the dynamic date range type. Model values should be in the following format: {
   * operator: "KEY", values: [param1, param2] }. Where the supported parameters are timestamps, month indexes
   * and numbers (all three are numbers). Their type is defined by the corresponding DynamicDateOption instance
   * identified by the same "KEY". This class is capable of formatting only the value parameters expected
   * by the DynamicDateRange control. A display format may be provided via the format options.
   *
   * @since 1.92
   */
  export default class DynamicDate extends SimpleType {
    /**
     * Constructor for a dynamic date range type.
     */
    constructor(
      /**
       * Format options. There are format options for each of the supported types of value parameters.
       */
      oFormatOptions?: {
        /**
         * Display format options for the values that contain dates. For a list of all available options, see {@link sap.ui.core.format.DateFormat.getDateInstance DateFormat}.
         */
        date?: object;
        /**
         * Display format options for the values that contain month names. The only supported option is the `pattern`
         * using the respective symbols for displaying months "MM", "MMM" or "MMMM".
         */
        month?: object;
        /**
         * Display format options for the values that contain numbers. For a list of all available options, see
         * {@link sap.ui.core.format.NumberFormat.getInstance NumberFormat}.
         */
        int?: object;
      },
      /**
       * Value constraints
       */
      oConstraints?: {
        /**
         * Smallest resulting date allowed for this type. Must be provided as a timestamps.
         */
        minimum?: int;
        /**
         * Greatest resulting date allowed for this type. Must be provided as a timestamps.
         */
        maximum?: int;
      }
    );

    /**
     * Creates a new subclass of class sap.m.DynamicDate with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.model.SimpleType.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, DynamicDate>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.DynamicDate.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): Metadata;
    /**
     * Formats the given object value to a similar object. The whole value is in the following format { operator:
     * "KEY", values: [...array with dates or numbers to be formatted]}. Only formats the 'values' part of the
     * given object. The dates are expected as 'timestamp' numbers and are converted to Javascript Date objects.
     * The numbers and strings are left untouched.
     *
     *
     * @returns A value object in a similar form
     */
    formatValue(
      /**
       * The value to be formatted
       */
      oValue: {
        operator: string;

        values: Array<number | string>;
      }
    ): {
      operator: string;

      values: Array<Date | number | string>;
    };
    /**
     * Parses the given object value to a similar object. The whole value is in the following format { operator:
     * "KEY", values: [...array with JS dates or numbers to be parsed]}. Only parses the 'values' part of the
     * given object. The dates are expected as Javascript Dates and are converted to timestamps. The numbers
     * and strings are left untouched. Special values with operator: "PARSEERROR" generate a parse exception.
     *
     *
     * @returns A value object in a similar form
     */
    parseValue(
      /**
       * The value to be parsed
       */
      oValue: {
        operator: string;

        values: Array<Date | number | string>;
      }
    ): {
      operator: string;

      values: Array<number | string | null>;
    };
  }
}

declare module "sap/m/DynamicDateFormat" {
  import { DynamicDateRangeValue } from "sap/m/library";

  import Locale from "sap/ui/core/Locale";

  /**
   * The DynamicDateFormat is a static class for formatting and parsing an array of strings in a locale-sensitive
   * manner according to a set of format options.
   */
  export default class DynamicDateFormat {
    /**
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    protected constructor();

    /**
     * Get an instance of the DynamicDateFormat which can be used for formatting.
     *
     *
     * @returns Instance of the DynamicDateFormat
     */
    static getInstance(
      /**
       * Object which defines the format options
       */
      oFormatOptions?: DynamicDateFormatOptions,
      /**
       * Locale to get the formatter for
       */
      oLocale?: Locale
    ): DynamicDateFormat;
    /**
     * Get an instance of the DynamicDateFormat which can be used for formatting.
     *
     *
     * @returns Instance of the DynamicDateFormat
     */
    static getInstance(
      /**
       * Locale to get the formatter for
       */
      oLocale?: Locale
    ): DynamicDateFormat;
    /**
     * Formats a list according to the given format options.
     *
     *
     * @returns The formatted output value.
     */
    format(
      /**
       * The value to format
       */
      oObj: DynamicDateRangeValue,
      /**
       * If set to `true` the formatter does not format to the equivalent user-friendly string. Instead, the formatter
       * uses the specified option key and parameters.
       */
      bSkipCustomFormatting: boolean
    ): string;
    /**
     * Parses a given list string into an array.
     *
     *
     * @returns The parsed output value
     */
    parse(
      /**
       * String value to be parsed
       */
      sValue: string,
      /**
       * String value of the key we will parse for
       */
      sKey: string
    ): DynamicDateRangeValue[];
  }
  /**
   * Object which defines the format options
   *
   * @since 1.111
   */
  export type DynamicDateFormatOptions = () => object;
}

declare module "sap/m/DynamicDateOption" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import DynamicDateRange from "sap/m/DynamicDateRange";

  import Event from "sap/ui/base/Event";

  import Control from "sap/ui/core/Control";

  import { DynamicDateRangeValue } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import DynamicDateValueHelpUIType from "sap/m/DynamicDateValueHelpUIType";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * A base type for the options used by the DynamicDateRange control.
   *
   * @since 1.92
   */
  export default class DynamicDateOption extends UI5Element {
    /**
     * Constructor for a new DynamicDateOption.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $DynamicDateOptionSettings
    );
    /**
     * Constructor for a new DynamicDateOption.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $DynamicDateOptionSettings
    );

    /**
     * Creates a new subclass of class sap.m.DynamicDateOption with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, DynamicDateOption>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.DynamicDateOption.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Creates the option's value help UI. Mainly used for custom scenarios where getValueHelpUITypes is not
     * enough to define the UI. In custom options, you can create different controls that are used by the user
     * to input data via interaction.
     *
     *
     * @returns An array with the option's value help UI controls
     */
    createValueHelpUI(
      /**
       * The control instance
       */
      oControl: DynamicDateRange,
      /**
       * A callback invoked when any of the created controls updates its value
       */
      fnControlsUpdated: (p1: Event) => void
    ): Control[];
    /**
     * Controls whether the formatted date range should be concatenated to the formatted value when displayed.
     *
     *
     * @returns True if the formatted value should be enhanced
     */
    enhanceFormattedValue(): boolean;
    /**
     * Formats the option's value to a string.
     *
     *
     * @returns A string representing this option's value
     */
    format(
      /**
       * A `sap.m.DynamicDateRangeValue`
       */
      oValue: DynamicDateRangeValue
    ): string;
    /**
     * Provides the order index of the option's group. Used for grouping within the options list inside a DynamicDateRange's
     * popup. Standard options are arranged in 6 groups - from 1 to 6. 1 - Single Dates 2 - Date Ranges 3 -
     * Weeks 4 - Months 5 - Quarters 6 - Years
     *
     *
     * @returns A group key from {@link sap.m.DynamicDateRangeGroups}
     */
    getGroup(): int | string;
    /**
     * Provides the option's group header text.
     *
     *
     * @returns A group header
     */
    getGroupHeader(): string;
    /**
     * Gets current value of property {@link #getKey key}.
     *
     * A key which identifies the option. The option produces DynamicDateRange values with operator same as
     * the option key.
     *
     *
     * @returns Value of property `key`
     */
    getKey(): string;
    /**
     * Defines the option's label for the DynamicDateRange's list of options.
     *
     *
     * @returns The option's label
     */
    getText(
      /**
       * The control instance which the label may depend on
       */
      oControl: DynamicDateRange
    ): string;
    /**
     * Gets the value help controls' output values and converts them to a `sap.m.DynamicDateRangeValue`.
     *
     *
     * @returns A `sap.m.DynamicDateRangeValue`
     */
    getValueHelpOutput(
      /**
       * The control instance
       */
      oControl: DynamicDateRange
    ): DynamicDateRangeValue;
    /**
     * Defines the UI types of the option. They are used to create predefined UI for the DynamicDateRange's
     * value help dialog corresponding to this option. The types are DynamicDateValueHelpUIType instances. Their
     * possible values are "date", "datetime", "daterange", "month", "int". The created UI consists of Calendar
     * or Input controls.
     *
     *
     * @returns An array with the option's UI types
     */
    getValueHelpUITypes(
      /**
       * The control instance
       */
      oControl: DynamicDateRange
    ): DynamicDateValueHelpUIType[];
    /**
     * Gets current value of property {@link #getValueTypes valueTypes}.
     *
     * Defines the types of the option's parameters. Possible values for the array items are "date" and "int".
     * A date range is usually represented with two consecutive "date" values.
     *
     *
     * @returns Value of property `valueTypes`
     */
    getValueTypes(): string[];
    /**
     * Parses a string to a `sap.m.DynamicDateRangeValue`.
     *
     *
     * @returns This parsed value
     */
    parse(
      /**
       * An input string
       */
      sValue: string
    ): DynamicDateRangeValue;
    /**
     * Sets a new value for property {@link #getKey key}.
     *
     * A key which identifies the option. The option produces DynamicDateRange values with operator same as
     * the option key.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setKey(
      /**
       * New value for property `key`
       */
      sKey: string
    ): this;
    /**
     * Sets a new value for property {@link #getValueTypes valueTypes}.
     *
     * Defines the types of the option's parameters. Possible values for the array items are "date" and "int".
     * A date range is usually represented with two consecutive "date" values.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueTypes(
      /**
       * New value for property `valueTypes`
       */
      sValueTypes: string[]
    ): this;
    /**
     * Calculates an absolute date range from the options relative value.
     *
     *
     * @returns A couple of dates marking the start and the end of the range
     */
    toDates(
      /**
       * A `sap.m.DynamicDateRangeValue`
       */
      oValue: DynamicDateRangeValue,
      /**
       * The type of calendar week numbering
       */
      sCalendarWeekNumbering: string
    ): /* was: sap.ui.core.date.UniversalDate */ any[];
    /**
     * Validates all input controls in the value help UI related to the current option. If one of the input
     * controls contains invalid value, then validation will return `false`. If all input controls contain valid
     * value, then the validation will return `true`.
     *
     *
     * @returns value help UI validity indicator
     */
    validateValueHelpUI(
      /**
       * The control instance
       */
      oControl: DynamicDateRange
    ): boolean;
  }
  /**
   * Describes the settings that can be provided to the DynamicDateOption constructor.
   */
  export interface $DynamicDateOptionSettings extends $ElementSettings {
    /**
     * A key which identifies the option. The option produces DynamicDateRange values with operator same as
     * the option key.
     */
    key?: string | PropertyBindingInfo;

    /**
     * Defines the types of the option's parameters. Possible values for the array items are "date" and "int".
     * A date range is usually represented with two consecutive "date" values.
     */
    valueTypes?: string[] | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/DynamicDateRange" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { ID, ValueState, CSSSize } from "sap/ui/core/library";

  import DynamicDateOption from "sap/m/DynamicDateOption";

  import CalendarWeekNumbering from "sap/base/i18n/date/CalendarWeekNumbering";

  import DynamicDateFormat from "sap/m/DynamicDateFormat";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { DynamicDateRangeValue } from "sap/m/library";

  import TooltipBase from "sap/ui/core/TooltipBase";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * A control base type.
   *
   * Overview:
   *
   * The dynamic date range is a control that offers a choice of absolute and relative dates, using different
   * offset from the current date. The list of values offered must be defined by the application.
   *
   * Usage:
   *
   * The control usage is recommended when:
   * 	 - Flexibility of choosing from absolute or relative dates and date ranges.
   * 	 - The relative representation of a date should be reused. (For example, show values from today regardless
   *     of when you open the application)
   *
   * The `DynamicDateRange` control supports a number of standard options: see {@link sap.m.StandardDynamicDateRangeKeys}.
   * A custom option could be defined by extending the `sap.m.DynamicDateOption` class and adding an instance
   * of this class into the `sap.m.DynamicDateRange` customOptions aggregation. In order for a specific option
   * to be used its key should be added into the `standardOptions` property of the control. No options are
   * added by default.
   *
   * **Note:** Property binding with the `value` and `formatter` properties is not supported. Instead, you
   * should use their public getter and setter methods.
   *
   * Suggestions are available when the user types in the control input field.
   *
   * Responsive behavior:
   *
   * On mobile devices, when user taps on the `DynamicDateRange` input icon a full screen dialog is opened.
   * The dialog is closed via a date time period value selection or by pressing the "Cancel" button.
   *
   * @since 1.92.0
   */
  export default class DynamicDateRange extends Control {
    /**
     * Constructor for a new DynamicDateRange.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $DynamicDateRangeSettings
    );
    /**
     * Constructor for a new DynamicDateRange.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $DynamicDateRangeSettings
    );

    /**
     * Creates a new subclass of class sap.m.DynamicDateRange with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, DynamicDateRange>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.DynamicDateRange.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Returns a date range from a provided object in the format of the DynamicDateRange's value.
     *
     *
     * @returns An array of two date objects - start and end date
     */
    static toDates(
      /**
       * A `sap.m.DynamicDateRangeValue`
       */
      oValue: DynamicDateRangeValue,
      /**
       * The type of calendar week numbering
       */
      sCalendarWeekNumbering: string
    ): Date[];
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     * @since 1.92
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.92
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds some customOption to the aggregation {@link #getCustomOptions customOptions}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addCustomOption(
      /**
       * The customOption to add; if empty, nothing is inserted
       */
      oCustomOption: DynamicDateOption
    ): this;
    /**
     * Adds a group to the enumeration containing the current groups in `sap.m.DynamicDateRange`
     *
     * @since 1.118
     */
    addGroup(
      /**
       * the name that the group will be selected by.
       */
      sGroupName: string,
      /**
       * the group header that will be presented in the list.
       */
      sGroupHeader: string
    ): void;
    /**
     * Appends an option key, identifying an additional standard option to be used by the control.
     *
     * @since 1.92
     */
    addStandardOption(
      /**
       * option key
       */
      sKey: string
    ): void;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.DynamicDateRange`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.DynamicDateRange` itself.
     *
     * Is fired when the text in the input field has changed and the focus leaves the input field or the Enter
     * key is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: DynamicDateRange$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.DynamicDateRange` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.DynamicDateRange`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.DynamicDateRange` itself.
     *
     * Is fired when the text in the input field has changed and the focus leaves the input field or the Enter
     * key is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: DynamicDateRange$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.DynamicDateRange` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the customOptions in the aggregation {@link #getCustomOptions customOptions}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCustomOptions(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:change change} event of this `sap.m.DynamicDateRange`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: DynamicDateRange$ChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:change change} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: DynamicDateRange$ChangeEventParameters
    ): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     * @since 1.92
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.92
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getCalendarWeekNumbering calendarWeekNumbering}.
     *
     * If set, the calendar week numbering is used for display. If not set, the calendar week numbering of the
     * global configuration is used.
     *
     * @since 1.111.0
     *
     * @returns Value of property `calendarWeekNumbering`
     */
    getCalendarWeekNumbering(): CalendarWeekNumbering;
    /**
     * Gets content of aggregation {@link #getCustomOptions customOptions}.
     *
     * Custom options for the `DynamicDateRange`.
     */
    getCustomOptions(): DynamicDateOption[];
    /**
     * Gets current value of property {@link #getEditable editable}.
     *
     * Defines whether the control can be modified by the user or not. **Note:** A user can tab to the non-editable
     * control, highlight it, and copy the text from it.
     *
     * Default value is `true`.
     *
     * @since 1.92
     *
     * @returns Value of property `editable`
     */
    getEditable(): boolean;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Indicates whether the user can interact with the control or not. **Note:** Disabled controls cannot be
     * focused and they are out of the tab-chain.
     *
     * Default value is `true`.
     *
     * @since 1.92
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets current value of property {@link #getEnableGroupHeaders enableGroupHeaders}.
     *
     * Disable list group headers.
     *
     * Default value is `true`.
     *
     * @since 1.92
     *
     * @returns Value of property `enableGroupHeaders`
     */
    getEnableGroupHeaders(): boolean;
    /**
     * Getter for the `formatter` of the control.
     *
     *
     * @returns A `sap.m.DynamicDateFormat`
     */
    getFormatter(): DynamicDateFormat;
    /**
     * Provides the option's group header text.
     *
     * @since 1.118
     *
     * @returns A group header
     */
    getGroupHeader(): string;
    /**
     * Gets current value of property {@link #getHideInput hideInput}.
     *
     * Determines whether the input field of the control is hidden or visible. When set to `true`, the input
     * field becomes invisible and there is no way to open the value help popover. In that case it can be opened
     * by another control through calling of control's `openBy` method, and the opening control's DOM reference
     * must be provided as parameter.
     *
     * Note: Since the Dynamic Date Range is not responsible for accessibility attributes of the control which
     * opens its popover, those attributes should be added by the application developer. The following is recommended
     * to be added to the opening control: a text or tooltip that describes the action (example: "Open Dynamic
     * Date Range"), and also aria-haspopup attribute with value of `true`.
     *
     * Default value is `false`.
     *
     * @since 1.105
     *
     * @returns Value of property `hideInput`
     */
    getHideInput(): boolean;
    /**
     * Returns the DOMNode Id to be used for the "labelFor" attribute of the label.
     *
     * By default, this is the Id of the control itself.
     *
     *
     * @returns Id to be used for the `labelFor`
     */
    getIdForLabel(): string;
    /**
     * Gets current value of property {@link #getName name}.
     *
     * Defines the name of the control for the purposes of form submission.
     *
     * @since 1.92
     *
     * @returns Value of property `name`
     */
    getName(): string;
    /**
     * Gets an option object by its key.
     *
     *
     * @returns The option
     */
    getOption(
      /**
       * The option key
       */
      sKey: string
    ): DynamicDateOption;
    /**
     * Gets current value of property {@link #getPlaceholder placeholder}.
     *
     * Defines a short hint intended to aid the user with data entry when the control has no value.
     *
     * @since 1.92
     *
     * @returns Value of property `placeholder`
     */
    getPlaceholder(): string;
    /**
     * Gets current value of property {@link #getRequired required}.
     *
     * Indicates that user input is required. This property is only needed for accessibility purposes when a
     * single relationship between the field and a label (see aggregation `labelFor` of `sap.m.Label`) cannot
     * be established (e.g. one label should label multiple fields).
     *
     * Default value is `false`.
     *
     * @since 1.92
     *
     * @returns Value of property `required`
     */
    getRequired(): boolean;
    /**
     * Gets current value of property {@link #getShowClearIcon showClearIcon}.
     *
     * Specifies whether clear icon is shown. Pressing the icon will clear input's value and fire the liveChange
     * event.
     *
     * Default value is `false`.
     *
     * @since 1.117
     *
     * @returns Value of property `showClearIcon`
     */
    getShowClearIcon(): boolean;
    /**
     * Gets current value of property {@link #getStandardOptions standardOptions}.
     *
     * Array of standard option keys
     *
     * Default value is `["DATE", "TODAY", "YESTERDAY", "TOMORROW", "FIRSTDAYWEEK", "LASTDAYWEEK", "FIRSTDAYMONTH",
     * "LASTDAYMONTH", "FIRSTDAYQUARTER", "LASTDAYQUARTER", "FIRSTDAYYEAR", "LASTDAYYEAR", "DATERANGE", "DATETIMERANGE",
     * "FROM", "TO", "FROMDATETIME", "TODATETIME", "YEARTODATE", "DATETOYEAR", "LASTMINUTES", "LASTHOURS", "LASTDAYS",
     * "LASTWEEKS", "LASTMONTHS", "LASTQUARTERS", "LASTYEARS", "LASTMINUTESINCLUDED", "LASTHOURSINCLUDED", "LASTDAYSINCLUDED",
     * "LASTWEEKSINCLUDED", "LASTMONTHSINCLUDED", "LASTQUARTERSINCLUDED", "LASTYEARSINCLUDED", "NEXTMINUTES",
     * "NEXTHOURS", "NEXTDAYS", "NEXTWEEKS", "NEXTMONTHS", "NEXTQUARTERS", "NEXTYEARS", "NEXTMINUTESINCLUDED",
     * "NEXTHOURSINCLUDED", "NEXTDAYSINCLUDED", "NEXTWEEKSINCLUDED", "NEXTMONTHSINCLUDED", "NEXTQUARTERSINCLUDED",
     * "NEXTYEARSINCLUDED", "TODAYFROMTO", "THISWEEK", "LASTWEEK", "NEXTWEEK", "SPECIFICMONTH", "SPECIFICMONTHINYEAR",
     * "THISMONTH", "LASTMONTH", "NEXTMONTH", "THISQUARTER", "LASTQUARTER", "NEXTQUARTER", "QUARTER1", "QUARTER2",
     * "QUARTER3", "QUARTER4", "THISYEAR", "LASTYEAR", "NEXTYEAR", "DATETIME"]`.
     *
     * @since 1.92
     *
     * @returns Value of property `standardOptions`
     */
    getStandardOptions(): string[];
    /**
     * Getter for the `value` of the control.
     *
     *
     * @returns A `sap.m.DynamicDateRangeValue`
     */
    getValue(): DynamicDateRangeValue;
    /**
     * Gets current value of property {@link #getValueState valueState}.
     *
     * Accepts the core enumeration ValueState.type that supports `None`, `Error`, `Warning` and `Success`.
     * ValueState is managed internally only when validation is triggered by user interaction.
     *
     * Default value is `None`.
     *
     * @since 1.92
     *
     * @returns Value of property `valueState`
     */
    getValueState(): ValueState;
    /**
     * Gets current value of property {@link #getValueStateText valueStateText}.
     *
     * Defines the text that appears in the value state message popup.
     *
     * @since 1.92
     *
     * @returns Value of property `valueStateText`
     */
    getValueStateText(): string;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Defines the width of the control.
     *
     * @since 1.92
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Checks for the provided `sap.m.DynamicDateOption` in the aggregation {@link #getCustomOptions customOptions}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfCustomOption(
      /**
       * The customOption whose index is looked for
       */
      oCustomOption: DynamicDateOption
    ): int;
    /**
     * Inserts a customOption into the aggregation {@link #getCustomOptions customOptions}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertCustomOption(
      /**
       * The customOption to insert; if empty, nothing is inserted
       */
      oCustomOption: DynamicDateOption,
      /**
       * The `0`-based index the customOption should be inserted at; for a negative value of `iIndex`, the customOption
       * is inserted at position 0; for a value greater than the current size of the aggregation, the customOption
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Opens the value help dialog.
     *
     * @since 1.92
     */
    open(
      /**
       * DOM reference of the opening control. On tablet or desktop, the popover is positioned relatively to this
       * control.
       */
      oDomRef: HTMLElement
    ): void;
    /**
     * Opens the value help popover. The popover is positioned relatively to the control given as `oDomRef`
     * parameter on tablet or desktop and is full screen on phone. Therefore the control parameter is only used
     * on tablet or desktop and is ignored on phone.
     *
     * Note: use this method to open the value help popover only when the `hideInput` property is set to `true`.
     * Please consider opening of the value help popover by another control only in scenarios that comply with
     * Fiori guidelines. For example, opening the value help popover by another popover is not recommended.
     * The application developer should implement the following accessibility attributes to the opening control:
     * a text or tooltip that describes the action (example: "Open Dynamic Date Range"), and aria-haspopup attribute
     * with value of `true`.
     *
     * @since 1.105
     */
    openBy(
      /**
       * DOM reference of the opening control. On tablet or desktop, the popover is positioned relatively to this
       * control.
       */
      oDomRef: HTMLElement
    ): void;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     * @since 1.92
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.92
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all the controls from the aggregation {@link #getCustomOptions customOptions}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllCustomOptions(): DynamicDateOption[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     * @since 1.92
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.92
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes all additionally added groups
     */
    removeCustomGroups(): void;
    /**
     * Removes a customOption from the aggregation {@link #getCustomOptions customOptions}.
     *
     *
     * @returns The removed customOption or `null`
     */
    removeCustomOption(
      /**
       * The customOption to remove or its index or id
       */
      vCustomOption: int | string | DynamicDateOption
    ): DynamicDateOption | null;
    /**
     * Sets a new value for property {@link #getCalendarWeekNumbering calendarWeekNumbering}.
     *
     * If set, the calendar week numbering is used for display. If not set, the calendar week numbering of the
     * global configuration is used.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.111.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCalendarWeekNumbering(
      /**
       * New value for property `calendarWeekNumbering`
       */
      sCalendarWeekNumbering?:
        | CalendarWeekNumbering
        | keyof typeof CalendarWeekNumbering
    ): this;
    /**
     * Sets a new value for property {@link #getEditable editable}.
     *
     * Defines whether the control can be modified by the user or not. **Note:** A user can tab to the non-editable
     * control, highlight it, and copy the text from it.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.92
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEditable(
      /**
       * New value for property `editable`
       */
      bEditable?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Indicates whether the user can interact with the control or not. **Note:** Disabled controls cannot be
     * focused and they are out of the tab-chain.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.92
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnableGroupHeaders enableGroupHeaders}.
     *
     * Disable list group headers.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.92
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableGroupHeaders(
      /**
       * New value for property `enableGroupHeaders`
       */
      bEnableGroupHeaders?: boolean
    ): this;
    /**
     * Setter for the `formatter` of the control.
     *
     *
     * @returns A `sap.m.DynamicDateFormat`
     */
    setFormatter(
      /**
       * A `sap.m.DynamicDateFormat`
       */
      oFormatter: DynamicDateFormat
    ): DynamicDateFormat;
    /**
     * Sets a new header to an existing custom group.
     */
    setGroupHeader(
      /**
       * the name that the group will be selected by.
       */
      sGroupName: string,
      /**
       * the group header that will be presented in the list.
       */
      sGroupHeader: string
    ): void;
    /**
     * Sets a new value for property {@link #getHideInput hideInput}.
     *
     * Determines whether the input field of the control is hidden or visible. When set to `true`, the input
     * field becomes invisible and there is no way to open the value help popover. In that case it can be opened
     * by another control through calling of control's `openBy` method, and the opening control's DOM reference
     * must be provided as parameter.
     *
     * Note: Since the Dynamic Date Range is not responsible for accessibility attributes of the control which
     * opens its popover, those attributes should be added by the application developer. The following is recommended
     * to be added to the opening control: a text or tooltip that describes the action (example: "Open Dynamic
     * Date Range"), and also aria-haspopup attribute with value of `true`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.105
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHideInput(
      /**
       * New value for property `hideInput`
       */
      bHideInput?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getName name}.
     *
     * Defines the name of the control for the purposes of form submission.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.92
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setName(
      /**
       * New value for property `name`
       */
      sName?: string
    ): this;
    /**
     * Sets a new value for property {@link #getPlaceholder placeholder}.
     *
     * Defines a short hint intended to aid the user with data entry when the control has no value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.92
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPlaceholder(
      /**
       * New value for property `placeholder`
       */
      sPlaceholder?: string
    ): this;
    /**
     * Sets a new value for property {@link #getRequired required}.
     *
     * Indicates that user input is required. This property is only needed for accessibility purposes when a
     * single relationship between the field and a label (see aggregation `labelFor` of `sap.m.Label`) cannot
     * be established (e.g. one label should label multiple fields).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.92
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRequired(
      /**
       * New value for property `required`
       */
      bRequired?: boolean
    ): this;
    /**
     * Sets the showClearIcon for the `DynamicDateRange`.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setShowClearIcon(
      /**
       * Whether to show clear icon.
       */
      bShowClearIcon: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getStandardOptions standardOptions}.
     *
     * Array of standard option keys
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `["DATE", "TODAY", "YESTERDAY", "TOMORROW", "FIRSTDAYWEEK", "LASTDAYWEEK", "FIRSTDAYMONTH",
     * "LASTDAYMONTH", "FIRSTDAYQUARTER", "LASTDAYQUARTER", "FIRSTDAYYEAR", "LASTDAYYEAR", "DATERANGE", "DATETIMERANGE",
     * "FROM", "TO", "FROMDATETIME", "TODATETIME", "YEARTODATE", "DATETOYEAR", "LASTMINUTES", "LASTHOURS", "LASTDAYS",
     * "LASTWEEKS", "LASTMONTHS", "LASTQUARTERS", "LASTYEARS", "LASTMINUTESINCLUDED", "LASTHOURSINCLUDED", "LASTDAYSINCLUDED",
     * "LASTWEEKSINCLUDED", "LASTMONTHSINCLUDED", "LASTQUARTERSINCLUDED", "LASTYEARSINCLUDED", "NEXTMINUTES",
     * "NEXTHOURS", "NEXTDAYS", "NEXTWEEKS", "NEXTMONTHS", "NEXTQUARTERS", "NEXTYEARS", "NEXTMINUTESINCLUDED",
     * "NEXTHOURSINCLUDED", "NEXTDAYSINCLUDED", "NEXTWEEKSINCLUDED", "NEXTMONTHSINCLUDED", "NEXTQUARTERSINCLUDED",
     * "NEXTYEARSINCLUDED", "TODAYFROMTO", "THISWEEK", "LASTWEEK", "NEXTWEEK", "SPECIFICMONTH", "SPECIFICMONTHINYEAR",
     * "THISMONTH", "LASTMONTH", "NEXTMONTH", "THISQUARTER", "LASTQUARTER", "NEXTQUARTER", "QUARTER1", "QUARTER2",
     * "QUARTER3", "QUARTER4", "THISYEAR", "LASTYEAR", "NEXTYEAR", "DATETIME"]`.
     *
     * @since 1.92
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setStandardOptions(
      /**
       * New value for property `standardOptions`
       */
      sStandardOptions?: string[]
    ): this;
    /**
     * Sets the tooltip for the `DynamicDateRange`.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setTooltip(
      /**
       * The tooltip that should be shown.
       */
      vTooltip: TooltipBase | string
    ): this;
    /**
     * Setter for the `value` control property.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setValue(
      /**
       * A `sap.m.DynamicDateRangeValue`
       */
      oValue: DynamicDateRangeValue
    ): this;
    /**
     * Sets a new value for property {@link #getValueState valueState}.
     *
     * Accepts the core enumeration ValueState.type that supports `None`, `Error`, `Warning` and `Success`.
     * ValueState is managed internally only when validation is triggered by user interaction.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     * @since 1.92
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueState(
      /**
       * New value for property `valueState`
       */
      sValueState?: ValueState | keyof typeof ValueState
    ): this;
    /**
     * Sets a new value for property {@link #getValueStateText valueStateText}.
     *
     * Defines the text that appears in the value state message popup.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.92
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueStateText(
      /**
       * New value for property `valueStateText`
       */
      sValueStateText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Defines the width of the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.92
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Calculates a date range from a provided object in the format of the DynamicDateRange's value.
     *
     *
     * @returns An array of two date objects - start and end date
     */
    toDates(
      /**
       * A `sap.m.DynamicDateRangeValue`
       */
      oValue: DynamicDateRangeValue
    ): /* was: sap.ui.core.date.UniversalDate */ any[];
  }
  /**
   * Describes the settings that can be provided to the DynamicDateRange constructor.
   */
  export interface $DynamicDateRangeSettings extends $ControlSettings {
    /**
     * Defines the width of the control.
     *
     * @since 1.92
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether the user can interact with the control or not. **Note:** Disabled controls cannot be
     * focused and they are out of the tab-chain.
     *
     * @since 1.92
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Accepts the core enumeration ValueState.type that supports `None`, `Error`, `Warning` and `Success`.
     * ValueState is managed internally only when validation is triggered by user interaction.
     *
     * @since 1.92
     */
    valueState?:
      | (ValueState | keyof typeof ValueState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the name of the control for the purposes of form submission.
     *
     * @since 1.92
     */
    name?: string | PropertyBindingInfo;

    /**
     * Defines a short hint intended to aid the user with data entry when the control has no value.
     *
     * @since 1.92
     */
    placeholder?: string | PropertyBindingInfo;

    /**
     * Defines whether the control can be modified by the user or not. **Note:** A user can tab to the non-editable
     * control, highlight it, and copy the text from it.
     *
     * @since 1.92
     */
    editable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the text that appears in the value state message popup.
     *
     * @since 1.92
     */
    valueStateText?: string | PropertyBindingInfo;

    /**
     * Indicates that user input is required. This property is only needed for accessibility purposes when a
     * single relationship between the field and a label (see aggregation `labelFor` of `sap.m.Label`) cannot
     * be established (e.g. one label should label multiple fields).
     *
     * @since 1.92
     */
    required?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Disable list group headers.
     *
     * @since 1.92
     */
    enableGroupHeaders?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Array of standard option keys
     *
     * @since 1.92
     */
    standardOptions?: string[] | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the input field of the control is hidden or visible. When set to `true`, the input
     * field becomes invisible and there is no way to open the value help popover. In that case it can be opened
     * by another control through calling of control's `openBy` method, and the opening control's DOM reference
     * must be provided as parameter.
     *
     * Note: Since the Dynamic Date Range is not responsible for accessibility attributes of the control which
     * opens its popover, those attributes should be added by the application developer. The following is recommended
     * to be added to the opening control: a text or tooltip that describes the action (example: "Open Dynamic
     * Date Range"), and also aria-haspopup attribute with value of `true`.
     *
     * @since 1.105
     */
    hideInput?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * If set, the calendar week numbering is used for display. If not set, the calendar week numbering of the
     * global configuration is used.
     *
     * @since 1.111.0
     */
    calendarWeekNumbering?:
      | (CalendarWeekNumbering | keyof typeof CalendarWeekNumbering)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies whether clear icon is shown. Pressing the icon will clear input's value and fire the liveChange
     * event.
     *
     * @since 1.117
     */
    showClearIcon?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Custom options for the `DynamicDateRange`.
     */
    customOptions?:
      | DynamicDateOption[]
      | DynamicDateOption
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Association to controls / IDs that label this control (see WAI-ARIA attribute aria-labelledby).
     *
     * @since 1.92
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Association to controls / IDs that describe this control (see WAI-ARIA attribute aria-describedby).
     *
     * @since 1.92
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Is fired when the text in the input field has changed and the focus leaves the input field or the Enter
     * key is pressed.
     */
    change?: (oEvent: DynamicDateRange$ChangeEvent) => void;
  }

  /**
   * Parameters of the DynamicDateRange#change event.
   */
  export interface DynamicDateRange$ChangeEventParameters {
    /**
     * The current value of the control.
     */
    value?: object;

    /**
     * Whether the new value is valid.
     */
    valid?: boolean;
  }

  /**
   * Event object of the DynamicDateRange#change event.
   */
  export type DynamicDateRange$ChangeEvent = Event<
    DynamicDateRange$ChangeEventParameters,
    DynamicDateRange
  >;
}

declare module "sap/m/DynamicDateUtil" {
  import DynamicDateOption from "sap/m/DynamicDateOption";

  import DynamicDateFormat from "sap/m/DynamicDateFormat";

  import { DynamicDateRangeValue } from "sap/m/library";

  /**
   * The DynamicDateUtil is a utility class for working with the DynamicDateOption instances.
   *
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  interface DynamicDateUtil {
    /**
     * Adds an option to be reused as a global object.
     */
    addOption(
      /**
       * The option to be added
       */
      option: DynamicDateOption
    ): void;
    /**
     * Gets all available standard and custom dynamic date option keys.
     *
     *
     * @returns An array of all option keys
     */
    getAllOptionKeys(): string[];
    /**
     * Gets an option by its key.
     *
     *
     * @returns The option
     */
    getOption(
      /**
       * The option key
       */
      sKey: string
    ): DynamicDateOption;
    /**
     * Gets sorted array of all standard keys.
     *
     *
     * @returns An array of standard option keys
     */
    getStandardKeys(): string[];
    /**
     * Parses a string to an array of objects of type `sap.m.DynamicDateRangeValue`. Uses the provided formatter.
     *
     *
     * @returns An array of `sap.m.DynamicDateRangeValue` objects
     */
    parse(
      /**
       * The string to be parsed
       */
      sValue: string,
      /**
       * A dynamic date formatter
       */
      oFormatter: DynamicDateFormat,
      /**
       * array of option names
       */
      aOptionKeys: string[]
    ): DynamicDateRangeValue[];
    /**
     * Returns a date in machine timezone setting, removing the offset added by the application configuration.
     *
     *
     * @returns A local JS date with removed offset
     */
    removeTimezoneOffset(
      /**
       * A local JS date with added offset
       */
      oDate: Date
    ): Date;
    /**
     * Calculates a date range from a provided object in the format of the DynamicDateRange's value.
     *
     *
     * @returns An array of two date objects - start and end date
     */
    toDates(
      /**
       * The provided value
       */
      oValue: string,
      /**
       * The type of calendar week numbering
       */
      sCalendarWeekNumbering: string
    ): /* was: sap.ui.core.date.UniversalDate */ any[];
  }
  const DynamicDateUtil: DynamicDateUtil;
  export default DynamicDateUtil;
}

declare module "sap/m/DynamicDateValueHelpUIType" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * A class that describes the predefined value help UI type of DynamicDateRange options.
   *
   * @since 1.92
   */
  export default class DynamicDateValueHelpUIType extends UI5Element {
    /**
     * Constructor for a new DynamicDateValueHelpUIType.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $DynamicDateValueHelpUITypeSettings
    );
    /**
     * Constructor for a new DynamicDateValueHelpUIType.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $DynamicDateValueHelpUITypeSettings
    );

    /**
     * Creates a new subclass of class sap.m.DynamicDateValueHelpUIType with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, DynamicDateValueHelpUIType>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.DynamicDateValueHelpUIType.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getAdditionalText additionalText}.
     *
     * A text for an additional label that describes the interactive UI and is placed after the UI element.
     *
     *
     * @returns Value of property `additionalText`
     */
    getAdditionalText(): string;
    /**
     * Gets current value of property {@link #getIncluded included}.
     *
     * Describes if the current period is included.
     *
     *
     * @returns Value of property `included`
     */
    getIncluded(): string;
    /**
     * Gets current value of property {@link #getOptions options}.
     *
     * Options are displayed into a select element.
     *
     *
     * @returns Value of property `options`
     */
    getOptions(): string[];
    /**
     * Gets current value of property {@link #getText text}.
     *
     * A text for an additional label that describes the interactive UI and is placed before the UI element.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getType type}.
     *
     * One of the predefined types - "date", "daterange", "month", "int". They determine controls - calendar
     * or input.
     *
     *
     * @returns Value of property `type`
     */
    getType(): string;
    /**
     * Sets a new value for property {@link #getAdditionalText additionalText}.
     *
     * A text for an additional label that describes the interactive UI and is placed after the UI element.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAdditionalText(
      /**
       * New value for property `additionalText`
       */
      sAdditionalText: string
    ): this;
    /**
     * Sets a new value for property {@link #getIncluded included}.
     *
     * Describes if the current period is included.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIncluded(
      /**
       * New value for property `included`
       */
      sIncluded?: string
    ): this;
    /**
     * Sets a new value for property {@link #getOptions options}.
     *
     * Options are displayed into a select element.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setOptions(
      /**
       * New value for property `options`
       */
      sOptions?: string[]
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * A text for an additional label that describes the interactive UI and is placed before the UI element.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText: string
    ): this;
    /**
     * Sets a new value for property {@link #getType type}.
     *
     * One of the predefined types - "date", "daterange", "month", "int". They determine controls - calendar
     * or input.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setType(
      /**
       * New value for property `type`
       */
      sType: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the DynamicDateValueHelpUIType constructor.
   */
  export interface $DynamicDateValueHelpUITypeSettings
    extends $ElementSettings {
    /**
     * One of the predefined types - "date", "daterange", "month", "int". They determine controls - calendar
     * or input.
     */
    type?: string | PropertyBindingInfo;

    /**
     * A text for an additional label that describes the interactive UI and is placed before the UI element.
     */
    text?: string | PropertyBindingInfo;

    /**
     * A text for an additional label that describes the interactive UI and is placed after the UI element.
     */
    additionalText?: string | PropertyBindingInfo;

    /**
     * Options are displayed into a select element.
     */
    options?: string[] | PropertyBindingInfo | `{${string}}`;

    /**
     * Describes if the current period is included.
     */
    included?: string | PropertyBindingInfo;
  }
}

declare module "sap/m/ExpandableText" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IFormContent,
    ILabelable,
    AccessibilityInfo,
    TextAlign,
    TextDirection,
  } from "sap/ui/core/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import {
    EmptyIndicatorMode,
    ExpandableTextOverflowMode,
    WrappingType,
  } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * The `ExpandableText` control can be used to display long texts inside a table, list or form.
   *
   * Overview: Only the first characters from the text field are shown initially and a "More" link which allows
   * the full text to be displayed. The `overflowMode` property determines if the full text will be displayed
   * expanded in place (default) or in a popover. If the text is expanded a "Less" link is displayed, which
   * allows collapsing the text field.
   *
   * Usage:
   *
   * When to use
   * 	 - You specifically have to deal with long texts/descriptions.
   *
   * When not to use
   * 	 - Do not use long texts and descriptions if you can provide short and meaningful alternatives.
   * 	 - The content is critical for the user. In this case use short descriptions that can fit in.
   *
   * @since 1.87
   */
  export default class ExpandableText
    extends Control
    implements IFormContent, ILabelable
  {
    __implements__sap_ui_core_IFormContent: boolean;
    __implements__sap_ui_core_ILabelable: boolean;
    /**
     * Constructor for a new ExpandableText.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ExpandableTextSettings
    );
    /**
     * Constructor for a new ExpandableText.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ExpandableTextSettings
    );

    /**
     * Creates a new subclass of class sap.m.ExpandableText with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ExpandableText>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ExpandableText.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Binds property {@link #getText text} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindProperty ManagedObject.bindProperty} for a detailed description
     * of the possible properties of `oBindingInfo`
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindText(
      /**
       * The binding information
       */
      oBindingInfo: PropertyBindingInfo
    ): this;
    /**
     * Gets the accessibility information for the text.
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Accessibility information for the text.
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Gets current value of property {@link #getEmptyIndicatorMode emptyIndicatorMode}.
     *
     * Specifies if an empty indicator should be displayed when there is no text.
     *
     * Default value is `Off`.
     *
     * @since 1.91
     *
     * @returns Value of property `emptyIndicatorMode`
     */
    getEmptyIndicatorMode(): EmptyIndicatorMode;
    /**
     * Gets current value of property {@link #getMaxCharacters maxCharacters}.
     *
     * Specifies the maximum number of characters from the beginning of the text field that are shown initially.
     *
     * Default value is `100`.
     *
     *
     * @returns Value of property `maxCharacters`
     */
    getMaxCharacters(): int;
    /**
     * Gets current value of property {@link #getOverflowMode overflowMode}.
     *
     * Determines how the full text will be displayed - InPlace or Popover
     *
     * Default value is `InPlace`.
     *
     *
     * @returns Value of property `overflowMode`
     */
    getOverflowMode(): ExpandableTextOverflowMode;
    /**
     * Gets current value of property {@link #getRenderWhitespace renderWhitespace}.
     *
     * Specifies how whitespace and tabs inside the control are handled. If true, whitespace will be preserved
     * by the browser.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `renderWhitespace`
     */
    getRenderWhitespace(): boolean;
    /**
     * Gets the text.
     *
     *
     * @returns Text value.
     */
    getText(
      /**
       * Indication for normalized text.
       */
      bNormalize?: boolean
    ): string;
    /**
     * Gets current value of property {@link #getTextAlign textAlign}.
     *
     * Sets the horizontal alignment of the text.
     *
     * Default value is `Begin`.
     *
     *
     * @returns Value of property `textAlign`
     */
    getTextAlign(): TextAlign;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * Available options for the text direction are left-to-right (LTR) and right-to-left (RTL) By default the
     * control inherits the text direction from its parent control.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Returns the text node container's DOM reference. This can be different from `getDomRef` when inner wrapper
     * is needed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns DOM reference of the text.
     */
    getTextDomRef(): HTMLElement | null;
    /**
     * Gets current value of property {@link #getWrappingType wrappingType}.
     *
     * Defines the type of text wrapping to be used (hyphenated or normal).
     *
     * Default value is `Normal`.
     *
     *
     * @returns Value of property `wrappingType`
     */
    getWrappingType(): WrappingType;
    /**
     * Returns if the control can be bound to a label
     *
     *
     * @returns `true` if the control can be bound to a label
     */
    hasLabelableHTMLElement(): boolean;
    /**
     * Sets a new value for property {@link #getEmptyIndicatorMode emptyIndicatorMode}.
     *
     * Specifies if an empty indicator should be displayed when there is no text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Off`.
     *
     * @since 1.91
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEmptyIndicatorMode(
      /**
       * New value for property `emptyIndicatorMode`
       */
      sEmptyIndicatorMode?: EmptyIndicatorMode | keyof typeof EmptyIndicatorMode
    ): this;
    /**
     * Sets a new value for property {@link #getMaxCharacters maxCharacters}.
     *
     * Specifies the maximum number of characters from the beginning of the text field that are shown initially.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `100`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxCharacters(
      /**
       * New value for property `maxCharacters`
       */
      iMaxCharacters?: int
    ): this;
    /**
     * Sets a new value for property {@link #getOverflowMode overflowMode}.
     *
     * Determines how the full text will be displayed - InPlace or Popover
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `InPlace`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setOverflowMode(
      /**
       * New value for property `overflowMode`
       */
      sOverflowMode?:
        | ExpandableTextOverflowMode
        | keyof typeof ExpandableTextOverflowMode
    ): this;
    /**
     * Sets a new value for property {@link #getRenderWhitespace renderWhitespace}.
     *
     * Specifies how whitespace and tabs inside the control are handled. If true, whitespace will be preserved
     * by the browser.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRenderWhitespace(
      /**
       * New value for property `renderWhitespace`
       */
      bRenderWhitespace?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Determines the text to be displayed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTextAlign textAlign}.
     *
     * Sets the horizontal alignment of the text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Begin`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextAlign(
      /**
       * New value for property `textAlign`
       */
      sTextAlign?: TextAlign | keyof typeof TextAlign
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * Available options for the text direction are left-to-right (LTR) and right-to-left (RTL) By default the
     * control inherits the text direction from its parent control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getWrappingType wrappingType}.
     *
     * Defines the type of text wrapping to be used (hyphenated or normal).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Normal`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWrappingType(
      /**
       * New value for property `wrappingType`
       */
      sWrappingType?: WrappingType | keyof typeof WrappingType
    ): this;
    /**
     * Unbinds property {@link #getText text} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindText(): this;
  }
  /**
   * Describes the settings that can be provided to the ExpandableText constructor.
   */
  export interface $ExpandableTextSettings extends $ControlSettings {
    /**
     * Determines the text to be displayed.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Available options for the text direction are left-to-right (LTR) and right-to-left (RTL) By default the
     * control inherits the text direction from its parent control.
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the type of text wrapping to be used (hyphenated or normal).
     */
    wrappingType?:
      | (WrappingType | keyof typeof WrappingType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Sets the horizontal alignment of the text.
     */
    textAlign?:
      | (TextAlign | keyof typeof TextAlign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies how whitespace and tabs inside the control are handled. If true, whitespace will be preserved
     * by the browser.
     */
    renderWhitespace?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines how the full text will be displayed - InPlace or Popover
     */
    overflowMode?:
      | (ExpandableTextOverflowMode | keyof typeof ExpandableTextOverflowMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies the maximum number of characters from the beginning of the text field that are shown initially.
     */
    maxCharacters?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies if an empty indicator should be displayed when there is no text.
     *
     * @since 1.91
     */
    emptyIndicatorMode?:
      | (EmptyIndicatorMode | keyof typeof EmptyIndicatorMode)
      | PropertyBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/FacetFilter" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { IShrinkable } from "sap/ui/core/library";

  import FacetFilterList from "sap/m/FacetFilterList";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { FacetFilterType } from "sap/m/library";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * Provides filtering functionality with multiple parameters.
   *
   * Overview:
   *
   * The `FacetFilter` control is used to provide filtering functionality with multiple parameters and supports
   * the users in finding the information they need from potentially very large data sets.
   *
   * Your app can have dependencies between facets where selection of filter items in one facet list limits
   * the list of valid filters in another facet list.
   *
   * The `FacetFilter` uses {@link sap.m.FacetFilterList FacetFilterList} and {@link sap.m.FacetFilterItem FacetFilterItem }
   * to model facets and their associated filters.
   *
   * **Note: **{@link sap.m.FacetFilterList FacetFilterList} is a subclass of {@link sap.m.List} and supports
   * growing enablement feature via the property `growing`. When you use this feature, be aware that it only
   * works with one-way data binding. Having growing feature enabled when the `items` aggregation is bound
   * to a model with two-way data binding, may lead to unexpected and/or inconsistent behavior across browsers,
   * such as unexpected closing of the list.
   *
   * Usage:
   *
   * Use the `FacetFilter` if your app displays a large list of items that can be grouped by multiple parameters,
   * for example products by category and supplier. With the `FacetFilter`, you allow the users to dynamically
   * filter the list so it only displays products from the categories and suppliers they want to see.
   *
   * While the {@link sap.m.FacetFilterList} popup is opened (when the user selects a button corresponding
   * to the list's name), any other activities leading to focus change will close it. For example, when the
   * popup is opened and the app developer loads a {@link sap.m.BusyDialog} or any other dialog that obtains
   * the focus, the popup will be closed.
   *
   * Responsive behavior:
   *
   * The `FacetFilter` supports the following two types, which can be configured using the control's `type`
   * property:
   *
   *
   * 	 - Simple type (default) - only available for desktop and tablet screen sizes. The active facets are
   *     displayed as individually selectable buttons on the toolbar.
   * 	 - Light type - automatically enabled on smart phone sized devices, but also available for desktop and
   *     tablets. The active facets and selected filter items are displayed in the summary bar. When the user
   *     selects the summary bar, a navigable dialog list of all facets is displayed. When the user selects a
   *     facet, the dialog scrolls to show the list of filters that are available for the selected facet.
   *
   * Additional Information:
   *
   * For more information, go to **Developer Guide** section in the Demo Kit and navigate to **More About
   * Controls** > **sap.m** > **Facet Filter**
   */
  export default class FacetFilter extends Control implements IShrinkable {
    __implements__sap_ui_core_IShrinkable: boolean;
    /**
     * Constructor for a new `FacetFilter`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/c6c38217a4a64001a22ad76cdfa97fae Facet Filter}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $FacetFilterSettings
    );
    /**
     * Constructor for a new `FacetFilter`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/c6c38217a4a64001a22ad76cdfa97fae Facet Filter}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $FacetFilterSettings
    );

    /**
     * Creates a new subclass of class sap.m.FacetFilter with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, FacetFilter>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.FacetFilter.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some list to the aggregation {@link #getLists lists}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addList(
      /**
       * The list to add; if empty, nothing is inserted
       */
      oList: FacetFilterList
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:confirm confirm} event of this `sap.m.FacetFilter`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FacetFilter` itself.
     *
     * Fired when the user confirms filter selection.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachConfirm(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FacetFilter` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:confirm confirm} event of this `sap.m.FacetFilter`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FacetFilter` itself.
     *
     * Fired when the user confirms filter selection.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachConfirm(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FacetFilter` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:reset reset} event of this `sap.m.FacetFilter`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FacetFilter` itself.
     *
     * Fired when the Reset button is pressed to inform that all FacetFilterLists need to be reset.
     *
     * The default filtering behavior of the sap.m.FacetFilterList can be prevented by calling `sap.ui.base.Event.prototype.preventDefault`
     * function in the `search` event handler function. If the default filtering behavior is prevented then
     * filtering behavior has to be defined at application level inside the `search` and `reset` event handler
     * functions.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachReset(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FacetFilter` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:reset reset} event of this `sap.m.FacetFilter`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FacetFilter` itself.
     *
     * Fired when the Reset button is pressed to inform that all FacetFilterLists need to be reset.
     *
     * The default filtering behavior of the sap.m.FacetFilterList can be prevented by calling `sap.ui.base.Event.prototype.preventDefault`
     * function in the `search` event handler function. If the default filtering behavior is prevented then
     * filtering behavior has to be defined at application level inside the `search` and `reset` event handler
     * functions.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachReset(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FacetFilter` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the lists in the aggregation {@link #getLists lists}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyLists(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:confirm confirm} event of this `sap.m.FacetFilter`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachConfirm(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:reset reset} event of this `sap.m.FacetFilter`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachReset(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:confirm confirm} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireConfirm(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:reset reset} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireReset(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets content of aggregation {@link #getLists lists}.
     *
     * Collection of FacetFilterList controls.
     */
    getLists(): FacetFilterList[];
    /**
     * Gets current value of property {@link #getLiveSearch liveSearch}.
     *
     * Enables/disables live search in the search field of all `sap.m.FacetFilterList` instances.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `liveSearch`
     */
    getLiveSearch(): boolean;
    /**
     * Gets current value of property {@link #getShowPersonalization showPersonalization}.
     *
     * If set to `true` and the FacetFilter type is `Simple`, then the Add Facet icon will be displayed and
     * each facet button will also have a Facet Remove icon displayed beside it, allowing the user to deactivate
     * the facet.
     *
     * **Note:** Always set this property to `true` when your facet lists are not active, so that the user is
     * able to select them and interact with them.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showPersonalization`
     */
    getShowPersonalization(): boolean;
    /**
     * Gets current value of property {@link #getShowPopoverOKButton showPopoverOKButton}.
     *
     * If set to `true`, an OK button is displayed for every FacetFilterList popover. This button allows the
     * user to close the popover from within the popover instead of having to click outside of it.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showPopoverOKButton`
     */
    getShowPopoverOKButton(): boolean;
    /**
     * Gets current value of property {@link #getShowReset showReset}.
     *
     * Shows/hides the FacetFilter Reset button.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showReset`
     */
    getShowReset(): boolean;
    /**
     * Gets current value of property {@link #getShowSummaryBar showSummaryBar}.
     *
     * Shows the summary bar instead of the FacetFilter buttons bar when set to `true`.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showSummaryBar`
     */
    getShowSummaryBar(): boolean;
    /**
     * Gets current value of property {@link #getType type}.
     *
     * Defines the default appearance of the FacetFilter on the device. Possible values are `Simple` (default)
     * and `Light`.
     *
     * Default value is `Simple`.
     *
     *
     * @returns Value of property `type`
     */
    getType(): FacetFilterType;
    /**
     * Checks for the provided `sap.m.FacetFilterList` in the aggregation {@link #getLists lists}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfList(
      /**
       * The list whose index is looked for
       */
      oList: FacetFilterList
    ): int;
    /**
     * Inserts a list into the aggregation {@link #getLists lists}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertList(
      /**
       * The list to insert; if empty, nothing is inserted
       */
      oList: FacetFilterList,
      /**
       * The `0`-based index the list should be inserted at; for a negative value of `iIndex`, the list is inserted
       * at position 0; for a value greater than the current size of the aggregation, the list is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Opens the FacetFilter dialog.
     *
     *
     * @returns this pointer for chaining
     */
    openFilterDialog(): this;
    /**
     * Removes all the controls from the aggregation {@link #getLists lists}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllLists(): FacetFilterList[];
    /**
     * Removes a list from the aggregation {@link #getLists lists}.
     *
     *
     * @returns The removed list or `null`
     */
    removeList(
      /**
       * The list to remove or its index or id
       */
      vList: int | string | FacetFilterList
    ): FacetFilterList | null;
    /**
     * Sets a new value for property {@link #getLiveSearch liveSearch}.
     *
     * Enables/disables live search in the search field of all `sap.m.FacetFilterList` instances.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLiveSearch(
      /**
       * New value for property `liveSearch`
       */
      bLiveSearch?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowPersonalization showPersonalization}.
     *
     * If set to `true` and the FacetFilter type is `Simple`, then the Add Facet icon will be displayed and
     * each facet button will also have a Facet Remove icon displayed beside it, allowing the user to deactivate
     * the facet.
     *
     * **Note:** Always set this property to `true` when your facet lists are not active, so that the user is
     * able to select them and interact with them.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowPersonalization(
      /**
       * New value for property `showPersonalization`
       */
      bShowPersonalization?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowPopoverOKButton showPopoverOKButton}.
     *
     * If set to `true`, an OK button is displayed for every FacetFilterList popover. This button allows the
     * user to close the popover from within the popover instead of having to click outside of it.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowPopoverOKButton(
      /**
       * New value for property `showPopoverOKButton`
       */
      bShowPopoverOKButton?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowReset showReset}.
     *
     * Shows/hides the FacetFilter Reset button.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowReset(
      /**
       * New value for property `showReset`
       */
      bShowReset?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowSummaryBar showSummaryBar}.
     *
     * Shows the summary bar instead of the FacetFilter buttons bar when set to `true`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowSummaryBar(
      /**
       * New value for property `showSummaryBar`
       */
      bShowSummaryBar?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getType type}.
     *
     * Defines the default appearance of the FacetFilter on the device. Possible values are `Simple` (default)
     * and `Light`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Simple`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setType(
      /**
       * New value for property `type`
       */
      sType?: FacetFilterType | keyof typeof FacetFilterType
    ): this;
  }
  /**
   * Describes the settings that can be provided to the FacetFilter constructor.
   */
  export interface $FacetFilterSettings extends $ControlSettings {
    /**
     * If set to `true` and the FacetFilter type is `Simple`, then the Add Facet icon will be displayed and
     * each facet button will also have a Facet Remove icon displayed beside it, allowing the user to deactivate
     * the facet.
     *
     * **Note:** Always set this property to `true` when your facet lists are not active, so that the user is
     * able to select them and interact with them.
     */
    showPersonalization?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the default appearance of the FacetFilter on the device. Possible values are `Simple` (default)
     * and `Light`.
     */
    type?:
      | (FacetFilterType | keyof typeof FacetFilterType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Enables/disables live search in the search field of all `sap.m.FacetFilterList` instances.
     */
    liveSearch?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Shows the summary bar instead of the FacetFilter buttons bar when set to `true`.
     */
    showSummaryBar?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Shows/hides the FacetFilter Reset button.
     */
    showReset?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * If set to `true`, an OK button is displayed for every FacetFilterList popover. This button allows the
     * user to close the popover from within the popover instead of having to click outside of it.
     */
    showPopoverOKButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Collection of FacetFilterList controls.
     */
    lists?:
      | FacetFilterList[]
      | FacetFilterList
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Fired when the Reset button is pressed to inform that all FacetFilterLists need to be reset.
     *
     * The default filtering behavior of the sap.m.FacetFilterList can be prevented by calling `sap.ui.base.Event.prototype.preventDefault`
     * function in the `search` event handler function. If the default filtering behavior is prevented then
     * filtering behavior has to be defined at application level inside the `search` and `reset` event handler
     * functions.
     */
    reset?: (oEvent: Event) => void;

    /**
     * Fired when the user confirms filter selection.
     */
    confirm?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the FacetFilter#confirm event.
   */
  export interface FacetFilter$ConfirmEventParameters {}

  /**
   * Event object of the FacetFilter#confirm event.
   */
  export type FacetFilter$ConfirmEvent = Event<
    FacetFilter$ConfirmEventParameters,
    FacetFilter
  >;

  /**
   * Parameters of the FacetFilter#reset event.
   */
  export interface FacetFilter$ResetEventParameters {}

  /**
   * Event object of the FacetFilter#reset event.
   */
  export type FacetFilter$ResetEvent = Event<
    FacetFilter$ResetEventParameters,
    FacetFilter
  >;
}

declare module "sap/m/FacetFilterItem" {
  import {
    default as ListItemBase,
    $ListItemBaseSettings,
  } from "sap/m/ListItemBase";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Represents a value for the {@link sap.m.FacetFilterList} control.
   */
  export default class FacetFilterItem extends ListItemBase {
    /**
     * Constructor for a new `FacetFilterItem`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/395392f30f2a4c4d80d110d5f923da77 Facet Filter Item}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $FacetFilterItemSettings
    );
    /**
     * Constructor for a new `FacetFilterItem`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/395392f30f2a4c4d80d110d5f923da77 Facet Filter Item}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $FacetFilterItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.FacetFilterItem with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ListItemBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, FacetFilterItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.FacetFilterItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getCount count}.
     *
     * Defines the number of objects that match this item in the target data set.
     *
     * @deprecated As of version 1.18.11. replaced by `setCounter` method
     *
     * @returns Value of property `count`
     */
    getCount(): int;
    /**
     * Gets current value of property {@link #getKey key}.
     *
     * Can be used as input for subsequent actions.
     *
     *
     * @returns Value of property `key`
     */
    getKey(): string;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Determines the text to be displayed for the item.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Sets a new value for property {@link #getKey key}.
     *
     * Can be used as input for subsequent actions.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setKey(
      /**
       * New value for property `key`
       */
      sKey?: string
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Determines the text to be displayed for the item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the FacetFilterItem constructor.
   */
  export interface $FacetFilterItemSettings extends $ListItemBaseSettings {
    /**
     * Can be used as input for subsequent actions.
     */
    key?: string | PropertyBindingInfo;

    /**
     * Determines the text to be displayed for the item.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Defines the number of objects that match this item in the target data set.
     *
     * @deprecated As of version 1.18.11. replaced by `setCounter` method
     */
    count?: int | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/FacetFilterList" {
  import { default as List, $ListSettings } from "sap/m/List";

  import Event from "sap/ui/base/Event";

  import { FacetFilterListDataType, ListMode } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import FacetFilterItem from "sap/m/FacetFilterItem";

  /**
   * Represents a list of values for the {@link sap.m.FacetFilter} control.
   *
   * **Note: **`FacetFilterList` is a subclass of {@link sap.m.List} and supports growing enablement feature
   * via the property `growing`. When you use this feature, be aware that it only works with one-way data
   * binding. Having growing feature enabled when the `items` aggregation is bound to a model with two-way
   * data binding, may lead to unexpected and/or inconsistent behavior across browsers, such as unexpected
   * closing of the list.
   *
   * While the `FacetFilterList` popup is opened (when the user selects a button corresponding to the list's
   * name), any other activities leading to focus change will close it. For example, when the popup is opened
   * and the app developer loads a {@link sap.m.BusyDialog} or any other dialog that obtains the focus, the
   * popup will be closed.
   */
  export default class FacetFilterList extends List {
    /**
     * Constructor for a new `FacetFilterList`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/395392f30f2a4c4d80d110d5f923da77 Facet Filter List}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $FacetFilterListSettings
    );
    /**
     * Constructor for a new `FacetFilterList`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/395392f30f2a4c4d80d110d5f923da77 Facet Filter List}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $FacetFilterListSettings
    );

    /**
     * Creates a new subclass of class sap.m.FacetFilterList with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.List.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, FacetFilterList>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.FacetFilterList.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:listClose listClose} event of this `sap.m.FacetFilterList`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FacetFilterList` itself.
     *
     * Triggered after the list of items is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachListClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: FacetFilterList$ListCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FacetFilterList` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:listClose listClose} event of this `sap.m.FacetFilterList`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FacetFilterList` itself.
     *
     * Triggered after the list of items is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachListClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: FacetFilterList$ListCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FacetFilterList` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:listOpen listOpen} event of this `sap.m.FacetFilterList`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FacetFilterList` itself.
     *
     * Fired before the filter list is opened.
     *
     * The default filtering behavior of the sap.m.FacetFilterList can be prevented by calling `sap.ui.base.Event.prototype.preventDefault`
     * function in the `listOpen` event handler function. If the default filtering behavior is prevented then
     * filtering behavior has to be defined at application level inside the `listOpen` event handler function.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachListOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FacetFilterList` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:listOpen listOpen} event of this `sap.m.FacetFilterList`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FacetFilterList` itself.
     *
     * Fired before the filter list is opened.
     *
     * The default filtering behavior of the sap.m.FacetFilterList can be prevented by calling `sap.ui.base.Event.prototype.preventDefault`
     * function in the `listOpen` event handler function. If the default filtering behavior is prevented then
     * filtering behavior has to be defined at application level inside the `listOpen` event handler function.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachListOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FacetFilterList` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:search search} event of this `sap.m.FacetFilterList`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FacetFilterList` itself.
     *
     * Triggered after the Search button is pressed or by pressing Enter in search input field.
     *
     * The default filtering behavior of the control can be prevented by calling `sap.ui.base.Event.prototype.preventDefault`
     * function in the `search` event handler function. Preventing the default behavior is useful in cases when
     * items aggregation could be taking long time fetching from the OData model. As a result, no list items
     * are loaded initially. If the default filtering behavior is prevented then filtering behavior has to be
     * defined at application level inside the `search` event handler function.
     *
     * @since 1.76
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSearch(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: FacetFilterList$SearchEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FacetFilterList` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:search search} event of this `sap.m.FacetFilterList`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FacetFilterList` itself.
     *
     * Triggered after the Search button is pressed or by pressing Enter in search input field.
     *
     * The default filtering behavior of the control can be prevented by calling `sap.ui.base.Event.prototype.preventDefault`
     * function in the `search` event handler function. Preventing the default behavior is useful in cases when
     * items aggregation could be taking long time fetching from the OData model. As a result, no list items
     * are loaded initially. If the default filtering behavior is prevented then filtering behavior has to be
     * defined at application level inside the `search` event handler function.
     *
     * @since 1.76
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSearch(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: FacetFilterList$SearchEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FacetFilterList` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:listClose listClose} event of this `sap.m.FacetFilterList`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachListClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: FacetFilterList$ListCloseEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:listOpen listOpen} event of this `sap.m.FacetFilterList`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachListOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:search search} event of this `sap.m.FacetFilterList`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.76
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSearch(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: FacetFilterList$SearchEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:listClose listClose} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireListClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: FacetFilterList$ListCloseEventParameters
    ): this;
    /**
     * Fires event {@link #event:listOpen listOpen} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireListOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): boolean;
    /**
     * Fires event {@link #event:search search} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @since 1.76
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireSearch(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: FacetFilterList$SearchEventParameters
    ): boolean;
    /**
     * Gets current value of property {@link #getActive active}.
     *
     * Indicates that the list is displayed as a button when the FacetFilter type is set to `Simple`.
     *
     * **Note:** Set the `showPersonalization` property of the `FacetFilter` to `true` when this property is
     * set to `false`. This is needed, as the non-active lists are not displayed, and without a personalization
     * button they can't be selected by the user.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `active`
     */
    getActive(): boolean;
    /**
     * Gets current value of property {@link #getAllCount allCount}.
     *
     * Determines the number of objects that match this item in the target data set when all filter items are
     * selected.
     *
     *
     * @returns Value of property `allCount`
     */
    getAllCount(): int;
    /**
     * Gets current value of property {@link #getDataType dataType}.
     *
     * FacetFilterList data type. Only String data type will provide search function.
     *
     * Default value is `String`.
     *
     *
     * @returns Value of property `dataType`
     */
    getDataType(): FacetFilterListDataType;
    /**
     * Gets current value of property {@link #getEnableCaseInsensitiveSearch enableCaseInsensitiveSearch}.
     *
     * If set to `true`, enables case-insensitive search for OData.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `enableCaseInsensitiveSearch`
     */
    getEnableCaseInsensitiveSearch(): boolean;
    /**
     * Gets current value of property {@link #getKey key}.
     *
     * Unique identifier for this filter list.
     *
     *
     * @returns Value of property `key`
     */
    getKey(): string;
    /**
     * Gets current value of property {@link #getMultiSelect multiSelect}.
     *
     * Specifies whether multiple or single selection is used.
     *
     * Default value is `true`.
     *
     * @deprecated As of version 1.20.0. replaced by `setMode` method. `FacetFilterList` overrides the `setMode`
     * method to restrict the possible modes to `MultiSelect` and `SingleSelectMaster`. All other modes are
     * ignored and will not be set.
     *
     * @returns Value of property `multiSelect`
     */
    getMultiSelect(): boolean;
    /**
     * Gets current value of property {@link #getRetainListSequence retainListSequence}.
     *
     * Retains the list sequence if it is inactive and made active again.
     *
     * Default value is `false`.
     *
     * @since 1.22.1
     *
     * @returns Value of property `retainListSequence`
     */
    getRetainListSequence(): boolean;
    /**
     * Returns the keys of the selected elements as an associative array. An empty object is returned if no
     * items are selected.
     *
     * @since 1.20.3
     *
     * @returns Object with the selected keys
     */
    getSelectedKeys(): Record<string, string>;
    /**
     * Gets current value of property {@link #getSequence sequence}.
     *
     * Sequence that determines the order in which FacetFilterList is shown on the FacetFilter. Lists are rendered
     * by ascending order of sequence.
     *
     * Default value is `-1`.
     *
     *
     * @returns Value of property `sequence`
     */
    getSequence(): int;
    /**
     * Gets current value of property {@link #getShowRemoveFacetIcon showRemoveFacetIcon}.
     *
     * Specifies whether remove icon for facet is visible or hidden.
     *
     * Default value is `true`.
     *
     * @since 1.20.4
     *
     * @returns Value of property `showRemoveFacetIcon`
     */
    getShowRemoveFacetIcon(): boolean;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Defines the title of the facet. The facet title is displayed on the facet button when the FacetFilter
     * type is set to `Simple`. It is also displayed as a list item in the facet page of the dialog.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getWordWrap wordWrap}.
     *
     * If set to `true`, the item text wraps when it is too long.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `wordWrap`
     */
    getWordWrap(): boolean;
    /**
     * Removes the specified key from the selected keys cache and deselects the item.
     *
     * @since 1.20.4
     */
    removeSelectedKey(
      /**
       * The key of the selected item to be removed from the cache. If `null` then the text parameter will be
       * used as the key.
       */
      sKey: string,
      /**
       * The text of the selected item to be removed from the cache. If the key parameter is `null` then text
       * will be used as the key.
       */
      sText: string
    ): void;
    /**
     * Removes all selected keys from the selected keys cache and deselects all items.
     *
     * @since 1.20.4
     */
    removeSelectedKeys(): void;
    /**
     * Sets a new value for property {@link #getActive active}.
     *
     * Indicates that the list is displayed as a button when the FacetFilter type is set to `Simple`.
     *
     * **Note:** Set the `showPersonalization` property of the `FacetFilter` to `true` when this property is
     * set to `false`. This is needed, as the non-active lists are not displayed, and without a personalization
     * button they can't be selected by the user.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setActive(
      /**
       * New value for property `active`
       */
      bActive?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getAllCount allCount}.
     *
     * Determines the number of objects that match this item in the target data set when all filter items are
     * selected.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAllCount(
      /**
       * New value for property `allCount`
       */
      iAllCount?: int
    ): this;
    /**
     * Sets a new value for property {@link #getDataType dataType}.
     *
     * FacetFilterList data type. Only String data type will provide search function.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `String`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDataType(
      /**
       * New value for property `dataType`
       */
      sDataType?: FacetFilterListDataType | keyof typeof FacetFilterListDataType
    ): this;
    /**
     * Sets a new value for property {@link #getEnableCaseInsensitiveSearch enableCaseInsensitiveSearch}.
     *
     * If set to `true`, enables case-insensitive search for OData.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableCaseInsensitiveSearch(
      /**
       * New value for property `enableCaseInsensitiveSearch`
       */
      bEnableCaseInsensitiveSearch?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getKey key}.
     *
     * Unique identifier for this filter list.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setKey(
      /**
       * New value for property `key`
       */
      sKey?: string
    ): this;
    /**
     * Overrides to allow only MultiSelect and SingleSelectMaster list modes. If an invalid mode is given then
     * the mode will not be changed.
     *
     *
     * @returns `this` to allow method chaining
     */
    setMode(
      /**
       * The list mode
       */
      mode: ListMode | keyof typeof ListMode
    ): this;
    /**
     * Sets a new value for property {@link #getRetainListSequence retainListSequence}.
     *
     * Retains the list sequence if it is inactive and made active again.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.22.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRetainListSequence(
      /**
       * New value for property `retainListSequence`
       */
      bRetainListSequence?: boolean
    ): this;
    /**
     * Used to pre-select FacetFilterItems, such as when restoring FacetFilterList selections from a variant.
     * Keys are cached separately from the actual FacetFilterItems so that they remain even when the physical
     * items are removed by filtering or sorting. If oKeys is `undefined`, `null`, or {} (empty object) then
     * all items will be deselected. After this method completes, only those items with matching keys will be
     * selected. All other items in the list will be deselected.
     *
     * @since 1.20.3
     */
    setSelectedKeys(
      /**
       * Associative array indicating which FacetFilterItems should be selected in the list. Each property must
       * be set to the value of a FacetFilterItem.key property. Each property value should be set to the FacetFilterItem.text
       * property value. The text value is used to display the FacetFilterItem text when the FacetFilterList button
       * or FacetFilter summary bar is displayed. If no property value is set then the property key is used for
       * the text.
       */
      oKeys?: Record<string, string | undefined> | null
    ): void;
    /**
     * Sets a new value for property {@link #getSequence sequence}.
     *
     * Sequence that determines the order in which FacetFilterList is shown on the FacetFilter. Lists are rendered
     * by ascending order of sequence.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `-1`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSequence(
      /**
       * New value for property `sequence`
       */
      iSequence?: int
    ): this;
    /**
     * Sets a new value for property {@link #getShowRemoveFacetIcon showRemoveFacetIcon}.
     *
     * Specifies whether remove icon for facet is visible or hidden.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.20.4
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowRemoveFacetIcon(
      /**
       * New value for property `showRemoveFacetIcon`
       */
      bShowRemoveFacetIcon?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Defines the title of the facet. The facet title is displayed on the facet button when the FacetFilter
     * type is set to `Simple`. It is also displayed as a list item in the facet page of the dialog.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getWordWrap wordWrap}.
     *
     * If set to `true`, the item text wraps when it is too long.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWordWrap(
      /**
       * New value for property `wordWrap`
       */
      bWordWrap?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the FacetFilterList constructor.
   */
  export interface $FacetFilterListSettings extends $ListSettings {
    /**
     * Defines the title of the facet. The facet title is displayed on the facet button when the FacetFilter
     * type is set to `Simple`. It is also displayed as a list item in the facet page of the dialog.
     */
    title?: string | PropertyBindingInfo;

    /**
     * If set to `true`, the item text wraps when it is too long.
     */
    wordWrap?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies whether multiple or single selection is used.
     *
     * @deprecated As of version 1.20.0. replaced by `setMode` method. `FacetFilterList` overrides the `setMode`
     * method to restrict the possible modes to `MultiSelect` and `SingleSelectMaster`. All other modes are
     * ignored and will not be set.
     */
    multiSelect?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates that the list is displayed as a button when the FacetFilter type is set to `Simple`.
     *
     * **Note:** Set the `showPersonalization` property of the `FacetFilter` to `true` when this property is
     * set to `false`. This is needed, as the non-active lists are not displayed, and without a personalization
     * button they can't be selected by the user.
     */
    active?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * If set to `true`, enables case-insensitive search for OData.
     */
    enableCaseInsensitiveSearch?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the number of objects that match this item in the target data set when all filter items are
     * selected.
     */
    allCount?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Sequence that determines the order in which FacetFilterList is shown on the FacetFilter. Lists are rendered
     * by ascending order of sequence.
     */
    sequence?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Unique identifier for this filter list.
     */
    key?: string | PropertyBindingInfo;

    /**
     * Specifies whether remove icon for facet is visible or hidden.
     *
     * @since 1.20.4
     */
    showRemoveFacetIcon?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Retains the list sequence if it is inactive and made active again.
     *
     * @since 1.22.1
     */
    retainListSequence?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * FacetFilterList data type. Only String data type will provide search function.
     */
    dataType?:
      | (FacetFilterListDataType | keyof typeof FacetFilterListDataType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Fired before the filter list is opened.
     *
     * The default filtering behavior of the sap.m.FacetFilterList can be prevented by calling `sap.ui.base.Event.prototype.preventDefault`
     * function in the `listOpen` event handler function. If the default filtering behavior is prevented then
     * filtering behavior has to be defined at application level inside the `listOpen` event handler function.
     */
    listOpen?: (oEvent: Event) => void;

    /**
     * Triggered after the list of items is closed.
     */
    listClose?: (oEvent: FacetFilterList$ListCloseEvent) => void;

    /**
     * Triggered after the Search button is pressed or by pressing Enter in search input field.
     *
     * The default filtering behavior of the control can be prevented by calling `sap.ui.base.Event.prototype.preventDefault`
     * function in the `search` event handler function. Preventing the default behavior is useful in cases when
     * items aggregation could be taking long time fetching from the OData model. As a result, no list items
     * are loaded initially. If the default filtering behavior is prevented then filtering behavior has to be
     * defined at application level inside the `search` event handler function.
     *
     * @since 1.76
     */
    search?: (oEvent: FacetFilterList$SearchEvent) => void;
  }

  /**
   * Parameters of the FacetFilterList#listClose event.
   */
  export interface FacetFilterList$ListCloseEventParameters {
    /**
     * Array of selected items. Items returned are only copies and therefore can only be used to read properties,
     * not set them.
     */
    selectedItems?: FacetFilterItem[];

    /**
     * `True` if the select All checkbox is selected. This will be `false` if all items are actually selected
     * (every FacetFilterItem.selected == true). In that case selectedItems will contain all selected items.
     */
    allSelected?: boolean;

    /**
     * Associative array containing the keys of selected FacetFilterItems. Unlike the selectedItems parameter,
     * this contains only the keys for all selected items, not the items themselves. Being an associative array,
     * each object property is the FacetFilterItem key value and the value of the property is the FacetFilterItem
     * text.
     */
    selectedKeys?: object;
  }

  /**
   * Event object of the FacetFilterList#listClose event.
   */
  export type FacetFilterList$ListCloseEvent = Event<
    FacetFilterList$ListCloseEventParameters,
    FacetFilterList
  >;

  /**
   * Parameters of the FacetFilterList#listOpen event.
   */
  export interface FacetFilterList$ListOpenEventParameters {}

  /**
   * Event object of the FacetFilterList#listOpen event.
   */
  export type FacetFilterList$ListOpenEvent = Event<
    FacetFilterList$ListOpenEventParameters,
    FacetFilterList
  >;

  /**
   * Parameters of the FacetFilterList#search event.
   */
  export interface FacetFilterList$SearchEventParameters {
    /**
     * Value received as user input in the `sap.m.SearchField`, and taken as a JavaScript string object.
     */
    term?: string;
  }

  /**
   * Event object of the FacetFilterList#search event.
   */
  export type FacetFilterList$SearchEvent = Event<
    FacetFilterList$SearchEventParameters,
    FacetFilterList
  >;
}

declare module "sap/m/FeedContent" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { Size, ValueColor } from "sap/m/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Displays a tile containing the text of the feed, a subheader, and a numeric value.
   *
   * @since 1.34
   */
  export default class FeedContent extends Control {
    /**
     * Constructor for a new sap.m.FeedContent control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $FeedContentSettings
    );
    /**
     * Constructor for a new sap.m.FeedContent control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $FeedContentSettings
    );

    /**
     * Creates a new subclass of class sap.m.FeedContent with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, FeedContent>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.FeedContent.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.FeedContent`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FeedContent` itself.
     *
     * The event is triggered when the feed content is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FeedContent` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.FeedContent`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FeedContent` itself.
     *
     * The event is triggered when the feed content is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FeedContent` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.FeedContent`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getContentText contentText}.
     *
     * The content text.
     *
     *
     * @returns Value of property `contentText`
     */
    getContentText(): string;
    /**
     * Gets current value of property {@link #getSize size}.
     *
     * Updates the size of the chart. If not set then the default size is applied based on the device tile.
     *
     * Default value is `Auto`.
     *
     * @deprecated As of version 1.38.0. The FeedContent control has now a fixed size, depending on the used
     * media (desktop, tablet or phone).
     *
     * @returns Value of property `size`
     */
    getSize(): Size;
    /**
     * Gets current value of property {@link #getSubheader subheader}.
     *
     * The subheader.
     *
     *
     * @returns Value of property `subheader`
     */
    getSubheader(): string;
    /**
     * Gets current value of property {@link #getTruncateValueTo truncateValueTo}.
     *
     * The number of characters to display for the value property.
     *
     * Default value is `4`.
     *
     *
     * @returns Value of property `truncateValueTo`
     */
    getTruncateValueTo(): int;
    /**
     * Gets current value of property {@link #getValue value}.
     *
     * The actual value.
     *
     *
     * @returns Value of property `value`
     */
    getValue(): string;
    /**
     * Gets current value of property {@link #getValueColor valueColor}.
     *
     * The semantic color of the value.
     *
     *
     * @returns Value of property `valueColor`
     */
    getValueColor(): ValueColor;
    /**
     * Sets a new value for property {@link #getContentText contentText}.
     *
     * The content text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContentText(
      /**
       * New value for property `contentText`
       */
      sContentText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSize size}.
     *
     * Updates the size of the chart. If not set then the default size is applied based on the device tile.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     * @deprecated As of version 1.38.0. The FeedContent control has now a fixed size, depending on the used
     * media (desktop, tablet or phone).
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSize(
      /**
       * New value for property `size`
       */
      sSize?: Size | keyof typeof Size
    ): this;
    /**
     * Sets a new value for property {@link #getSubheader subheader}.
     *
     * The subheader.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSubheader(
      /**
       * New value for property `subheader`
       */
      sSubheader?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTruncateValueTo truncateValueTo}.
     *
     * The number of characters to display for the value property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `4`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTruncateValueTo(
      /**
       * New value for property `truncateValueTo`
       */
      iTruncateValueTo?: int
    ): this;
    /**
     * Sets a new value for property {@link #getValue value}.
     *
     * The actual value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValue(
      /**
       * New value for property `value`
       */
      sValue?: string
    ): this;
    /**
     * Sets a new value for property {@link #getValueColor valueColor}.
     *
     * The semantic color of the value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueColor(
      /**
       * New value for property `valueColor`
       */
      sValueColor?: ValueColor | keyof typeof ValueColor
    ): this;
  }
  /**
   * Describes the settings that can be provided to the FeedContent constructor.
   */
  export interface $FeedContentSettings extends $ControlSettings {
    /**
     * Updates the size of the chart. If not set then the default size is applied based on the device tile.
     *
     * @deprecated As of version 1.38.0. The FeedContent control has now a fixed size, depending on the used
     * media (desktop, tablet or phone).
     */
    size?: (Size | keyof typeof Size) | PropertyBindingInfo | `{${string}}`;

    /**
     * The content text.
     */
    contentText?: string | PropertyBindingInfo;

    /**
     * The subheader.
     */
    subheader?: string | PropertyBindingInfo;

    /**
     * The actual value.
     */
    value?: string | PropertyBindingInfo;

    /**
     * The semantic color of the value.
     */
    valueColor?:
      | (ValueColor | keyof typeof ValueColor)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The number of characters to display for the value property.
     */
    truncateValueTo?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * The event is triggered when the feed content is pressed.
     */
    press?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the FeedContent#press event.
   */
  export interface FeedContent$PressEventParameters {}

  /**
   * Event object of the FeedContent#press event.
   */
  export type FeedContent$PressEvent = Event<
    FeedContent$PressEventParameters,
    FeedContent
  >;
}

declare module "sap/m/FeedInput" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import TooltipBase from "sap/ui/core/TooltipBase";

  import { URI } from "sap/ui/core/library";

  import AvatarShape from "sap/m/AvatarShape";

  import AvatarSize from "sap/m/AvatarSize";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * The Feed Input allows the user to enter text for a new feed entry and then post it.
   *
   * @since 1.22
   */
  export default class FeedInput extends Control {
    /**
     * Constructor for a new FeedInput.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $FeedInputSettings
    );
    /**
     * Constructor for a new FeedInput.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $FeedInputSettings
    );

    /**
     * Creates a new subclass of class sap.m.FeedInput with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, FeedInput>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.FeedInput.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:post post} event of this `sap.m.FeedInput`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FeedInput` itself.
     *
     * The Post event is triggered when the user has entered a value and pressed the post button. After firing
     * this event, the value is reset.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPost(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: FeedInput$PostEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FeedInput` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:post post} event of this `sap.m.FeedInput`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FeedInput` itself.
     *
     * The Post event is triggered when the user has entered a value and pressed the post button. After firing
     * this event, the value is reset.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPost(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: FeedInput$PostEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FeedInput` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:post post} event of this `sap.m.FeedInput`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPost(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: FeedInput$PostEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:post post} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePost(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: FeedInput$PostEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getAriaLabelForPicture ariaLabelForPicture}.
     *
     * Text for Picture which will be read by screenreader. If a new ariaLabelForPicture is set, any previously
     * set ariaLabelForPicture is deactivated.
     *
     * @deprecated As of version 1.88. This will not have any effect in code now.
     *
     * @returns Value of property `ariaLabelForPicture`
     */
    getAriaLabelForPicture(): string;
    /**
     * Gets current value of property {@link #getButtonTooltip buttonTooltip}.
     *
     * Sets a new tooltip for Submit button. The tooltip can either be a simple string (which in most cases
     * will be rendered as the title attribute of this element) or an instance of sap.ui.core.TooltipBase. If
     * a new tooltip is set, any previously set tooltip is deactivated. The default value is set language dependent.
     *
     * Default value is `"Submit"`.
     *
     * @since 1.28
     *
     * @returns Value of property `buttonTooltip`
     */
    getButtonTooltip(): TooltipBase | string;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Set this flag to "false" to disable both text input and post button.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets current value of property {@link #getGrowing growing}.
     *
     * Indicates the ability of the control to automatically grow and shrink dynamically with its content.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `growing`
     */
    getGrowing(): boolean;
    /**
     * Gets current value of property {@link #getGrowingMaxLines growingMaxLines}.
     *
     * Defines the maximum number of lines that the control can grow. Value is set to 0 by default, which means
     * an unlimited numbers of rows. **Note:** Minimum value to set is equal to the `rows` property value, maximum
     * value is 15.
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `growingMaxLines`
     */
    getGrowingMaxLines(): int;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Icon to be displayed as a graphical element within the feed input. This can be an image or an icon from
     * the icon font.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getIconDensityAware iconDensityAware}.
     *
     * Some mobile devices support higher resolution images while others do not. Therefore, you should provide
     * image resources for all relevant densities. If the property is set to "true", one or more requests are
     * sent to the server to try and get the perfect density version of an image. If an image of a certain density
     * is not available, the image control falls back to the default image, which should be provided.
     *
     * If you do not have higher resolution images, you should set the property to "false" to avoid unnecessary
     * round-trips.
     *
     * Please be aware that this property is relevant only for images and not for icons.
     *
     * Default value is `true`.
     *
     * @deprecated As of version 1.88. Image replaced by {@link sap.m.Avatar }
     *
     * @returns Value of property `iconDensityAware`
     */
    getIconDensityAware(): boolean;
    /**
     * Gets current value of property {@link #getIconDisplayShape iconDisplayShape}.
     *
     * Defines the shape of the icon.
     *
     * Default value is `Circle`.
     *
     * @since 1.88
     *
     * @returns Value of property `iconDisplayShape`
     */
    getIconDisplayShape(): AvatarShape;
    /**
     * Gets current value of property {@link #getIconInitials iconInitials}.
     *
     * Defines the initials of the icon.
     *
     * Default value is `empty string`.
     *
     * @since 1.88
     *
     * @returns Value of property `iconInitials`
     */
    getIconInitials(): string;
    /**
     * Gets current value of property {@link #getIconSize iconSize}.
     *
     * Defines the size of the icon.
     *
     * Default value is `M`.
     *
     * @since 1.88
     *
     * @returns Value of property `iconSize`
     */
    getIconSize(): AvatarSize;
    /**
     * Gets current value of property {@link #getMaxLength maxLength}.
     *
     * The maximum length (the maximum number of characters) for the feed's input value. By default this is
     * not limited.
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `maxLength`
     */
    getMaxLength(): int;
    /**
     * Gets current value of property {@link #getPlaceholder placeholder}.
     *
     * The placeholder text shown in the input area as long as the user has not entered any text value.
     *
     * Default value is `"Post something here"`.
     *
     *
     * @returns Value of property `placeholder`
     */
    getPlaceholder(): string;
    /**
     * Gets current value of property {@link #getRows rows}.
     *
     * Defines the number of visible text lines for the control. **Note:** Minimum value is 2, maximum value
     * is 15.
     *
     * Default value is `2`.
     *
     *
     * @returns Value of property `rows`
     */
    getRows(): int;
    /**
     * Gets current value of property {@link #getShowExceededText showExceededText}.
     *
     * Determines whether the characters, exceeding the maximum allowed character count, are visible in the
     * input field.
     *
     * If set to `false`, the user is not allowed to enter more characters than what is set in the `maxLength`
     * property. If set to `true`, the characters exceeding the `maxLength` value are selected on paste and
     * the counter below the input field displays their number.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showExceededText`
     */
    getShowExceededText(): boolean;
    /**
     * Gets current value of property {@link #getShowIcon showIcon}.
     *
     * If set to "true" (default), icons will be displayed. In case no icon is provided the standard placeholder
     * will be displayed. if set to "false" icons are hidden
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showIcon`
     */
    getShowIcon(): boolean;
    /**
     * Gets current value of property {@link #getValue value}.
     *
     * The text value of the feed input. As long as the user has not entered any text the post button is disabled
     *
     *
     * @returns Value of property `value`
     */
    getValue(): string;
    /**
     * Sets a new value for property {@link #getAriaLabelForPicture ariaLabelForPicture}.
     *
     * Text for Picture which will be read by screenreader. If a new ariaLabelForPicture is set, any previously
     * set ariaLabelForPicture is deactivated.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @deprecated As of version 1.88. This will not have any effect in code now.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAriaLabelForPicture(
      /**
       * New value for property `ariaLabelForPicture`
       */
      sAriaLabelForPicture?: string
    ): this;
    /**
     * Sets a new value for property {@link #getButtonTooltip buttonTooltip}.
     *
     * Sets a new tooltip for Submit button. The tooltip can either be a simple string (which in most cases
     * will be rendered as the title attribute of this element) or an instance of sap.ui.core.TooltipBase. If
     * a new tooltip is set, any previously set tooltip is deactivated. The default value is set language dependent.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Submit"`.
     *
     * @since 1.28
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setButtonTooltip(
      /**
       * New value for property `buttonTooltip`
       */
      sButtonTooltip?: TooltipBase | string
    ): this;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Set this flag to "false" to disable both text input and post button.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getGrowing growing}.
     *
     * Indicates the ability of the control to automatically grow and shrink dynamically with its content.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGrowing(
      /**
       * New value for property `growing`
       */
      bGrowing?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getGrowingMaxLines growingMaxLines}.
     *
     * Defines the maximum number of lines that the control can grow. Value is set to 0 by default, which means
     * an unlimited numbers of rows. **Note:** Minimum value to set is equal to the `rows` property value, maximum
     * value is 15.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGrowingMaxLines(
      /**
       * New value for property `growingMaxLines`
       */
      iGrowingMaxLines?: int
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Icon to be displayed as a graphical element within the feed input. This can be an image or an icon from
     * the icon font.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getIconDensityAware iconDensityAware}.
     *
     * Some mobile devices support higher resolution images while others do not. Therefore, you should provide
     * image resources for all relevant densities. If the property is set to "true", one or more requests are
     * sent to the server to try and get the perfect density version of an image. If an image of a certain density
     * is not available, the image control falls back to the default image, which should be provided.
     *
     * If you do not have higher resolution images, you should set the property to "false" to avoid unnecessary
     * round-trips.
     *
     * Please be aware that this property is relevant only for images and not for icons.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @deprecated As of version 1.88. Image replaced by {@link sap.m.Avatar }
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconDensityAware(
      /**
       * New value for property `iconDensityAware`
       */
      bIconDensityAware?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIconDisplayShape iconDisplayShape}.
     *
     * Defines the shape of the icon.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Circle`.
     *
     * @since 1.88
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconDisplayShape(
      /**
       * New value for property `iconDisplayShape`
       */
      sIconDisplayShape?: AvatarShape | keyof typeof AvatarShape
    ): this;
    /**
     * Sets a new value for property {@link #getIconInitials iconInitials}.
     *
     * Defines the initials of the icon.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.88
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconInitials(
      /**
       * New value for property `iconInitials`
       */
      sIconInitials?: string
    ): this;
    /**
     * Sets a new value for property {@link #getIconSize iconSize}.
     *
     * Defines the size of the icon.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `M`.
     *
     * @since 1.88
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconSize(
      /**
       * New value for property `iconSize`
       */
      sIconSize?: AvatarSize | keyof typeof AvatarSize
    ): this;
    /**
     * Sets a new value for property {@link #getMaxLength maxLength}.
     *
     * The maximum length (the maximum number of characters) for the feed's input value. By default this is
     * not limited.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxLength(
      /**
       * New value for property `maxLength`
       */
      iMaxLength?: int
    ): this;
    /**
     * Sets a new value for property {@link #getPlaceholder placeholder}.
     *
     * The placeholder text shown in the input area as long as the user has not entered any text value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Post something here"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPlaceholder(
      /**
       * New value for property `placeholder`
       */
      sPlaceholder?: string
    ): this;
    /**
     * Sets a new value for property {@link #getRows rows}.
     *
     * Defines the number of visible text lines for the control. **Note:** Minimum value is 2, maximum value
     * is 15.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `2`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRows(
      /**
       * New value for property `rows`
       */
      iRows?: int
    ): this;
    /**
     * Sets a new value for property {@link #getShowExceededText showExceededText}.
     *
     * Determines whether the characters, exceeding the maximum allowed character count, are visible in the
     * input field.
     *
     * If set to `false`, the user is not allowed to enter more characters than what is set in the `maxLength`
     * property. If set to `true`, the characters exceeding the `maxLength` value are selected on paste and
     * the counter below the input field displays their number.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowExceededText(
      /**
       * New value for property `showExceededText`
       */
      bShowExceededText?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowIcon showIcon}.
     *
     * If set to "true" (default), icons will be displayed. In case no icon is provided the standard placeholder
     * will be displayed. if set to "false" icons are hidden
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowIcon(
      /**
       * New value for property `showIcon`
       */
      bShowIcon?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getValue value}.
     *
     * The text value of the feed input. As long as the user has not entered any text the post button is disabled
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValue(
      /**
       * New value for property `value`
       */
      sValue?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the FeedInput constructor.
   */
  export interface $FeedInputSettings extends $ControlSettings {
    /**
     * Set this flag to "false" to disable both text input and post button.
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the number of visible text lines for the control. **Note:** Minimum value is 2, maximum value
     * is 15.
     */
    rows?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the characters, exceeding the maximum allowed character count, are visible in the
     * input field.
     *
     * If set to `false`, the user is not allowed to enter more characters than what is set in the `maxLength`
     * property. If set to `true`, the characters exceeding the `maxLength` value are selected on paste and
     * the counter below the input field displays their number.
     */
    showExceededText?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The maximum length (the maximum number of characters) for the feed's input value. By default this is
     * not limited.
     */
    maxLength?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates the ability of the control to automatically grow and shrink dynamically with its content.
     */
    growing?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the maximum number of lines that the control can grow. Value is set to 0 by default, which means
     * an unlimited numbers of rows. **Note:** Minimum value to set is equal to the `rows` property value, maximum
     * value is 15.
     */
    growingMaxLines?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * The placeholder text shown in the input area as long as the user has not entered any text value.
     */
    placeholder?: string | PropertyBindingInfo;

    /**
     * The text value of the feed input. As long as the user has not entered any text the post button is disabled
     */
    value?: string | PropertyBindingInfo;

    /**
     * Icon to be displayed as a graphical element within the feed input. This can be an image or an icon from
     * the icon font.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the shape of the icon.
     *
     * @since 1.88
     */
    iconDisplayShape?:
      | (AvatarShape | keyof typeof AvatarShape)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the initials of the icon.
     *
     * @since 1.88
     */
    iconInitials?: string | PropertyBindingInfo;

    /**
     * Defines the size of the icon.
     *
     * @since 1.88
     */
    iconSize?:
      | (AvatarSize | keyof typeof AvatarSize)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * If set to "true" (default), icons will be displayed. In case no icon is provided the standard placeholder
     * will be displayed. if set to "false" icons are hidden
     */
    showIcon?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Some mobile devices support higher resolution images while others do not. Therefore, you should provide
     * image resources for all relevant densities. If the property is set to "true", one or more requests are
     * sent to the server to try and get the perfect density version of an image. If an image of a certain density
     * is not available, the image control falls back to the default image, which should be provided.
     *
     * If you do not have higher resolution images, you should set the property to "false" to avoid unnecessary
     * round-trips.
     *
     * Please be aware that this property is relevant only for images and not for icons.
     *
     * @deprecated As of version 1.88. Image replaced by {@link sap.m.Avatar }
     */
    iconDensityAware?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets a new tooltip for Submit button. The tooltip can either be a simple string (which in most cases
     * will be rendered as the title attribute of this element) or an instance of sap.ui.core.TooltipBase. If
     * a new tooltip is set, any previously set tooltip is deactivated. The default value is set language dependent.
     *
     * @since 1.28
     */
    buttonTooltip?: TooltipBase | string | PropertyBindingInfo | `{${string}}`;

    /**
     * Text for Picture which will be read by screenreader. If a new ariaLabelForPicture is set, any previously
     * set ariaLabelForPicture is deactivated.
     *
     * @deprecated As of version 1.88. This will not have any effect in code now.
     */
    ariaLabelForPicture?: string | PropertyBindingInfo;

    /**
     * The Post event is triggered when the user has entered a value and pressed the post button. After firing
     * this event, the value is reset.
     */
    post?: (oEvent: FeedInput$PostEvent) => void;
  }

  /**
   * Parameters of the FeedInput#post event.
   */
  export interface FeedInput$PostEventParameters {
    /**
     * The value of the feed input before reseting it.
     */
    value?: string;
  }

  /**
   * Event object of the FeedInput#post event.
   */
  export type FeedInput$PostEvent = Event<
    FeedInput$PostEventParameters,
    FeedInput
  >;
}

declare module "sap/m/FeedListItem" {
  import {
    default as ListItemBase,
    $ListItemBaseSettings,
  } from "sap/m/ListItemBase";

  import FeedListItemAction from "sap/m/FeedListItemAction";

  import { URI } from "sap/ui/core/library";

  import { LinkConversion, ListType } from "sap/m/library";

  import AvatarShape from "sap/m/AvatarShape";

  import AvatarSize from "sap/m/AvatarSize";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * The control provides a set of properties for text, sender information, time stamp. Beginning with release
   * 1.23 the new feature expand / collapse was introduced, which uses the property maxCharacters. Beginning
   * with release 1.44, sap.m.FormattedText was introduced which allows html formatted text to be displayed
   *
   * @since 1.12
   */
  export default class FeedListItem extends ListItemBase {
    /**
     * Constructor for a new FeedListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $FeedListItemSettings
    );
    /**
     * Constructor for a new FeedListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $FeedListItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.FeedListItem with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ListItemBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, FeedListItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.FeedListItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some action to the aggregation {@link #getActions actions}.
     *
     * @since 1.52.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAction(
      /**
       * The action to add; if empty, nothing is inserted
       */
      oAction: FeedListItemAction
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:iconPress iconPress} event of this `sap.m.FeedListItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FeedListItem` itself.
     *
     * Event is fired when the icon is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachIconPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: FeedListItem$IconPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FeedListItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:iconPress iconPress} event of this `sap.m.FeedListItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FeedListItem` itself.
     *
     * Event is fired when the icon is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachIconPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: FeedListItem$IconPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FeedListItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:senderPress senderPress} event of this `sap.m.FeedListItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FeedListItem` itself.
     *
     * Event is fired when name of the sender is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSenderPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: FeedListItem$SenderPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FeedListItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:senderPress senderPress} event of this `sap.m.FeedListItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FeedListItem` itself.
     *
     * Event is fired when name of the sender is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSenderPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: FeedListItem$SenderPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FeedListItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the actions in the aggregation {@link #getActions actions}.
     *
     * @since 1.52.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyActions(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:iconPress iconPress} event of this `sap.m.FeedListItem`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachIconPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: FeedListItem$IconPressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:senderPress senderPress} event of this `sap.m.FeedListItem`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSenderPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: FeedListItem$SenderPressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:iconPress iconPress} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireIconPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: FeedListItem$IconPressEventParameters
    ): this;
    /**
     * Fires event {@link #event:senderPress senderPress} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSenderPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: FeedListItem$SenderPressEventParameters
    ): this;
    /**
     * Gets content of aggregation {@link #getActions actions}.
     *
     * Contains {@link sap.m.FeedListItemAction elements} that are displayed in the action sheet.
     *
     * @since 1.52.0
     */
    getActions(): FeedListItemAction[];
    /**
     * Gets current value of property {@link #getActiveIcon activeIcon}.
     *
     * Icon displayed when the list item is active.
     *
     *
     * @returns Value of property `activeIcon`
     */
    getActiveIcon(): URI;
    /**
     * Gets current value of property {@link #getConvertedLinksDefaultTarget convertedLinksDefaultTarget}.
     *
     * Determines the target attribute of the generated HTML anchor tags. Note: Applicable only if ConvertLinksToAnchorTags
     * property is used with a value other than sap.m.LinkConversion.None. Options are the standard values for
     * the target attribute of the HTML anchor tag: _self, _top, _blank, _parent, _search.
     *
     * Default value is `"_blank"`.
     *
     * @since 1.46.1
     *
     * @returns Value of property `convertedLinksDefaultTarget`
     */
    getConvertedLinksDefaultTarget(): string;
    /**
     * Gets current value of property {@link #getConvertLinksToAnchorTags convertLinksToAnchorTags}.
     *
     * Determines whether strings that appear to be links will be converted to HTML anchor tags, and what are
     * the criteria for recognizing them.
     *
     * Default value is `None`.
     *
     * @since 1.46.1
     *
     * @returns Value of property `convertLinksToAnchorTags`
     */
    getConvertLinksToAnchorTags(): LinkConversion;
    /**
     * Gets current value of property {@link #getDisableStyleAttribute disableStyleAttribute}.
     *
     * Disables rendering of the `style` attribute in the `FormattedText`.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `disableStyleAttribute`
     */
    getDisableStyleAttribute(): boolean;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Icon to be displayed as graphical element within the FeedListItem. This can be an image or an icon from
     * the icon font. If no icon is provided, a default person-placeholder icon is displayed. Icon is only shown
     * if showIcon = true.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getIconActive iconActive}.
     *
     * If true, icon is a link, which will fire 'iconPress' events. If false, icon is normal image
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `iconActive`
     */
    getIconActive(): boolean;
    /**
     * Gets current value of property {@link #getIconDensityAware iconDensityAware}.
     *
     * By default, this is set to true but then one or more requests are sent trying to get the density perfect
     * version of image if this version of image doesn't exist on the server.
     *
     * If bandwidth is the key for the application, set this value to false.
     *
     * Default value is `true`.
     *
     * @deprecated As of version 1.88. Image is replaced by {@link sap.m.Avatar }
     *
     * @returns Value of property `iconDensityAware`
     */
    getIconDensityAware(): boolean;
    /**
     * Gets current value of property {@link #getIconDisplayShape iconDisplayShape}.
     *
     * Defines the shape of the icon.
     *
     * Default value is `Circle`.
     *
     * @since 1.88
     *
     * @returns Value of property `iconDisplayShape`
     */
    getIconDisplayShape(): AvatarShape;
    /**
     * Gets current value of property {@link #getIconInitials iconInitials}.
     *
     * Defines the initials of the icon.
     *
     * Default value is `empty string`.
     *
     * @since 1.88
     *
     * @returns Value of property `iconInitials`
     */
    getIconInitials(): string;
    /**
     * Gets current value of property {@link #getIconSize iconSize}.
     *
     * Defines the size of the icon.
     *
     * Default value is `S`.
     *
     * @since 1.88
     *
     * @returns Value of property `iconSize`
     */
    getIconSize(): AvatarSize;
    /**
     * Gets current value of property {@link #getInfo info}.
     *
     * The Info text.
     *
     *
     * @returns Value of property `info`
     */
    getInfo(): string;
    /**
     * Gets current value of property {@link #getLessLabel lessLabel}.
     *
     * Customizable text for the "LESS" link at the end of the feed list item.
     *  Clicking the "LESS" link collapses the item, hiding the text that exceeds the allowed maximum number
     * of characters.
     *
     * @since 1.60
     *
     * @returns Value of property `lessLabel`
     */
    getLessLabel(): string;
    /**
     * Gets current value of property {@link #getMaxCharacters maxCharacters}.
     *
     * The expand and collapse feature is set by default and uses 300 characters on mobile devices and 500 characters
     * on desktops as limits. Based on these values, the text of the FeedListItem is collapsed once text reaches
     * these limits. In this case, only the specified number of characters is displayed. By clicking on the
     * text link More, the entire text can be displayed. The text link Less collapses the text. The application
     * is able to set the value to its needs.
     *
     *
     * @returns Value of property `maxCharacters`
     */
    getMaxCharacters(): int;
    /**
     * Gets current value of property {@link #getMoreLabel moreLabel}.
     *
     * Customizable text for the "MORE" link at the end of the feed list item.
     *  When the maximum number of characters defined by the `maxCharacters` property is exceeded and the text
     * of the feed list item is collapsed, the "MORE" link can be used to expand the feed list item and show
     * the rest of the text.
     *
     * @since 1.60
     *
     * @returns Value of property `moreLabel`
     */
    getMoreLabel(): string;
    /**
     * Gets current value of property {@link #getSender sender}.
     *
     * Sender of the chunk
     *
     *
     * @returns Value of property `sender`
     */
    getSender(): string;
    /**
     * Gets current value of property {@link #getSenderActive senderActive}.
     *
     * If true, sender string is a link, which will fire 'senderPress' events. If false, sender is normal text.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `senderActive`
     */
    getSenderActive(): boolean;
    /**
     * Gets current value of property {@link #getShowIcon showIcon}.
     *
     * If set to "true" (default), icons will be displayed, if set to false icons are hidden
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showIcon`
     */
    getShowIcon(): boolean;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * The FeedListItem text. It supports html formatted tags as described in the documentation of sap.m.FormattedText
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getTimestamp timestamp}.
     *
     * This chunks timestamp
     *
     *
     * @returns Value of property `timestamp`
     */
    getTimestamp(): string;
    /**
     * Checks for the provided `sap.m.FeedListItemAction` in the aggregation {@link #getActions actions}. and
     * returns its index if found or -1 otherwise.
     *
     * @since 1.52.0
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfAction(
      /**
       * The action whose index is looked for
       */
      oAction: FeedListItemAction
    ): int;
    /**
     * Inserts a action into the aggregation {@link #getActions actions}.
     *
     * @since 1.52.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertAction(
      /**
       * The action to insert; if empty, nothing is inserted
       */
      oAction: FeedListItemAction,
      /**
       * The `0`-based index the action should be inserted at; for a negative value of `iIndex`, the action is
       * inserted at position 0; for a value greater than the current size of the aggregation, the action is inserted
       * at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes a action from the aggregation {@link #getActions actions}.
     *
     * @since 1.52.0
     *
     * @returns The removed action or `null`
     */
    removeAction(
      /**
       * The action to remove or its index or id
       */
      vAction: int | string | FeedListItemAction
    ): FeedListItemAction | null;
    /**
     * Removes all the controls from the aggregation {@link #getActions actions}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.52.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllActions(): FeedListItemAction[];
    /**
     * Sets a new value for property {@link #getActiveIcon activeIcon}.
     *
     * Icon displayed when the list item is active.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setActiveIcon(
      /**
       * New value for property `activeIcon`
       */
      sActiveIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getConvertedLinksDefaultTarget convertedLinksDefaultTarget}.
     *
     * Determines the target attribute of the generated HTML anchor tags. Note: Applicable only if ConvertLinksToAnchorTags
     * property is used with a value other than sap.m.LinkConversion.None. Options are the standard values for
     * the target attribute of the HTML anchor tag: _self, _top, _blank, _parent, _search.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"_blank"`.
     *
     * @since 1.46.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setConvertedLinksDefaultTarget(
      /**
       * New value for property `convertedLinksDefaultTarget`
       */
      sConvertedLinksDefaultTarget?: string
    ): this;
    /**
     * Sets a new value for property {@link #getConvertLinksToAnchorTags convertLinksToAnchorTags}.
     *
     * Determines whether strings that appear to be links will be converted to HTML anchor tags, and what are
     * the criteria for recognizing them.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     * @since 1.46.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setConvertLinksToAnchorTags(
      /**
       * New value for property `convertLinksToAnchorTags`
       */
      sConvertLinksToAnchorTags?: LinkConversion | keyof typeof LinkConversion
    ): this;
    /**
     * Sets a new value for property {@link #getDisableStyleAttribute disableStyleAttribute}.
     *
     * Disables rendering of the `style` attribute in the `FormattedText`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisableStyleAttribute(
      /**
       * New value for property `disableStyleAttribute`
       */
      bDisableStyleAttribute?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Icon to be displayed as graphical element within the FeedListItem. This can be an image or an icon from
     * the icon font. If no icon is provided, a default person-placeholder icon is displayed. Icon is only shown
     * if showIcon = true.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getIconActive iconActive}.
     *
     * If true, icon is a link, which will fire 'iconPress' events. If false, icon is normal image
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconActive(
      /**
       * New value for property `iconActive`
       */
      bIconActive?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIconDensityAware iconDensityAware}.
     *
     * By default, this is set to true but then one or more requests are sent trying to get the density perfect
     * version of image if this version of image doesn't exist on the server.
     *
     * If bandwidth is the key for the application, set this value to false.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @deprecated As of version 1.88. Image is replaced by {@link sap.m.Avatar }
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconDensityAware(
      /**
       * New value for property `iconDensityAware`
       */
      bIconDensityAware?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIconDisplayShape iconDisplayShape}.
     *
     * Defines the shape of the icon.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Circle`.
     *
     * @since 1.88
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconDisplayShape(
      /**
       * New value for property `iconDisplayShape`
       */
      sIconDisplayShape?: AvatarShape | keyof typeof AvatarShape
    ): this;
    /**
     * Sets a new value for property {@link #getIconInitials iconInitials}.
     *
     * Defines the initials of the icon.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.88
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconInitials(
      /**
       * New value for property `iconInitials`
       */
      sIconInitials?: string
    ): this;
    /**
     * Sets a new value for property {@link #getIconSize iconSize}.
     *
     * Defines the size of the icon.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `S`.
     *
     * @since 1.88
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconSize(
      /**
       * New value for property `iconSize`
       */
      sIconSize?: AvatarSize | keyof typeof AvatarSize
    ): this;
    /**
     * Sets a new value for property {@link #getInfo info}.
     *
     * The Info text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInfo(
      /**
       * New value for property `info`
       */
      sInfo?: string
    ): this;
    /**
     * Sets a new value for property {@link #getLessLabel lessLabel}.
     *
     * Customizable text for the "LESS" link at the end of the feed list item.
     *  Clicking the "LESS" link collapses the item, hiding the text that exceeds the allowed maximum number
     * of characters.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.60
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLessLabel(
      /**
       * New value for property `lessLabel`
       */
      sLessLabel?: string
    ): this;
    /**
     * Sets a new value for property {@link #getMaxCharacters maxCharacters}.
     *
     * The expand and collapse feature is set by default and uses 300 characters on mobile devices and 500 characters
     * on desktops as limits. Based on these values, the text of the FeedListItem is collapsed once text reaches
     * these limits. In this case, only the specified number of characters is displayed. By clicking on the
     * text link More, the entire text can be displayed. The text link Less collapses the text. The application
     * is able to set the value to its needs.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxCharacters(
      /**
       * New value for property `maxCharacters`
       */
      iMaxCharacters?: int
    ): this;
    /**
     * Sets a new value for property {@link #getMoreLabel moreLabel}.
     *
     * Customizable text for the "MORE" link at the end of the feed list item.
     *  When the maximum number of characters defined by the `maxCharacters` property is exceeded and the text
     * of the feed list item is collapsed, the "MORE" link can be used to expand the feed list item and show
     * the rest of the text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.60
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMoreLabel(
      /**
       * New value for property `moreLabel`
       */
      sMoreLabel?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSender sender}.
     *
     * Sender of the chunk
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSender(
      /**
       * New value for property `sender`
       */
      sSender?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSenderActive senderActive}.
     *
     * If true, sender string is a link, which will fire 'senderPress' events. If false, sender is normal text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSenderActive(
      /**
       * New value for property `senderActive`
       */
      bSenderActive?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowIcon showIcon}.
     *
     * If set to "true" (default), icons will be displayed, if set to false icons are hidden
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowIcon(
      /**
       * New value for property `showIcon`
       */
      bShowIcon?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * The FeedListItem text. It supports html formatted tags as described in the documentation of sap.m.FormattedText
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTimestamp timestamp}.
     *
     * This chunks timestamp
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTimestamp(
      /**
       * New value for property `timestamp`
       */
      sTimestamp?: string
    ): this;
    /**
     * Redefinition of sap.m.ListItemBase.setType: type = "sap.m.ListType.Navigation" behaves like type = "sap.m.ListType.Active"
     * for a FeedListItem
     *
     *
     * @returns this allows method chaining
     */
    setType(
      /**
       * new value for property type
       */
      type: ListType | keyof typeof ListType
    ): this;
  }
  /**
   * Describes the settings that can be provided to the FeedListItem constructor.
   */
  export interface $FeedListItemSettings extends $ListItemBaseSettings {
    /**
     * Icon to be displayed as graphical element within the FeedListItem. This can be an image or an icon from
     * the icon font. If no icon is provided, a default person-placeholder icon is displayed. Icon is only shown
     * if showIcon = true.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the shape of the icon.
     *
     * @since 1.88
     */
    iconDisplayShape?:
      | (AvatarShape | keyof typeof AvatarShape)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the initials of the icon.
     *
     * @since 1.88
     */
    iconInitials?: string | PropertyBindingInfo;

    /**
     * Defines the size of the icon.
     *
     * @since 1.88
     */
    iconSize?:
      | (AvatarSize | keyof typeof AvatarSize)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Icon displayed when the list item is active.
     */
    activeIcon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Sender of the chunk
     */
    sender?: string | PropertyBindingInfo;

    /**
     * The FeedListItem text. It supports html formatted tags as described in the documentation of sap.m.FormattedText
     */
    text?: string | PropertyBindingInfo;

    /**
     * Customizable text for the "MORE" link at the end of the feed list item.
     *  When the maximum number of characters defined by the `maxCharacters` property is exceeded and the text
     * of the feed list item is collapsed, the "MORE" link can be used to expand the feed list item and show
     * the rest of the text.
     *
     * @since 1.60
     */
    moreLabel?: string | PropertyBindingInfo;

    /**
     * Customizable text for the "LESS" link at the end of the feed list item.
     *  Clicking the "LESS" link collapses the item, hiding the text that exceeds the allowed maximum number
     * of characters.
     *
     * @since 1.60
     */
    lessLabel?: string | PropertyBindingInfo;

    /**
     * The Info text.
     */
    info?: string | PropertyBindingInfo;

    /**
     * This chunks timestamp
     */
    timestamp?: string | PropertyBindingInfo;

    /**
     * If true, sender string is a link, which will fire 'senderPress' events. If false, sender is normal text.
     */
    senderActive?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * If true, icon is a link, which will fire 'iconPress' events. If false, icon is normal image
     */
    iconActive?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * By default, this is set to true but then one or more requests are sent trying to get the density perfect
     * version of image if this version of image doesn't exist on the server.
     *
     * If bandwidth is the key for the application, set this value to false.
     *
     * @deprecated As of version 1.88. Image is replaced by {@link sap.m.Avatar }
     */
    iconDensityAware?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * If set to "true" (default), icons will be displayed, if set to false icons are hidden
     */
    showIcon?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether strings that appear to be links will be converted to HTML anchor tags, and what are
     * the criteria for recognizing them.
     *
     * @since 1.46.1
     */
    convertLinksToAnchorTags?:
      | (LinkConversion | keyof typeof LinkConversion)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the target attribute of the generated HTML anchor tags. Note: Applicable only if ConvertLinksToAnchorTags
     * property is used with a value other than sap.m.LinkConversion.None. Options are the standard values for
     * the target attribute of the HTML anchor tag: _self, _top, _blank, _parent, _search.
     *
     * @since 1.46.1
     */
    convertedLinksDefaultTarget?: string | PropertyBindingInfo;

    /**
     * The expand and collapse feature is set by default and uses 300 characters on mobile devices and 500 characters
     * on desktops as limits. Based on these values, the text of the FeedListItem is collapsed once text reaches
     * these limits. In this case, only the specified number of characters is displayed. By clicking on the
     * text link More, the entire text can be displayed. The text link Less collapses the text. The application
     * is able to set the value to its needs.
     */
    maxCharacters?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Disables rendering of the `style` attribute in the `FormattedText`.
     */
    disableStyleAttribute?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Contains {@link sap.m.FeedListItemAction elements} that are displayed in the action sheet.
     *
     * @since 1.52.0
     */
    actions?:
      | FeedListItemAction[]
      | FeedListItemAction
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Event is fired when name of the sender is pressed.
     */
    senderPress?: (oEvent: FeedListItem$SenderPressEvent) => void;

    /**
     * Event is fired when the icon is pressed.
     */
    iconPress?: (oEvent: FeedListItem$IconPressEvent) => void;
  }

  /**
   * Parameters of the FeedListItem#iconPress event.
   */
  export interface FeedListItem$IconPressEventParameters {
    /**
     * Dom reference of the feed item's icon to be used for positioning.
     */
    domRef?: string;

    /**
     * Function to retrieve the DOM reference for the `iconPress` event. The function returns the DOM element
     * of the icon or null
     */
    getDomRef?: Function;
  }

  /**
   * Event object of the FeedListItem#iconPress event.
   */
  export type FeedListItem$IconPressEvent = Event<
    FeedListItem$IconPressEventParameters,
    FeedListItem
  >;

  /**
   * Parameters of the FeedListItem#senderPress event.
   */
  export interface FeedListItem$SenderPressEventParameters {
    /**
     * Dom reference of the feed item's sender string to be used for positioning.
     */
    domRef?: string;

    /**
     * Function to retrieve the DOM reference for the `senderPress` event. The function returns the DOM element
     * of the sender link or null
     */
    getDomRef?: Function;
  }

  /**
   * Event object of the FeedListItem#senderPress event.
   */
  export type FeedListItem$SenderPressEvent = Event<
    FeedListItem$SenderPressEventParameters,
    FeedListItem
  >;
}

declare module "sap/m/FeedListItemAction" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import Event from "sap/ui/base/Event";

  import { URI } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * An action item of FeedListItem
   *
   * @since 1.52.0
   */
  export default class FeedListItemAction extends UI5Element {
    /**
     * Constructor for a new FeedListItemAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new element
       */
      mSettings?: $FeedListItemActionSettings
    );
    /**
     * Constructor for a new FeedListItemAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new element, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new element
       */
      mSettings?: $FeedListItemActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.FeedListItemAction with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, FeedListItemAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.FeedListItemAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.FeedListItemAction`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FeedListItemAction` itself.
     *
     * The `press` event is fired when the user triggers the corresponding action.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FeedListItemAction` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.FeedListItemAction`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.FeedListItemAction` itself.
     *
     * The `press` event is fired when the user triggers the corresponding action.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.FeedListItemAction` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.FeedListItemAction`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Enables or disables a button on the UI. All buttons are enabled by default. Disabled buttons are colored
     * differently as per the theme of the UI.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * The icon of the action.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getKey key}.
     *
     * The key of the item.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `key`
     */
    getKey(): string;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * The text of the item. It is used as a tooltip and for accessibility reasons.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * Hides or shows a button on the UI.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Enables or disables a button on the UI. All buttons are enabled by default. Disabled buttons are colored
     * differently as per the theme of the UI.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * The icon of the action.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getKey key}.
     *
     * The key of the item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setKey(
      /**
       * New value for property `key`
       */
      sKey?: string
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * The text of the item. It is used as a tooltip and for accessibility reasons.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * Hides or shows a button on the UI.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the FeedListItemAction constructor.
   */
  export interface $FeedListItemActionSettings extends $ElementSettings {
    /**
     * The icon of the action.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * The text of the item. It is used as a tooltip and for accessibility reasons.
     */
    text?: string | PropertyBindingInfo;

    /**
     * The key of the item.
     */
    key?: string | PropertyBindingInfo;

    /**
     * Hides or shows a button on the UI.
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Enables or disables a button on the UI. All buttons are enabled by default. Disabled buttons are colored
     * differently as per the theme of the UI.
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The `press` event is fired when the user triggers the corresponding action.
     */
    press?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the FeedListItemAction#press event.
   */
  export interface FeedListItemAction$PressEventParameters {}

  /**
   * Event object of the FeedListItemAction#press event.
   */
  export type FeedListItemAction$PressEvent = Event<
    FeedListItemAction$PressEventParameters,
    FeedListItemAction
  >;
}

declare module "sap/m/FlexBox" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    AccessibilityInfo,
    CSSSize,
    CSSGapShortHand,
  } from "sap/ui/core/library";

  import {
    FlexAlignContent,
    FlexAlignItems,
    BackgroundDesign,
    FlexDirection,
    FlexJustifyContent,
    FlexRendertype,
    FlexWrap,
  } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * The `sap.m.FlexBox` control builds the container for a flexible box layout.
   *
   *  **Note:** Be sure to check the `renderType` setting to avoid issues due to browser inconsistencies.
   */
  export default class FlexBox extends Control {
    /**
     * Constructor for a new `sap.m.FlexBox`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	https://www.w3.org/TR/css-flexbox-1/
     * 	https://www.w3schools.com/css/css3_flexbox.asp
     * 	{@link https://ui5.sap.com/#/topic/674890e6d8534eaba2eaf63242e077eb Flex Box}
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $FlexBoxSettings
    );
    /**
     * Constructor for a new `sap.m.FlexBox`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	https://www.w3.org/TR/css-flexbox-1/
     * 	https://www.w3schools.com/css/css3_flexbox.asp
     * 	{@link https://ui5.sap.com/#/topic/674890e6d8534eaba2eaf63242e077eb Flex Box}
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $FlexBoxSettings
    );

    /**
     * Creates a new subclass of class sap.m.FlexBox with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, FlexBox>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.FlexBox.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: Control
    ): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Gets the accessibility information.
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The accessibility information.
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Gets current value of property {@link #getAlignContent alignContent}.
     *
     * Determines the layout behavior of container lines when there's extra space along the cross-axis.
     *
     * Default value is `Stretch`.
     *
     * @since 1.36.0
     *
     * @returns Value of property `alignContent`
     */
    getAlignContent(): FlexAlignContent;
    /**
     * Gets current value of property {@link #getAlignItems alignItems}.
     *
     * Determines the layout behavior of items along the cross-axis.
     *
     * Default value is `Stretch`.
     *
     *
     * @returns Value of property `alignItems`
     */
    getAlignItems(): FlexAlignItems;
    /**
     * Gets current value of property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Defines the background style of the `sap.m.FlexBox`.
     *
     * Default value is `Transparent`.
     *
     * @since 1.38.5
     *
     * @returns Value of property `backgroundDesign`
     */
    getBackgroundDesign(): BackgroundDesign;
    /**
     * Gets current value of property {@link #getColumnGap columnGap}.
     *
     * The size of the gap between columns.
     *
     * Default value is `empty string`.
     *
     * @since 1.134
     *
     * @returns Value of property `columnGap`
     */
    getColumnGap(): CSSSize;
    /**
     * Gets current value of property {@link #getDirection direction}.
     *
     * Determines the direction of the layout of child elements.
     *
     * Default value is `Row`.
     *
     *
     * @returns Value of property `direction`
     */
    getDirection(): FlexDirection;
    /**
     * Gets current value of property {@link #getDisplayInline displayInline}.
     *
     * Determines whether the `sap.m.FlexBox` is in block or inline mode.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `displayInline`
     */
    getDisplayInline(): boolean;
    /**
     * Gets current value of property {@link #getFitContainer fitContainer}.
     *
     * Determines whether the `sap.m.FlexBox` will be sized to completely fill its container. If the `sap.m.FlexBox`
     * is inserted into a Page, the property 'enableScrolling' of the Page needs to be set to 'false' for the
     * FlexBox to fit the entire viewport.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `fitContainer`
     */
    getFitContainer(): boolean;
    /**
     * Gets current value of property {@link #getGap gap}.
     *
     * The size of the gap between columns and rows. It serves as a shorthand property for `rowGap` and `columnGap`
     * properties. If either of the properties is set, the `gap` value will have lower priority and will be
     * overwritten.
     *
     * Default value is `empty string`.
     *
     * @since 1.134
     *
     * @returns Value of property `gap`
     */
    getGap(): CSSGapShortHand;
    /**
     * Gets current value of property {@link #getHeight height}.
     *
     * The height of the `sap.m.FlexBox`. Note that when a percentage is given, for the height to work as expected,
     * the height of the surrounding container must be defined.
     *
     * Default value is `empty string`.
     *
     * @since 1.9.1
     *
     * @returns Value of property `height`
     */
    getHeight(): CSSSize;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * Flex items within the flexible box layout
     */
    getItems(): Control[];
    /**
     * Gets current value of property {@link #getJustifyContent justifyContent}.
     *
     * Determines the layout behavior along the main axis.
     *
     * Default value is `Start`.
     *
     *
     * @returns Value of property `justifyContent`
     */
    getJustifyContent(): FlexJustifyContent;
    /**
     * Gets current value of property {@link #getRenderType renderType}.
     *
     * Determines whether the layout is rendered as a series of divs or as an unordered list (ul).
     *
     *  **Note:** We recommend to use `Bare` in most cases to avoid layout issues due to browser inconsistencies.
     *
     * Default value is `Div`.
     *
     *
     * @returns Value of property `renderType`
     */
    getRenderType(): FlexRendertype;
    /**
     * Gets current value of property {@link #getRowGap rowGap}.
     *
     * The size of the gap between rows.
     *
     * Default value is `empty string`.
     *
     * @since 1.134
     *
     * @returns Value of property `rowGap`
     */
    getRowGap(): CSSSize;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * The width of the `sap.m.FlexBox`. Note that when a percentage is given, for the width to work as expected,
     * the width of the surrounding container must be defined.
     *
     * Default value is `empty string`.
     *
     * @since 1.9.1
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getWrap wrap}.
     *
     * Determines the wrapping behavior of the flex container. This property has no effect in older browsers,
     * e.g. Android Native 4.3 and below.
     *
     * Default value is `NoWrap`.
     *
     * @since 1.36.0
     *
     * @returns Value of property `wrap`
     */
    getWrap(): FlexWrap;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getItems items}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: Control
    ): int;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: Control,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): Control[];
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | Control
    ): Control | null;
    /**
     * Sets a new value for property {@link #getAlignContent alignContent}.
     *
     * Determines the layout behavior of container lines when there's extra space along the cross-axis.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Stretch`.
     *
     * @since 1.36.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAlignContent(
      /**
       * New value for property `alignContent`
       */
      sAlignContent?: FlexAlignContent | keyof typeof FlexAlignContent
    ): this;
    /**
     * Sets a new value for property {@link #getAlignItems alignItems}.
     *
     * Determines the layout behavior of items along the cross-axis.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Stretch`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAlignItems(
      /**
       * New value for property `alignItems`
       */
      sAlignItems?: FlexAlignItems | keyof typeof FlexAlignItems
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Defines the background style of the `sap.m.FlexBox`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Transparent`.
     *
     * @since 1.38.5
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundDesign(
      /**
       * New value for property `backgroundDesign`
       */
      sBackgroundDesign?: BackgroundDesign | keyof typeof BackgroundDesign
    ): this;
    /**
     * Sets a new value for property {@link #getColumnGap columnGap}.
     *
     * The size of the gap between columns.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.134
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setColumnGap(
      /**
       * New value for property `columnGap`
       */
      sColumnGap?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getDirection direction}.
     *
     * Determines the direction of the layout of child elements.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Row`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDirection(
      /**
       * New value for property `direction`
       */
      sDirection?: FlexDirection | keyof typeof FlexDirection
    ): this;
    /**
     * Sets a new value for property {@link #getDisplayInline displayInline}.
     *
     * Determines whether the `sap.m.FlexBox` is in block or inline mode.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisplayInline(
      /**
       * New value for property `displayInline`
       */
      bDisplayInline?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getFitContainer fitContainer}.
     *
     * Determines whether the `sap.m.FlexBox` will be sized to completely fill its container. If the `sap.m.FlexBox`
     * is inserted into a Page, the property 'enableScrolling' of the Page needs to be set to 'false' for the
     * FlexBox to fit the entire viewport.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFitContainer(
      /**
       * New value for property `fitContainer`
       */
      bFitContainer?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getGap gap}.
     *
     * The size of the gap between columns and rows. It serves as a shorthand property for `rowGap` and `columnGap`
     * properties. If either of the properties is set, the `gap` value will have lower priority and will be
     * overwritten.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.134
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGap(
      /**
       * New value for property `gap`
       */
      sGap?: CSSGapShortHand
    ): this;
    /**
     * Sets a new value for property {@link #getHeight height}.
     *
     * The height of the `sap.m.FlexBox`. Note that when a percentage is given, for the height to work as expected,
     * the height of the surrounding container must be defined.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.9.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeight(
      /**
       * New value for property `height`
       */
      sHeight?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getJustifyContent justifyContent}.
     *
     * Determines the layout behavior along the main axis.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Start`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setJustifyContent(
      /**
       * New value for property `justifyContent`
       */
      sJustifyContent?: FlexJustifyContent | keyof typeof FlexJustifyContent
    ): this;
    /**
     * Sets the render type of the FlexBox.
     *
     *
     * @returns `this` FlexBox reference for chaining.
     */
    setRenderType(
      /**
       * Render type in string format.
       */
      sValue: FlexRendertype | keyof typeof FlexRendertype
    ): this;
    /**
     * Sets a new value for property {@link #getRowGap rowGap}.
     *
     * The size of the gap between rows.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.134
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRowGap(
      /**
       * New value for property `rowGap`
       */
      sRowGap?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * The width of the `sap.m.FlexBox`. Note that when a percentage is given, for the width to work as expected,
     * the width of the surrounding container must be defined.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.9.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getWrap wrap}.
     *
     * Determines the wrapping behavior of the flex container. This property has no effect in older browsers,
     * e.g. Android Native 4.3 and below.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `NoWrap`.
     *
     * @since 1.36.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWrap(
      /**
       * New value for property `wrap`
       */
      sWrap?: FlexWrap | keyof typeof FlexWrap
    ): this;
  }
  /**
   * Describes the settings that can be provided to the FlexBox constructor.
   */
  export interface $FlexBoxSettings extends $ControlSettings {
    /**
     * The height of the `sap.m.FlexBox`. Note that when a percentage is given, for the height to work as expected,
     * the height of the surrounding container must be defined.
     *
     * @since 1.9.1
     */
    height?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * The width of the `sap.m.FlexBox`. Note that when a percentage is given, for the width to work as expected,
     * the width of the surrounding container must be defined.
     *
     * @since 1.9.1
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the `sap.m.FlexBox` is in block or inline mode.
     */
    displayInline?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the direction of the layout of child elements.
     */
    direction?:
      | (FlexDirection | keyof typeof FlexDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines whether the `sap.m.FlexBox` will be sized to completely fill its container. If the `sap.m.FlexBox`
     * is inserted into a Page, the property 'enableScrolling' of the Page needs to be set to 'false' for the
     * FlexBox to fit the entire viewport.
     */
    fitContainer?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the layout is rendered as a series of divs or as an unordered list (ul).
     *
     *  **Note:** We recommend to use `Bare` in most cases to avoid layout issues due to browser inconsistencies.
     */
    renderType?:
      | (FlexRendertype | keyof typeof FlexRendertype)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the layout behavior along the main axis.
     */
    justifyContent?:
      | (FlexJustifyContent | keyof typeof FlexJustifyContent)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the layout behavior of items along the cross-axis.
     */
    alignItems?:
      | (FlexAlignItems | keyof typeof FlexAlignItems)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the wrapping behavior of the flex container. This property has no effect in older browsers,
     * e.g. Android Native 4.3 and below.
     *
     * @since 1.36.0
     */
    wrap?:
      | (FlexWrap | keyof typeof FlexWrap)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the layout behavior of container lines when there's extra space along the cross-axis.
     *
     * @since 1.36.0
     */
    alignContent?:
      | (FlexAlignContent | keyof typeof FlexAlignContent)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the background style of the `sap.m.FlexBox`.
     *
     * @since 1.38.5
     */
    backgroundDesign?:
      | (BackgroundDesign | keyof typeof BackgroundDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The size of the gap between columns and rows. It serves as a shorthand property for `rowGap` and `columnGap`
     * properties. If either of the properties is set, the `gap` value will have lower priority and will be
     * overwritten.
     *
     * @since 1.134
     */
    gap?: CSSGapShortHand | PropertyBindingInfo | `{${string}}`;

    /**
     * The size of the gap between rows.
     *
     * @since 1.134
     */
    rowGap?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * The size of the gap between columns.
     *
     * @since 1.134
     */
    columnGap?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Flex items within the flexible box layout
     */
    items?: Control[] | Control | AggregationBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/FlexItemData" {
  import {
    default as LayoutData,
    $LayoutDataSettings,
  } from "sap/ui/core/LayoutData";

  import { FlexAlignSelf, BackgroundDesign } from "sap/m/library";

  import { CSSSize } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Holds layout data for a FlexBox / HBox / VBox.
   */
  export default class FlexItemData extends LayoutData {
    /**
     * Constructor for a new `sap.m.FlexItemData`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new element.
       */
      mSettings?: $FlexItemDataSettings
    );
    /**
     * Constructor for a new `sap.m.FlexItemData`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new element, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new element.
       */
      mSettings?: $FlexItemDataSettings
    );

    /**
     * Creates a new subclass of class sap.m.FlexItemData with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.LayoutData.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, FlexItemData>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.FlexItemData.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getAlignSelf alignSelf}.
     *
     * Determines cross-axis alignment of individual element.
     *
     * Default value is `Auto`.
     *
     *
     * @returns Value of property `alignSelf`
     */
    getAlignSelf(): FlexAlignSelf;
    /**
     * Gets current value of property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Defines the background style of the flex item.
     *
     * Default value is `Transparent`.
     *
     * @since 1.38.5
     *
     * @returns Value of property `backgroundDesign`
     */
    getBackgroundDesign(): BackgroundDesign;
    /**
     * Gets current value of property {@link #getBaseSize baseSize}.
     *
     * The base size is the initial main size of the item for the flex algorithm. If set to "auto", this will
     * be the computed size of the item.
     *
     * Default value is `"auto"`.
     *
     * @since 1.32.0
     *
     * @returns Value of property `baseSize`
     */
    getBaseSize(): CSSSize;
    /**
     * Returns the correct FlexBox item DOM reference.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The Element's DOM Element, sub DOM Element or `null`
     */
    getDomRef(
      /**
       * ID suffix to get the DOMRef for
       */
      sSuffix?: string
    ): Element | null;
    /**
     * Gets current value of property {@link #getGrowFactor growFactor}.
     *
     * Determines the flexibility of the flex item when allocatable space is remaining.
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `growFactor`
     */
    getGrowFactor(): float;
    /**
     * Gets current value of property {@link #getMaxHeight maxHeight}.
     *
     * The maximum height of the flex item.
     *
     * Default value is `empty string`.
     *
     * @since 1.36.0
     *
     * @returns Value of property `maxHeight`
     */
    getMaxHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getMaxWidth maxWidth}.
     *
     * The maximum width of the flex item.
     *
     * Default value is `empty string`.
     *
     * @since 1.36.0
     *
     * @returns Value of property `maxWidth`
     */
    getMaxWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getMinHeight minHeight}.
     *
     * The minimum height of the flex item.
     *
     * Default value is `"auto"`.
     *
     * @since 1.36.0
     *
     * @returns Value of property `minHeight`
     */
    getMinHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getMinWidth minWidth}.
     *
     * The minimum width of the flex item.
     *
     * Default value is `"auto"`.
     *
     * @since 1.36.0
     *
     * @returns Value of property `minWidth`
     */
    getMinWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getOrder order}.
     *
     * Determines the display order of flex items independent of their source code order.
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `order`
     */
    getOrder(): int;
    /**
     * Gets current value of property {@link #getShrinkFactor shrinkFactor}.
     *
     * The shrink factor determines how much the flex item will shrink relative to the rest of the flex items
     * in the flex container when negative free space is distributed.
     *
     * Default value is `1`.
     *
     * @since 1.24.0
     *
     * @returns Value of property `shrinkFactor`
     */
    getShrinkFactor(): float;
    /**
     * Gets current value of property {@link #getStyleClass styleClass}.
     *
     * The style class will be applied to the flex item and can be used for CSS selectors.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `styleClass`
     */
    getStyleClass(): string;
    /**
     * Sets the `alignSelf` property.
     *
     *
     * @returns `this` FlexItemData reference for chaining.
     */
    setAlignSelf(
      /**
       * Align option.
       */
      sValue: FlexAlignSelf | keyof typeof FlexAlignSelf
    ): this;
    /**
     * Sets background design for flex items.
     *
     *
     * @returns `this` FlexItemData reference for chaining.
     */
    setBackgroundDesign(
      /**
       * Background design in string format.
       */
      sValue: BackgroundDesign | keyof typeof BackgroundDesign
    ): this;
    /**
     * Sets the base size for flex items.
     *
     *
     * @returns `this` FlexItemData reference for chaining.
     */
    setBaseSize(
      /**
       * Base size in string format.
       */
      sValue: CSSSize
    ): this;
    /**
     * Sets the `growFactor` property.
     *
     *
     * @returns this FlexItemData reference for chaining.
     */
    setGrowFactor(
      /**
       * Grow factor as a number.
       */
      fValue: float
    ): this;
    /**
     * Sets maximum height.
     *
     *
     * @returns `this` FlexItemData reference for chaining.
     */
    setMaxHeight(
      /**
       * Maximum height in string format.
       */
      sValue: CSSSize
    ): this;
    /**
     * Sets maximum width.
     *
     *
     * @returns `this` FlexItemData reference for chaining.
     */
    setMaxWidth(
      /**
       * Maximum width in string format.
       */
      sValue: CSSSize
    ): this;
    /**
     * Sets minimum height.
     *
     *
     * @returns `this` FlexItemData reference for chaining.
     */
    setMinHeight(
      /**
       * Minimum height in string format.
       */
      sValue: CSSSize
    ): this;
    /**
     * Sets minimum width.
     *
     *
     * @returns `this` FlexItemData reference for chaining.
     */
    setMinWidth(
      /**
       * Minimum width in string format.
       */
      sValue: CSSSize
    ): this;
    /**
     * Sets the order.
     *
     *
     * @returns `this` FlexItemData reference for chaining.
     */
    setOrder(
      /**
       * Order in integer format.
       */
      iValue: int
    ): this;
    /**
     * Sets the `shrinkFactor` property.
     * See:
     * 	https://www.w3.org/TR/css-flexbox-1/#propdef-flex-shrink
     *
     *
     * @returns `this` FlexItemData reference for chaining.
     */
    setShrinkFactor(
      /**
       * Shrink factor as a number.
       */
      fValue: float
    ): this;
    /**
     * Sets style class.
     *
     *
     * @returns `this` FlexItemData reference for chaining.
     */
    setStyleClass(
      /**
       * Style class.
       */
      sValue: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the FlexItemData constructor.
   */
  export interface $FlexItemDataSettings extends $LayoutDataSettings {
    /**
     * Determines cross-axis alignment of individual element.
     */
    alignSelf?:
      | (FlexAlignSelf | keyof typeof FlexAlignSelf)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the display order of flex items independent of their source code order.
     */
    order?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the flexibility of the flex item when allocatable space is remaining.
     */
    growFactor?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * The shrink factor determines how much the flex item will shrink relative to the rest of the flex items
     * in the flex container when negative free space is distributed.
     *
     * @since 1.24.0
     */
    shrinkFactor?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * The base size is the initial main size of the item for the flex algorithm. If set to "auto", this will
     * be the computed size of the item.
     *
     * @since 1.32.0
     */
    baseSize?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * The minimum height of the flex item.
     *
     * @since 1.36.0
     */
    minHeight?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * The maximum height of the flex item.
     *
     * @since 1.36.0
     */
    maxHeight?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * The minimum width of the flex item.
     *
     * @since 1.36.0
     */
    minWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * The maximum width of the flex item.
     *
     * @since 1.36.0
     */
    maxWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * The style class will be applied to the flex item and can be used for CSS selectors.
     */
    styleClass?: string | PropertyBindingInfo;

    /**
     * Defines the background style of the flex item.
     *
     * @since 1.38.5
     */
    backgroundDesign?:
      | (BackgroundDesign | keyof typeof BackgroundDesign)
      | PropertyBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/FormattedText" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import Link from "sap/m/Link";

  import {
    AccessibilityInfo,
    CSSSize,
    TextAlign,
    TextDirection,
  } from "sap/ui/core/library";

  import { LinkConversion } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * The FormattedText control allows the usage of a limited set of tags for inline display of formatted text
   * in HTML format.
   *
   * @since 1.38.0
   */
  export default class FormattedText extends Control {
    /**
     * Constructor for a new FormattedText.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $FormattedTextSettings
    );
    /**
     * Constructor for a new FormattedText.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $FormattedTextSettings
    );

    /**
     * Creates a new subclass of class sap.m.FormattedText with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, FormattedText>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.FormattedText.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some control to the aggregation {@link #getControls controls}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addControl(
      /**
       * The control to add; if empty, nothing is inserted
       */
      oControl: Link
    ): this;
    /**
     * Destroys all the controls in the aggregation {@link #getControls controls}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyControls(): this;
    /**
     * Returns the `sap.m.FormattedText` accessibility information.
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The `sap.m.FormattedText` accessibility information
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Gets content of aggregation {@link #getControls controls}.
     *
     * List of `sap.m.Link` controls that will be used to replace the placeholders in the text. Placeholders
     * are replaced according to their indexes. The placeholder with index %%0 will be replaced by the first
     * link in the aggregation, etc.
     */
    getControls(): Link[];
    /**
     * Gets current value of property {@link #getConvertedLinksDefaultTarget convertedLinksDefaultTarget}.
     *
     * Determines the `target` attribute of the generated HTML anchor tags.
     *
     * **Note:** Applicable only if `ConvertLinksToAnchorTags` property is used with a value other than `sap.m.LinkConversion.None`.
     * Options are the standard values for the `target` attribute of the HTML anchor tag: `_self`, `_top`, `_blank`,
     * `_parent`, `_search`.
     *
     * Default value is `"_blank"`.
     *
     * @since 1.45.5
     *
     * @returns Value of property `convertedLinksDefaultTarget`
     */
    getConvertedLinksDefaultTarget(): string;
    /**
     * Gets current value of property {@link #getConvertLinksToAnchorTags convertLinksToAnchorTags}.
     *
     * Determines whether strings that appear to be links will be converted to HTML anchor tags, and what are
     * the criteria for recognizing them.
     *
     * Default value is `None`.
     *
     * @since 1.45.5
     *
     * @returns Value of property `convertLinksToAnchorTags`
     */
    getConvertLinksToAnchorTags(): LinkConversion;
    /**
     * Gets current value of property {@link #getDisableStyleAttribute disableStyleAttribute}.
     *
     * Disables rendering of the `style` attribute in the `FormattedText`.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `disableStyleAttribute`
     */
    getDisableStyleAttribute(): boolean;
    /**
     * Gets current value of property {@link #getHeight height}.
     *
     * Optional height of the control in CSS units.
     *
     *
     * @returns Value of property `height`
     */
    getHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getHtmlText htmlText}.
     *
     * Text in HTML format. The following tags are supported:
     * 	 - `a`
     * 	 - `abbr`
     * 	 - `bdi`
     * 	 - `blockquote`
     * 	 - `br`
     * 	 - `cite`
     * 	 - `code`
     * 	 - `em`
     * 	 - `h1`
     * 	 - `h2`
     * 	 - `h3`
     * 	 - `h4`
     * 	 - `h5`
     * 	 - `h6`
     * 	 - `p`
     * 	 - `pre`
     * 	 - `strong`
     * 	 - `span`
     * 	 - `u`
     * 	 - `dl`
     * 	 - `dt`
     * 	 - `dd`
     * 	 - `ul`
     * 	 - `ol`
     * 	 - `li`  `style, dir` and `target` attributes are allowed. If `target` is not set, links
     *     open in a new window by default. Only safe `href` attributes can be used. See {@link module:sap/base/security/URLListValidator URLListValidator}.
     *
     * **Note:** Keep in mind that not supported HTML tags and the content nested inside them are both not rendered
     * by the control.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `htmlText`
     */
    getHtmlText(): string;
    /**
     * Gets current value of property {@link #getTextAlign textAlign}.
     *
     * Determines the text alignment in the text elements in the `FormattedText`.
     *
     * **Note:** This functionality if set to the root element. To set explicit alignment to an element use
     * the `style` attribute.
     *
     * Default value is `Begin`.
     *
     * @since 1.86.0
     *
     * @returns Value of property `textAlign`
     */
    getTextAlign(): TextAlign;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * Defines the directionality of the text in the `FormattedText`, e.g. right-to-left(`RTL`) or left-to-right
     * (`LTR`).
     *
     * **Note:** This functionality if set to the root element. Use the `bdi` element and the `dir` attribute
     * to set explicit direction to an element.
     *
     * Default value is `Inherit`.
     *
     * @since 1.86.0
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Optional width of the control in CSS units.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Checks for the provided `sap.m.Link` in the aggregation {@link #getControls controls}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfControl(
      /**
       * The control whose index is looked for
       */
      oControl: Link
    ): int;
    /**
     * Inserts a control into the aggregation {@link #getControls controls}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertControl(
      /**
       * The control to insert; if empty, nothing is inserted
       */
      oControl: Link,
      /**
       * The `0`-based index the control should be inserted at; for a negative value of `iIndex`, the control
       * is inserted at position 0; for a value greater than the current size of the aggregation, the control
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getControls controls}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllControls(): Link[];
    /**
     * Removes a control from the aggregation {@link #getControls controls}.
     *
     *
     * @returns The removed control or `null`
     */
    removeControl(
      /**
       * The control to remove or its index or id
       */
      vControl: int | string | Link
    ): Link | null;
    /**
     * Sets a new value for property {@link #getConvertedLinksDefaultTarget convertedLinksDefaultTarget}.
     *
     * Determines the `target` attribute of the generated HTML anchor tags.
     *
     * **Note:** Applicable only if `ConvertLinksToAnchorTags` property is used with a value other than `sap.m.LinkConversion.None`.
     * Options are the standard values for the `target` attribute of the HTML anchor tag: `_self`, `_top`, `_blank`,
     * `_parent`, `_search`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"_blank"`.
     *
     * @since 1.45.5
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setConvertedLinksDefaultTarget(
      /**
       * New value for property `convertedLinksDefaultTarget`
       */
      sConvertedLinksDefaultTarget?: string
    ): this;
    /**
     * Sets a new value for property {@link #getConvertLinksToAnchorTags convertLinksToAnchorTags}.
     *
     * Determines whether strings that appear to be links will be converted to HTML anchor tags, and what are
     * the criteria for recognizing them.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     * @since 1.45.5
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setConvertLinksToAnchorTags(
      /**
       * New value for property `convertLinksToAnchorTags`
       */
      sConvertLinksToAnchorTags?: LinkConversion | keyof typeof LinkConversion
    ): this;
    /**
     * Sets a new value for property {@link #getDisableStyleAttribute disableStyleAttribute}.
     *
     * Disables rendering of the `style` attribute in the `FormattedText`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisableStyleAttribute(
      /**
       * New value for property `disableStyleAttribute`
       */
      bDisableStyleAttribute?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getHeight height}.
     *
     * Optional height of the control in CSS units.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeight(
      /**
       * New value for property `height`
       */
      sHeight?: CSSSize
    ): this;
    /**
     * Defines the HTML text to be displayed.
     *
     *
     * @returns this for chaining
     */
    setHtmlText(
      /**
       * HTML text as a string
       */
      sText: string
    ): this;
    /**
     * Sets a new value for property {@link #getTextAlign textAlign}.
     *
     * Determines the text alignment in the text elements in the `FormattedText`.
     *
     * **Note:** This functionality if set to the root element. To set explicit alignment to an element use
     * the `style` attribute.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Begin`.
     *
     * @since 1.86.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextAlign(
      /**
       * New value for property `textAlign`
       */
      sTextAlign?: TextAlign | keyof typeof TextAlign
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * Defines the directionality of the text in the `FormattedText`, e.g. right-to-left(`RTL`) or left-to-right
     * (`LTR`).
     *
     * **Note:** This functionality if set to the root element. Use the `bdi` element and the `dir` attribute
     * to set explicit direction to an element.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.86.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Optional width of the control in CSS units.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
  }
  /**
   * Describes the settings that can be provided to the FormattedText constructor.
   */
  export interface $FormattedTextSettings extends $ControlSettings {
    /**
     * Text in HTML format. The following tags are supported:
     * 	 - `a`
     * 	 - `abbr`
     * 	 - `bdi`
     * 	 - `blockquote`
     * 	 - `br`
     * 	 - `cite`
     * 	 - `code`
     * 	 - `em`
     * 	 - `h1`
     * 	 - `h2`
     * 	 - `h3`
     * 	 - `h4`
     * 	 - `h5`
     * 	 - `h6`
     * 	 - `p`
     * 	 - `pre`
     * 	 - `strong`
     * 	 - `span`
     * 	 - `u`
     * 	 - `dl`
     * 	 - `dt`
     * 	 - `dd`
     * 	 - `ul`
     * 	 - `ol`
     * 	 - `li`  `style, dir` and `target` attributes are allowed. If `target` is not set, links
     *     open in a new window by default. Only safe `href` attributes can be used. See {@link module:sap/base/security/URLListValidator URLListValidator}.
     *
     * **Note:** Keep in mind that not supported HTML tags and the content nested inside them are both not rendered
     * by the control.
     */
    htmlText?: string | PropertyBindingInfo;

    /**
     * Optional width of the control in CSS units.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether strings that appear to be links will be converted to HTML anchor tags, and what are
     * the criteria for recognizing them.
     *
     * @since 1.45.5
     */
    convertLinksToAnchorTags?:
      | (LinkConversion | keyof typeof LinkConversion)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the `target` attribute of the generated HTML anchor tags.
     *
     * **Note:** Applicable only if `ConvertLinksToAnchorTags` property is used with a value other than `sap.m.LinkConversion.None`.
     * Options are the standard values for the `target` attribute of the HTML anchor tag: `_self`, `_top`, `_blank`,
     * `_parent`, `_search`.
     *
     * @since 1.45.5
     */
    convertedLinksDefaultTarget?: string | PropertyBindingInfo;

    /**
     * Optional height of the control in CSS units.
     */
    height?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the directionality of the text in the `FormattedText`, e.g. right-to-left(`RTL`) or left-to-right
     * (`LTR`).
     *
     * **Note:** This functionality if set to the root element. Use the `bdi` element and the `dir` attribute
     * to set explicit direction to an element.
     *
     * @since 1.86.0
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the text alignment in the text elements in the `FormattedText`.
     *
     * **Note:** This functionality if set to the root element. To set explicit alignment to an element use
     * the `style` attribute.
     *
     * @since 1.86.0
     */
    textAlign?:
      | (TextAlign | keyof typeof TextAlign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Disables rendering of the `style` attribute in the `FormattedText`.
     */
    disableStyleAttribute?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * List of `sap.m.Link` controls that will be used to replace the placeholders in the text. Placeholders
     * are replaced according to their indexes. The placeholder with index %%0 will be replaced by the first
     * link in the aggregation, etc.
     */
    controls?: Link[] | Link | AggregationBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/GenericTag" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IOverflowToolbarContent,
    IToolbarInteractiveControl,
    GenericTagDesign,
    OverflowToolbarConfig,
    GenericTagValueState,
  } from "sap/m/library";

  import { ID, ValueState } from "sap/ui/core/library";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import ObjectNumber from "sap/m/ObjectNumber";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The `sap.m.GenericTag` control displays app-specific, essential information. Structure: The control consists
   * of four different parts:
   * 	 - Status indicator with semantic colors (required)
   * 	 - Icon that is displayed in the same color as the status indicator (optional)
   * 	 - Text that is truncated automatically (required)
   * 	 - Content area that can display either a control of type {@link sap.m.ObjectNumber} or a warning icon
   *     (optional)
   *
   * @since 1.62.0
   */
  export default class GenericTag
    extends Control
    implements IOverflowToolbarContent, IToolbarInteractiveControl
  {
    __implements__sap_m_IOverflowToolbarContent: boolean;
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new `sap.m.GenericTag`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $GenericTagSettings
    );
    /**
     * Constructor for a new `sap.m.GenericTag`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $GenericTagSettings
    );

    /**
     * Creates a new subclass of class sap.m.GenericTag with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, GenericTag>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.GenericTag.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.97.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.GenericTag`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.GenericTag` itself.
     *
     * Fired when the user clicks/taps on the control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.GenericTag` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.GenericTag`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.GenericTag` itself.
     *
     * Fired when the user clicks/taps on the control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.GenericTag` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys the value in the aggregation {@link #getValue value}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyValue(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.GenericTag`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.97.0
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getDesign design}.
     *
     * Determines the visual mode of the control.
     *
     * Default value is `Full`.
     *
     *
     * @returns Value of property `design`
     */
    getDesign(): GenericTagDesign;
    /**
     * Sets the behavior of the `GenericTag` inside an `OverflowToolbar` configuration. Required by the {@link sap.m.IOverflowToolbarContent }
     * interface.
     *
     *
     * @returns Configuration information for the `sap.m.IOverflowToolbarContent` interface.
     */
    getOverflowToolbarConfig(): OverflowToolbarConfig;
    /**
     * Gets current value of property {@link #getStatus status}.
     *
     * Determines the control status that is represented in different colors, including the color bar and the
     * color and type of the displayed icon.
     *
     * Default value is `None`.
     *
     *
     * @returns Value of property `status`
     */
    getStatus(): ValueState;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Defines the text rendered by the control. It's a value-descriptive text rendered on one line.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets content of aggregation {@link #getValue value}.
     *
     * Numeric value rendered by the control.
     */
    getValue(): ObjectNumber;
    /**
     * Gets current value of property {@link #getValueState valueState}.
     *
     * Determines the state of the control.
     *
     * **Note:** When the error state is set, a warning type of icon is displayed that overrides the control
     * set through the `value` aggregation.
     *
     * Default value is `None`.
     *
     *
     * @returns Value of property `valueState`
     */
    getValueState(): GenericTagValueState;
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.97.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.97.0
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getDesign design}.
     *
     * Determines the visual mode of the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Full`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDesign(
      /**
       * New value for property `design`
       */
      sDesign?: GenericTagDesign | keyof typeof GenericTagDesign
    ): this;
    /**
     * Sets the `status` property.
     *
     * Default value is `None`.
     *
     *
     * @returns `this` to allow method chaining.
     */
    setStatus(
      /**
       * New value for property `status`.
       */
      sStatus: ValueState | keyof typeof ValueState
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Defines the text rendered by the control. It's a value-descriptive text rendered on one line.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets the aggregated {@link #getValue value}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValue(
      /**
       * The value to set
       */
      oValue: ObjectNumber
    ): this;
    /**
     * Sets a new value for property {@link #getValueState valueState}.
     *
     * Determines the state of the control.
     *
     * **Note:** When the error state is set, a warning type of icon is displayed that overrides the control
     * set through the `value` aggregation.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueState(
      /**
       * New value for property `valueState`
       */
      sValueState?: GenericTagValueState | keyof typeof GenericTagValueState
    ): this;
  }
  /**
   * Describes the settings that can be provided to the GenericTag constructor.
   */
  export interface $GenericTagSettings extends $ControlSettings {
    /**
     * Defines the text rendered by the control. It's a value-descriptive text rendered on one line.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Determines the control status that is represented in different colors, including the color bar and the
     * color and type of the displayed icon.
     */
    status?:
      | (ValueState | keyof typeof ValueState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the visual mode of the control.
     */
    design?:
      | (GenericTagDesign | keyof typeof GenericTagDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the state of the control.
     *
     * **Note:** When the error state is set, a warning type of icon is displayed that overrides the control
     * set through the `value` aggregation.
     */
    valueState?:
      | (GenericTagValueState | keyof typeof GenericTagValueState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Numeric value rendered by the control.
     */
    value?: ObjectNumber;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledBy).
     *
     * @since 1.97.0
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Fired when the user clicks/taps on the control.
     */
    press?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the GenericTag#press event.
   */
  export interface GenericTag$PressEventParameters {}

  /**
   * Event object of the GenericTag#press event.
   */
  export type GenericTag$PressEvent = Event<
    GenericTag$PressEventParameters,
    GenericTag
  >;
}

declare module "sap/m/GenericTile" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import Button from "sap/m/Button";

  import LinkTileContent from "sap/m/LinkTileContent";

  import TileContent from "sap/m/TileContent";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import { URI, CSSSize } from "sap/ui/core/library";

  import TileInfo from "sap/m/TileInfo";

  import {
    FrameType,
    GenericTileMode,
    GenericTileScope,
    Size,
    TileSizeBehavior,
    LoadState,
    ValueColor,
    WrappingType,
  } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Event from "sap/ui/base/Event";

  /**
   * Displays header, subheader, and a customizable main area in a tile format. Since 1.44, also an in-line
   * format which contains only header and subheader is supported.
   *
   * @since 1.34.0
   */
  export default class GenericTile
    extends Control
    implements /* was: sap.f.IGridContainerItem */ Object
  {
    __implements__sap_f_IGridContainerItem: boolean;
    /**
     * Constructor for a new sap.m.GenericTile control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $GenericTileSettings
    );
    /**
     * Constructor for a new sap.m.GenericTile control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $GenericTileSettings
    );

    /**
     * Creates a new subclass of class sap.m.GenericTile with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, GenericTile>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.GenericTile.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some actionButton to the aggregation {@link #getActionButtons actionButtons}.
     *
     * @since 1.96
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addActionButton(
      /**
       * The actionButton to add; if empty, nothing is inserted
       */
      oActionButton: Button
    ): this;
    /**
     * Adds some linkTileContent to the aggregation {@link #getLinkTileContents linkTileContents}.
     *
     * @since 1.120
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addLinkTileContent(
      /**
       * The linkTileContent to add; if empty, nothing is inserted
       */
      oLinkTileContent: LinkTileContent
    ): this;
    /**
     * Adds some tileContent to the aggregation {@link #getTileContent tileContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addTileContent(
      /**
       * The tileContent to add; if empty, nothing is inserted
       */
      oTileContent: TileContent
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.GenericTile`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.GenericTile` itself.
     *
     * The event is triggered when the user presses the tile.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: GenericTile$PressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.GenericTile` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.GenericTile`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.GenericTile` itself.
     *
     * The event is triggered when the user presses the tile.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: GenericTile$PressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.GenericTile` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getActionButtons actionButtons} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     * @since 1.96
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindActionButtons(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Binds aggregation {@link #getBadge badge} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     * @since 1.124
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindBadge(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Binds aggregation {@link #getTileContent tileContent} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindTileContent(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the actionButtons in the aggregation {@link #getActionButtons actionButtons}.
     *
     * @since 1.96
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyActionButtons(): this;
    /**
     * Destroys the badge in the aggregation {@link #getBadge badge}.
     *
     * @since 1.124
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyBadge(): this;
    /**
     * Destroys the icon in the aggregation {@link #getIcon icon}.
     *
     * @deprecated As of version 1.36.0. This aggregation is deprecated, use sap.m.ImageContent control to display
     * an icon instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyIcon(): this;
    /**
     * Destroys all the linkTileContents in the aggregation {@link #getLinkTileContents linkTileContents}.
     *
     * @since 1.120
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyLinkTileContents(): this;
    /**
     * Destroys all the tileContent in the aggregation {@link #getTileContent tileContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyTileContent(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.GenericTile`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: GenericTile$PressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: GenericTile$PressEventParameters
    ): this;
    /**
     * Gets content of aggregation {@link #getActionButtons actionButtons}.
     *
     * Action buttons added in ActionMode.
     *
     * @since 1.96
     */
    getActionButtons(): Button[];
    /**
     * Gets current value of property {@link #getAdditionalTooltip additionalTooltip}.
     *
     * Tooltip text which is added at the tooltip generated by the control.
     *
     * @since 1.82
     *
     * @returns Value of property `additionalTooltip`
     */
    getAdditionalTooltip(): string;
    /**
     * Gets current value of property {@link #getAppShortcut appShortcut}.
     *
     * Application information such as ID/Shortcut
     *
     * @since 1.92.0
     *
     * @returns Value of property `appShortcut`
     */
    getAppShortcut(): string;
    /**
     * Gets current value of property {@link #getAriaLabel ariaLabel}.
     *
     * Additional description for aria-label. The aria-label is rendered before the standard aria-label.
     *
     * @since 1.50.0
     *
     * @returns Value of property `ariaLabel`
     */
    getAriaLabel(): string;
    /**
     * Gets current value of property {@link #getAriaRole ariaRole}.
     *
     * Additional description for aria-role. *Note:** When the control is placed inside a `sap.f.GridContainer`,
     * its accessibility role is overridden by the accessibility role specified by the `sap.f.GridContainer`.
     *
     * @since 1.83
     *
     * @returns Value of property `ariaRole`
     */
    getAriaRole(): string;
    /**
     * Gets current value of property {@link #getAriaRoleDescription ariaRoleDescription}.
     *
     * Additional description for aria-roledescription.
     *
     * @since 1.83
     *
     * @returns Value of property `ariaRoleDescription`
     */
    getAriaRoleDescription(): string;
    /**
     * Gets current value of property {@link #getBackgroundColor backgroundColor}.
     *
     * Background color of the GenericTile. Only applicable for IconMode.
     *
     * Default value is `...see text or source`.
     *
     * @since 1.96
     *
     * @returns Value of property `backgroundColor`
     */
    getBackgroundColor(): string;
    /**
     * Gets current value of property {@link #getBackgroundImage backgroundImage}.
     *
     * The URI of the background image.
     *
     *
     * @returns Value of property `backgroundImage`
     */
    getBackgroundImage(): URI;
    /**
     * Gets content of aggregation {@link #getBadge badge}.
     *
     * A badge that is attached to the GenericTile.
     *
     * @since 1.124
     */
    getBadge(): TileInfo;
    /**
     * Provides an interface to the tile's layout information consistent in all modes and content densities.
     *
     * @since 1.44.1
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns An array containing all of the tile's bounding rectangles
     */
    getBoundingRects(): object[];
    /**
     * Gets current value of property {@link #getEnableNavigationButton enableNavigationButton}.
     *
     * Renders the given link as a button, enabling the option of opening the link in new tab/window functionality.
     * Works only in ArticleMode.
     *
     * Default value is `false`.
     *
     * @since 1.96
     *
     * @returns Value of property `enableNavigationButton`
     */
    getEnableNavigationButton(): boolean;
    /**
     * Gets current value of property {@link #getFailedText failedText}.
     *
     * The message that appears when the control is in the Failed state.
     *
     *
     * @returns Value of property `failedText`
     */
    getFailedText(): string;
    /**
     * Gets current value of property {@link #getFrameType frameType}.
     *
     * The FrameType: OneByOne, TwoByOne, OneByHalf, or TwoByHalf. Default set to OneByOne if property is not
     * defined or set to Auto by the app.
     *
     * Default value is `OneByOne`.
     *
     *
     * @returns Value of property `frameType`
     */
    getFrameType(): FrameType;
    /**
     * Returns the accessibility role for the `sap.f.GridContainer` item.
     *
     *
     * @returns The accessibility role for the `sap.f.GridContainer` item
     */
    getGridItemRole(): string;
    /**
     * Gets current value of property {@link #getHeader header}.
     *
     * The header of the tile.
     *
     *
     * @returns Value of property `header`
     */
    getHeader(): string;
    /**
     * Gets current value of property {@link #getHeaderImage headerImage}.
     *
     * The image to be displayed as a graphical element within the header. This can be an image or an icon from
     * the icon font.
     *
     *
     * @returns Value of property `headerImage`
     */
    getHeaderImage(): URI;
    /**
     * Gets content of aggregation {@link #getIcon icon}.
     *
     * An icon or image to be displayed in the control. This aggregation is deprecated since version 1.36.0,
     * to display an icon or image use sap.m.ImageContent control instead.
     *
     * @deprecated As of version 1.36.0. This aggregation is deprecated, use sap.m.ImageContent control to display
     * an icon instead.
     */
    getIcon(): Control;
    /**
     * Gets current value of property {@link #getIconLoaded iconLoaded}.
     *
     * The load state of the tileIcon.
     *
     * Default value is `true`.
     *
     * @since 1.103
     *
     * @returns Value of property `iconLoaded`
     */
    getIconLoaded(): boolean;
    /**
     * Gets current value of property {@link #getImageDescription imageDescription}.
     *
     * Description of a header image that is used in the tooltip.
     *
     *
     * @returns Value of property `imageDescription`
     */
    getImageDescription(): string;
    /**
     * Gets content of aggregation {@link #getLinkTileContents linkTileContents}.
     *
     * LinkTileContent is being added to the GenericTile, it is advised to use in TwoByOne frameType
     *
     * @since 1.120
     */
    getLinkTileContents(): LinkTileContent[];
    /**
     * Gets current value of property {@link #getMode mode}.
     *
     * The mode of the GenericTile.
     *
     * Default value is `ContentMode`.
     *
     *
     * @returns Value of property `mode`
     */
    getMode(): GenericTileMode;
    /**
     * Gets current value of property {@link #getNavigationButtonText navigationButtonText}.
     *
     * Text for navigate action button. Default Value is "Read More". Works only in ArticleMode.
     *
     * @since 1.96
     *
     * @returns Value of property `navigationButtonText`
     */
    getNavigationButtonText(): string;
    /**
     * Gets current value of property {@link #getPressEnabled pressEnabled}.
     *
     * Disables press event for the tile control.
     *
     * Default value is `true`.
     *
     * @since 1.96
     *
     * @returns Value of property `pressEnabled`
     */
    getPressEnabled(): boolean;
    /**
     * Gets current value of property {@link #getRenderOnThemeChange renderOnThemeChange}.
     *
     * The Tile rerenders on theme change.
     *
     * Default value is `false`.
     *
     * @since 1.106
     *
     * @returns Value of property `renderOnThemeChange`
     */
    getRenderOnThemeChange(): boolean;
    /**
     * Gets current value of property {@link #getScope scope}.
     *
     * Changes the visualization in order to enable additional actions with the Generic Tile.
     *
     * Default value is `Display`.
     *
     * @since 1.46.0
     *
     * @returns Value of property `scope`
     */
    getScope(): GenericTileScope;
    /**
     * Gets current value of property {@link #getSize size}.
     *
     * The size of the tile. If not set, then the default size is applied based on the device.
     *
     * Default value is `Auto`.
     *
     * @deprecated As of version 1.38.0. The GenericTile control has now a fixed size, depending on the used
     * media (desktop, tablet or phone).
     *
     * @returns Value of property `size`
     */
    getSize(): Size;
    /**
     * Gets current value of property {@link #getSizeBehavior sizeBehavior}.
     *
     * If set to `TileSizeBehavior.Small`, the tile size is the same as it would be on a small-screened phone
     * (374px wide and lower), regardless of the screen size of the actual device being used. If set to `TileSizeBehavior.Responsive`,
     * the tile size adapts to the size of the screen.
     *
     * Default value is `Responsive`.
     *
     *
     * @returns Value of property `sizeBehavior`
     */
    getSizeBehavior(): TileSizeBehavior;
    /**
     * Gets current value of property {@link #getState state}.
     *
     * The load status.
     *
     * Default value is `Loaded`.
     *
     *
     * @returns Value of property `state`
     */
    getState(): LoadState;
    /**
     * Gets current value of property {@link #getSubheader subheader}.
     *
     * The subheader of the tile.
     *
     *
     * @returns Value of property `subheader`
     */
    getSubheader(): string;
    /**
     * Gets current value of property {@link #getSystemInfo systemInfo}.
     *
     * Backend system context information
     *
     * @since 1.92.0
     *
     * @returns Value of property `systemInfo`
     */
    getSystemInfo(): string;
    /**
     * Gets current value of property {@link #getTileBadge tileBadge}.
     *
     * Show Badge Information associated with a Tile. Limited to 3 characters. When enabled, the badge information
     * is displayed inside a folder icon. Display limited only for tile in IconMode in TwoByHalf frameType.
     * Characters currently trimmed to 3.
     *
     * Default value is `empty string`.
     *
     * @since 1.113
     *
     * @returns Value of property `tileBadge`
     */
    getTileBadge(): string;
    /**
     * Gets content of aggregation {@link #getTileContent tileContent}.
     *
     * The content of the tile.
     */
    getTileContent(): TileContent[];
    /**
     * Gets current value of property {@link #getTileIcon tileIcon}.
     *
     * Icon of the GenericTile. Only applicable for IconMode.
     *
     * @since 1.96
     *
     * @returns Value of property `tileIcon`
     */
    getTileIcon(): URI;
    /**
     * Gets current value of property {@link #getUrl url}.
     *
     * Renders the given link as root element and therefore enables the open in new tab / window functionality
     *
     * @since 1.76
     *
     * @returns Value of property `url`
     */
    getUrl(): URI;
    /**
     * Gets current value of property {@link #getValueColor valueColor}.
     *
     * The semantic color of the value.
     *
     * Default value is `"None"`.
     *
     * @since 1.95
     *
     * @returns Value of property `valueColor`
     */
    getValueColor(): ValueColor;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Width of the control.
     *
     * @since 1.72
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getWrappingType wrappingType}.
     *
     * Defines the type of text wrapping to be used (hyphenated or normal).
     *
     * Default value is `Normal`.
     *
     * @since 1.60
     *
     * @returns Value of property `wrappingType`
     */
    getWrappingType(): WrappingType;
    /**
     * Checks for the provided `sap.m.Button` in the aggregation {@link #getActionButtons actionButtons}. and
     * returns its index if found or -1 otherwise.
     *
     * @since 1.96
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfActionButton(
      /**
       * The actionButton whose index is looked for
       */
      oActionButton: Button
    ): int;
    /**
     * Checks for the provided `sap.m.LinkTileContent` in the aggregation {@link #getLinkTileContents linkTileContents}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.120
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfLinkTileContent(
      /**
       * The linkTileContent whose index is looked for
       */
      oLinkTileContent: LinkTileContent
    ): int;
    /**
     * Checks for the provided `sap.m.TileContent` in the aggregation {@link #getTileContent tileContent}. and
     * returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfTileContent(
      /**
       * The tileContent whose index is looked for
       */
      oTileContent: TileContent
    ): int;
    /**
     * Inserts a actionButton into the aggregation {@link #getActionButtons actionButtons}.
     *
     * @since 1.96
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertActionButton(
      /**
       * The actionButton to insert; if empty, nothing is inserted
       */
      oActionButton: Button,
      /**
       * The `0`-based index the actionButton should be inserted at; for a negative value of `iIndex`, the actionButton
       * is inserted at position 0; for a value greater than the current size of the aggregation, the actionButton
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a linkTileContent into the aggregation {@link #getLinkTileContents linkTileContents}.
     *
     * @since 1.120
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertLinkTileContent(
      /**
       * The linkTileContent to insert; if empty, nothing is inserted
       */
      oLinkTileContent: LinkTileContent,
      /**
       * The `0`-based index the linkTileContent should be inserted at; for a negative value of `iIndex`, the
       * linkTileContent is inserted at position 0; for a value greater than the current size of the aggregation,
       * the linkTileContent is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a tileContent into the aggregation {@link #getTileContent tileContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertTileContent(
      /**
       * The tileContent to insert; if empty, nothing is inserted
       */
      oTileContent: TileContent,
      /**
       * The `0`-based index the tileContent should be inserted at; for a negative value of `iIndex`, the tileContent
       * is inserted at position 0; for a value greater than the current size of the aggregation, the tileContent
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes a actionButton from the aggregation {@link #getActionButtons actionButtons}.
     *
     * @since 1.96
     *
     * @returns The removed actionButton or `null`
     */
    removeActionButton(
      /**
       * The actionButton to remove or its index or id
       */
      vActionButton: int | string | Button
    ): Button | null;
    /**
     * Removes all the controls from the aggregation {@link #getActionButtons actionButtons}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.96
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllActionButtons(): Button[];
    /**
     * Removes all the controls from the aggregation {@link #getLinkTileContents linkTileContents}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.120
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllLinkTileContents(): LinkTileContent[];
    /**
     * Removes all the controls from the aggregation {@link #getTileContent tileContent}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllTileContent(): TileContent[];
    /**
     * Removes a linkTileContent from the aggregation {@link #getLinkTileContents linkTileContents}.
     *
     * @since 1.120
     *
     * @returns The removed linkTileContent or `null`
     */
    removeLinkTileContent(
      /**
       * The linkTileContent to remove or its index or id
       */
      vLinkTileContent: int | string | LinkTileContent
    ): LinkTileContent | null;
    /**
     * Removes a tileContent from the aggregation {@link #getTileContent tileContent}.
     *
     *
     * @returns The removed tileContent or `null`
     */
    removeTileContent(
      /**
       * The tileContent to remove or its index or id
       */
      vTileContent: int | string | TileContent
    ): TileContent | null;
    /**
     * Sets a new value for property {@link #getAdditionalTooltip additionalTooltip}.
     *
     * Tooltip text which is added at the tooltip generated by the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.82
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAdditionalTooltip(
      /**
       * New value for property `additionalTooltip`
       */
      sAdditionalTooltip?: string
    ): this;
    /**
     * Sets a new value for property {@link #getAppShortcut appShortcut}.
     *
     * Application information such as ID/Shortcut
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.92.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAppShortcut(
      /**
       * New value for property `appShortcut`
       */
      sAppShortcut?: string
    ): this;
    /**
     * Sets a new value for property {@link #getAriaLabel ariaLabel}.
     *
     * Additional description for aria-label. The aria-label is rendered before the standard aria-label.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.50.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAriaLabel(
      /**
       * New value for property `ariaLabel`
       */
      sAriaLabel?: string
    ): this;
    /**
     * Sets a new value for property {@link #getAriaRole ariaRole}.
     *
     * Additional description for aria-role. *Note:** When the control is placed inside a `sap.f.GridContainer`,
     * its accessibility role is overridden by the accessibility role specified by the `sap.f.GridContainer`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.83
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAriaRole(
      /**
       * New value for property `ariaRole`
       */
      sAriaRole?: string
    ): this;
    /**
     * Sets a new value for property {@link #getAriaRoleDescription ariaRoleDescription}.
     *
     * Additional description for aria-roledescription.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.83
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAriaRoleDescription(
      /**
       * New value for property `ariaRoleDescription`
       */
      sAriaRoleDescription?: string
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundColor backgroundColor}.
     *
     * Background color of the GenericTile. Only applicable for IconMode.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `...see text or source`.
     *
     * @since 1.96
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundColor(
      /**
       * New value for property `backgroundColor`
       */
      sBackgroundColor?: string
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundImage backgroundImage}.
     *
     * The URI of the background image.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundImage(
      /**
       * New value for property `backgroundImage`
       */
      sBackgroundImage?: URI
    ): this;
    /**
     * Sets the aggregated {@link #getBadge badge}.
     *
     * @since 1.124
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBadge(
      /**
       * The badge to set
       */
      oBadge: TileInfo
    ): this;
    /**
     * Sets a new value for property {@link #getEnableNavigationButton enableNavigationButton}.
     *
     * Renders the given link as a button, enabling the option of opening the link in new tab/window functionality.
     * Works only in ArticleMode.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.96
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableNavigationButton(
      /**
       * New value for property `enableNavigationButton`
       */
      bEnableNavigationButton?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getFailedText failedText}.
     *
     * The message that appears when the control is in the Failed state.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFailedText(
      /**
       * New value for property `failedText`
       */
      sFailedText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getFrameType frameType}.
     *
     * The FrameType: OneByOne, TwoByOne, OneByHalf, or TwoByHalf. Default set to OneByOne if property is not
     * defined or set to Auto by the app.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `OneByOne`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFrameType(
      /**
       * New value for property `frameType`
       */
      sFrameType?: FrameType | keyof typeof FrameType
    ): this;
    /**
     * Sets a new value for property {@link #getHeader header}.
     *
     * The header of the tile.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeader(
      /**
       * New value for property `header`
       */
      sHeader?: string
    ): this;
    /**
     * Sets a new value for property {@link #getHeaderImage headerImage}.
     *
     * The image to be displayed as a graphical element within the header. This can be an image or an icon from
     * the icon font.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeaderImage(
      /**
       * New value for property `headerImage`
       */
      sHeaderImage?: URI
    ): this;
    /**
     * Sets the aggregated {@link #getIcon icon}.
     *
     * @deprecated As of version 1.36.0. This aggregation is deprecated, use sap.m.ImageContent control to display
     * an icon instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * The icon to set
       */
      oIcon: Control
    ): this;
    /**
     * Sets a new value for property {@link #getIconLoaded iconLoaded}.
     *
     * The load state of the tileIcon.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.103
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconLoaded(
      /**
       * New value for property `iconLoaded`
       */
      bIconLoaded?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getImageDescription imageDescription}.
     *
     * Description of a header image that is used in the tooltip.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setImageDescription(
      /**
       * New value for property `imageDescription`
       */
      sImageDescription?: string
    ): this;
    /**
     * Sets a new value for property {@link #getMode mode}.
     *
     * The mode of the GenericTile.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `ContentMode`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMode(
      /**
       * New value for property `mode`
       */
      sMode?: GenericTileMode | keyof typeof GenericTileMode
    ): this;
    /**
     * Sets a new value for property {@link #getNavigationButtonText navigationButtonText}.
     *
     * Text for navigate action button. Default Value is "Read More". Works only in ArticleMode.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.96
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNavigationButtonText(
      /**
       * New value for property `navigationButtonText`
       */
      sNavigationButtonText?: string
    ): this;
    /**
     * Provides an interface to switch on or off the tile's press event. Used in SlideTile for Actions scope.
     *
     * @since 1.46
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    setPressEnabled(
      /**
       * If set to true, the press event of the tile is active.
       */
      value: boolean
    ): void;
    /**
     * Sets a new value for property {@link #getRenderOnThemeChange renderOnThemeChange}.
     *
     * The Tile rerenders on theme change.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.106
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRenderOnThemeChange(
      /**
       * New value for property `renderOnThemeChange`
       */
      bRenderOnThemeChange?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getScope scope}.
     *
     * Changes the visualization in order to enable additional actions with the Generic Tile.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Display`.
     *
     * @since 1.46.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setScope(
      /**
       * New value for property `scope`
       */
      sScope?: GenericTileScope | keyof typeof GenericTileScope
    ): this;
    /**
     * Sets a new value for property {@link #getSize size}.
     *
     * The size of the tile. If not set, then the default size is applied based on the device.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     * @deprecated As of version 1.38.0. The GenericTile control has now a fixed size, depending on the used
     * media (desktop, tablet or phone).
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSize(
      /**
       * New value for property `size`
       */
      sSize?: Size | keyof typeof Size
    ): this;
    /**
     * Sets a new value for property {@link #getSizeBehavior sizeBehavior}.
     *
     * If set to `TileSizeBehavior.Small`, the tile size is the same as it would be on a small-screened phone
     * (374px wide and lower), regardless of the screen size of the actual device being used. If set to `TileSizeBehavior.Responsive`,
     * the tile size adapts to the size of the screen.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Responsive`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSizeBehavior(
      /**
       * New value for property `sizeBehavior`
       */
      sSizeBehavior?: TileSizeBehavior | keyof typeof TileSizeBehavior
    ): this;
    /**
     * Sets a new value for property {@link #getState state}.
     *
     * The load status.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Loaded`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setState(
      /**
       * New value for property `state`
       */
      sState?: LoadState | keyof typeof LoadState
    ): this;
    /**
     * Sets a new value for property {@link #getSubheader subheader}.
     *
     * The subheader of the tile.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSubheader(
      /**
       * New value for property `subheader`
       */
      sSubheader?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSystemInfo systemInfo}.
     *
     * Backend system context information
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.92.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSystemInfo(
      /**
       * New value for property `systemInfo`
       */
      sSystemInfo?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTileBadge tileBadge}.
     *
     * Show Badge Information associated with a Tile. Limited to 3 characters. When enabled, the badge information
     * is displayed inside a folder icon. Display limited only for tile in IconMode in TwoByHalf frameType.
     * Characters currently trimmed to 3.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.113
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTileBadge(
      /**
       * New value for property `tileBadge`
       */
      sTileBadge?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTileIcon tileIcon}.
     *
     * Icon of the GenericTile. Only applicable for IconMode.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.96
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTileIcon(
      /**
       * New value for property `tileIcon`
       */
      sTileIcon: URI
    ): this;
    /**
     * Sets a new value for property {@link #getUrl url}.
     *
     * Renders the given link as root element and therefore enables the open in new tab / window functionality
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.76
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUrl(
      /**
       * New value for property `url`
       */
      sUrl?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getValueColor valueColor}.
     *
     * The semantic color of the value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"None"`.
     *
     * @since 1.95
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueColor(
      /**
       * New value for property `valueColor`
       */
      sValueColor?: ValueColor | keyof typeof ValueColor
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Width of the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.72
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getWrappingType wrappingType}.
     *
     * Defines the type of text wrapping to be used (hyphenated or normal).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Normal`.
     *
     * @since 1.60
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWrappingType(
      /**
       * New value for property `wrappingType`
       */
      sWrappingType?: WrappingType | keyof typeof WrappingType
    ): this;
    /**
     * Shows the actions scope view of GenericTile without changing the scope. Used in SlideTile for Actions
     * scope.
     *
     * @since 1.46
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    showActionsView(
      /**
       * If set to true, actions view is showed.
       */
      value: boolean
    ): void;
    /**
     * Unbinds aggregation {@link #getActionButtons actionButtons} from model data.
     *
     * @since 1.96
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindActionButtons(): this;
    /**
     * Unbinds aggregation {@link #getBadge badge} from model data.
     *
     * @since 1.124
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindBadge(): this;
    /**
     * Unbinds aggregation {@link #getTileContent tileContent} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindTileContent(): this;
  }
  /**
   * Describes the settings that can be provided to the GenericTile constructor.
   */
  export interface $GenericTileSettings extends $ControlSettings {
    /**
     * The mode of the GenericTile.
     */
    mode?:
      | (GenericTileMode | keyof typeof GenericTileMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The header of the tile.
     */
    header?: string | PropertyBindingInfo;

    /**
     * The subheader of the tile.
     */
    subheader?: string | PropertyBindingInfo;

    /**
     * The message that appears when the control is in the Failed state.
     */
    failedText?: string | PropertyBindingInfo;

    /**
     * The size of the tile. If not set, then the default size is applied based on the device.
     *
     * @deprecated As of version 1.38.0. The GenericTile control has now a fixed size, depending on the used
     * media (desktop, tablet or phone).
     */
    size?: (Size | keyof typeof Size) | PropertyBindingInfo | `{${string}}`;

    /**
     * The FrameType: OneByOne, TwoByOne, OneByHalf, or TwoByHalf. Default set to OneByOne if property is not
     * defined or set to Auto by the app.
     */
    frameType?:
      | (FrameType | keyof typeof FrameType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Backend system context information
     *
     * @since 1.92.0
     */
    systemInfo?: string | PropertyBindingInfo;

    /**
     * Application information such as ID/Shortcut
     *
     * @since 1.92.0
     */
    appShortcut?: string | PropertyBindingInfo;

    /**
     * The URI of the background image.
     */
    backgroundImage?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * The image to be displayed as a graphical element within the header. This can be an image or an icon from
     * the icon font.
     */
    headerImage?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * The load status.
     */
    state?:
      | (LoadState | keyof typeof LoadState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Description of a header image that is used in the tooltip.
     */
    imageDescription?: string | PropertyBindingInfo;

    /**
     * Changes the visualization in order to enable additional actions with the Generic Tile.
     *
     * @since 1.46.0
     */
    scope?:
      | (GenericTileScope | keyof typeof GenericTileScope)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * If set to `TileSizeBehavior.Small`, the tile size is the same as it would be on a small-screened phone
     * (374px wide and lower), regardless of the screen size of the actual device being used. If set to `TileSizeBehavior.Responsive`,
     * the tile size adapts to the size of the screen.
     */
    sizeBehavior?:
      | (TileSizeBehavior | keyof typeof TileSizeBehavior)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Additional description for aria-label. The aria-label is rendered before the standard aria-label.
     *
     * @since 1.50.0
     */
    ariaLabel?: string | PropertyBindingInfo;

    /**
     * Additional description for aria-role.
     *
     * **Note:** When the control is placed inside a `sap.f.GridContainer`, its accessibility role is overridden
     * by the accessibility role specified by the `sap.f.GridContainer`.
     *
     * @since 1.83
     */
    ariaRole?: string | PropertyBindingInfo;

    /**
     * Additional description for aria-roledescription.
     *
     * @since 1.83
     */
    ariaRoleDescription?: string | PropertyBindingInfo;

    /**
     * Renders the given link as root element and therefore enables the open in new tab / window functionality
     *
     * @since 1.76
     */
    url?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Renders the given link as a button, enabling the option of opening the link in new tab/window functionality.
     * Works only in ArticleMode.
     *
     * @since 1.96
     */
    enableNavigationButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Disables press event for the tile control.
     *
     * @since 1.96
     */
    pressEnabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Text for navigate action button. Default Value is "Read More". Works only in ArticleMode.
     *
     * @since 1.96
     */
    navigationButtonText?: string | PropertyBindingInfo;

    /**
     * Defines the type of text wrapping to be used (hyphenated or normal).
     *
     * @since 1.60
     */
    wrappingType?:
      | (WrappingType | keyof typeof WrappingType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Width of the control.
     *
     * @since 1.72
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Tooltip text which is added at the tooltip generated by the control.
     *
     * @since 1.82
     */
    additionalTooltip?: string | PropertyBindingInfo;

    /**
     * Icon of the GenericTile. Only applicable for IconMode.
     *
     * @since 1.96
     */
    tileIcon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Background color of the GenericTile. Only applicable for IconMode.
     *
     * @since 1.96
     */
    backgroundColor?: string | PropertyBindingInfo;

    /**
     * The semantic color of the value.
     *
     * @since 1.95
     */
    valueColor?:
      | (ValueColor | keyof typeof ValueColor)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The load state of the tileIcon.
     *
     * @since 1.103
     */
    iconLoaded?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The Tile rerenders on theme change.
     *
     * @since 1.106
     */
    renderOnThemeChange?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Show Badge Information associated with a Tile. Limited to 3 characters. When enabled, the badge information
     * is displayed inside a folder icon. Display limited only for tile in IconMode in TwoByHalf frameType.
     * Characters currently trimmed to 3.
     *
     * @since 1.113
     */
    tileBadge?: string | PropertyBindingInfo;

    /**
     * The content of the tile.
     */
    tileContent?:
      | TileContent[]
      | TileContent
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * LinkTileContent is being added to the GenericTile, it is advised to use in TwoByOne frameType
     *
     * @since 1.120
     */
    linkTileContents?:
      | LinkTileContent[]
      | LinkTileContent
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * An icon or image to be displayed in the control. This aggregation is deprecated since version 1.36.0,
     * to display an icon or image use sap.m.ImageContent control instead.
     *
     * @deprecated As of version 1.36.0. This aggregation is deprecated, use sap.m.ImageContent control to display
     * an icon instead.
     */
    icon?: Control;

    /**
     * Action buttons added in ActionMode.
     *
     * @since 1.96
     */
    actionButtons?: Button[] | Button | AggregationBindingInfo | `{${string}}`;

    /**
     * A badge that is attached to the GenericTile.
     *
     * @since 1.124
     */
    badge?: TileInfo;

    /**
     * The event is triggered when the user presses the tile.
     */
    press?: (oEvent: GenericTile$PressEvent) => void;
  }

  /**
   * Parameters of the GenericTile#press event.
   */
  export interface GenericTile$PressEventParameters {
    /**
     * The current scope the GenericTile was in when the event occurred.
     */
    scope?: GenericTileScope | keyof typeof GenericTileScope;

    /**
     * The action that was pressed on the tile. In the Actions scope, the available actions are Press and Remove.
     * In Display scope, the parameter value is only Press.
     */
    action?: string;

    /**
     * The pressed DOM Element pointing to the GenericTile's DOM Element in Display scope. In Actions scope
     * it points to the more icon, when the tile is pressed, or to the DOM Element of the remove button, when
     * the remove button is pressed.
     */
    domRef?: any;
  }

  /**
   * Event object of the GenericTile#press event.
   */
  export type GenericTile$PressEvent = Event<
    GenericTile$PressEventParameters,
    GenericTile
  >;
}

declare module "sap/m/GroupHeaderListItem" {
  import {
    default as ListItemBase,
    $ListItemBaseSettings,
  } from "sap/m/ListItemBase";

  import { ITableItem } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { TextDirection } from "sap/ui/core/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * `sap.m.GroupHeaderListItem` is used to display the title of a group and act as separator between groups
   * in `sap.m.List` and `sap.m.Table`. **Note:** The inherited properties `unread`, `selected`, `counter`
   * and `press` event from `sap.m.ListItemBase` are not supported.
   *
   * There are the following known restrictions:
   * 	 - When a list is manually populated with items and groups without using data binding, changes to the
   *     order or group structure will only be correctly applied when all items are removed and reinserted again.
   *
   *
   * @since 1.12
   */
  export default class GroupHeaderListItem
    extends ListItemBase
    implements ITableItem
  {
    __implements__sap_m_ITableItem: boolean;
    /**
     * Constructor for a new GroupHeaderListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $GroupHeaderListItemSettings
    );
    /**
     * Constructor for a new GroupHeaderListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $GroupHeaderListItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.GroupHeaderListItem with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ListItemBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, GroupHeaderListItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.GroupHeaderListItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getCount count}.
     *
     * Defines the count of items in the group, but it could also be an amount which represents the sum of all
     * amounts in the group. **Note:** Will not be displayed if not set.
     *
     *
     * @returns Value of property `count`
     */
    getCount(): string;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Defines the title of the group header.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getTitleTextDirection titleTextDirection}.
     *
     * Defines the title text directionality with enumerated options. By default, the control inherits text
     * direction from the DOM.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Value of property `titleTextDirection`
     */
    getTitleTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getUpperCase upperCase}.
     *
     * Allows to uppercase the group title.
     *
     * Default value is `false`.
     *
     * @since 1.13.2
     * @deprecated As of version 1.40.10. the concept has been discarded.
     *
     * @returns Value of property `upperCase`
     */
    getUpperCase(): boolean;
    /**
     * Sets a new value for property {@link #getCount count}.
     *
     * Defines the count of items in the group, but it could also be an amount which represents the sum of all
     * amounts in the group. **Note:** Will not be displayed if not set.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCount(
      /**
       * New value for property `count`
       */
      sCount?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Defines the title of the group header.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitleTextDirection titleTextDirection}.
     *
     * Defines the title text directionality with enumerated options. By default, the control inherits text
     * direction from the DOM.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleTextDirection(
      /**
       * New value for property `titleTextDirection`
       */
      sTitleTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getUpperCase upperCase}.
     *
     * Allows to uppercase the group title.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.13.2
     * @deprecated As of version 1.40.10. the concept has been discarded.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUpperCase(
      /**
       * New value for property `upperCase`
       */
      bUpperCase?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the GroupHeaderListItem constructor.
   */
  export interface $GroupHeaderListItemSettings extends $ListItemBaseSettings {
    /**
     * Defines the title of the group header.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Defines the count of items in the group, but it could also be an amount which represents the sum of all
     * amounts in the group. **Note:** Will not be displayed if not set.
     */
    count?: string | PropertyBindingInfo;

    /**
     * Allows to uppercase the group title.
     *
     * @since 1.13.2
     * @deprecated As of version 1.40.10. the concept has been discarded.
     */
    upperCase?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the title text directionality with enumerated options. By default, the control inherits text
     * direction from the DOM.
     *
     * @since 1.28.0
     */
    titleTextDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/GrowingEnablement" {
  import BaseObject from "sap/ui/base/Object";

  import ListBase from "sap/m/ListBase";

  import Metadata from "sap/ui/base/Metadata";

  /**
   * @since 1.16
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export default class GrowingEnablement extends BaseObject {
    /**
     * Creates a GrowingEnablement delegate that can be attached to ListBase Controls requiring capabilities
     * for growing.
     *
     * **Note**: Do not extend this class.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    protected constructor(
      /**
       * the ListBase control of which this Growing is the delegate
       */
      oControl: ListBase
    );

    /**
     * Creates a new subclass of class sap.m.GrowingEnablement with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.base.Object.extend}.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, GrowingEnablement>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.GrowingEnablement.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): Metadata;
  }
}

declare module "sap/m/GrowingList" {
  import { default as List, $ListSettings } from "sap/m/List";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * `sap.m.GrowingList` control is the container for all list items and inherits from sap.m.List control.
   * Everything like the selection, deletion, unread states and inset style are also maintained here. In addition
   * the control provides a loading mechanism to request data from the model and append the list items to
   * the list. The request is started manually by tapping on the trigger at the end of the list.
   *
   * @deprecated As of version 1.16. Instead use "List" or "Table" control with setting "growing" property
   * to "true"
   */
  export default class GrowingList extends List {
    /**
     * Constructor for a new GrowingList.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $GrowingListSettings
    );
    /**
     * Constructor for a new GrowingList.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $GrowingListSettings
    );

    /**
     * Creates a new subclass of class sap.m.GrowingList with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.List.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, GrowingList>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.GrowingList.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getScrollToLoad scrollToLoad}.
     *
     * If you set this property to true then user needs to scroll end to trigger loading a new page. Default
     * value is false which means user needs to scroll end and then click button to load new page. NOTE: This
     * property can be set true, if growing property is set "true" and if you only have one instance of this
     * control inside the scroll container(e.g Page).
     *
     * Default value is `false`.
     *
     * @since 1.16
     *
     * @returns Value of property `scrollToLoad`
     */
    getScrollToLoad(): boolean;
    /**
     * Gets current value of property {@link #getThreshold threshold}.
     *
     * Number of items requested from the server. To activate this you should set growing property to "true"
     *
     * Default value is `20`.
     *
     * @since 1.16
     *
     * @returns Value of property `threshold`
     */
    getThreshold(): int;
    /**
     * Gets current value of property {@link #getTriggerText triggerText}.
     *
     * Text which is displayed on the trigger at the end of the list. The default is a translated text ("Load
     * More Data") coming from the messagebundle properties. This property can be used only if growing property
     * is set "true" and scrollToLoad property is set "false".
     *
     * @since 1.16
     *
     * @returns Value of property `triggerText`
     */
    getTriggerText(): string;
    /**
     * Sets a new value for property {@link #getScrollToLoad scrollToLoad}.
     *
     * If you set this property to true then user needs to scroll end to trigger loading a new page. Default
     * value is false which means user needs to scroll end and then click button to load new page. NOTE: This
     * property can be set true, if growing property is set "true" and if you only have one instance of this
     * control inside the scroll container(e.g Page).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setScrollToLoad(
      /**
       * New value for property `scrollToLoad`
       */
      bScrollToLoad?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getThreshold threshold}.
     *
     * Number of items requested from the server. To activate this you should set growing property to "true"
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `20`.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setThreshold(
      /**
       * New value for property `threshold`
       */
      iThreshold?: int
    ): this;
    /**
     * Sets a new value for property {@link #getTriggerText triggerText}.
     *
     * Text which is displayed on the trigger at the end of the list. The default is a translated text ("Load
     * More Data") coming from the messagebundle properties. This property can be used only if growing property
     * is set "true" and scrollToLoad property is set "false".
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTriggerText(
      /**
       * New value for property `triggerText`
       */
      sTriggerText?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the GrowingList constructor.
   *
   * @deprecated As of version 1.16. Instead use "List" or "Table" control with setting "growing" property
   * to "true"
   */
  export interface $GrowingListSettings extends $ListSettings {
    /**
     * Number of items requested from the server. To activate this you should set growing property to "true"
     *
     * @since 1.16
     */
    threshold?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Text which is displayed on the trigger at the end of the list. The default is a translated text ("Load
     * More Data") coming from the messagebundle properties. This property can be used only if growing property
     * is set "true" and scrollToLoad property is set "false".
     *
     * @since 1.16
     */
    triggerText?: string | PropertyBindingInfo;

    /**
     * If you set this property to true then user needs to scroll end to trigger loading a new page. Default
     * value is false which means user needs to scroll end and then click button to load new page. NOTE: This
     * property can be set true, if growing property is set "true" and if you only have one instance of this
     * control inside the scroll container(e.g Page).
     *
     * @since 1.16
     */
    scrollToLoad?: boolean | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/HBox" {
  import { default as FlexBox, $FlexBoxSettings } from "sap/m/FlexBox";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * The HBox control builds the container for a horizontal flexible box layout. HBox is a convenience control,
   * as it is just a specialized FlexBox control.
   *
   *  **Note:** Be sure to check the `renderType` setting to avoid issues due to browser inconsistencies.
   */
  export default class HBox extends FlexBox {
    /**
     * Constructor for a new HBox.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.FlexBox#constructor sap.m.FlexBox }
     * can be used.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $HBoxSettings
    );
    /**
     * Constructor for a new HBox.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.FlexBox#constructor sap.m.FlexBox }
     * can be used.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $HBoxSettings
    );

    /**
     * Creates a new subclass of class sap.m.HBox with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.FlexBox.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, HBox>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.HBox.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the HBox constructor.
   */
  export interface $HBoxSettings extends $FlexBoxSettings {}
}

declare module "sap/m/HeaderContainer" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { ObjectHeaderContainer, BackgroundDesign } from "sap/m/library";

  import { ID, CSSSize, Orientation } from "sap/ui/core/library";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * The container that provides a horizontal layout. It provides a horizontal scrolling on the mobile devices.
   * On the desktop, it provides scroll left and scroll right buttons. This control supports keyboard navigation.
   * You can use left and right arrow keys to navigate through the inner content. The Home key puts focus
   * on the first control and the End key puts focus on the last control. Use Enter or Space key to choose
   * the control.
   *
   * @since 1.44.0
   */
  export default class HeaderContainer
    extends Control
    implements ObjectHeaderContainer
  {
    __implements__sap_m_ObjectHeaderContainer: boolean;
    /**
     * Constructor for the new HeaderContainer control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $HeaderContainerSettings
    );
    /**
     * Constructor for the new HeaderContainer control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $HeaderContainerSettings
    );

    /**
     * Creates a new subclass of class sap.m.HeaderContainer with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, HeaderContainer>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.HeaderContainer.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.62.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds some content to the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContent(
      /**
       * The content to add; if empty, nothing is inserted
       */
      oContent: Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:scroll scroll} event of this `sap.m.HeaderContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.HeaderContainer` itself.
     *
     * This event is triggered on pressing the scroll button.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachScroll(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.HeaderContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:scroll scroll} event of this `sap.m.HeaderContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.HeaderContainer` itself.
     *
     * This event is triggered on pressing the scroll button.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachScroll(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.HeaderContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:scroll scroll} event of this `sap.m.HeaderContainer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachScroll(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:scroll scroll} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireScroll(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.62.0
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Specifies the background color of the content. The visualization of the different options depends on
     * the used theme.
     *
     * Default value is `Transparent`.
     *
     *
     * @returns Value of property `backgroundDesign`
     */
    getBackgroundDesign(): BackgroundDesign;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * Content to add to HeaderContainer.
     */
    getContent(): Control[];
    /**
     * Gets current value of property {@link #getGridLayout gridLayout}.
     *
     * Enables grid layout in mobile view.
     *
     * Default value is `false`.
     *
     * @since 1.99
     *
     * @returns Value of property `gridLayout`
     */
    getGridLayout(): boolean;
    /**
     * Gets current value of property {@link #getHeight height}.
     *
     * The height of the whole HeaderContainer. If not specified, it is rendered as 'auto' in horizontal orientation
     * and as '100%' in vertical orientation.
     *
     *
     * @returns Value of property `height`
     */
    getHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getOrientation orientation}.
     *
     * The orientation of the HeaderContainer. There are two orientation modes: horizontal and vertical. In
     * horizontal mode the content controls are displayed next to each other, in vertical mode the content controls
     * are displayed on top of each other.
     *
     * Default value is `Horizontal`.
     *
     *
     * @returns Value of property `orientation`
     */
    getOrientation(): Orientation;
    /**
     * Gets current value of property {@link #getScrollStep scrollStep}.
     *
     * Number of pixels to scroll when the user chooses Next or Previous buttons. Relevant only for desktop.
     *
     * Default value is `300`.
     *
     *
     * @returns Value of property `scrollStep`
     */
    getScrollStep(): int;
    /**
     * Gets current value of property {@link #getScrollStepByItem scrollStepByItem}.
     *
     * Number of items to scroll when the user chose Next or Previous buttons. Relevant only for desktop. Have
     * priority over 'ScrollStep'. Have to be positive number.
     *
     * Default value is `1`.
     *
     *
     * @returns Value of property `scrollStepByItem`
     */
    getScrollStepByItem(): int;
    /**
     * Gets current value of property {@link #getScrollTime scrollTime}.
     *
     * Scroll animation time in milliseconds.
     *
     * Default value is `500`.
     *
     *
     * @returns Value of property `scrollTime`
     */
    getScrollTime(): int;
    /**
     * Gets current value of property {@link #getShowDividers showDividers}.
     *
     * If set to true, it shows dividers between the different content controls.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showDividers`
     */
    getShowDividers(): boolean;
    /**
     * Gets current value of property {@link #getShowOverflowItem showOverflowItem}.
     *
     * Indicates whether the incomplete item on the edge of visible area is displayed or hidden.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showOverflowItem`
     */
    getShowOverflowItem(): boolean;
    /**
     * Gets current value of property {@link #getSnapToRow snapToRow}.
     *
     * The height of all the items is stretched to match the largest item in the row within the HeaderContainer.
     *
     * If set to `true`, the items are going to get stretched.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `snapToRow`
     */
    getSnapToRow(): boolean;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * The width of the whole HeaderContainer. If not specified, it is rendered as '100%' in horizontal orientation
     * and as 'auto' in vertical orientation.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContent content}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContent(
      /**
       * The content whose index is looked for
       */
      oContent: Control
    ): int;
    /**
     * Inserts a content into the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContent(
      /**
       * The content to insert; if empty, nothing is inserted
       */
      oContent: Control,
      /**
       * The `0`-based index the content should be inserted at; for a negative value of `iIndex`, the content
       * is inserted at position 0; for a value greater than the current size of the aggregation, the content
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.62.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all the controls from the aggregation {@link #getContent content}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContent(): Control[];
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.62.0
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes a content from the aggregation {@link #getContent content}.
     *
     *
     * @returns The removed content or `null`
     */
    removeContent(
      /**
       * The content to remove or its index or id
       */
      vContent: int | string | Control
    ): Control | null;
    /**
     * Sets a new value for property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Specifies the background color of the content. The visualization of the different options depends on
     * the used theme.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Transparent`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundDesign(
      /**
       * New value for property `backgroundDesign`
       */
      sBackgroundDesign?: BackgroundDesign | keyof typeof BackgroundDesign
    ): this;
    /**
     * Sets a new value for property {@link #getGridLayout gridLayout}.
     *
     * Enables grid layout in mobile view.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.99
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGridLayout(
      /**
       * New value for property `gridLayout`
       */
      bGridLayout?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getHeight height}.
     *
     * The height of the whole HeaderContainer. If not specified, it is rendered as 'auto' in horizontal orientation
     * and as '100%' in vertical orientation.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeight(
      /**
       * New value for property `height`
       */
      sHeight: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getOrientation orientation}.
     *
     * The orientation of the HeaderContainer. There are two orientation modes: horizontal and vertical. In
     * horizontal mode the content controls are displayed next to each other, in vertical mode the content controls
     * are displayed on top of each other.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Horizontal`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setOrientation(
      /**
       * New value for property `orientation`
       */
      sOrientation?: Orientation | keyof typeof Orientation
    ): this;
    /**
     * Sets a new value for property {@link #getScrollStep scrollStep}.
     *
     * Number of pixels to scroll when the user chooses Next or Previous buttons. Relevant only for desktop.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `300`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setScrollStep(
      /**
       * New value for property `scrollStep`
       */
      iScrollStep?: int
    ): this;
    /**
     * Sets a new value for property {@link #getScrollStepByItem scrollStepByItem}.
     *
     * Number of items to scroll when the user chose Next or Previous buttons. Relevant only for desktop. Have
     * priority over 'ScrollStep'. Have to be positive number.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `1`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setScrollStepByItem(
      /**
       * New value for property `scrollStepByItem`
       */
      iScrollStepByItem?: int
    ): this;
    /**
     * Sets a new value for property {@link #getScrollTime scrollTime}.
     *
     * Scroll animation time in milliseconds.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `500`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setScrollTime(
      /**
       * New value for property `scrollTime`
       */
      iScrollTime?: int
    ): this;
    /**
     * Sets a new value for property {@link #getShowDividers showDividers}.
     *
     * If set to true, it shows dividers between the different content controls.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowDividers(
      /**
       * New value for property `showDividers`
       */
      bShowDividers?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowOverflowItem showOverflowItem}.
     *
     * Indicates whether the incomplete item on the edge of visible area is displayed or hidden.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowOverflowItem(
      /**
       * New value for property `showOverflowItem`
       */
      bShowOverflowItem?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getSnapToRow snapToRow}.
     *
     * The height of all the items is stretched to match the largest item in the row within the HeaderContainer.
     *
     * If set to `true`, the items are going to get stretched.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSnapToRow(
      /**
       * New value for property `snapToRow`
       */
      bSnapToRow?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * The width of the whole HeaderContainer. If not specified, it is rendered as '100%' in horizontal orientation
     * and as 'auto' in vertical orientation.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth: CSSSize
    ): this;
  }
  /**
   * Describes the settings that can be provided to the HeaderContainer constructor.
   */
  export interface $HeaderContainerSettings extends $ControlSettings {
    /**
     * Number of pixels to scroll when the user chooses Next or Previous buttons. Relevant only for desktop.
     */
    scrollStep?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Number of items to scroll when the user chose Next or Previous buttons. Relevant only for desktop. Have
     * priority over 'ScrollStep'. Have to be positive number.
     */
    scrollStepByItem?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Scroll animation time in milliseconds.
     */
    scrollTime?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether the incomplete item on the edge of visible area is displayed or hidden.
     */
    showOverflowItem?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * If set to true, it shows dividers between the different content controls.
     */
    showDividers?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The orientation of the HeaderContainer. There are two orientation modes: horizontal and vertical. In
     * horizontal mode the content controls are displayed next to each other, in vertical mode the content controls
     * are displayed on top of each other.
     */
    orientation?:
      | (Orientation | keyof typeof Orientation)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies the background color of the content. The visualization of the different options depends on
     * the used theme.
     */
    backgroundDesign?:
      | (BackgroundDesign | keyof typeof BackgroundDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The width of the whole HeaderContainer. If not specified, it is rendered as '100%' in horizontal orientation
     * and as 'auto' in vertical orientation.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * The height of the whole HeaderContainer. If not specified, it is rendered as 'auto' in horizontal orientation
     * and as '100%' in vertical orientation.
     */
    height?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Enables grid layout in mobile view.
     *
     * @since 1.99
     */
    gridLayout?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The height of all the items is stretched to match the largest item in the row within the HeaderContainer.
     *
     * If set to `true`, the items are going to get stretched.
     */
    snapToRow?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Content to add to HeaderContainer.
     */
    content?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * Controls or IDs that label controls in the `content` aggregation. Each ariaLabelledBy item is assigned
     * to its appropriate counterpart in the `content` aggregation.
     * If you want to annotate all the controls in the `content` aggregation, add the same number of items to
     * the `ariaLabelledBy` annotation.
     * Can be used by screen reader software.
     *
     * @since 1.62.0
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * This event is triggered on pressing the scroll button.
     */
    scroll?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the HeaderContainer#scroll event.
   */
  export interface HeaderContainer$ScrollEventParameters {}

  /**
   * Event object of the HeaderContainer#scroll event.
   */
  export type HeaderContainer$ScrollEvent = Event<
    HeaderContainer$ScrollEventParameters,
    HeaderContainer
  >;
}

declare module "sap/m/IconTabBar" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    ObjectHeaderContainer,
    IconTab,
    BackgroundDesign,
    IconTabHeaderMode,
    IconTabDensityMode,
    TabsOverflowMode,
  } from "sap/m/library";

  import { IDynamicPageStickyContent } from "sap/f/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  import IconTabFilter from "sap/m/IconTabFilter";

  /**
   * The IconTabBar represents a collection of tabs with associated content. Overview: The IconTabBar can
   * be used for navigation within an object, or as a filter. Different types of IconTabBar are used based
   * on the contents.
   * 	 - Filter - There is only one main content for all tabs. The main content can be filtered, based on
   *     the selected tab.
   * 	 - Normal tab bar - The contents of each tab are independent from each other.
   * 	 - Combination of the above - There can be both filtered and independent contents.  Structure:
   *     The IconTabBar can hold two types of entities {@link sap.m.IconTabFilter sap.m.IconTabFilter} and {@link sap.m.IconTabSeparator sap.m.IconTabSeparator}
   *
   * The IconTabFilter holds all information on an item - text, icon and count.
   *
   * The IconTabSeparator holds an icon that can be used to show a process that runs from item to item. Usage:
   * Text only: Uses text labels as tabs with optional counter
   * 	 - Used when there are no suitable icons for all items.
   * 	 - Used when longer labels are needed.
   * 	 - If `headerMode` property is set to `Inline` the text and the count are displayed in one line.
   * 	 - `UpperCase` is disabled.
   * 	 - Use title case.  Icon Tabs: Round tabs with optional counter and label
   * 	 - Used when there are unique icons for all items.
   * 	 - Only shorter labels are possible.
   * 	 - Provide labels for all icons or for none. Do not mix these.  Tabs as filters: Tabs with filtered
   *     content from the same set of items
   * 	 - Provide an "All" tab to show all items without filtering.
   * 	 - Use counters to show the number of items in each filter.  Tabs as process steps: Tabs show a
   *     single step in a process
   * 	 - Use an arrow (e.g. triple-chevron) as a separator to connect the steps.
   * 	 - Use counters to show the number of items in each filter.  Hierarchies: Multiple sub tabs could
   *     be placed underneath one main tab. Nesting allows deeper hierarchies with indentations to indicate the
   *     level of each nested tab. When a tab has both sub tabs and own content its click area is split to allow
   *     the user to display the content or alternatively to expand/collapse the list of sub tabs. Responsive
   *     Behavior:
   * 	 - Text-only tabs are never truncated.
   * 	 - Use the `expandable` property to specify whether users can collapse the tab container (default =
   *     true).
   * 	 - On desktop, tabs can be dragged and dropped (property `enableTabReordering`).
   * 	 - If you have a large number of tabs, only the tabs that can fit on screen will be visible. All other
   *     tabs that can't fit on the screen are available in an overflow tab "More".  When using the `sap.m.IconTabBar`
   *     in SAP Quartz and Horizon themes, the breakpoints and layout paddings could be determined by the Icon
   *     Tab Bar's width. To enable this concept and add responsive paddings to an element of the Icon Tab Bar
   *     control, you have to add the following classes depending on your use case: `sapUiResponsivePadding--header`,
   *     `sapUiResponsivePadding--content`.
   */
  export default class IconTabBar
    extends Control
    implements ObjectHeaderContainer, IDynamicPageStickyContent
  {
    __implements__sap_m_ObjectHeaderContainer: boolean;
    __implements__sap_f_IDynamicPageStickyContent: boolean;
    /**
     * Constructor for a new IconTabBar.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/icontabbar/ Icon Tab Bar}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $IconTabBarSettings
    );
    /**
     * Constructor for a new IconTabBar.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/icontabbar/ Icon Tab Bar}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $IconTabBarSettings
    );

    /**
     * Creates a new subclass of class sap.m.IconTabBar with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, IconTabBar>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.IconTabBar.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some content to the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContent(
      /**
       * The content to add; if empty, nothing is inserted
       */
      oContent: Control
    ): this;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: IconTab
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:expand expand} event of this `sap.m.IconTabBar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.IconTabBar` itself.
     *
     * Indicates that the tab will expand or collapse.
     *
     * @since 1.15.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachExpand(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: IconTabBar$ExpandEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.IconTabBar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:expand expand} event of this `sap.m.IconTabBar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.IconTabBar` itself.
     *
     * Indicates that the tab will expand or collapse.
     *
     * @since 1.15.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachExpand(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: IconTabBar$ExpandEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.IconTabBar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:select select} event of this `sap.m.IconTabBar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.IconTabBar` itself.
     *
     * Fires when an item is selected.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: IconTabBar$SelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.IconTabBar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:select select} event of this `sap.m.IconTabBar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.IconTabBar` itself.
     *
     * Fires when an item is selected.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: IconTabBar$SelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.IconTabBar` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:expand expand} event of this `sap.m.IconTabBar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.15.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachExpand(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: IconTabBar$ExpandEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:select select} event of this `sap.m.IconTabBar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: IconTabBar$SelectEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:expand expand} to attached listeners.
     *
     * @since 1.15.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireExpand(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: IconTabBar$ExpandEventParameters
    ): this;
    /**
     * Fires event {@link #event:select select} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: IconTabBar$SelectEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getApplyContentPadding applyContentPadding}.
     *
     * Determines whether the IconTabBar content fits to the full area. The paddings are removed if it's set
     * to false.
     *
     * Default value is `true`.
     *
     * @since 1.26
     *
     * @returns Value of property `applyContentPadding`
     */
    getApplyContentPadding(): boolean;
    /**
     * Gets current value of property {@link #getAriaTexts ariaTexts}.
     *
     * Specifies optional texts for the screen reader.
     *
     * The given object can contain the following keys: `headerLabel` - text to serve as a label for the header,
     * `headerDescription` - text to serve as a description for the header.
     *
     *
     * @returns Value of property `ariaTexts`
     */
    getAriaTexts(): {
      headerLabel: string;

      headerDescription: string;
    } | null;
    /**
     * Gets current value of property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Specifies the background color of the IconTabBar.
     *
     * Depending on the theme, you can change the state of the background color to "Solid", "Translucent", or
     * "Transparent". Default is "Solid".
     *
     * Default value is `Solid`.
     *
     * @since 1.26
     *
     * @returns Value of property `backgroundDesign`
     */
    getBackgroundDesign(): BackgroundDesign;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * Represents the contents displayed below the IconTabBar. If there are multiple contents, they are rendered
     * after each other. The developer has to manage to display the right one or use the content aggregation
     * inside the IconTabFilter (which will be displayed instead if it is set).
     */
    getContent(): Control[];
    /**
     * Gets current value of property {@link #getEnableTabReordering enableTabReordering}.
     *
     * Specifies whether tab reordering is enabled. Relevant only for desktop devices. The {@link sap.m.IconTabSeparator sap.m.IconTabSeparator }
     * cannot be dragged and dropped Items can be moved around {@link sap.m.IconTabSeparator sap.m.IconTabSeparator }
     * Reordering is enabled via keyboard using `Ctrl` + arrow keys (Windows) and `Control` + arrow keys (Mac
     * OS)
     *
     * Default value is `false`.
     *
     * @since 1.46
     *
     * @returns Value of property `enableTabReordering`
     */
    getEnableTabReordering(): boolean;
    /**
     * Gets current value of property {@link #getExpandable expandable}.
     *
     * Defines if the tabs are collapsible and expandable.
     *
     * Default value is `true`.
     *
     * @since 1.15.0
     *
     * @returns Value of property `expandable`
     */
    getExpandable(): boolean;
    /**
     * Gets current value of property {@link #getExpanded expanded}.
     *
     * Indicates if the actual tab content is expanded or not.
     *
     * Default value is `true`.
     *
     * @since 1.15.0
     *
     * @returns Value of property `expanded`
     */
    getExpanded(): boolean;
    /**
     * Gets current value of property {@link #getHeaderBackgroundDesign headerBackgroundDesign}.
     *
     * Specifies the background color of the header.
     *
     * Depending on the theme, you can change the state of the background color to "Solid", "Translucent", or
     * "Transparent". **Note:** In SAP Belize Deep (sap_belize_plus) theme this property should be set to "Solid".
     *
     * Default value is `Solid`.
     *
     * @since 1.44
     *
     * @returns Value of property `headerBackgroundDesign`
     */
    getHeaderBackgroundDesign(): BackgroundDesign;
    /**
     * Gets current value of property {@link #getHeaderMode headerMode}.
     *
     * Specifies the header mode.
     *
     * Default value is `Standard`.
     *
     * @since 1.40
     *
     * @returns Value of property `headerMode`
     */
    getHeaderMode(): IconTabHeaderMode;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * The items displayed in the IconTabBar.
     */
    getItems(): IconTab[];
    /**
     * Gets current value of property {@link #getMaxNestingLevel maxNestingLevel}.
     *
     * Specifies the allowed level of tabs nesting within one another using drag and drop. Default value is
     * 0 which means nesting via interaction is not allowed. Maximum value is 100. This property allows nesting
     * via user interaction only, and does not restrict adding items to the `items` aggregation of {@link sap.m.IconTabFilter sap.m.IconTabFilter}.
     *
     * Default value is `0`.
     *
     * @since 1.79
     *
     * @returns Value of property `maxNestingLevel`
     */
    getMaxNestingLevel(): int;
    /**
     * Reflector for the internal header's selectedKey property.
     *
     *
     * @returns The current property value.
     */
    getSelectedKey(): string;
    /**
     * Gets current value of property {@link #getShowOverflowSelectList showOverflowSelectList}.
     *
     * Specifies if the overflow select list is displayed.
     *
     * The overflow select list represents a list, where all tab filters are displayed, so the user can select
     * specific tab filter easier.
     *
     * Default value is `false`.
     *
     * @since 1.42
     * @deprecated As of version 1.77. the concept has been discarded. All tab filters that don't fit in the
     * header, will be displayed in overflow menu.
     *
     * @returns Value of property `showOverflowSelectList`
     */
    getShowOverflowSelectList(): boolean;
    /**
     * Gets current value of property {@link #getShowSelection showSelection}.
     *
     * Defines whether the current selection should be visualized.
     *
     * Default value is `true`.
     *
     * @deprecated As of version 1.15.0. Regarding to changes of this control this property is not needed anymore.
     *
     * @returns Value of property `showSelection`
     */
    getShowSelection(): boolean;
    /**
     * Gets current value of property {@link #getStretchContentHeight stretchContentHeight}.
     *
     * Determines whether the IconTabBar height is stretched to the maximum possible height of its parent container.
     * As a prerequisite, the height of the parent container must be defined as a fixed value.
     *
     * Default value is `false`.
     *
     * @since 1.26
     *
     * @returns Value of property `stretchContentHeight`
     */
    getStretchContentHeight(): boolean;
    /**
     * Gets current value of property {@link #getTabDensityMode tabDensityMode}.
     *
     * Specifies the visual density mode of the tabs.
     *
     * The values that can be applied are `Cozy`, `Compact` and `Inherit`. `Cozy` and `Compact` render the control
     * in one of these modes independent of the global density settings. The `Inherit` value follows the global
     * density settings which are applied. For compatibility reasons, the default value is `Cozy`.
     *
     * Default value is `Cozy`.
     *
     * @since 1.56
     *
     * @returns Value of property `tabDensityMode`
     */
    getTabDensityMode(): IconTabDensityMode;
    /**
     * Gets current value of property {@link #getTabsOverflowMode tabsOverflowMode}.
     *
     * Specifies the overflow mode of the header.
     *
     * The default `End` mode shows as many tabs that can fit on the screen, then shows one overflow at the
     * end containing the remaining items. The `StartAndEnd` is used to keep the order of tabs intact and offers
     * two overflow tabs on both ends of the bar.
     *
     * Default value is `End`.
     *
     * @since 1.90
     *
     * @returns Value of property `tabsOverflowMode`
     */
    getTabsOverflowMode(): TabsOverflowMode;
    /**
     * Gets current value of property {@link #getUpperCase upperCase}.
     *
     * Determines whether the text of the icon tab filter (not the count) is displayed in uppercase.
     *
     * Default value is `false`.
     *
     * @since 1.22
     *
     * @returns Value of property `upperCase`
     */
    getUpperCase(): boolean;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContent content}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContent(
      /**
       * The content whose index is looked for
       */
      oContent: Control
    ): int;
    /**
     * Checks for the provided `sap.m.IconTab` in the aggregation {@link #getItems items}. and returns its index
     * if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: IconTab
    ): int;
    /**
     * Inserts a content into the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContent(
      /**
       * The content to insert; if empty, nothing is inserted
       */
      oContent: Control,
      /**
       * The `0`-based index the content should be inserted at; for a negative value of `iIndex`, the content
       * is inserted at position 0; for a value greater than the current size of the aggregation, the content
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: IconTab,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getContent content}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContent(): Control[];
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): IconTab[];
    /**
     * Removes a content from the aggregation {@link #getContent content}.
     *
     *
     * @returns The removed content or `null`
     */
    removeContent(
      /**
       * The content to remove or its index or id
       */
      vContent: int | string | Control
    ): Control | null;
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | IconTab
    ): IconTab | null;
    /**
     * Sets a new value for property {@link #getApplyContentPadding applyContentPadding}.
     *
     * Determines whether the IconTabBar content fits to the full area. The paddings are removed if it's set
     * to false.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.26
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setApplyContentPadding(
      /**
       * New value for property `applyContentPadding`
       */
      bApplyContentPadding?: boolean
    ): this;
    /**
     * Sets the ariaTexts property.
     *
     *
     * @returns this Reference to this in order to allow method chaining
     */
    setAriaTexts(
      /**
       * New value for ariaTexts.
       */
      oAriaTexts: {
        headerLabel: string;

        headerDescription: string;
      }
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Specifies the background color of the IconTabBar.
     *
     * Depending on the theme, you can change the state of the background color to "Solid", "Translucent", or
     * "Transparent". Default is "Solid".
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Solid`.
     *
     * @since 1.26
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundDesign(
      /**
       * New value for property `backgroundDesign`
       */
      sBackgroundDesign?: BackgroundDesign | keyof typeof BackgroundDesign
    ): this;
    /**
     * Sets the enableTabReordering property.
     *
     *
     * @returns this IconTabBar reference for chaining.
     */
    setEnableTabReordering(
      /**
       * New value for enableTabReordering.
       */
      value: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getExpandable expandable}.
     *
     * Defines if the tabs are collapsible and expandable.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.15.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setExpandable(
      /**
       * New value for property `expandable`
       */
      bExpandable?: boolean
    ): this;
    /**
     * Sets the tab content as expanded.
     *
     *
     * @returns this IconTabBar reference for chaining.
     */
    setExpanded(
      /**
       * New parameter value.
       */
      bExpanded: boolean
    ): this;
    /**
     * Sets the header background design.
     *
     *
     * @returns this IconTabBar reference for chaining.
     */
    setHeaderBackgroundDesign(
      /**
       * New parameter value.
       */
      headerBackgroundDesign: BackgroundDesign | keyof typeof BackgroundDesign
    ): this;
    /**
     * Sets the header mode.
     *
     *
     * @returns this IconTabBar reference for chaining.
     */
    setHeaderMode(
      /**
       * New parameter value.
       */
      mode: IconTabHeaderMode | keyof typeof IconTabHeaderMode
    ): this;
    /**
     * Sets a new value for property {@link #getMaxNestingLevel maxNestingLevel}.
     *
     * Specifies the allowed level of tabs nesting within one another using drag and drop. Default value is
     * 0 which means nesting via interaction is not allowed. Maximum value is 100. This property allows nesting
     * via user interaction only, and does not restrict adding items to the `items` aggregation of {@link sap.m.IconTabFilter sap.m.IconTabFilter}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     * @since 1.79
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxNestingLevel(
      /**
       * New value for property `maxNestingLevel`
       */
      iMaxNestingLevel?: int
    ): this;
    /**
     * Reflector for the internal header's selectedKey property.
     *
     *
     * @returns this Pointer for chaining.
     */
    setSelectedKey(
      /**
       * The new value.
       */
      sValue: string
    ): this;
    /**
     * Sets a new value for property {@link #getShowOverflowSelectList showOverflowSelectList}.
     *
     * Specifies if the overflow select list is displayed.
     *
     * The overflow select list represents a list, where all tab filters are displayed, so the user can select
     * specific tab filter easier.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.42
     * @deprecated As of version 1.77. the concept has been discarded. All tab filters that don't fit in the
     * header, will be displayed in overflow menu.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowOverflowSelectList(
      /**
       * New value for property `showOverflowSelectList`
       */
      bShowOverflowSelectList?: boolean
    ): this;
    /**
     * Reflector for the internal header's showSelection property.
     *
     * @deprecated As of version 1.15.0. Regarding to changes of this control this property is not needed anymore.
     *
     * @returns this IconTabBar reference for chaining.
     */
    setShowSelection(
      /**
       * the new value.
       */
      bValue: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getStretchContentHeight stretchContentHeight}.
     *
     * Determines whether the IconTabBar height is stretched to the maximum possible height of its parent container.
     * As a prerequisite, the height of the parent container must be defined as a fixed value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.26
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setStretchContentHeight(
      /**
       * New value for property `stretchContentHeight`
       */
      bStretchContentHeight?: boolean
    ): this;
    /**
     * Sets the tab density mode.
     *
     *
     * @returns this IconTabBar reference for chaining.
     */
    setTabDensityMode(
      /**
       * New parameter value.
       */
      mode: IconTabDensityMode | keyof typeof IconTabDensityMode
    ): this;
    /**
     * Sets a new value for property {@link #getTabsOverflowMode tabsOverflowMode}.
     *
     * Specifies the overflow mode of the header.
     *
     * The default `End` mode shows as many tabs that can fit on the screen, then shows one overflow at the
     * end containing the remaining items. The `StartAndEnd` is used to keep the order of tabs intact and offers
     * two overflow tabs on both ends of the bar.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `End`.
     *
     * @since 1.90
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTabsOverflowMode(
      /**
       * New value for property `tabsOverflowMode`
       */
      sTabsOverflowMode?: TabsOverflowMode | keyof typeof TabsOverflowMode
    ): this;
    /**
     * Sets a new value for property {@link #getUpperCase upperCase}.
     *
     * Determines whether the text of the icon tab filter (not the count) is displayed in uppercase.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.22
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUpperCase(
      /**
       * New value for property `upperCase`
       */
      bUpperCase?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the IconTabBar constructor.
   */
  export interface $IconTabBarSettings extends $ControlSettings {
    /**
     * Defines whether the current selection should be visualized.
     *
     * @deprecated As of version 1.15.0. Regarding to changes of this control this property is not needed anymore.
     */
    showSelection?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines if the tabs are collapsible and expandable.
     *
     * @since 1.15.0
     */
    expandable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates if the actual tab content is expanded or not.
     *
     * @since 1.15.0
     */
    expanded?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Key of the selected tab item.
     *
     * If the key has no corresponding aggregated item, no changes will apply. If duplicate keys exists the
     * first item matching the key is used.
     *
     * @since 1.15.0
     */
    selectedKey?: string | PropertyBindingInfo;

    /**
     * Determines whether the text of the icon tab filter (not the count) is displayed in uppercase.
     *
     * @since 1.22
     */
    upperCase?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the IconTabBar height is stretched to the maximum possible height of its parent container.
     * As a prerequisite, the height of the parent container must be defined as a fixed value.
     *
     * @since 1.26
     */
    stretchContentHeight?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the IconTabBar content fits to the full area. The paddings are removed if it's set
     * to false.
     *
     * @since 1.26
     */
    applyContentPadding?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the background color of the IconTabBar.
     *
     * Depending on the theme, you can change the state of the background color to "Solid", "Translucent", or
     * "Transparent". Default is "Solid".
     *
     * @since 1.26
     */
    backgroundDesign?:
      | (BackgroundDesign | keyof typeof BackgroundDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies the header mode.
     *
     * @since 1.40
     */
    headerMode?:
      | (IconTabHeaderMode | keyof typeof IconTabHeaderMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies if the overflow select list is displayed.
     *
     * The overflow select list represents a list, where all tab filters are displayed, so the user can select
     * specific tab filter easier.
     *
     * @since 1.42
     * @deprecated As of version 1.77. the concept has been discarded. All tab filters that don't fit in the
     * header, will be displayed in overflow menu.
     */
    showOverflowSelectList?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the background color of the header.
     *
     * Depending on the theme, you can change the state of the background color to "Solid", "Translucent", or
     * "Transparent". **Note:** In SAP Belize Deep (sap_belize_plus) theme this property should be set to "Solid".
     *
     * @since 1.44
     */
    headerBackgroundDesign?:
      | (BackgroundDesign | keyof typeof BackgroundDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies whether tab reordering is enabled. Relevant only for desktop devices. The {@link sap.m.IconTabSeparator sap.m.IconTabSeparator }
     * cannot be dragged and dropped Items can be moved around {@link sap.m.IconTabSeparator sap.m.IconTabSeparator }
     * Reordering is enabled via keyboard using `Ctrl` + arrow keys (Windows) and `Control` + arrow keys (Mac
     * OS)
     *
     * @since 1.46
     */
    enableTabReordering?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the allowed level of tabs nesting within one another using drag and drop. Default value is
     * 0 which means nesting via interaction is not allowed. Maximum value is 100. This property allows nesting
     * via user interaction only, and does not restrict adding items to the `items` aggregation of {@link sap.m.IconTabFilter sap.m.IconTabFilter}.
     *
     * @since 1.79
     */
    maxNestingLevel?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the visual density mode of the tabs.
     *
     * The values that can be applied are `Cozy`, `Compact` and `Inherit`. `Cozy` and `Compact` render the control
     * in one of these modes independent of the global density settings. The `Inherit` value follows the global
     * density settings which are applied. For compatibility reasons, the default value is `Cozy`.
     *
     * @since 1.56
     */
    tabDensityMode?:
      | (IconTabDensityMode | keyof typeof IconTabDensityMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies optional texts for the screen reader.
     *
     * The given object can contain the following keys: `headerLabel` - text to serve as a label for the header,
     * `headerDescription` - text to serve as a description for the header.
     *
     * @since 1.78
     */
    ariaTexts?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the overflow mode of the header.
     *
     * The default `End` mode shows as many tabs that can fit on the screen, then shows one overflow at the
     * end containing the remaining items. The `StartAndEnd` is used to keep the order of tabs intact and offers
     * two overflow tabs on both ends of the bar.
     *
     * @since 1.90
     */
    tabsOverflowMode?:
      | (TabsOverflowMode | keyof typeof TabsOverflowMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The items displayed in the IconTabBar.
     */
    items?: IconTab[] | IconTab | AggregationBindingInfo | `{${string}}`;

    /**
     * Represents the contents displayed below the IconTabBar. If there are multiple contents, they are rendered
     * after each other. The developer has to manage to display the right one or use the content aggregation
     * inside the IconTabFilter (which will be displayed instead if it is set).
     */
    content?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * Fires when an item is selected.
     */
    select?: (oEvent: IconTabBar$SelectEvent) => void;

    /**
     * Indicates that the tab will expand or collapse.
     *
     * @since 1.15.0
     */
    expand?: (oEvent: IconTabBar$ExpandEvent) => void;
  }

  /**
   * Parameters of the IconTabBar#expand event.
   */
  export interface IconTabBar$ExpandEventParameters {
    /**
     * If the tab will expand, this is true.
     */
    expand?: boolean;

    /**
     * If the tab will collapse, this is true.
     */
    collapse?: boolean;
  }

  /**
   * Event object of the IconTabBar#expand event.
   */
  export type IconTabBar$ExpandEvent = Event<
    IconTabBar$ExpandEventParameters,
    IconTabBar
  >;

  /**
   * Parameters of the IconTabBar#select event.
   */
  export interface IconTabBar$SelectEventParameters {
    /**
     * The selected item
     */
    item?: IconTabFilter;

    /**
     * The key of the selected item
     */
    key?: string;

    /**
     * The key of the previous selected item
     */
    previousKey?: string;

    /**
     * The selected item
     */
    selectedItem?: IconTabFilter;

    /**
     * The key of the selected item
     */
    selectedKey?: string;
  }

  /**
   * Event object of the IconTabBar#select event.
   */
  export type IconTabBar$SelectEvent = Event<
    IconTabBar$SelectEventParameters,
    IconTabBar
  >;
}

declare module "sap/m/IconTabFilter" {
  import { default as Item, $ItemSettings } from "sap/ui/core/Item";

  import {
    IconTab,
    IBadge,
    IconTabFilterDesign,
    IconTabFilterInteractionMode,
  } from "sap/m/library";

  import { PopupInterface, URI, IconColor } from "sap/ui/core/library";

  import Control from "sap/ui/core/Control";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import RenderManager from "sap/ui/core/RenderManager";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * Represents a selectable item inside an IconTabBar.
   */
  export default class IconTabFilter
    extends Item
    implements IconTab, PopupInterface, IBadge
  {
    __implements__sap_m_IconTab: boolean;
    __implements__sap_ui_core_PopupInterface: boolean;
    __implements__sap_m_IBadge: boolean;
    /**
     * Constructor for a new IconTabFilter.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $IconTabFilterSettings
    );
    /**
     * Constructor for a new IconTabFilter.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given.
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $IconTabFilterSettings
    );

    /**
     * Creates a new subclass of class sap.m.IconTabFilter with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Item.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, IconTabFilter>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.IconTabFilter.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some content to the aggregation {@link #getContent content}.
     *
     * @since 1.15.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContent(
      /**
       * The content to add; if empty, nothing is inserted
       */
      oContent: Control
    ): this;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     * @since 1.77
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: IconTab
    ): this;
    /**
     * Destroys all the content in the aggregation {@link #getContent content}.
     *
     * @since 1.15.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     * @since 1.77
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * The content displayed for this item (optional).
     *
     * If this content is set, it is displayed instead of the general content inside the IconTabBar.
     *
     * @since 1.15.0
     */
    getContent(): Control[];
    /**
     * Gets current value of property {@link #getCount count}.
     *
     * Represents the "count" text, which is displayed in the tab filter.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `count`
     */
    getCount(): string;
    /**
     * Gets current value of property {@link #getDesign design}.
     *
     * Specifies whether the icon and the texts are placed vertically or horizontally.
     *
     * Default value is `Vertical`.
     *
     *
     * @returns Value of property `design`
     */
    getDesign(): IconTabFilterDesign;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Specifies the icon to be displayed for the tab filter.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getIconColor iconColor}.
     *
     * Specifies the icon color.
     *
     * If an icon font is used, the color can be chosen from the icon colors (sap.ui.core.IconColor). Possible
     * semantic colors are: Neutral, Positive, Critical, Negative. Instead of the semantic icon color the brand
     * color can be used, this is named Default. Semantic colors and brand colors should not be mixed up inside
     * one IconTabBar.
     *
     * Default value is `Default`.
     *
     *
     * @returns Value of property `iconColor`
     */
    getIconColor(): IconColor;
    /**
     * Gets current value of property {@link #getIconDensityAware iconDensityAware}.
     *
     * If set to true, it sends one or more requests, trying to get the density perfect version of the image
     * if this version of the image doesn't exist on the server. Default value is set to true.
     *
     * If bandwidth is key for the application, set this value to false.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `iconDensityAware`
     */
    getIconDensityAware(): boolean;
    /**
     * Gets current value of property {@link #getInteractionMode interactionMode}.
     *
     * Specifies the interaction mode.
     *
     * Default value is `Auto`.
     *
     * @experimental As of version 1.121. Disclaimer: this property is in a beta state - incompatible API changes
     * may be done before its official public release. Use at your own discretion.
     *
     * @returns Value of property `interactionMode`
     */
    getInteractionMode(): IconTabFilterInteractionMode;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * The sub items of this filter (optional).
     *
     * @since 1.77
     */
    getItems(): IconTab[];
    /**
     * Gets current value of property {@link #getShowAll showAll}.
     *
     * Enables special visualization for disabled filter (show all items). **Note:** You can use this property
     * when you use `IconTabBar` as a filter. In order for it to be displayed correctly, the other tabs in the
     * filter should consist of an icon, text and an optional count. It can be set to true for the first tab
     * filter. You can find more detailed information in the {@link https://experience.sap.com/fiori-design-web/icontabbar/#tabs-as-filters UX Guidelines}.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showAll`
     */
    getShowAll(): boolean;
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * Specifies whether the tab filter is rendered.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContent content}. and returns
     * its index if found or -1 otherwise.
     *
     * @since 1.15.0
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContent(
      /**
       * The content whose index is looked for
       */
      oContent: Control
    ): int;
    /**
     * Checks for the provided `sap.m.IconTab` in the aggregation {@link #getItems items}. and returns its index
     * if found or -1 otherwise.
     *
     * @since 1.77
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: IconTab
    ): int;
    /**
     * Inserts a content into the aggregation {@link #getContent content}.
     *
     * @since 1.15.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContent(
      /**
       * The content to insert; if empty, nothing is inserted
       */
      oContent: Control,
      /**
       * The `0`-based index the content should be inserted at; for a negative value of `iIndex`, the content
       * is inserted at position 0; for a value greater than the current size of the aggregation, the content
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     * @since 1.77
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: IconTab,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getContent content}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.15.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContent(): Control[];
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.77
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): IconTab[];
    /**
     * Removes a content from the aggregation {@link #getContent content}.
     *
     * @since 1.15.0
     *
     * @returns The removed content or `null`
     */
    removeContent(
      /**
       * The content to remove or its index or id
       */
      vContent: int | string | Control
    ): Control | null;
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     * @since 1.77
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | IconTab
    ): IconTab | null;
    /**
     * Renders this item in the IconTabHeader.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    render(
      /**
       * the RenderManager that can be used for writing to the render output buffer
       */
      oRM: RenderManager,
      /**
       * the visible index within the parent control
       */
      iVisibleIndex: int,
      /**
       * the visible items count
       */
      iVisibleItemsCount: int
    ): void;
    /**
     * Renders this item in the IconTabSelectList.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    renderInSelectList(
      /**
       * RenderManager used for writing to the render output buffer
       */
      oRM: RenderManager,
      /**
       * the select list in which this filter is rendered
       */
      oSelectList: /* was: sap.m.IconTabBarSelectList */ any,
      /**
       * this item's index within the aggregation of items
       */
      iIndexInSet: int,
      /**
       * total length of the aggregation of items
       */
      iSetSize: int,
      /**
       * the padding with which the item should be indented
       */
      fPaddingValue: float
    ): void;
    /**
     * Sets a new value for property {@link #getCount count}.
     *
     * Represents the "count" text, which is displayed in the tab filter.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCount(
      /**
       * New value for property `count`
       */
      sCount?: string
    ): this;
    /**
     * Sets a new value for property {@link #getDesign design}.
     *
     * Specifies whether the icon and the texts are placed vertically or horizontally.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Vertical`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDesign(
      /**
       * New value for property `design`
       */
      sDesign?: IconTabFilterDesign | keyof typeof IconTabFilterDesign
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Specifies the icon to be displayed for the tab filter.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getIconColor iconColor}.
     *
     * Specifies the icon color.
     *
     * If an icon font is used, the color can be chosen from the icon colors (sap.ui.core.IconColor). Possible
     * semantic colors are: Neutral, Positive, Critical, Negative. Instead of the semantic icon color the brand
     * color can be used, this is named Default. Semantic colors and brand colors should not be mixed up inside
     * one IconTabBar.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Default`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconColor(
      /**
       * New value for property `iconColor`
       */
      sIconColor?: IconColor | keyof typeof IconColor
    ): this;
    /**
     * Sets a new value for property {@link #getIconDensityAware iconDensityAware}.
     *
     * If set to true, it sends one or more requests, trying to get the density perfect version of the image
     * if this version of the image doesn't exist on the server. Default value is set to true.
     *
     * If bandwidth is key for the application, set this value to false.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconDensityAware(
      /**
       * New value for property `iconDensityAware`
       */
      bIconDensityAware?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getInteractionMode interactionMode}.
     *
     * Specifies the interaction mode.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     * @experimental As of version 1.121. Disclaimer: this property is in a beta state - incompatible API changes
     * may be done before its official public release. Use at your own discretion.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInteractionMode(
      /**
       * New value for property `interactionMode`
       */
      sInteractionMode?:
        | IconTabFilterInteractionMode
        | keyof typeof IconTabFilterInteractionMode
    ): this;
    /**
     * Sets a new value for property {@link #getShowAll showAll}.
     *
     * Enables special visualization for disabled filter (show all items). **Note:** You can use this property
     * when you use `IconTabBar` as a filter. In order for it to be displayed correctly, the other tabs in the
     * filter should consist of an icon, text and an optional count. It can be set to true for the first tab
     * filter. You can find more detailed information in the {@link https://experience.sap.com/fiori-design-web/icontabbar/#tabs-as-filters UX Guidelines}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowAll(
      /**
       * New value for property `showAll`
       */
      bShowAll?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * Specifies whether the tab filter is rendered.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the IconTabFilter constructor.
   */
  export interface $IconTabFilterSettings extends $ItemSettings {
    /**
     * Represents the "count" text, which is displayed in the tab filter.
     */
    count?: string | PropertyBindingInfo;

    /**
     * Enables special visualization for disabled filter (show all items). **Note:** You can use this property
     * when you use `IconTabBar` as a filter. In order for it to be displayed correctly, the other tabs in the
     * filter should consist of an icon, text and an optional count. It can be set to true for the first tab
     * filter. You can find more detailed information in the {@link https://experience.sap.com/fiori-design-web/icontabbar/#tabs-as-filters UX Guidelines}.
     */
    showAll?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the icon to be displayed for the tab filter.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the icon color.
     *
     * If an icon font is used, the color can be chosen from the icon colors (sap.ui.core.IconColor). Possible
     * semantic colors are: Neutral, Positive, Critical, Negative. Instead of the semantic icon color the brand
     * color can be used, this is named Default. Semantic colors and brand colors should not be mixed up inside
     * one IconTabBar.
     */
    iconColor?:
      | (IconColor | keyof typeof IconColor)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * If set to true, it sends one or more requests, trying to get the density perfect version of the image
     * if this version of the image doesn't exist on the server. Default value is set to true.
     *
     * If bandwidth is key for the application, set this value to false.
     */
    iconDensityAware?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies whether the tab filter is rendered.
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies whether the icon and the texts are placed vertically or horizontally.
     */
    design?:
      | (IconTabFilterDesign | keyof typeof IconTabFilterDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies the interaction mode.
     *
     * @experimental As of version 1.121. Disclaimer: this property is in a beta state - incompatible API changes
     * may be done before its official public release. Use at your own discretion.
     */
    interactionMode?:
      | (
          | IconTabFilterInteractionMode
          | keyof typeof IconTabFilterInteractionMode
        )
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The content displayed for this item (optional).
     *
     * If this content is set, it is displayed instead of the general content inside the IconTabBar.
     *
     * @since 1.15.0
     */
    content?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * The sub items of this filter (optional).
     *
     * @since 1.77
     */
    items?: IconTab[] | IconTab | AggregationBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/IconTabHeader" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IconTab,
    BackgroundDesign,
    IconTabHeaderMode,
    IconTabDensityMode,
    TabsOverflowMode,
  } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import IconTabFilter from "sap/m/IconTabFilter";

  import Event from "sap/ui/base/Event";

  /**
   * This control displays a number of IconTabFilters and IconTabSeparators. If the available horizontal space
   * is exceeded, an overflow tab appears.
   *
   * Usage: Use `IconTabHeader` if you need it as a standalone header. If you need to manage content use {@link sap.m.IconTabBar }
   * instead.
   *
   * @since 1.15
   */
  export default class IconTabHeader extends Control {
    /**
     * Constructor for a new IconTabHeader.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $IconTabHeaderSettings
    );
    /**
     * Constructor for a new IconTabHeader.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $IconTabHeaderSettings
    );

    /**
     * Creates a new subclass of class sap.m.IconTabHeader with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, IconTabHeader>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.IconTabHeader.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: IconTab
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:select select} event of this `sap.m.IconTabHeader`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.IconTabHeader` itself.
     *
     * Fires when an item is selected.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: IconTabHeader$SelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.IconTabHeader` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:select select} event of this `sap.m.IconTabHeader`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.IconTabHeader` itself.
     *
     * Fires when an item is selected.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: IconTabHeader$SelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.IconTabHeader` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:select select} event of this `sap.m.IconTabHeader`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: IconTabHeader$SelectEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:select select} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: IconTabHeader$SelectEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getAriaTexts ariaTexts}.
     *
     * Specifies optional texts for the screen reader.
     *
     * The given object can contain the following keys: `headerLabel` - text to serve as a label for the header,
     * `headerDescription` - text to serve as a description for the header.
     *
     *
     * @returns Value of property `ariaTexts`
     */
    getAriaTexts(): {
      headerLabel: string;

      headerDescription: string;
    } | null;
    /**
     * Gets current value of property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Specifies the background color of the header.
     *
     * Depending on the theme, you can change the state of the background color to "Solid", "Translucent", or
     * "Transparent". **Note:** In SAP Belize Deep (sap_belize_plus) theme this property should be set to "Solid".
     *
     * Default value is `Solid`.
     *
     * @since 1.44
     *
     * @returns Value of property `backgroundDesign`
     */
    getBackgroundDesign(): BackgroundDesign;
    /**
     * Gets current value of property {@link #getEnableTabReordering enableTabReordering}.
     *
     * Specifies whether tab reordering is enabled. Relevant only for desktop devices. The {@link sap.m.IconTabSeparator sap.m.IconTabSeparator }
     * cannot be dragged and dropped Items can be moved around {@link sap.m.IconTabSeparator sap.m.IconTabSeparator }
     * Reordering is enabled via keyboard using `Ctrl` + arrow keys (Windows) and `Control` + arrow keys (Mac
     * OS)
     *
     * Default value is `false`.
     *
     * @since 1.46
     *
     * @returns Value of property `enableTabReordering`
     */
    getEnableTabReordering(): boolean;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * The items displayed in the IconTabHeader.
     */
    getItems(): IconTab[];
    /**
     * Gets current value of property {@link #getMaxNestingLevel maxNestingLevel}.
     *
     * Specifies the allowed level of tabs nesting within one another using drag and drop. Default value is
     * 0 which means nesting via interaction is not allowed. Maximum value is 100. This property allows nesting
     * via user interaction only, and does not restrict adding items to the `items` aggregation of {@link sap.m.IconTabFilter sap.m.IconTabFilter}.
     *
     * Default value is `0`.
     *
     * @since 1.79
     *
     * @returns Value of property `maxNestingLevel`
     */
    getMaxNestingLevel(): int;
    /**
     * Gets current value of property {@link #getMode mode}.
     *
     * Specifies the header mode.
     *
     * Default value is `Standard`.
     *
     * @since 1.40
     *
     * @returns Value of property `mode`
     */
    getMode(): IconTabHeaderMode;
    /**
     * Gets current value of property {@link #getSelectedKey selectedKey}.
     *
     * Key of the selected item.
     *
     * If the key has no corresponding aggregated item, no changes will apply. If duplicate keys exists the
     * first item matching, the key is used.
     *
     * @since 1.15.0
     *
     * @returns Value of property `selectedKey`
     */
    getSelectedKey(): string;
    /**
     * Gets current value of property {@link #getShowOverflowSelectList showOverflowSelectList}.
     *
     * Specifies if the overflow select list is displayed.
     *
     * The overflow select list represents a list, where all tab filters are displayed, so the user can select
     * specific tab filter easier.
     *
     * Default value is `false`.
     *
     * @deprecated As of version 1.75. the concept has been discarded. All tab filters that don't fit in the
     * header, will be displayed in overflow menu.
     *
     * @returns Value of property `showOverflowSelectList`
     */
    getShowOverflowSelectList(): boolean;
    /**
     * Gets current value of property {@link #getShowSelection showSelection}.
     *
     * Defines whether the current selection is visualized.
     *
     * Default value is `true`.
     *
     * @deprecated As of version 1.15.0. Regarding to changes of this control this property is not needed anymore.
     *
     * @returns Value of property `showSelection`
     */
    getShowSelection(): boolean;
    /**
     * Gets current value of property {@link #getTabDensityMode tabDensityMode}.
     *
     * Specifies the visual density mode of the tabs.
     *
     * The values that can be applied are `Cozy`, `Compact` and `Inherit`. `Cozy` and `Compact` render the control
     * in one of these modes independent of the global density settings. The `Inherit` value follows the global
     * density settings which are applied. For compatibility reasons, the default value is `Cozy`.
     *
     * Default value is `Cozy`.
     *
     * @since 1.56
     *
     * @returns Value of property `tabDensityMode`
     */
    getTabDensityMode(): IconTabDensityMode;
    /**
     * Gets current value of property {@link #getTabsOverflowMode tabsOverflowMode}.
     *
     * Specifies the overflow mode of the header.
     *
     * The default `End` mode shows as many tabs that can fit on the screen, then shows one overflow at the
     * end containing the remaining items. The `StartAndEnd` is used to keep the order of tabs intact and offers
     * overflow tabs on both ends of the bar.
     *
     * Default value is `End`.
     *
     * @since 1.90
     *
     * @returns Value of property `tabsOverflowMode`
     */
    getTabsOverflowMode(): TabsOverflowMode;
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * Specifies whether the control is rendered.
     *
     * Default value is `true`.
     *
     * @since 1.15.0
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Checks for the provided `sap.m.IconTab` in the aggregation {@link #getItems items}. and returns its index
     * if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: IconTab
    ): int;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: IconTab,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): IconTab[];
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | IconTab
    ): IconTab | null;
    /**
     * Sets a new value for property {@link #setAriaTexts ariaTexts}.
     *
     * Specifies optional texts for the screen reader.
     *
     * The given object can contain the following keys: `headerLabel` - text to serve as a label for the header,
     * `headerDescription` - text to serve as a description for the header.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAriaTexts(
      /**
       * New value for property `ariaTexts`
       */
      oAriaTexts?: {
        headerLabel: string;

        headerDescription: string;
      }
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Specifies the background color of the header.
     *
     * Depending on the theme, you can change the state of the background color to "Solid", "Translucent", or
     * "Transparent". **Note:** In SAP Belize Deep (sap_belize_plus) theme this property should be set to "Solid".
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Solid`.
     *
     * @since 1.44
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundDesign(
      /**
       * New value for property `backgroundDesign`
       */
      sBackgroundDesign?: BackgroundDesign | keyof typeof BackgroundDesign
    ): this;
    /**
     * Sets a new value for property {@link #getEnableTabReordering enableTabReordering}.
     *
     * Specifies whether tab reordering is enabled. Relevant only for desktop devices. The {@link sap.m.IconTabSeparator sap.m.IconTabSeparator }
     * cannot be dragged and dropped Items can be moved around {@link sap.m.IconTabSeparator sap.m.IconTabSeparator }
     * Reordering is enabled via keyboard using `Ctrl` + arrow keys (Windows) and `Control` + arrow keys (Mac
     * OS)
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.46
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableTabReordering(
      /**
       * New value for property `enableTabReordering`
       */
      bEnableTabReordering?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getMaxNestingLevel maxNestingLevel}.
     *
     * Specifies the allowed level of tabs nesting within one another using drag and drop. Default value is
     * 0 which means nesting via interaction is not allowed. Maximum value is 100. This property allows nesting
     * via user interaction only, and does not restrict adding items to the `items` aggregation of {@link sap.m.IconTabFilter sap.m.IconTabFilter}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     * @since 1.79
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxNestingLevel(
      /**
       * New value for property `maxNestingLevel`
       */
      iMaxNestingLevel?: int
    ): this;
    /**
     * Sets a new value for property {@link #getMode mode}.
     *
     * Specifies the header mode.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Standard`.
     *
     * @since 1.40
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMode(
      /**
       * New value for property `mode`
       */
      sMode?: IconTabHeaderMode | keyof typeof IconTabHeaderMode
    ): this;
    /**
     * Sets the selected item based on key.
     *
     *
     * @returns this pointer for chaining
     */
    setSelectedKey(
      /**
       * The key of the item to be selected
       */
      sKey: string
    ): this;
    /**
     * Sets a new value for property {@link #getShowOverflowSelectList showOverflowSelectList}.
     *
     * Specifies if the overflow select list is displayed.
     *
     * The overflow select list represents a list, where all tab filters are displayed, so the user can select
     * specific tab filter easier.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @deprecated As of version 1.75. the concept has been discarded. All tab filters that don't fit in the
     * header, will be displayed in overflow menu.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowOverflowSelectList(
      /**
       * New value for property `showOverflowSelectList`
       */
      bShowOverflowSelectList?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowSelection showSelection}.
     *
     * Defines whether the current selection is visualized.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @deprecated As of version 1.15.0. Regarding to changes of this control this property is not needed anymore.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowSelection(
      /**
       * New value for property `showSelection`
       */
      bShowSelection?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getTabDensityMode tabDensityMode}.
     *
     * Specifies the visual density mode of the tabs.
     *
     * The values that can be applied are `Cozy`, `Compact` and `Inherit`. `Cozy` and `Compact` render the control
     * in one of these modes independent of the global density settings. The `Inherit` value follows the global
     * density settings which are applied. For compatibility reasons, the default value is `Cozy`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Cozy`.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTabDensityMode(
      /**
       * New value for property `tabDensityMode`
       */
      sTabDensityMode?: IconTabDensityMode | keyof typeof IconTabDensityMode
    ): this;
    /**
     * Sets a new value for property {@link #getTabsOverflowMode tabsOverflowMode}.
     *
     * Specifies the overflow mode of the header.
     *
     * The default `End` mode shows as many tabs that can fit on the screen, then shows one overflow at the
     * end containing the remaining items. The `StartAndEnd` is used to keep the order of tabs intact and offers
     * overflow tabs on both ends of the bar.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `End`.
     *
     * @since 1.90
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTabsOverflowMode(
      /**
       * New value for property `tabsOverflowMode`
       */
      sTabsOverflowMode?: TabsOverflowMode | keyof typeof TabsOverflowMode
    ): this;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * Specifies whether the control is rendered.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.15.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the IconTabHeader constructor.
   */
  export interface $IconTabHeaderSettings extends $ControlSettings {
    /**
     * Defines whether the current selection is visualized.
     *
     * @deprecated As of version 1.15.0. Regarding to changes of this control this property is not needed anymore.
     */
    showSelection?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Key of the selected item.
     *
     * If the key has no corresponding aggregated item, no changes will apply. If duplicate keys exists the
     * first item matching, the key is used.
     *
     * @since 1.15.0
     */
    selectedKey?: string | PropertyBindingInfo;

    /**
     * Specifies whether the control is rendered.
     *
     * @since 1.15.0
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the header mode.
     *
     * @since 1.40
     */
    mode?:
      | (IconTabHeaderMode | keyof typeof IconTabHeaderMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies if the overflow select list is displayed.
     *
     * The overflow select list represents a list, where all tab filters are displayed, so the user can select
     * specific tab filter easier.
     *
     * @deprecated As of version 1.75. the concept has been discarded. All tab filters that don't fit in the
     * header, will be displayed in overflow menu.
     */
    showOverflowSelectList?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the background color of the header.
     *
     * Depending on the theme, you can change the state of the background color to "Solid", "Translucent", or
     * "Transparent". **Note:** In SAP Belize Deep (sap_belize_plus) theme this property should be set to "Solid".
     *
     * @since 1.44
     */
    backgroundDesign?:
      | (BackgroundDesign | keyof typeof BackgroundDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies whether tab reordering is enabled. Relevant only for desktop devices. The {@link sap.m.IconTabSeparator sap.m.IconTabSeparator }
     * cannot be dragged and dropped Items can be moved around {@link sap.m.IconTabSeparator sap.m.IconTabSeparator }
     * Reordering is enabled via keyboard using `Ctrl` + arrow keys (Windows) and `Control` + arrow keys (Mac
     * OS)
     *
     * @since 1.46
     */
    enableTabReordering?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the allowed level of tabs nesting within one another using drag and drop. Default value is
     * 0 which means nesting via interaction is not allowed. Maximum value is 100. This property allows nesting
     * via user interaction only, and does not restrict adding items to the `items` aggregation of {@link sap.m.IconTabFilter sap.m.IconTabFilter}.
     *
     * @since 1.79
     */
    maxNestingLevel?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the visual density mode of the tabs.
     *
     * The values that can be applied are `Cozy`, `Compact` and `Inherit`. `Cozy` and `Compact` render the control
     * in one of these modes independent of the global density settings. The `Inherit` value follows the global
     * density settings which are applied. For compatibility reasons, the default value is `Cozy`.
     *
     * @since 1.56
     */
    tabDensityMode?:
      | (IconTabDensityMode | keyof typeof IconTabDensityMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies optional texts for the screen reader.
     *
     * The given object can contain the following keys: `headerLabel` - text to serve as a label for the header,
     * `headerDescription` - text to serve as a description for the header.
     *
     * @since 1.80
     */
    ariaTexts?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the overflow mode of the header.
     *
     * The default `End` mode shows as many tabs that can fit on the screen, then shows one overflow at the
     * end containing the remaining items. The `StartAndEnd` is used to keep the order of tabs intact and offers
     * overflow tabs on both ends of the bar.
     *
     * @since 1.90
     */
    tabsOverflowMode?:
      | (TabsOverflowMode | keyof typeof TabsOverflowMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The items displayed in the IconTabHeader.
     */
    items?: IconTab[] | IconTab | AggregationBindingInfo | `{${string}}`;

    /**
     * Fires when an item is selected.
     */
    select?: (oEvent: IconTabHeader$SelectEvent) => void;
  }

  /**
   * Parameters of the IconTabHeader#select event.
   */
  export interface IconTabHeader$SelectEventParameters {
    /**
     * The selected item
     */
    item?: IconTabFilter;

    /**
     * The key of the selected item
     */
    key?: string;

    /**
     * The key of the previous selected item
     */
    previousKey?: string;
  }

  /**
   * Event object of the IconTabHeader#select event.
   */
  export type IconTabHeader$SelectEvent = Event<
    IconTabHeader$SelectEventParameters,
    IconTabHeader
  >;
}

declare module "sap/m/IconTabSeparator" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import { IconTab } from "sap/m/library";

  import { URI } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import RenderManager from "sap/ui/core/RenderManager";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Represents an Icon used to separate 2 tab filters.
   */
  export default class IconTabSeparator extends UI5Element implements IconTab {
    __implements__sap_m_IconTab: boolean;
    /**
     * Constructor for a new IconTabSeparator.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $IconTabSeparatorSettings
    );
    /**
     * Constructor for a new IconTabSeparator.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $IconTabSeparatorSettings
    );

    /**
     * Creates a new subclass of class sap.m.IconTabSeparator with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, IconTabSeparator>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.IconTabSeparator.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * The icon to display for this separator. If no icon is given, a separator line is used instead.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getIconDensityAware iconDensityAware}.
     *
     * If set to true, it sends one or more requests, trying to get the density perfect version of the image
     * if this version of the image doesn't exist on the server. Default value is set to true.
     *
     * If bandwidth is key for the application, set this value to false.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `iconDensityAware`
     */
    getIconDensityAware(): boolean;
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * Specifies whether the separator is rendered.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Renders the item in the IconTabHeader.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    render(
      /**
       * the RenderManager that can be used for writing to the render output buffer
       */
      oRM: RenderManager
    ): void;
    /**
     * Renders this item in the IconTabSelectList.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    renderInSelectList(
      /**
       * RenderManager used for writing to the render output buffer
       */
      oRM: RenderManager,
      /**
       * the select list in which this filter is rendered
       */
      oSelectList: /* was: sap.m.IconTabBarSelectList */ any,
      /**
       * this item's index within the aggregation of items
       */
      iIndexInSet: int,
      /**
       * total length of the aggregation of items
       */
      iSetSize: int,
      /**
       * the padding with which the item should be indented
       */
      fPaddingValue: float
    ): void;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * The icon to display for this separator. If no icon is given, a separator line is used instead.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getIconDensityAware iconDensityAware}.
     *
     * If set to true, it sends one or more requests, trying to get the density perfect version of the image
     * if this version of the image doesn't exist on the server. Default value is set to true.
     *
     * If bandwidth is key for the application, set this value to false.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconDensityAware(
      /**
       * New value for property `iconDensityAware`
       */
      bIconDensityAware?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * Specifies whether the separator is rendered.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the IconTabSeparator constructor.
   */
  export interface $IconTabSeparatorSettings extends $ElementSettings {
    /**
     * The icon to display for this separator. If no icon is given, a separator line is used instead.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies whether the separator is rendered.
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * If set to true, it sends one or more requests, trying to get the density perfect version of the image
     * if this version of the image doesn't exist on the server. Default value is set to true.
     *
     * If bandwidth is key for the application, set this value to false.
     */
    iconDensityAware?: boolean | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/IllustratedMessage" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { ID, TitleLevel, URI } from "sap/ui/core/library";

  import IllustratedMessageSize from "sap/m/IllustratedMessageSize";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * A combination of message and illustration to represent an empty or a success state.
   *
   * Overview:
   *
   * An `IllustratedMessage` is a recommended combination of a solution-oriented message, an engaging illustration,
   * and conversational tone to better communicate an empty or a success state than just show a message alone.
   * Empty states are moments in the user experience where there's no data to display. Success states are
   * occasions to celebrate and reward a user's special accomplishment or the completion of an important task.
   *
   * The `IllustratedMessage` control is meant to be used inside container controls, for example a `Card`,
   * a `Dialog`, or a `Page`.
   *
   * Structure:
   *
   * The `IllustratedMessage` consists of the following elements, which are displayed below each other in
   * the following order:
   * 	 - Illustration
   * 	 - Title
   * 	 - Description
   * 	 - Additional Content
   *
   * Responsive Behavior:
   *
   * The `IllustratedMessage` control can adapt depending on the API settings provided by the app developer
   * and the available space of its parent container. Some of the structural elements are displayed differently
   * or are omitted in the different breakpoint sizes (XS, S, M, L).
   *
   * @since 1.98
   */
  export default class IllustratedMessage extends Control {
    /**
     * Constructor for a new `IllustratedMessage`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $IllustratedMessageSettings
    );
    /**
     * Constructor for a new `IllustratedMessage`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $IllustratedMessageSettings
    );

    /**
     * Creates a new subclass of class sap.m.IllustratedMessage with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, IllustratedMessage>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.IllustratedMessage.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some additionalContent to the aggregation {@link #getAdditionalContent additionalContent}.
     *
     * @since 1.98
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAdditionalContent(
      /**
       * The additionalContent to add; if empty, nothing is inserted
       */
      oAdditionalContent: Control
    ): this;
    /**
     * Adds some illustrationAriaDescribedBy into the association {@link #getIllustrationAriaDescribedBy illustrationAriaDescribedBy}.
     *
     * @since 1.133.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addIllustrationAriaDescribedBy(
      /**
       * The illustrationAriaDescribedBy to add; if empty, nothing is inserted
       */
      vIllustrationAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some illustrationAriaLabelledBy into the association {@link #getIllustrationAriaLabelledBy illustrationAriaLabelledBy}.
     *
     * @since 1.106.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addIllustrationAriaLabelledBy(
      /**
       * The illustrationAriaLabelledBy to add; if empty, nothing is inserted
       */
      vIllustrationAriaLabelledBy: ID | Control
    ): this;
    /**
     * Destroys all the additionalContent in the aggregation {@link #getAdditionalContent additionalContent}.
     *
     * @since 1.98
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyAdditionalContent(): this;
    /**
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @since 1.101
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Accessibility information for `sap.m.IllustratedMessage` control
     */
    getAccessibilityInfo(): object;
    /**
     * Returns object with ID references of the title and description containers.
     *
     * **Note:** Changing the value of the `enableFormattedText` property changes the references of of title
     * and description containers.
     *
     * @since 1.98.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Object with 2 fields representing the ID references of the title and description in the IllustratedMessage
     */
    getAccessibilityReferences(): object;
    /**
     * Gets content of aggregation {@link #getAdditionalContent additionalContent}.
     *
     * Defines the controls placed below the description as additional content.
     *
     * **Note:** Not displayed when `illustrationSize` is set to `Base`.
     *
     * @since 1.98
     */
    getAdditionalContent(): Control[];
    /**
     * Gets current value of property {@link #getAriaTitleLevel ariaTitleLevel}.
     *
     * Defines the semantic level of the title. When using `Auto`, no explicit level information is written.
     *
     * **Note:** Used for accessibility purposes only.
     *
     * Default value is `Auto`.
     *
     * @since 1.111
     *
     * @returns Value of property `ariaTitleLevel`
     */
    getAriaTitleLevel(): TitleLevel;
    /**
     * Gets current value of property {@link #getDescription description}.
     *
     * Defines the description displayed below the title.
     *
     * If there is no initial input from the app developer, `enableDefaultTitleAndDescription` is `true` and
     * the default illustration set is being used, a default description for the current illustration type is
     * going to be displayed. The default description is stored in the `sap.m` resource bundle.
     *
     * Default value is `empty string`.
     *
     * @since 1.98
     *
     * @returns Value of property `description`
     */
    getDescription(): string;
    /**
     * Gets current value of property {@link #getEnableDefaultTitleAndDescription enableDefaultTitleAndDescription}.
     *
     * Defines whether the default title and description should be used when the input for their respective
     * part is empty and the default illustration set is being used. Title and description are stored in the
     * `sap.m` resource bundle.
     *
     * Default value is `true`.
     *
     * @since 1.111
     *
     * @returns Value of property `enableDefaultTitleAndDescription`
     */
    getEnableDefaultTitleAndDescription(): boolean;
    /**
     * Gets current value of property {@link #getEnableFormattedText enableFormattedText}.
     *
     * Defines whether the value set in the `description` property is displayed as formatted text in HTML format.
     *
     * For details regarding supported HTML tags, see {@link sap.m.FormattedText}.
     *
     * Default value is `false`.
     *
     * @since 1.98
     *
     * @returns Value of property `enableFormattedText`
     */
    getEnableFormattedText(): boolean;
    /**
     * Gets current value of property {@link #getEnableVerticalResponsiveness enableVerticalResponsiveness}.
     *
     * Defines whether the `IllustratedMessage` would resize itself according to it's height if `illustrationSize`
     * property is set to `IllustratedMessageSize.Auto`.
     *
     * Default value is `false`.
     *
     * @since 1.104
     *
     * @returns Value of property `enableVerticalResponsiveness`
     */
    getEnableVerticalResponsiveness(): boolean;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getIllustrationAriaDescribedBy illustrationAriaDescribedBy}.
     *
     * @since 1.133.0
     */
    getIllustrationAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getIllustrationAriaLabelledBy illustrationAriaLabelledBy}.
     *
     * @since 1.106.0
     */
    getIllustrationAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getIllustrationSize illustrationSize}.
     *
     * Determines which illustration breakpoint variant is used.
     *
     * As `IllustratedMessage` adapts itself around the `Illustration`, the other elements of the control are
     * displayed differently on the different breakpoints/illustration sizes.
     *
     * Default value is `Auto`.
     *
     * @since 1.98
     *
     * @returns Value of property `illustrationSize`
     */
    getIllustrationSize(): IllustratedMessageSize;
    /**
     * Gets current value of property {@link #getIllustrationType illustrationType}.
     *
     * Determines which illustration type is displayed.
     *
     * **Note:** The {@link sap.m.IllustratedMessageType} enumeration contains a default illustration set. If
     * you want to use another illustration set, you have to register it in the {@link sap.m.IllustrationPool}.
     *
     * Example input for the `illustrationType` property is `sapIllus-UnableToLoad`. The logic behind this format
     * is as follows:
     * 	 - First is the the illustration set - sapIllus
     * 	 - Second is the illustration type - UnableToLoad
     * 	 - The `src` property takes precedence over this property.
     *
     * Default value is `IllustratedMessageType.NoSearchResults`.
     *
     * @since 1.98
     *
     * @returns Value of property `illustrationType`
     */
    getIllustrationType(): string;
    /**
     * Gets current value of property {@link #getSrc src}.
     *
     * Defines the illustration to be displayed as graphical element within the `IllustratedMessage`. It can
     * be an illustration from the illustration set described in the URI.
     *
     * **Notes:**
     * 	 - The `sap-illustration://name` syntax supports only the default illustration set. If you want to include
     *     another illustration set in the URI `sap-illustration://tnt/name`, you have to register it in the {@link sap.m.IllustrationPool}.
     *
     * 	 - This property takes precedence over the `illustrationType` property.
     *
     * Default value is `empty string`.
     *
     * @since 1.132
     *
     * @returns Value of property `src`
     */
    getSrc(): URI;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Defines the title that is displayed below the illustration.
     *
     * If there is no initial input from the app developer, `enableDefaultTitleAndDescription` is `true` and
     * the default illustration set is being used, a default title is displayed corresponding to the current
     * `illustrationType`. The default title is stored in the `sap.m` resource bundle.
     *
     * Default value is `empty string`.
     *
     * @since 1.98
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getAdditionalContent additionalContent}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.98
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfAdditionalContent(
      /**
       * The additionalContent whose index is looked for
       */
      oAdditionalContent: Control
    ): int;
    /**
     * Inserts a additionalContent into the aggregation {@link #getAdditionalContent additionalContent}.
     *
     * @since 1.98
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertAdditionalContent(
      /**
       * The additionalContent to insert; if empty, nothing is inserted
       */
      oAdditionalContent: Control,
      /**
       * The `0`-based index the additionalContent should be inserted at; for a negative value of `iIndex`, the
       * additionalContent is inserted at position 0; for a value greater than the current size of the aggregation,
       * the additionalContent is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes a additionalContent from the aggregation {@link #getAdditionalContent additionalContent}.
     *
     * @since 1.98
     *
     * @returns The removed additionalContent or `null`
     */
    removeAdditionalContent(
      /**
       * The additionalContent to remove or its index or id
       */
      vAdditionalContent: int | string | Control
    ): Control | null;
    /**
     * Removes all the controls from the aggregation {@link #getAdditionalContent additionalContent}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.98
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAdditionalContent(): Control[];
    /**
     * Removes all the controls in the association named {@link #getIllustrationAriaDescribedBy illustrationAriaDescribedBy}.
     *
     * @since 1.133.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllIllustrationAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getIllustrationAriaLabelledBy illustrationAriaLabelledBy}.
     *
     * @since 1.106.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllIllustrationAriaLabelledBy(): ID[];
    /**
     * Removes an illustrationAriaDescribedBy from the association named {@link #getIllustrationAriaDescribedBy illustrationAriaDescribedBy}.
     *
     * @since 1.133.0
     *
     * @returns The removed illustrationAriaDescribedBy or `null`
     */
    removeIllustrationAriaDescribedBy(
      /**
       * The illustrationAriaDescribedBy to be removed or its index or ID
       */
      vIllustrationAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an illustrationAriaLabelledBy from the association named {@link #getIllustrationAriaLabelledBy illustrationAriaLabelledBy}.
     *
     * @since 1.106.0
     *
     * @returns The removed illustrationAriaLabelledBy or `null`
     */
    removeIllustrationAriaLabelledBy(
      /**
       * The illustrationAriaLabelledBy to be removed or its index or ID
       */
      vIllustrationAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getAriaTitleLevel ariaTitleLevel}.
     *
     * Defines the semantic level of the title. When using `Auto`, no explicit level information is written.
     *
     * **Note:** Used for accessibility purposes only.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     * @since 1.111
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAriaTitleLevel(
      /**
       * New value for property `ariaTitleLevel`
       */
      sAriaTitleLevel?: TitleLevel | keyof typeof TitleLevel
    ): this;
    /**
     * Sets a new value for property {@link #getDescription description}.
     *
     * Defines the description displayed below the title.
     *
     * If there is no initial input from the app developer, `enableDefaultTitleAndDescription` is `true` and
     * the default illustration set is being used, a default description for the current illustration type is
     * going to be displayed. The default description is stored in the `sap.m` resource bundle.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.98
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDescription(
      /**
       * New value for property `description`
       */
      sDescription?: string
    ): this;
    /**
     * Sets a new value for property {@link #getEnableDefaultTitleAndDescription enableDefaultTitleAndDescription}.
     *
     * Defines whether the default title and description should be used when the input for their respective
     * part is empty and the default illustration set is being used. Title and description are stored in the
     * `sap.m` resource bundle.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.111
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableDefaultTitleAndDescription(
      /**
       * New value for property `enableDefaultTitleAndDescription`
       */
      bEnableDefaultTitleAndDescription?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnableFormattedText enableFormattedText}.
     *
     * Defines whether the value set in the `description` property is displayed as formatted text in HTML format.
     *
     * For details regarding supported HTML tags, see {@link sap.m.FormattedText}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.98
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableFormattedText(
      /**
       * New value for property `enableFormattedText`
       */
      bEnableFormattedText?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnableVerticalResponsiveness enableVerticalResponsiveness}.
     *
     * Defines whether the `IllustratedMessage` would resize itself according to it's height if `illustrationSize`
     * property is set to `IllustratedMessageSize.Auto`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.104
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableVerticalResponsiveness(
      /**
       * New value for property `enableVerticalResponsiveness`
       */
      bEnableVerticalResponsiveness?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIllustrationSize illustrationSize}.
     *
     * Determines which illustration breakpoint variant is used.
     *
     * As `IllustratedMessage` adapts itself around the `Illustration`, the other elements of the control are
     * displayed differently on the different breakpoints/illustration sizes.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     * @since 1.98
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIllustrationSize(
      /**
       * New value for property `illustrationSize`
       */
      sIllustrationSize?:
        | IllustratedMessageSize
        | keyof typeof IllustratedMessageSize
    ): this;
    /**
     * Sets a new value for property {@link #getIllustrationType illustrationType}.
     *
     * Determines which illustration type is displayed.
     *
     * **Note:** The {@link sap.m.IllustratedMessageType} enumeration contains a default illustration set. If
     * you want to use another illustration set, you have to register it in the {@link sap.m.IllustrationPool}.
     *
     * Example input for the `illustrationType` property is `sapIllus-UnableToLoad`. The logic behind this format
     * is as follows:
     * 	 - First is the the illustration set - sapIllus
     * 	 - Second is the illustration type - UnableToLoad
     * 	 - The `src` property takes precedence over this property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `IllustratedMessageType.NoSearchResults`.
     *
     * @since 1.98
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIllustrationType(
      /**
       * New value for property `illustrationType`
       */
      sIllustrationType?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSrc src}.
     *
     * Defines the illustration to be displayed as graphical element within the `IllustratedMessage`. It can
     * be an illustration from the illustration set described in the URI.
     *
     * **Notes:**
     * 	 - The `sap-illustration://name` syntax supports only the default illustration set. If you want to include
     *     another illustration set in the URI `sap-illustration://tnt/name`, you have to register it in the {@link sap.m.IllustrationPool}.
     *
     * 	 - This property takes precedence over the `illustrationType` property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.132
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSrc(
      /**
       * New value for property `src`
       */
      sSrc?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Defines the title that is displayed below the illustration.
     *
     * If there is no initial input from the app developer, `enableDefaultTitleAndDescription` is `true` and
     * the default illustration set is being used, a default title is displayed corresponding to the current
     * `illustrationType`. The default title is stored in the `sap.m` resource bundle.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.98
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the IllustratedMessage constructor.
   */
  export interface $IllustratedMessageSettings extends $ControlSettings {
    /**
     * Defines the description displayed below the title.
     *
     * If there is no initial input from the app developer, `enableDefaultTitleAndDescription` is `true` and
     * the default illustration set is being used, a default description for the current illustration type is
     * going to be displayed. The default description is stored in the `sap.m` resource bundle.
     *
     * @since 1.98
     */
    description?: string | PropertyBindingInfo;

    /**
     * Defines whether the default title and description should be used when the input for their respective
     * part is empty and the default illustration set is being used. Title and description are stored in the
     * `sap.m` resource bundle.
     *
     * @since 1.111
     */
    enableDefaultTitleAndDescription?:
      | boolean
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines whether the value set in the `description` property is displayed as formatted text in HTML format.
     *
     * For details regarding supported HTML tags, see {@link sap.m.FormattedText}.
     *
     * @since 1.98
     */
    enableFormattedText?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether the `IllustratedMessage` would resize itself according to it's height if `illustrationSize`
     * property is set to `IllustratedMessageSize.Auto`.
     *
     * @since 1.104
     */
    enableVerticalResponsiveness?:
      | boolean
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines which illustration breakpoint variant is used.
     *
     * As `IllustratedMessage` adapts itself around the `Illustration`, the other elements of the control are
     * displayed differently on the different breakpoints/illustration sizes.
     *
     * @since 1.98
     */
    illustrationSize?:
      | (IllustratedMessageSize | keyof typeof IllustratedMessageSize)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines which illustration type is displayed.
     *
     * **Note:** The {@link sap.m.IllustratedMessageType} enumeration contains a default illustration set. If
     * you want to use another illustration set, you have to register it in the {@link sap.m.IllustrationPool}.
     *
     * Example input for the `illustrationType` property is `sapIllus-UnableToLoad`. The logic behind this format
     * is as follows:
     * 	 - First is the the illustration set - sapIllus
     * 	 - Second is the illustration type - UnableToLoad
     * 	 - The `src` property takes precedence over this property.
     *
     * @since 1.98
     */
    illustrationType?: string | PropertyBindingInfo;

    /**
     * Defines the illustration to be displayed as graphical element within the `IllustratedMessage`. It can
     * be an illustration from the illustration set described in the URI.
     *
     * **Notes:**
     * 	 - The `sap-illustration://name` syntax supports only the default illustration set. If you want to include
     *     another illustration set in the URI `sap-illustration://tnt/name`, you have to register it in the {@link sap.m.IllustrationPool}.
     *
     * 	 - This property takes precedence over the `illustrationType` property.
     *
     * @since 1.132
     */
    src?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the title that is displayed below the illustration.
     *
     * If there is no initial input from the app developer, `enableDefaultTitleAndDescription` is `true` and
     * the default illustration set is being used, a default title is displayed corresponding to the current
     * `illustrationType`. The default title is stored in the `sap.m` resource bundle.
     *
     * @since 1.98
     */
    title?: string | PropertyBindingInfo;

    /**
     * Defines the semantic level of the title. When using `Auto`, no explicit level information is written.
     *
     * **Note:** Used for accessibility purposes only.
     *
     * @since 1.111
     */
    ariaTitleLevel?:
      | (TitleLevel | keyof typeof TitleLevel)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the controls placed below the description as additional content.
     *
     * **Note:** Not displayed when `illustrationSize` is set to `Base`.
     *
     * @since 1.98
     */
    additionalContent?:
      | Control[]
      | Control
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Association to controls / IDs which label those controls (see WAI-ARIA attribute aria-labelledBy).
     *
     * @since 1.106.0
     */
    illustrationAriaLabelledBy?: Array<Control | string>;

    /**
     * Association to controls / IDs which label those controls (see WAI-ARIA attribute aria-describedBy).
     *
     * @since 1.133.0
     */
    illustrationAriaDescribedBy?: Array<Control | string>;
  }
}

declare module "sap/m/IllustratedMessageSize" {
  /**
   * Available `Illustration` sizes for the {@link sap.m.IllustratedMessage} control.
   *
   * @since 1.98
   */
  enum IllustratedMessageSize {
    /**
     * Automatically decides the `Illustration` size (`Base`, `Spot`, `Dialog`, or `Scene`) depending on the
     * `IllustratedMessage` container width.
     *
     * **Note:** `Auto` is the only option where the illustration size is changed according to the available
     * container width. If any other `IllustratedMessageSize` is chosen, it remains until changed by the app
     * developer.
     */
    Auto = "Auto",
    /**
     * Base `Illustration` size. Suitable for cards (two columns).
     *
     * **Note:** When `Base` is in use, no illustration is displayed.
     */
    Base = "Base",
    /**
     * Dialog `Illustration` size (M breakpoint). Suitable for dialogs.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageSize.Medium}
     */
    Dialog = "Dialog",
    /**
     * Dot `Illustration` size (XS breakpoint). Suitable for spaces with little vertical space.
     *
     * @since 1.108
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageSize.ExtraSmall}
     */
    Dot = "Dot",
    /**
     * Extra Small `Illustration` size. Alias for `Dot` size (XS breakpoint). Suitable for spaces with little
     * vertical space.
     *
     * @since 1.136
     */
    ExtraSmall = "ExtraSmall",
    /**
     * Large `Illustration` size. Alias for `Scene` size (L breakpoint). Suitable for a `Page` or a table.
     *
     * @since 1.136
     */
    Large = "Large",
    /**
     * Medium `Illustration` size. Alias for `Dialog` size (M breakpoint). Suitable for dialogs.
     *
     * @since 1.136
     */
    Medium = "Medium",
    /**
     * Scene `Illustration` size (L breakpoint). Suitable for a `Page` or a table.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageSize.Large}
     */
    Scene = "Scene",
    /**
     * Small `Illustration` size. Alias for `Spot` size (S breakpoint). Suitable for cards (four columns).
     *
     * @since 1.136
     */
    Small = "Small",
    /**
     * Spot `Illustration` size (S breakpoint). Suitable for cards (four columns).
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageSize.Small}
     */
    Spot = "Spot",
  }
  export default IllustratedMessageSize;
}

declare module "sap/m/IllustratedMessageType" {
  /**
   * Available `Illustration` types for the {@link sap.m.IllustratedMessage} control.
   *
   * @since 1.98
   */
  enum IllustratedMessageType {
    /**
     * "Achievement" illustration type.
     */
    Achievement = "sapIllus-Achievement",
    /**
     * "Add Column" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.AddingColumns}
     */
    AddColumn = "sapIllus-AddColumn",
    /**
     * "Add Dimensions" illustration type.
     */
    AddDimensions = "sapIllus-AddDimensions",
    /**
     * "Adding Columns" illustration type.
     */
    AddingColumns = "sapIllus-AddingColumns",
    /**
     * "Add People" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.AddPeopleToCalendar}
     */
    AddPeople = "sapIllus-AddPeople",
    /**
     * "Add People To Calendar" illustration type.
     */
    AddPeopleToCalendar = "sapIllus-AddPeopleToCalendar",
    /**
     * "Balloon Sky" illustration type.
     *
     * @deprecated As of version 1.136. replaced by {@link sap.m.IllustratedMessageType.ReceiveAppreciation}
     */
    BalloonSky = "sapIllus-BalloonSky",
    /**
     * "Before Search" illustration type.
     */
    BeforeSearch = "sapIllus-BeforeSearch",
    /**
     * "Connection" illustration type.
     *
     * @deprecated As of version 1.136. replaced by {@link sap.m.IllustratedMessageType.UnableToLoad}
     */
    Connection = "sapIllus-Connection",
    /**
     * "Drag Files To Upload" illustration type.
     */
    DragFilesToUpload = "sapIllus-DragFilesToUpload",
    /**
     * "Empty Calendar" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.NoActivities}
     */
    EmptyCalendar = "sapIllus-EmptyCalendar",
    /**
     * "Empty List" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.NoEntries}
     */
    EmptyList = "sapIllus-EmptyList",
    /**
     * "Empty Planning Calendar" illustration type.
     */
    EmptyPlanningCalendar = "sapIllus-EmptyPlanningCalendar",
    /**
     * "Error Screen" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.UnableToUpload}
     */
    ErrorScreen = "sapIllus-ErrorScreen",
    /**
     * "Filtering Columns" illustration type.
     */
    FilteringColumns = "sapIllus-FilteringColumns",
    /**
     * "Filter Table" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.FilteringColumns}
     */
    FilterTable = "sapIllus-FilterTable",
    /**
     * "Grouping Columns" illustration type.
     */
    GroupingColumns = "sapIllus-GroupingColumns",
    /**
     * "Group Table" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.GroupingColumns}
     */
    GroupTable = "sapIllus-GroupTable",
    /**
     * "KeyTask" illustration type.
     */
    KeyTask = "sapIllus-KeyTask",
    /**
     * "New Mail" illustration type.
     */
    NewMail = "sapIllus-NewMail",
    /**
     * "No Activities" illustration type.
     */
    NoActivities = "sapIllus-NoActivities",
    /**
     * "No Chart Data" illustration type.
     */
    NoChartData = "sapIllus-NoChartData",
    /**
     * "No Columns Set" illustration type.
     */
    NoColumnsSet = "sapIllus-NoColumnsSet",
    /**
     * "No Data" illustration type.
     */
    NoData = "sapIllus-NoData",
    /**
     * "No Dimensions Set" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.NoChartData}
     */
    NoDimensionsSet = "sapIllus-NoDimensionsSet",
    /**
     * "No Entries" illustration type.
     */
    NoEntries = "sapIllus-NoEntries",
    /**
     * "No Filter Results" illustration type.
     */
    NoFilterResults = "sapIllus-NoFilterResults",
    /**
     * "No Email" illustration type.
     */
    NoMail = "sapIllus-NoMail",
    /**
     * "No Email v1" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.NoMail}
     */
    NoMailV1 = "sapIllus-NoMail_v1",
    /**
     * "No Notifications" illustration type.
     */
    NoNotifications = "sapIllus-NoNotifications",
    /**
     * "No Saved Items" illustration type.
     */
    NoSavedItems = "sapIllus-NoSavedItems",
    /**
     * "No Saved Items v1" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.NoSavedItems}
     */
    NoSavedItemsV1 = "sapIllus-NoSavedItems_v1",
    /**
     * "No Search Results" illustration type.
     */
    NoSearchResults = "sapIllus-NoSearchResults",
    /**
     * "No Tasks" illustration type.
     */
    NoTasks = "sapIllus-NoTasks",
    /**
     * "No Tasks v1" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.NoTasks}
     */
    NoTasksV1 = "sapIllus-NoTasks_v1",
    /**
     * "Page Not Found" illustration type.
     */
    PageNotFound = "sapIllus-PageNotFound",
    /**
     * "Receive Appreciation" illustration type.
     */
    ReceiveAppreciation = "sapIllus-ReceiveAppreciation",
    /**
     * "Reload Screen" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.UnableToLoad}
     */
    ReloadScreen = "sapIllus-ReloadScreen",
    /**
     * "Resize Column" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.ResizingColumns}
     */
    ResizeColumn = "sapIllus-ResizeColumn",
    /**
     * "Resizing Columns" illustration type.
     */
    ResizingColumns = "sapIllus-ResizingColumns",
    /**
     * "Search Earth" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.BeforeSearch}
     */
    SearchEarth = "sapIllus-SearchEarth",
    /**
     * "Search Folder" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.NoSearchResults}
     */
    SearchFolder = "sapIllus-SearchFolder",
    /**
     * "Sign Out" illustration type.
     */
    SignOut = "sapIllus-SignOut",
    /**
     * "Simple Balloon" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.ReceiveAppreciation}
     */
    SimpleBalloon = "sapIllus-SimpleBalloon",
    /**
     * "Simple Bell" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.NoNotifications}
     */
    SimpleBell = "sapIllus-SimpleBell",
    /**
     * "Simple Calendar" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.NoActivities}
     */
    SimpleCalendar = "sapIllus-SimpleCalendar",
    /**
     * "Simple CheckMark" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.KeyTask}
     */
    SimpleCheckMark = "sapIllus-SimpleCheckMark",
    /**
     * "Simple Connection" illustration type.
     *
     * @deprecated As of version 1.136. replaced by {@link sap.m.IllustratedMessageType.UnableToLoad}
     */
    SimpleConnection = "sapIllus-SimpleConnection",
    /**
     * "Simple Empty Doc" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.NoData}
     */
    SimpleEmptyDoc = "sapIllus-SimpleEmptyDoc",
    /**
     * "Simple Empty List" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.NoEntries}
     */
    SimpleEmptyList = "sapIllus-SimpleEmptyList",
    /**
     * "Simple Error" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.UnableToUpload}
     */
    SimpleError = "sapIllus-SimpleError",
    /**
     * "Simple Magnifier" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.BeforeSearch}
     */
    SimpleMagnifier = "sapIllus-SimpleMagnifier",
    /**
     * "Simple Mail" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.NoMail}
     */
    SimpleMail = "sapIllus-SimpleMail",
    /**
     * "Simple No Saved Items" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.NoSavedItems}
     */
    SimpleNoSavedItems = "sapIllus-SimpleNoSavedItems",
    /**
     * "Simple Not Found Magnifier" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.NoSearchResults}
     */
    SimpleNotFoundMagnifier = "sapIllus-SimpleNotFoundMagnifier",
    /**
     * "Simple Reload" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.UnableToLoad}
     */
    SimpleReload = "sapIllus-SimpleReload",
    /**
     * "Simple Task" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.NoTasks}
     */
    SimpleTask = "sapIllus-SimpleTask",
    /**
     * "Sleeping Bell" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.NoNotifications}
     */
    SleepingBell = "sapIllus-SleepingBell",
    /**
     * "Sort Column" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.SortingColumns}
     */
    SortColumn = "sapIllus-SortColumn",
    /**
     * "Sorting Columns" illustration type.
     */
    SortingColumns = "sapIllus-SortingColumns",
    /**
     * "Success Balloon" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.ReceiveAppreciation}
     */
    SuccessBalloon = "sapIllus-SuccessBalloon",
    /**
     * "Success CheckMark" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.KeyTask}
     */
    SuccessCheckMark = "sapIllus-SuccessCheckMark",
    /**
     * "Success HighFive" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.ReceiveAppreciation}
     */
    SuccessHighFive = "sapIllus-SuccessHighFive",
    /**
     * "Success Screen" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.KeyTask}
     */
    SuccessScreen = "sapIllus-SuccessScreen",
    /**
     * "Survey" illustration type.
     */
    Survey = "sapIllus-Survey",
    /**
     * "Tent" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.NoData}
     */
    Tent = "sapIllus-Tent",
    /**
     * "Unable To Load" illustration type.
     */
    UnableToLoad = "sapIllus-UnableToLoad",
    /**
     * "Unable To Load Image" illustration type.
     */
    UnableToLoadImage = "sapIllus-UnableToLoadImage",
    /**
     * "Unable To Upload" illustration type.
     */
    UnableToUpload = "sapIllus-UnableToUpload",
    /**
     * "Upload Collection" illustration type.
     *
     * @deprecated As of version 1.135. replaced by {@link sap.m.IllustratedMessageType.DragFilesToUpload}
     */
    UploadCollection = "sapIllus-UploadCollection",
    /**
     * "Upload To Cloud" illustration type.
     */
    UploadToCloud = "sapIllus-UploadToCloud",
    /**
     * "User has signed up for an application" illustration type.
     */
    UserHasSignedUp = "sapIllus-UserHasSignedUp",
  }
  export default IllustratedMessageType;
}

declare module "sap/m/Illustration" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { ID } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * A simple control which uses a Symbol ID to visualize an SVG which has already been loaded in the {@link sap.m.IllustrationPool}.
   *
   * To build a Symbol ID, all of the `Illustration` properties must be populated with data.
   *
   * @since 1.98
   */
  export default class Illustration extends Control {
    /**
     * Constructor for a new `Illustration`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $IllustrationSettings
    );
    /**
     * Constructor for a new `Illustration`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $IllustrationSettings
    );

    /**
     * Creates a new subclass of class sap.m.Illustration with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Illustration>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Illustration.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     * @since 1.133.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.106.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     * @since 1.133.0
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.106.0
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getMedia media}.
     *
     * Defines which media/breakpoint should be used when building the Symbol ID.
     *
     * @since 1.98
     *
     * @returns Value of property `media`
     */
    getMedia(): string;
    /**
     * Gets current value of property {@link #getSet set}.
     *
     * Defines which illustration set should be used when building the Symbol ID.
     *
     * @since 1.98
     *
     * @returns Value of property `set`
     */
    getSet(): string;
    /**
     * Gets current value of property {@link #getType type}.
     *
     * Defines which illustration type should be used when building the Symbol ID.
     *
     * @since 1.98
     *
     * @returns Value of property `type`
     */
    getType(): string;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     * @since 1.133.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.106.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     * @since 1.133.0
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.106.0
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getMedia media}.
     *
     * Defines which media/breakpoint should be used when building the Symbol ID.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.98
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMedia(
      /**
       * New value for property `media`
       */
      sMedia?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSet set}.
     *
     * Defines which illustration set should be used when building the Symbol ID.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.98
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSet(
      /**
       * New value for property `set`
       */
      sSet?: string
    ): this;
    /**
     * Sets a new value for property {@link #getType type}.
     *
     * Defines which illustration type should be used when building the Symbol ID.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.98
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setType(
      /**
       * New value for property `type`
       */
      sType?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Illustration constructor.
   */
  export interface $IllustrationSettings extends $ControlSettings {
    /**
     * Defines which illustration set should be used when building the Symbol ID.
     *
     * @since 1.98
     */
    set?: string | PropertyBindingInfo;

    /**
     * Defines which media/breakpoint should be used when building the Symbol ID.
     *
     * @since 1.98
     */
    media?: string | PropertyBindingInfo;

    /**
     * Defines which illustration type should be used when building the Symbol ID.
     *
     * @since 1.98
     */
    type?: string | PropertyBindingInfo;

    /**
     * Association to controls / IDs which label those controls (see WAI-ARIA attribute aria-labelledBy).
     *
     * @since 1.106.0
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Association to controls / IDs which label those controls (see WAI-ARIA attribute aria-describedBy).
     *
     * @since 1.133.0
     */
    ariaDescribedBy?: Array<Control | string>;
  }
}

declare module "sap/m/IllustrationPool" {
  /**
   * `IllustrationPool` loads the illustration assets (SVGs) via XMLHttpRequest requests.
   *
   * The successfully loaded data is kept in the DOM (div with ID `sap-illustration-pool`) in the `sap-ui-static`
   * DOM element.
   *
   * To load a given asset, register its illustration set through the {@link sap.m.IllustrationPool.registerIllustrationSet registerIllustrationSet }
   * API of `IllustrationPool`. The exception being the `sapIllus`, which is the default illustration set
   * that is registered by default.
   *
   * The default behavior of `IllustrationPool` is to load/require an asset only when it's needed by using
   * the {@link sap.m.IllustrationPool.loadAsset} API. When registering the new illustration set, you are
   * given the option to load all of its assets.
   *
   * If some of the assets are not loaded initially, you can load the rest of them on a later state with the
   * {@link sap.m.IllustrationPool.loadRestOfTheAssets} API.
   *
   * @since 1.98
   */
  interface IllustrationPool {
    /**
     * Returns the metadata of an Illustration Set. The metadata contains the names of the symbols and the theme
     * mappings. If the Illustration Set is not registered, an error is logged and null is returned.
     *
     * @since 1.116.0
     *
     * @returns The metadata of the Illustration Set
     */
    getIllustrationSetMetadata(
      /**
       * The name of the illustration set
       */
      sSet: string
    ): object;
    /**
     * Loads an SVG asset depending on the input asset ID.
     */
    loadAsset(
      /**
       * The string ID of the asset being loaded
       */
      sAssetId: string,
      /**
       * the ID of the Illustration instance which is requiring the asset
       */
      sInstanceId: string,
      /**
       * The prefix of the path of the asset being loaded. Used for loading assets from different collections.
       * Used to store the asset ID in the DOM pool, so it can be distinguished from other assets with the same
       * ID.
       */
      sIdPrefix: string
    ): void;
    /**
     * Loads the rest of the SVG assets for a given illustration set.
     */
    loadRestOfTheAssets(
      /**
       * The illustration set, the rest of the assets should be loaded for
       */
      sIllustrationSet: string
    ): void;
    /**
     * Registers an illustration set, which is needed before loading any of its assets.
     */
    registerIllustrationSet(
      /**
       * object containing the name and the path of the Illustration Set
       */
      oConfig: {
        /**
         * Name of the Illustration Set
         */
        setFamily: string;
        /**
         * URL Path of the Illustration Set
         */
        setURI: string;
      },
      /**
       * whether or not all of the assets for the Illustration Set should be loaded once the metadata is loaded
       */
      bLoadAllResources: boolean,
      /**
       * optional array containing the Illustration Set symbols
       */
      aOptionalSymbols: any[]
    ): void;
  }
  const IllustrationPool: IllustrationPool;
  export default IllustrationPool;
}

declare module "sap/m/Image" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IFormContent,
    ID,
    AccessibilityInfo,
    URI,
    aria,
    CSSSize,
  } from "sap/ui/core/library";

  import Event from "sap/ui/base/Event";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import LightBox from "sap/m/LightBox";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { ImageMode } from "sap/m/library";

  /**
   * A wrapper around the <img> tag; the image can be loaded from a remote or local server.
   *
   * If property `densityAware` is true, a density-specific image will be loaded by constructing a density-specific
   * image name in format `[imageName]@[densityValue].[extension]` from the given `src` and the `devicePixelRatio`
   * of the current device. The only supported density values are 1, 1.5 and 2. If the original `devicePixelRatio`
   * ratio isn't one of the three valid numbers, it will be rounded to the nearest one.
   *
   * There are various size setting options available, and the images can be combined with actions.
   *
   * From version 1.30, a new image mode {@link sap.m.ImageMode.Background} is added. When this mode is set,
   * the `src` property is set using the CSS style `background-image`. The properties `backgroundSize`, `backgroundPosition`,
   * and `backgroundRepeat` take effect only when the image is in `sap.m.ImageMode.Background` mode. In order
   * to display the high density image correctly, the `backgroundSize` should be set to the dimension of the
   * normal density version.
   */
  export default class Image extends Control implements IFormContent {
    __implements__sap_ui_core_IFormContent: boolean;
    /**
     * Constructor for a new Image.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/f86dbe9d7f7d48dea5286003b1322165 Image}
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/image/ Image}
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $ImageSettings
    );
    /**
     * Constructor for a new Image.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/f86dbe9d7f7d48dea5286003b1322165 Image}
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/image/ Image}
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $ImageSettings
    );

    /**
     * Creates a new subclass of class sap.m.Image with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Image>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Image.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Checks if the given value is valid for the `background-position` CSS property
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns the check result
     */
    _isValidBackgroundPositionValue(
      /**
       * the value to check
       */
      sValue: string
    ): boolean;
    /**
     * Checks if the given value is valid for the `background-size` CSS property
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns the check result
     */
    _isValidBackgroundSizeValue(
      /**
       * the value to check
       */
      sValue: string
    ): boolean;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaDetails into the association {@link #getAriaDetails ariaDetails}.
     *
     * @since 1.79
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDetails(
      /**
       * The ariaDetails to add; if empty, nothing is inserted
       */
      vAriaDetails: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:error error} event of this `sap.m.Image`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Image` itself.
     *
     * Event is fired when the image resource can't be loaded. If densityAware is set to true, the event is
     * fired when none of the fallback resources can be loaded.
     *
     * @since 1.36.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachError(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Image` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:error error} event of this `sap.m.Image`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Image` itself.
     *
     * Event is fired when the image resource can't be loaded. If densityAware is set to true, the event is
     * fired when none of the fallback resources can be loaded.
     *
     * @since 1.36.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachError(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Image` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:load load} event of this `sap.m.Image`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Image` itself.
     *
     * Event is fired when the image resource is loaded.
     *
     * @since 1.36.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLoad(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Image` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:load load} event of this `sap.m.Image`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Image` itself.
     *
     * Event is fired when the image resource is loaded.
     *
     * @since 1.36.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLoad(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Image` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.Image`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Image` itself.
     *
     * Event is fired when the user clicks on the control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Image` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.Image`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Image` itself.
     *
     * Event is fired when the user clicks on the control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Image` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tap tap} event of this `sap.m.Image`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Image` itself.
     *
     * Event is fired when the user clicks on the control.
     *
     * @deprecated As of version 1.107.0. Use the {@link #event:press press} event instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTap(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Image` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tap tap} event of this `sap.m.Image`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Image` itself.
     *
     * Event is fired when the user clicks on the control.
     *
     * @deprecated As of version 1.107.0. Use the {@link #event:press press} event instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTap(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Image` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getDetailBox detailBox} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindDetailBox(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys the detailBox in the aggregation {@link #getDetailBox detailBox}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyDetailBox(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:error error} event of this `sap.m.Image`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.36.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachError(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:load load} event of this `sap.m.Image`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.36.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLoad(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.Image`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:tap tap} event of this `sap.m.Image`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @deprecated As of version 1.107.0. Use the {@link #event:press press} event instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachTap(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:error error} to attached listeners.
     *
     * @since 1.36.2
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireError(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:load load} to attached listeners.
     *
     * @since 1.36.2
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLoad(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:tap tap} to attached listeners.
     *
     * @deprecated As of version 1.107.0. Use the {@link #event:press press} event instead.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireTap(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Returns the `sap.m.Image` accessibility information.
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The object contains the accessibility information for `sap.m.Image`
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Gets current value of property {@link #getActiveSrc activeSrc}.
     *
     * The source property which is used when the image is pressed.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `activeSrc`
     */
    getActiveSrc(): URI;
    /**
     * Gets current value of property {@link #getAlt alt}.
     *
     * The alternative text that is displayed in case the image is not available, or cannot be displayed.
     *
     * If the image is set to decorative, this property is ignored.
     *
     *
     * @returns Value of property `alt`
     */
    getAlt(): string;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDetails ariaDetails}.
     *
     * @since 1.79
     */
    getAriaDetails(): ID[];
    /**
     * Gets current value of property {@link #getAriaHasPopup ariaHasPopup}.
     *
     * Defines the aria-haspopup attribute of the `Image`.
     *
     * **Guidance for choosing appropriate value:**
     * 	 -  We recommend you to use the property only when press handler is set.
     * 	 -  If you use controls based on `sap.m.Popover` or `sap.m.Dialog`, then you must use `AriaHasPopup.Dialog`
     *     (both `sap.m.Popover` and `sap.m.Dialog` have role "dialog" assigned internally).
     * 	 -  If you use other controls, or directly `sap.ui.core.Popup`, you need to check the container role/type
     *     and map the value of `ariaHasPopup` accordingly.
     *
     * Default value is `None`.
     *
     * @since 1.87.0
     *
     * @returns Value of property `ariaHasPopup`
     */
    getAriaHasPopup(): aria.HasPopup;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getBackgroundPosition backgroundPosition}.
     *
     * Defines the position of the image in `sap.m.ImageMode.Background` mode.
     *
     * This property is set on the output DOM element using the CSS style `background-position`. It takes effect
     * only when the `mode` property is set to `sap.m.ImageMode.Background`.
     *
     * Default value is `"initial"`.
     *
     * @since 1.30.0
     *
     * @returns Value of property `backgroundPosition`
     */
    getBackgroundPosition(): string;
    /**
     * Gets current value of property {@link #getBackgroundRepeat backgroundRepeat}.
     *
     * Defines whether the source image is repeated when the output DOM element is bigger than the source.
     *
     * This property is set on the output DOM element using the CSS style `background-repeat`. It takes effect
     * only when the `mode` property is set to `sap.m.ImageMode.Background`.
     *
     * Default value is `"no-repeat"`.
     *
     * @since 1.30.0
     *
     * @returns Value of property `backgroundRepeat`
     */
    getBackgroundRepeat(): string;
    /**
     * Gets current value of property {@link #getBackgroundSize backgroundSize}.
     *
     * Defines the size of the image in `sap.m.ImageMode.Background` mode.
     *
     * This property is set on the output DOM element using the CSS style `background-size`. It takes effect
     * only when the `mode` property is set to `sap.m.ImageMode.Background`.
     *
     * Default value is `"cover"`.
     *
     * @since 1.30.0
     *
     * @returns Value of property `backgroundSize`
     */
    getBackgroundSize(): string;
    /**
     * Gets current value of property {@link #getDecorative decorative}.
     *
     * A decorative image is included for design reasons; accessibility tools will ignore decorative images.
     *
     * Note: If the image has an image map (`useMap` is set), this property will be overridden (the image will
     * not be rendered as decorative). A decorative image has no `ALT` attribute, so the `alt` property is ignored
     * if the image is decorative.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `decorative`
     */
    getDecorative(): boolean;
    /**
     * Gets current value of property {@link #getDensityAware densityAware}.
     *
     * If this is set to `true`, one or more network requests will be made that try to obtain the density perfect
     * version of the image.
     *
     * By default, this is set to `false`, so the `src` image is loaded directly without attempting to fetch
     * the density perfect image for high-density devices.
     *
     * **Note:** Before 1.60, the default value was set to `true`, which brought redundant network requests
     * for apps that used the default but did not provide density perfect image versions on server-side. You
     * should set this property to `true` only if you also provide the corresponding image versions for high-density
     * devices.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `densityAware`
     */
    getDensityAware(): boolean;
    /**
     * Gets content of aggregation {@link #getDetailBox detailBox}.
     *
     * A `sap.m.LightBox` instance that will be opened automatically when the user interacts with the `Image`
     * control.
     *
     * The `tap` event will still be fired.
     */
    getDetailBox(): LightBox;
    /**
     * Gets current value of property {@link #getHeight height}.
     *
     * When the empty value is kept, the original size is not changed.
     *
     * It is also possible to make settings for width or height only, in which case the original ratio between
     * width/height is maintained. When the `mode` property is set to `sap.m.ImageMode.Background`, this property
     * always needs to be set. Otherwise the output DOM element has a 0 size.
     *
     *
     * @returns Value of property `height`
     */
    getHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getLazyLoading lazyLoading}.
     *
     * Enables lazy loading for images that are offscreen. If set to `true`, the property ensures that offscreen
     * images are loaded early enough so that they have finished loading once the user scrolls near them.
     *
     * **Note:** Keep in mind that the property uses the loading attribute of HTML `<img>` element which
     * is not supported for Internet Explorer.
     *
     * Default value is `false`.
     *
     * @since 1.87
     *
     * @returns Value of property `lazyLoading`
     */
    getLazyLoading(): boolean;
    /**
     * Gets current value of property {@link #getMode mode}.
     *
     * Defines how the `src` and the `activeSrc` is output to the DOM Element.
     *
     * When set to `sap.m.ImageMode.Image`, which is the default value, the `src` (`activeSrc`) is set to the
     * `src` attribute of the <img> tag. When set to `sap.m.ImageMode.Background`, the `src` (`activeSrc`)
     * is set to the CSS style `background-image` and the root DOM element is rendered as a <span> tag
     * instead of an <img> tag.
     *
     * Default value is `"Image"`.
     *
     * @since 1.30.0
     *
     * @returns Value of property `mode`
     */
    getMode(): ImageMode;
    /**
     * Gets current value of property {@link #getSrc src}.
     *
     * Relative or absolute path to URL where the image file is stored.
     *
     * The path will be adapted to the density-aware format according to the density of the device following
     * the naming convention [imageName]@[densityValue].[extension].
     *
     *
     * @returns Value of property `src`
     */
    getSrc(): URI;
    /**
     * Gets current value of property {@link #getUseMap useMap}.
     *
     * The name of the image map that defines the clickable areas.
     *
     *
     * @returns Value of property `useMap`
     */
    getUseMap(): string;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * When the empty value is kept, the original size is not changed.
     *
     * It is also possible to make settings for width or height only, in which case the original ratio between
     * width/height is maintained. When the `mode` property is set to `sap.m.ImageMode.Background`, this property
     * always needs to be set. Otherwise the output DOM element has a 0 size.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaDetails ariaDetails}.
     *
     * @since 1.79
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDetails(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaDetails from the association named {@link #getAriaDetails ariaDetails}.
     *
     * @since 1.79
     *
     * @returns The removed ariaDetails or `null`
     */
    removeAriaDetails(
      /**
       * The ariaDetails to be removed or its index or ID
       */
      vAriaDetails: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getActiveSrc activeSrc}.
     *
     * The source property which is used when the image is pressed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setActiveSrc(
      /**
       * New value for property `activeSrc`
       */
      sActiveSrc?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getAlt alt}.
     *
     * The alternative text that is displayed in case the image is not available, or cannot be displayed.
     *
     * If the image is set to decorative, this property is ignored.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAlt(
      /**
       * New value for property `alt`
       */
      sAlt?: string
    ): this;
    /**
     * Sets a new value for property {@link #getAriaHasPopup ariaHasPopup}.
     *
     * Defines the aria-haspopup attribute of the `Image`.
     *
     * **Guidance for choosing appropriate value:**
     * 	 -  We recommend you to use the property only when press handler is set.
     * 	 -  If you use controls based on `sap.m.Popover` or `sap.m.Dialog`, then you must use `AriaHasPopup.Dialog`
     *     (both `sap.m.Popover` and `sap.m.Dialog` have role "dialog" assigned internally).
     * 	 -  If you use other controls, or directly `sap.ui.core.Popup`, you need to check the container role/type
     *     and map the value of `ariaHasPopup` accordingly.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     * @since 1.87.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAriaHasPopup(
      /**
       * New value for property `ariaHasPopup`
       */
      sAriaHasPopup?: aria.HasPopup | keyof typeof aria.HasPopup
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundPosition backgroundPosition}.
     *
     * Defines the position of the image in `sap.m.ImageMode.Background` mode.
     *
     * This property is set on the output DOM element using the CSS style `background-position`. It takes effect
     * only when the `mode` property is set to `sap.m.ImageMode.Background`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"initial"`.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundPosition(
      /**
       * New value for property `backgroundPosition`
       */
      sBackgroundPosition?: string
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundRepeat backgroundRepeat}.
     *
     * Defines whether the source image is repeated when the output DOM element is bigger than the source.
     *
     * This property is set on the output DOM element using the CSS style `background-repeat`. It takes effect
     * only when the `mode` property is set to `sap.m.ImageMode.Background`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"no-repeat"`.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundRepeat(
      /**
       * New value for property `backgroundRepeat`
       */
      sBackgroundRepeat?: string
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundSize backgroundSize}.
     *
     * Defines the size of the image in `sap.m.ImageMode.Background` mode.
     *
     * This property is set on the output DOM element using the CSS style `background-size`. It takes effect
     * only when the `mode` property is set to `sap.m.ImageMode.Background`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"cover"`.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundSize(
      /**
       * New value for property `backgroundSize`
       */
      sBackgroundSize?: string
    ): this;
    /**
     * Sets a new value for property {@link #getDecorative decorative}.
     *
     * A decorative image is included for design reasons; accessibility tools will ignore decorative images.
     *
     * Note: If the image has an image map (`useMap` is set), this property will be overridden (the image will
     * not be rendered as decorative). A decorative image has no `ALT` attribute, so the `alt` property is ignored
     * if the image is decorative.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDecorative(
      /**
       * New value for property `decorative`
       */
      bDecorative?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getDensityAware densityAware}.
     *
     * If this is set to `true`, one or more network requests will be made that try to obtain the density perfect
     * version of the image.
     *
     * By default, this is set to `false`, so the `src` image is loaded directly without attempting to fetch
     * the density perfect image for high-density devices.
     *
     * **Note:** Before 1.60, the default value was set to `true`, which brought redundant network requests
     * for apps that used the default but did not provide density perfect image versions on server-side. You
     * should set this property to `true` only if you also provide the corresponding image versions for high-density
     * devices.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDensityAware(
      /**
       * New value for property `densityAware`
       */
      bDensityAware?: boolean
    ): this;
    /**
     * Sets the `detailBox` aggregation.
     *
     *
     * @returns `this` for chaining
     */
    setDetailBox(
      /**
       * Instance of the `LightBox` control or undefined
       */
      oLightBox: LightBox | undefined
    ): this;
    /**
     * Sets a new value for property {@link #getHeight height}.
     *
     * When the empty value is kept, the original size is not changed.
     *
     * It is also possible to make settings for width or height only, in which case the original ratio between
     * width/height is maintained. When the `mode` property is set to `sap.m.ImageMode.Background`, this property
     * always needs to be set. Otherwise the output DOM element has a 0 size.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeight(
      /**
       * New value for property `height`
       */
      sHeight?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getLazyLoading lazyLoading}.
     *
     * Enables lazy loading for images that are offscreen. If set to `true`, the property ensures that offscreen
     * images are loaded early enough so that they have finished loading once the user scrolls near them.
     *
     * **Note:** Keep in mind that the property uses the loading attribute of HTML `<img>` element which
     * is not supported for Internet Explorer.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.87
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLazyLoading(
      /**
       * New value for property `lazyLoading`
       */
      bLazyLoading?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getMode mode}.
     *
     * Defines how the `src` and the `activeSrc` is output to the DOM Element.
     *
     * When set to `sap.m.ImageMode.Image`, which is the default value, the `src` (`activeSrc`) is set to the
     * `src` attribute of the <img> tag. When set to `sap.m.ImageMode.Background`, the `src` (`activeSrc`)
     * is set to the CSS style `background-image` and the root DOM element is rendered as a <span> tag
     * instead of an <img> tag.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Image"`.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMode(
      /**
       * New value for property `mode`
       */
      sMode?: ImageMode | keyof typeof ImageMode
    ): this;
    /**
     * Sets a new value for property {@link #getSrc src}.
     *
     * Relative or absolute path to URL where the image file is stored.
     *
     * The path will be adapted to the density-aware format according to the density of the device following
     * the naming convention [imageName]@[densityValue].[extension].
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSrc(
      /**
       * New value for property `src`
       */
      sSrc?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getUseMap useMap}.
     *
     * The name of the image map that defines the clickable areas.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUseMap(
      /**
       * New value for property `useMap`
       */
      sUseMap?: string
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * When the empty value is kept, the original size is not changed.
     *
     * It is also possible to make settings for width or height only, in which case the original ratio between
     * width/height is maintained. When the `mode` property is set to `sap.m.ImageMode.Background`, this property
     * always needs to be set. Otherwise the output DOM element has a 0 size.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Unbinds aggregation {@link #getDetailBox detailBox} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindDetailBox(): this;
  }
  /**
   * Describes the settings that can be provided to the Image constructor.
   */
  export interface $ImageSettings extends $ControlSettings {
    /**
     * Relative or absolute path to URL where the image file is stored.
     *
     * The path will be adapted to the density-aware format according to the density of the device following
     * the naming convention [imageName]@[densityValue].[extension].
     */
    src?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * When the empty value is kept, the original size is not changed.
     *
     * It is also possible to make settings for width or height only, in which case the original ratio between
     * width/height is maintained. When the `mode` property is set to `sap.m.ImageMode.Background`, this property
     * always needs to be set. Otherwise the output DOM element has a 0 size.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * When the empty value is kept, the original size is not changed.
     *
     * It is also possible to make settings for width or height only, in which case the original ratio between
     * width/height is maintained. When the `mode` property is set to `sap.m.ImageMode.Background`, this property
     * always needs to be set. Otherwise the output DOM element has a 0 size.
     */
    height?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * A decorative image is included for design reasons; accessibility tools will ignore decorative images.
     *
     * Note: If the image has an image map (`useMap` is set), this property will be overridden (the image will
     * not be rendered as decorative). A decorative image has no `ALT` attribute, so the `alt` property is ignored
     * if the image is decorative.
     */
    decorative?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The alternative text that is displayed in case the image is not available, or cannot be displayed.
     *
     * If the image is set to decorative, this property is ignored.
     */
    alt?: string | PropertyBindingInfo;

    /**
     * The name of the image map that defines the clickable areas.
     */
    useMap?: string | PropertyBindingInfo;

    /**
     * If this is set to `true`, one or more network requests will be made that try to obtain the density perfect
     * version of the image.
     *
     * By default, this is set to `false`, so the `src` image is loaded directly without attempting to fetch
     * the density perfect image for high-density devices.
     *
     * **Note:** Before 1.60, the default value was set to `true`, which brought redundant network requests
     * for apps that used the default but did not provide density perfect image versions on server-side. You
     * should set this property to `true` only if you also provide the corresponding image versions for high-density
     * devices.
     */
    densityAware?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The source property which is used when the image is pressed.
     */
    activeSrc?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines how the `src` and the `activeSrc` is output to the DOM Element.
     *
     * When set to `sap.m.ImageMode.Image`, which is the default value, the `src` (`activeSrc`) is set to the
     * `src` attribute of the <img> tag. When set to `sap.m.ImageMode.Background`, the `src` (`activeSrc`)
     * is set to the CSS style `background-image` and the root DOM element is rendered as a <span> tag
     * instead of an <img> tag.
     *
     * @since 1.30.0
     */
    mode?:
      | (ImageMode | keyof typeof ImageMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the size of the image in `sap.m.ImageMode.Background` mode.
     *
     * This property is set on the output DOM element using the CSS style `background-size`. It takes effect
     * only when the `mode` property is set to `sap.m.ImageMode.Background`.
     *
     * @since 1.30.0
     */
    backgroundSize?: string | PropertyBindingInfo;

    /**
     * Defines the position of the image in `sap.m.ImageMode.Background` mode.
     *
     * This property is set on the output DOM element using the CSS style `background-position`. It takes effect
     * only when the `mode` property is set to `sap.m.ImageMode.Background`.
     *
     * @since 1.30.0
     */
    backgroundPosition?: string | PropertyBindingInfo;

    /**
     * Defines whether the source image is repeated when the output DOM element is bigger than the source.
     *
     * This property is set on the output DOM element using the CSS style `background-repeat`. It takes effect
     * only when the `mode` property is set to `sap.m.ImageMode.Background`.
     *
     * @since 1.30.0
     */
    backgroundRepeat?: string | PropertyBindingInfo;

    /**
     * Enables lazy loading for images that are offscreen. If set to `true`, the property ensures that offscreen
     * images are loaded early enough so that they have finished loading once the user scrolls near them.
     *
     * **Note:** Keep in mind that the property uses the loading attribute of HTML `<img>` element which
     * is not supported for Internet Explorer.
     *
     * @since 1.87
     */
    lazyLoading?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the aria-haspopup attribute of the `Image`.
     *
     * **Guidance for choosing appropriate value:**
     * 	 -  We recommend you to use the property only when press handler is set.
     * 	 -  If you use controls based on `sap.m.Popover` or `sap.m.Dialog`, then you must use `AriaHasPopup.Dialog`
     *     (both `sap.m.Popover` and `sap.m.Dialog` have role "dialog" assigned internally).
     * 	 -  If you use other controls, or directly `sap.ui.core.Popup`, you need to check the container role/type
     *     and map the value of `ariaHasPopup` accordingly.
     *
     * @since 1.87.0
     */
    ariaHasPopup?:
      | (aria.HasPopup | keyof typeof aria.HasPopup)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * A `sap.m.LightBox` instance that will be opened automatically when the user interacts with the `Image`
     * control.
     *
     * The `tap` event will still be fired.
     */
    detailBox?: LightBox;

    /**
     * Association to controls / ids which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledBy).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Association to controls / IDs which are details to this control (see WAI-ARIA attribute aria-details).
     *
     * @since 1.79
     */
    ariaDetails?: Array<Control | string>;

    /**
     * Event is fired when the user clicks on the control.
     *
     * @deprecated As of version 1.107.0. Use the {@link #event:press press} event instead.
     */
    tap?: (oEvent: Event) => void;

    /**
     * Event is fired when the user clicks on the control.
     */
    press?: (oEvent: Event) => void;

    /**
     * Event is fired when the image resource is loaded.
     *
     * @since 1.36.2
     */
    load?: (oEvent: Event) => void;

    /**
     * Event is fired when the image resource can't be loaded. If densityAware is set to true, the event is
     * fired when none of the fallback resources can be loaded.
     *
     * @since 1.36.2
     */
    error?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the Image#error event.
   */
  export interface Image$ErrorEventParameters {}

  /**
   * Event object of the Image#error event.
   */
  export type Image$ErrorEvent = Event<Image$ErrorEventParameters, Image>;

  /**
   * Parameters of the Image#load event.
   */
  export interface Image$LoadEventParameters {}

  /**
   * Event object of the Image#load event.
   */
  export type Image$LoadEvent = Event<Image$LoadEventParameters, Image>;

  /**
   * Parameters of the Image#press event.
   */
  export interface Image$PressEventParameters {}

  /**
   * Event object of the Image#press event.
   */
  export type Image$PressEvent = Event<Image$PressEventParameters, Image>;

  /**
   * Parameters of the Image#tap event.
   *
   * @deprecated As of version 1.107.0. Use the {@link #event:press press} event instead.
   */
  export interface Image$TapEventParameters {}

  /**
   * Event object of the Image#tap event.
   *
   * @deprecated As of version 1.107.0. Use the {@link #event:press press} event instead.
   */
  export type Image$TapEvent = Event<Image$TapEventParameters, Image>;
}

declare module "sap/m/ImageContent" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { URI } from "sap/ui/core/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * This control can be used to display image content in a GenericTile.
   *
   * @since 1.38
   */
  export default class ImageContent extends Control {
    /**
     * Constructor for a new sap.m.ImageContent control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ImageContentSettings
    );
    /**
     * Constructor for a new sap.m.ImageContent control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ImageContentSettings
    );

    /**
     * Creates a new subclass of class sap.m.ImageContent with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ImageContent>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ImageContent.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.ImageContent`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ImageContent` itself.
     *
     * The event is triggered when the image content is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ImageContent` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.ImageContent`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ImageContent` itself.
     *
     * The event is triggered when the image content is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ImageContent` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.ImageContent`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getDescription description}.
     *
     * Description of image. This text is used to provide ScreenReader information.
     *
     *
     * @returns Value of property `description`
     */
    getDescription(): string;
    /**
     * Gets current value of property {@link #getSrc src}.
     *
     * The image to be displayed as a graphical element within the imageContent. This can be an image or an
     * icon from the icon font.
     *
     *
     * @returns Value of property `src`
     */
    getSrc(): URI;
    /**
     * Sets a new value for property {@link #getDescription description}.
     *
     * Description of image. This text is used to provide ScreenReader information.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDescription(
      /**
       * New value for property `description`
       */
      sDescription?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSrc src}.
     *
     * The image to be displayed as a graphical element within the imageContent. This can be an image or an
     * icon from the icon font.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSrc(
      /**
       * New value for property `src`
       */
      sSrc?: URI
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ImageContent constructor.
   */
  export interface $ImageContentSettings extends $ControlSettings {
    /**
     * The image to be displayed as a graphical element within the imageContent. This can be an image or an
     * icon from the icon font.
     */
    src?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Description of image. This text is used to provide ScreenReader information.
     */
    description?: string | PropertyBindingInfo;

    /**
     * The event is triggered when the image content is pressed.
     */
    press?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the ImageContent#press event.
   */
  export interface ImageContent$PressEventParameters {}

  /**
   * Event object of the ImageContent#press event.
   */
  export type ImageContent$PressEvent = Event<
    ImageContent$PressEventParameters,
    ImageContent
  >;
}

declare module "sap/m/Input" {
  import { default as InputBase, $InputBaseSettings } from "sap/m/InputBase";

  import {
    IAccessKeySupport,
    AccessibilityInfo,
    CSSSize,
    ID,
    URI,
  } from "sap/ui/core/library";

  import Column from "sap/m/Column";

  import Item from "sap/ui/core/Item";

  import { ITableItem, InputTextFormatMode, InputType } from "sap/m/library";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import ColumnListItem from "sap/m/ColumnListItem";

  import Event from "sap/ui/base/Event";

  import ListBase from "sap/m/ListBase";

  /**
   * Allows the user to enter and edit text or numeric values in one line.
   *
   * Overview:
   *
   * You can enable the autocomplete suggestion feature and the value help option to easily enter a valid
   * value.
   *
   * Guidelines:
   *
   *
   * 	 -  Always provide a meaningful label for any input field
   * 	 -  Limit the length of the input field. This will visually emphasize the constraints for the field.
   *
   * 	 -  Do not use the `placeholder` property as a label.
   * 	 -  Use the `description` property only for small fields with no placeholders (i.e. for currencies).
   *
   *
   * Structure:
   *
   * The controls inherits from {@link sap.m.InputBase} which controls the core properties like:
   * 	 -  editable / read-only
   * 	 -  enabled / disabled
   * 	 -  placeholder
   * 	 -  text direction
   * 	 -  value states  To aid the user during input, you can enable value help (`showValueHelp`) or
   *     autocomplete (`showSuggestion`). **Value help** will open a new dialog where you can refine your input.
   *     **Autocomplete** has three types of suggestions:
   * 	 -  Single value - a list of suggestions of type `sap.ui.core.Item` or `sap.ui.core.ListItem`
   * 	 -  Two values - a list of two suggestions (ID and description) of type `sap.ui.core.Item` or `sap.ui.core.ListItem`
   *
   * 	 -  Tabular suggestions of type `sap.m.ColumnListItem`   The suggestions are stored in two aggregations
   *     `suggestionItems` (for single and double values) and `suggestionRows` (for tabular values).
   *
   * Usage:
   *
   * **When to use:** Use the control for short inputs like emails, phones, passwords, fields for assisted
   * value selection.
   *
   * **When not to use:** Don't use the control for long texts, dates, designated search fields, fields for
   * multiple selection.
   *
   * Known Restrictions:
   *
   * If `showValueHelp` or if `showSuggestion` is `true`, the native browser autofill will not fire a change
   * event.
   *
   * Note:: The control has the following behavior regarding the `selectedKey` and `value` properties:
   *
   * 	 -  On initial loading, if the control has a `selectedKey` set which corresponds to a matching item,
   *     and a set `value`, the `value` will be updated to the matching item's text.
   * 	 -  If a `selectedKey` is set and the user types an input which corresponds to an item's text, the `selectedKey`
   *     will be updated with the matching item's key.
   * 	 -  If a `selectedKey` is set and the user types an input which does not correspond to any item's text,
   *     the `selectedKey` will be set to an empty string ("")
   * 	 -  If a `selectedKey` is set and the user selects an item, the `selectedKey` will be updated to match
   *     the selected item's key.
   * 	 -  If a `selectedKey` is bound and the user types before the data is loaded, the user's input will
   *     be overwritten by the binding update.
   */
  export default class Input extends InputBase implements IAccessKeySupport {
    __implements__sap_ui_core_IAccessKeySupport: boolean;
    /**
     * Constructor for a new `Input`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/input-field/ Input}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $InputSettings
    );
    /**
     * Constructor for a new `Input`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/input-field/ Input}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $InputSettings
    );

    /**
     * Creates a new subclass of class sap.m.Input with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.InputBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Input>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Input.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some suggestionColumn to the aggregation {@link #getSuggestionColumns suggestionColumns}.
     *
     * @since 1.21.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addSuggestionColumn(
      /**
       * The suggestionColumn to add; if empty, nothing is inserted
       */
      oSuggestionColumn: Column
    ): this;
    /**
     * Adds suggestion item.
     *
     *
     * @returns this Input instance for chaining.
     */
    addSuggestionItem(
      /**
       * Suggestion item.
       */
      oItem: Item
    ): this;
    /**
     * Adds some suggestionRow to the aggregation {@link #getSuggestionRows suggestionRows}.
     *
     * @since 1.21.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addSuggestionRow(
      /**
       * The suggestionRow to add; if empty, nothing is inserted
       */
      oSuggestionRow: ITableItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.Input`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Input` itself.
     *
     * Fired when the value of the input is changed by user interaction - each keystroke, delete, paste, etc.
     *
     * **Note:** Browsing autocomplete suggestions does not fire the event.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Input$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Input` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.Input`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Input` itself.
     *
     * Fired when the value of the input is changed by user interaction - each keystroke, delete, paste, etc.
     *
     * **Note:** Browsing autocomplete suggestions does not fire the event.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Input$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Input` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:submit submit} event of this `sap.m.Input`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Input` itself.
     *
     * This event is fired when user presses the Enter key on the input.
     *
     * **Notes:**
     * 	 - The event is fired independent of whether there was a change before or not. If a change was performed,
     *     the event is fired after the change event.
     * 	 - The event is also fired when an item of the select list is selected via Enter.
     * 	 - The event is only fired on an input which allows text input (`editable`, `enabled` and not `valueHelpOnly`).
     *
     *
     * @since 1.33.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSubmit(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Input$SubmitEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Input` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:submit submit} event of this `sap.m.Input`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Input` itself.
     *
     * This event is fired when user presses the Enter key on the input.
     *
     * **Notes:**
     * 	 - The event is fired independent of whether there was a change before or not. If a change was performed,
     *     the event is fired after the change event.
     * 	 - The event is also fired when an item of the select list is selected via Enter.
     * 	 - The event is only fired on an input which allows text input (`editable`, `enabled` and not `valueHelpOnly`).
     *
     *
     * @since 1.33.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSubmit(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Input$SubmitEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Input` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:suggest suggest} event of this `sap.m.Input`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Input` itself.
     *
     * This event is fired when user types in the input and showSuggestion is set to true. Changing the suggestItems
     * aggregation will show the suggestions within a popup.
     *
     * @since 1.16.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSuggest(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Input$SuggestEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Input` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:suggest suggest} event of this `sap.m.Input`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Input` itself.
     *
     * This event is fired when user types in the input and showSuggestion is set to true. Changing the suggestItems
     * aggregation will show the suggestions within a popup.
     *
     * @since 1.16.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSuggest(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Input$SuggestEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Input` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:suggestionItemSelected suggestionItemSelected }
     * event of this `sap.m.Input`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Input` itself.
     *
     * This event is fired when suggestionItem shown in suggestion popup are selected. This event is only fired
     * when showSuggestion is set to true and there are suggestionItems shown in the suggestion popup.
     *
     * @since 1.16.3
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSuggestionItemSelected(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Input$SuggestionItemSelectedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Input` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:suggestionItemSelected suggestionItemSelected }
     * event of this `sap.m.Input`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Input` itself.
     *
     * This event is fired when suggestionItem shown in suggestion popup are selected. This event is only fired
     * when showSuggestion is set to true and there are suggestionItems shown in the suggestion popup.
     *
     * @since 1.16.3
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSuggestionItemSelected(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Input$SuggestionItemSelectedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Input` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:valueHelpRequest valueHelpRequest} event of
     * this `sap.m.Input`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Input` itself.
     *
     * When the value help indicator is clicked, this event will be fired.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachValueHelpRequest(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Input$ValueHelpRequestEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Input` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:valueHelpRequest valueHelpRequest} event of
     * this `sap.m.Input`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Input` itself.
     *
     * When the value help indicator is clicked, this event will be fired.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachValueHelpRequest(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Input$ValueHelpRequestEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Input` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getSuggestionColumns suggestionColumns} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     * @since 1.21.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindSuggestionColumns(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Binds aggregation {@link #getSuggestionRows suggestionRows} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     * @since 1.21.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindSuggestionRows(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Cancels any pending suggestions.
     */
    cancelPendingSuggest(): void;
    /**
     * Clones input.
     *
     *
     * @returns Cloned input.
     */
    clone(): this;
    /**
     * Closes the suggestion list.
     *
     * @since 1.48
     */
    closeSuggestions(): void;
    /**
     * Destroys all the suggestionColumns in the aggregation {@link #getSuggestionColumns suggestionColumns}.
     *
     * @since 1.21.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySuggestionColumns(): this;
    /**
     * Destroys suggestion items.
     *
     *
     * @returns this Input instance for chaining.
     */
    destroySuggestionItems(): this;
    /**
     * Destroys all the suggestionRows in the aggregation {@link #getSuggestionRows suggestionRows}.
     *
     * @since 1.21.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySuggestionRows(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:liveChange liveChange} event of this `sap.m.Input`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLiveChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Input$LiveChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:submit submit} event of this `sap.m.Input`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.33.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSubmit(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Input$SubmitEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:suggest suggest} event of this `sap.m.Input`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.16.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSuggest(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Input$SuggestEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:suggestionItemSelected suggestionItemSelected }
     * event of this `sap.m.Input`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.16.3
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSuggestionItemSelected(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Input$SuggestionItemSelectedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:valueHelpRequest valueHelpRequest} event of
     * this `sap.m.Input`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachValueHelpRequest(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Input$ValueHelpRequestEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:liveChange liveChange} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLiveChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Input$LiveChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:submit submit} to attached listeners.
     *
     * @since 1.33.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSubmit(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Input$SubmitEventParameters
    ): this;
    /**
     * Fires event {@link #event:suggest suggest} to attached listeners.
     *
     * @since 1.16.1
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSuggest(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Input$SuggestEventParameters
    ): this;
    /**
     * Fires event {@link #event:suggestionItemSelected suggestionItemSelected} to attached listeners.
     *
     * @since 1.16.3
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSuggestionItemSelected(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Input$SuggestionItemSelectedEventParameters
    ): this;
    /**
     * Fires event {@link #event:valueHelpRequest valueHelpRequest} to attached listeners.
     *
     * @since 1.16
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireValueHelpRequest(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Input$ValueHelpRequestEventParameters
    ): this;
    /**
     * Gets accessibility information for the input.
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Accessibility information.
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Gets current value of property {@link #getAutocomplete autocomplete}.
     *
     * Specifies whether autocomplete is enabled. Works only if "showSuggestion" property is set to true. **Note:**
     * The autocomplete feature is disabled on Android devices due to a OS specific issue.
     *
     * Default value is `true`.
     *
     * @since 1.61
     *
     * @returns Value of property `autocomplete`
     */
    getAutocomplete(): boolean;
    /**
     * Gets current value of property {@link #getDateFormat dateFormat}.
     *
     * Only used if type=date and no datepicker is available. The data is displayed and the user input is parsed
     * according to this format. **Note:** The value property is always of the form RFC 3339 (YYYY-MM-dd).
     *
     * Default value is `'YYYY-MM-dd'`.
     *
     * @deprecated As of version 1.9.1. `sap.m.DatePicker`, `sap.m.TimePicker` or `sap.m.DateTimePicker` should
     * be used for date/time inputs and formating.
     *
     * @returns Value of property `dateFormat`
     */
    getDateFormat(): string;
    /**
     * Gets current value of property {@link #getDescription description}.
     *
     * The description is a text after the input field, e.g. units of measurement, currencies.
     *
     *
     * @returns Value of property `description`
     */
    getDescription(): string;
    /**
     * Gets the inner input DOM value.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The value of the input.
     */
    getDOMValue(): any;
    /**
     * Gets current value of property {@link #getEnableSuggestionsHighlighting enableSuggestionsHighlighting}.
     *
     * Specifies whether the suggestions highlighting is enabled. **Note:** Due to performance constraints,
     * the functionality will be disabled above 200 items. **Note:** Highlighting in table suggestions will
     * work only for cells containing sap.m.Label or sap.m.Text controls.
     *
     * Default value is `true`.
     *
     * @since 1.46
     *
     * @returns Value of property `enableSuggestionsHighlighting`
     */
    getEnableSuggestionsHighlighting(): boolean;
    /**
     * Gets current value of property {@link #getEnableTableAutoPopinMode enableTableAutoPopinMode}.
     *
     * Enables the `autoPopinMode` of `sap.m.Table`, when the input has tabular suggestions. **Note:** The `autoPopinMode`
     * overwrites the `demandPopin` and the `minScreenWidth` properties of the `sap.m.Column`. When setting,
     * `enableTableAutoPopinMode`, from true to false, the application must reconfigure the `demandPopin` and
     * `minScreenWidth` properties of the `sap.m.Column` control by itself.
     *
     * Default value is `false`.
     *
     * @since 1.89
     *
     * @returns Value of property `enableTableAutoPopinMode`
     */
    getEnableTableAutoPopinMode(): boolean;
    /**
     * Gets current value of property {@link #getFieldWidth fieldWidth}.
     *
     * This property only takes effect if the description property is set. It controls the distribution of space
     * between the input field and the description text. The default value is 50% leaving the other 50% for
     * the description.
     *
     * Default value is `'50%'`.
     *
     *
     * @returns Value of property `fieldWidth`
     */
    getFieldWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getFilterSuggests filterSuggests}.
     *
     * Defines whether to filter the provided suggestions before showing them to the user.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `filterSuggests`
     */
    getFilterSuggests(): boolean;
    /**
     * Gets current value of property {@link #getMaxLength maxLength}.
     *
     * Maximum number of characters. Value '0' means the feature is switched off. This parameter is not compatible
     * with the input type `sap.m.InputType.Number`. If the input type is set to `Number`, the `maxLength` value
     * is ignored. If the `maxLength` is set after there is already a longer value, this value will not get
     * truncated. The `maxLength` property has effect only when the value is modified by user interaction.
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `maxLength`
     */
    getMaxLength(): int;
    /**
     * Gets current value of property {@link #getMaxSuggestionWidth maxSuggestionWidth}.
     *
     * If set, this parameter will control the horizontal size of the suggestion list to display more data.
     * By default, the suggestion list has a minimum width equal to the input field's width and a maximum width
     * of 640px. This property allows the suggestion list to contract or expand based on available space, potentially
     * exceeding 640px. **Note:** If the actual width of the input field exceeds the specified parameter value,
     * the value will be ignored.
     *
     * @since 1.21.1
     *
     * @returns Value of property `maxSuggestionWidth`
     */
    getMaxSuggestionWidth(): CSSSize;
    /**
     * ID of the element which is the current target of the association {@link #getSelectedItem selectedItem},
     * or `null`.
     *
     * @since 1.44
     */
    getSelectedItem(): ID | null;
    /**
     * Gets current value of property {@link #getSelectedKey selectedKey}.
     *
     * Defines the key of the selected item.
     *
     * **Note:** If duplicate keys exist, the first item matching the key is used.
     *
     * Default value is `empty string`.
     *
     * @since 1.44
     *
     * @returns Value of property `selectedKey`
     */
    getSelectedKey(): string;
    /**
     * ID of the element which is the current target of the association {@link #getSelectedRow selectedRow},
     * or `null`.
     *
     * @since 1.44
     */
    getSelectedRow(): ID | null;
    /**
     * Gets current value of property {@link #getShowClearIcon showClearIcon}.
     *
     * Specifies whether clear icon is shown. Pressing the icon will clear input's value and fire the liveChange
     * event.
     *
     * Default value is `false`.
     *
     * @since 1.94
     *
     * @returns Value of property `showClearIcon`
     */
    getShowClearIcon(): boolean;
    /**
     * Gets current value of property {@link #getShowSuggestion showSuggestion}.
     *
     * If this is set to true, suggest event is fired when user types in the input. Changing the suggestItems
     * aggregation in suggest event listener will show suggestions within a popup. When runs on phone, input
     * will first open a dialog where the input and suggestions are shown. When runs on a tablet, the suggestions
     * are shown in a popup next to the input.
     *
     * Default value is `false`.
     *
     * @since 1.16.1
     *
     * @returns Value of property `showSuggestion`
     */
    getShowSuggestion(): boolean;
    /**
     * Gets current value of property {@link #getShowTableSuggestionValueHelp showTableSuggestionValueHelp}.
     *
     * For tabular suggestions, this flag will show/hide the button at the end of the suggestion table that
     * triggers the event "valueHelpRequest" when pressed. The default value is true.
     *
     * **Note:** If suggestions are not tabular or no suggestions are used, the button will not be displayed
     * and this flag is without effect.
     *
     * Default value is `true`.
     *
     * @since 1.22.1
     *
     * @returns Value of property `showTableSuggestionValueHelp`
     */
    getShowTableSuggestionValueHelp(): boolean;
    /**
     * Gets current value of property {@link #getShowValueHelp showValueHelp}.
     *
     * If set to true, a value help indicator will be displayed inside the control. When clicked the event "valueHelpRequest"
     * will be fired.
     *
     * Default value is `false`.
     *
     * @since 1.16
     *
     * @returns Value of property `showValueHelp`
     */
    getShowValueHelp(): boolean;
    /**
     * Getter for property `showValueStateMessage`. Whether the value state message should be shown. This property
     * is already available for sap.m.Input since 1.16.0.
     *
     * Default value is `true`
     *
     * @since 1.16
     *
     * @returns the value of property `showValueStateMessage`
     */
    getShowValueStateMessage(): boolean;
    /**
     * Gets current value of property {@link #getStartSuggestion startSuggestion}.
     *
     * Minimum length of the entered text in input before suggest event is fired. The default value is 1 which
     * means the suggest event is fired after user types in input.
     *
     * **Note:** When it's set to 0, suggest event is fired when input with no text gets focus. In this case
     * no suggestion popup will open.
     *
     * Default value is `1`.
     *
     * @since 1.21.2
     *
     * @returns Value of property `startSuggestion`
     */
    getStartSuggestion(): int;
    /**
     * Gets content of aggregation {@link #getSuggestionColumns suggestionColumns}.
     *
     * The suggestionColumns and suggestionRows are for tabular input suggestions. This aggregation allows for
     * binding the table columns; for more details see the aggregation "suggestionRows".
     *
     * @since 1.21.1
     */
    getSuggestionColumns(): Column[];
    /**
     * Gets the item with the given key from the aggregation `suggestionItems`. **Note:** If duplicate keys
     * exist, the first item matching the key is returned.
     *
     * @since 1.44
     *
     * @returns Suggestion item.
     */
    getSuggestionItemByKey(
      /**
       * An item key that specifies the item to retrieve.
       */
      sKey: string
    ): Item;
    /**
     * Gets content of aggregation {@link #getSuggestionItems suggestionItems}.
     *
     * Defines the items displayed in the suggestion popup. Changing this aggregation (by calling `addSuggestionItem`,
     * `insertSuggestionItem`, `removeSuggestionItem`, `removeAllSuggestionItems`, or `destroySuggestionItems`)
     * after `Input` is rendered opens/closes the suggestion popup.
     *
     * To display suggestions with two text values, add `sap.ui.core.ListItem` as `SuggestionItems` (since 1.21.1).
     * For the selected `ListItem`, only the first value is returned to the input field.
     *
     * **Note:** Only `text` and `additionalText` property values of the item are displayed. For example, if
     * an `icon` is set, it is ignored. To display more information per item (including icons), you can use
     * the `suggestionRows` aggregation.
     *
     * **Note:** Disabled items are not visualized in the list with the suggestions, however they can still
     * be accessed through the aggregation. **Note:** If `suggestionItems` & `suggestionRows` are set in parallel,
     * the last aggeragtion to come would overwrite the previous ones.
     *
     * @since 1.16.1
     */
    getSuggestionItems(): Item[];
    /**
     * Gets content of aggregation {@link #getSuggestionRows suggestionRows}.
     *
     * The suggestionColumns and suggestionRows are for tabular input suggestions. This aggregation allows for
     * binding the table cells. The items of this aggregation are to be bound directly or to set in the suggest
     * event method. **Note:** If `suggestionItems` & `suggestionRows` are set in parallel, the last aggeragtion
     * to come would overwrite the previous ones.
     *
     * @since 1.21.1
     */
    getSuggestionRows(): ITableItem[];
    /**
     * Gets current value of property {@link #getSuggestionRowValidator suggestionRowValidator}.
     *
     * Defines the validation callback function called when a suggestion row gets selected.
     *
     * @since 1.44
     *
     * @returns Value of property `suggestionRowValidator`
     */
    getSuggestionRowValidator(): Function;
    /**
     * Gets current value of property {@link #getTextFormatMode textFormatMode}.
     *
     * Defines the display text format mode.
     *
     * Default value is `Value`.
     *
     * @since 1.44
     *
     * @returns Value of property `textFormatMode`
     */
    getTextFormatMode(): InputTextFormatMode;
    /**
     * Gets current value of property {@link #getTextFormatter textFormatter}.
     *
     * Defines the display text formatter function.
     *
     * @since 1.44
     *
     * @returns Value of property `textFormatter`
     */
    getTextFormatter(): Function;
    /**
     * Gets current value of property {@link #getType type}.
     *
     * HTML type of the internal `input` tag (e.g. Text, Number, Email, Phone). The particular effect of this
     * property differs depending on the browser and the current language settings, especially for the type
     * Number.
     *  This parameter is intended to be used with touch devices that use different soft keyboard layouts depending
     * on the given input type.
     *  Only the default value `sap.m.InputType.Text` may be used in combination with data model formats. `sap.ui.model`
     * defines extended formats that are mostly incompatible with normal HTML representations for numbers and
     * dates.
     *
     * Default value is `Text`.
     *
     *
     * @returns Value of property `type`
     */
    getType(): InputType;
    /**
     * Gets the input value.
     *
     *
     * @returns Value of the input.
     */
    getValue(): string;
    /**
     * Gets current value of property {@link #getValueHelpIconSrc valueHelpIconSrc}.
     *
     * Set custom value help icon.
     *
     * Default value is `"sap-icon://value-help"`.
     *
     * @since 1.84.0
     *
     * @returns Value of property `valueHelpIconSrc`
     */
    getValueHelpIconSrc(): URI;
    /**
     * Gets current value of property {@link #getValueHelpOnly valueHelpOnly}.
     *
     * If set to true, direct text input is disabled and the control will trigger the event "valueHelpRequest"
     * for all user interactions. The properties "showValueHelp", "editable", and "enabled" must be set to true,
     * otherwise the property will have no effect. In this scenario, the `showItems` API will not work.
     *
     *  **Note:** The property is deprecated, as it creates unnecessary usability and accessibility restrictions.
     * The decision to deprecate it is based on the fact that it serves no purpose to have an input field where
     * the user cannot type. This property restricts even the paste functionality, which can be useful, e.g.
     * the needed info is already in the clipboard. If the user's input needs to match specific predefined values,
     * the application should validate the input against the set of values and provide feedback to the user
     * or use other mechanism for selection, where freestyle input is not allowed by design (Select, SelectDialog,
     * etc). **Note:** Please note that there is no direct replacement for this property.
     *
     * Default value is `false`.
     *
     * @since 1.21.0
     * @deprecated As of version 1.119. The property valueHelpOnly should not be used anymore
     *
     * @returns Value of property `valueHelpOnly`
     */
    getValueHelpOnly(): boolean;
    /**
     * Gets current value of property {@link #getValueLiveUpdate valueLiveUpdate}.
     *
     * Indicates when the value gets updated with the user changes: At each keystroke (true) or first when the
     * user presses enter or tabs out (false).
     *
     * **Note:** When set to true and the value of the Input control is bound to a model, the change event becomes
     * obsolete and will not be fired, as the value in the model will be updated each time the user provides
     * input. In such cases, subscription to the liveChange event is more appropriate, as it corresponds to
     * the way the underlying model gets updated.
     *
     * Default value is `false`.
     *
     * @since 1.24
     *
     * @returns Value of property `valueLiveUpdate`
     */
    getValueLiveUpdate(): boolean;
    /**
     * Getter for property `valueStateText`. The text which is shown in the value state message popup. If not
     * specfied a default text is shown. This property is already available for sap.m.Input since 1.16.0.
     *
     * Default value is empty/`undefined`
     *
     * @since 1.16
     *
     * @returns the value of property `valueStateText`
     */
    getValueStateText(): string;
    /**
     * Checks for the provided `sap.m.Column` in the aggregation {@link #getSuggestionColumns suggestionColumns}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.21.1
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfSuggestionColumn(
      /**
       * The suggestionColumn whose index is looked for
       */
      oSuggestionColumn: Column
    ): int;
    /**
     * Checks for the provided `sap.ui.core.Item` in the aggregation {@link #getSuggestionItems suggestionItems}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.16.1
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfSuggestionItem(
      /**
       * The suggestionItem whose index is looked for
       */
      oSuggestionItem: Item
    ): int;
    /**
     * Checks for the provided `sap.m.ITableItem` in the aggregation {@link #getSuggestionRows suggestionRows}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.21.1
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfSuggestionRow(
      /**
       * The suggestionRow whose index is looked for
       */
      oSuggestionRow: ITableItem
    ): int;
    /**
     * Inserts a suggestionColumn into the aggregation {@link #getSuggestionColumns suggestionColumns}.
     *
     * @since 1.21.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertSuggestionColumn(
      /**
       * The suggestionColumn to insert; if empty, nothing is inserted
       */
      oSuggestionColumn: Column,
      /**
       * The `0`-based index the suggestionColumn should be inserted at; for a negative value of `iIndex`, the
       * suggestionColumn is inserted at position 0; for a value greater than the current size of the aggregation,
       * the suggestionColumn is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts suggestion item.
     *
     *
     * @returns this Input instance for chaining.
     */
    insertSuggestionItem(
      /**
       * Suggestion item.
       */
      oItem: Item,
      /**
       * Index to be inserted.
       */
      iIndex: int
    ): this;
    /**
     * Inserts a suggestionRow into the aggregation {@link #getSuggestionRows suggestionRows}.
     *
     * @since 1.21.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertSuggestionRow(
      /**
       * The suggestionRow to insert; if empty, nothing is inserted
       */
      oSuggestionRow: ITableItem,
      /**
       * The `0`-based index the suggestionRow should be inserted at; for a negative value of `iIndex`, the suggestionRow
       * is inserted at position 0; for a value greater than the current size of the aggregation, the suggestionRow
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Invalidates the control.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    invalidate(): void;
    /**
     * Gets the supported openers for the valueHelpOnly. In the context of the Input, all targets are valid.
     *
     * @deprecated As of version 1.119. the property valueHelpOnly should not be used anymore
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Boolean indicating if the target is a valid opener.
     */
    isValueHelpOnlyOpener(
      /**
       * The target of the event.
       */
      oTarget: HTMLElement | undefined
    ): boolean;
    /**
     * Event handler for browsers' `change` event.
     *
     * @since 1.73
     */
    onchange(
      /**
       * The event.
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * Event handler for the onFocusIn event.
     */
    onfocusin(
      /**
       * On focus in event.
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * Event handler for user input.
     */
    oninput(
      /**
       * User input.
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * Keyboard handler for the onMouseDown event.
     */
    onmousedown(
      /**
       * Keyboard event.
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * Keyboard handler for enter key.
     */
    onsapenter(
      /**
       * Keyboard event.
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * Keyboard handler for escape key.
     */
    onsapescape(
      /**
       * Keyboard event.
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * Keyboard handler for the onFocusLeave event.
     */
    onsapfocusleave(
      /**
       * Keyboard event.
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * Finalizes autocomplete and fires liveChange event eventually.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onsapright(): void;
    /**
     * Fire valueHelpRequest event on tap.
     */
    ontap(
      /**
       * Ontap event.
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * Hook method to prevent the change event from being fired when the text input field loses focus.
     *
     * @since 1.46
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not the change event should be prevented.
     */
    preventChangeOnFocusLeave(
      /**
       * The event object.
       */
      oEvent?: jQuery.Event
    ): boolean;
    /**
     * Removes all the controls from the aggregation {@link #getSuggestionColumns suggestionColumns}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.21.1
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllSuggestionColumns(): Column[];
    /**
     * Removes all suggestion items.
     *
     *
     * @returns Determines whether the suggestion items are removed.
     */
    removeAllSuggestionItems(): boolean;
    /**
     * Removes all the controls from the aggregation {@link #getSuggestionRows suggestionRows}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.21.1
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllSuggestionRows(): ITableItem[];
    /**
     * Removes a suggestionColumn from the aggregation {@link #getSuggestionColumns suggestionColumns}.
     *
     * @since 1.21.1
     *
     * @returns The removed suggestionColumn or `null`
     */
    removeSuggestionColumn(
      /**
       * The suggestionColumn to remove or its index or id
       */
      vSuggestionColumn: int | string | Column
    ): Column | null;
    /**
     * Removes suggestion item.
     *
     *
     * @returns Determines whether the suggestion item has been removed.
     */
    removeSuggestionItem(
      /**
       * Suggestion item.
       */
      oItem: Item
    ): boolean;
    /**
     * Removes a suggestionRow from the aggregation {@link #getSuggestionRows suggestionRows}.
     *
     * @since 1.21.1
     *
     * @returns The removed suggestionRow or `null`
     */
    removeSuggestionRow(
      /**
       * The suggestionRow to remove or its index or id
       */
      vSuggestionRow: int | string | ITableItem
    ): ITableItem | null;
    /**
     * Sets a new value for property {@link #getAutocomplete autocomplete}.
     *
     * Specifies whether autocomplete is enabled. Works only if "showSuggestion" property is set to true. **Note:**
     * The autocomplete feature is disabled on Android devices due to a OS specific issue.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.61
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAutocomplete(
      /**
       * New value for property `autocomplete`
       */
      bAutocomplete?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getDateFormat dateFormat}.
     *
     * Only used if type=date and no datepicker is available. The data is displayed and the user input is parsed
     * according to this format. **Note:** The value property is always of the form RFC 3339 (YYYY-MM-dd).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `'YYYY-MM-dd'`.
     *
     * @deprecated As of version 1.9.1. `sap.m.DatePicker`, `sap.m.TimePicker` or `sap.m.DateTimePicker` should
     * be used for date/time inputs and formating.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDateFormat(
      /**
       * New value for property `dateFormat`
       */
      sDateFormat?: string
    ): this;
    /**
     * Sets a new value for property {@link #getDescription description}.
     *
     * The description is a text after the input field, e.g. units of measurement, currencies.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDescription(
      /**
       * New value for property `description`
       */
      sDescription?: string
    ): this;
    /**
     * Sets the inner input DOM value.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    setDOMValue(
      /**
       * Dom value which will be set.
       */
      value: string
    ): void;
    /**
     * Sets a new value for property {@link #getEnableSuggestionsHighlighting enableSuggestionsHighlighting}.
     *
     * Specifies whether the suggestions highlighting is enabled. **Note:** Due to performance constraints,
     * the functionality will be disabled above 200 items. **Note:** Highlighting in table suggestions will
     * work only for cells containing sap.m.Label or sap.m.Text controls.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.46
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableSuggestionsHighlighting(
      /**
       * New value for property `enableSuggestionsHighlighting`
       */
      bEnableSuggestionsHighlighting?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnableTableAutoPopinMode enableTableAutoPopinMode}.
     *
     * Enables the `autoPopinMode` of `sap.m.Table`, when the input has tabular suggestions. **Note:** The `autoPopinMode`
     * overwrites the `demandPopin` and the `minScreenWidth` properties of the `sap.m.Column`. When setting,
     * `enableTableAutoPopinMode`, from true to false, the application must reconfigure the `demandPopin` and
     * `minScreenWidth` properties of the `sap.m.Column` control by itself.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.89
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableTableAutoPopinMode(
      /**
       * New value for property `enableTableAutoPopinMode`
       */
      bEnableTableAutoPopinMode?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getFieldWidth fieldWidth}.
     *
     * This property only takes effect if the description property is set. It controls the distribution of space
     * between the input field and the description text. The default value is 50% leaving the other 50% for
     * the description.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `'50%'`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFieldWidth(
      /**
       * New value for property `fieldWidth`
       */
      sFieldWidth?: CSSSize
    ): this;
    /**
     * Sets a custom filter function for suggestions. The default is to check whether the first item text begins
     * with the typed value. For one and two-value suggestions this callback function will operate on sap.ui.core.Item
     * types, for tabular suggestions the function will operate on sap.m.ColumnListItem types.
     *
     * @since 1.16.1
     *
     * @returns this pointer for chaining
     */
    setFilterFunction(
      /**
       * The filter function is called when displaying suggestion items and has two input parameters: the first
       * one is the string that is currently typed in the input field and the second one is the item that is being
       * filtered. Returning true will add this item to the popup, returning false will not display it.
       */
      fnFilter: (
        p1?: string,
        p2?: Item,
        p3?: boolean
      ) => boolean | undefined | Function
    ): this;
    /**
     * Sets a new value for property {@link #getFilterSuggests filterSuggests}.
     *
     * Defines whether to filter the provided suggestions before showing them to the user.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFilterSuggests(
      /**
       * New value for property `filterSuggests`
       */
      bFilterSuggests?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getMaxLength maxLength}.
     *
     * Maximum number of characters. Value '0' means the feature is switched off. This parameter is not compatible
     * with the input type `sap.m.InputType.Number`. If the input type is set to `Number`, the `maxLength` value
     * is ignored. If the `maxLength` is set after there is already a longer value, this value will not get
     * truncated. The `maxLength` property has effect only when the value is modified by user interaction.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxLength(
      /**
       * New value for property `maxLength`
       */
      iMaxLength?: int
    ): this;
    /**
     * Sets a new value for property {@link #getMaxSuggestionWidth maxSuggestionWidth}.
     *
     * If set, this parameter will control the horizontal size of the suggestion list to display more data.
     * By default, the suggestion list has a minimum width equal to the input field's width and a maximum width
     * of 640px. This property allows the suggestion list to contract or expand based on available space, potentially
     * exceeding 640px. **Note:** If the actual width of the input field exceeds the specified parameter value,
     * the value will be ignored.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.21.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxSuggestionWidth(
      /**
       * New value for property `maxSuggestionWidth`
       */
      sMaxSuggestionWidth?: CSSSize
    ): this;
    /**
     * Sets a custom result filter function for tabular suggestions to select the text that is passed to the
     * input field. Default is to check whether the first cell with a "text" property begins with the typed
     * value. For one value and two-value suggestions this callback function is not called.
     *
     * @since 1.21.1
     *
     * @returns this pointer for chaining
     */
    setRowResultFunction(
      /**
       * The result function is called with one parameter: the sap.m.ColumnListItem that is selected. The function
       * must return a result string that will be displayed as the input field's value.
       */
      fnFilter: (
        p1?: string,
        p2?: Item,
        p3?: boolean
      ) => boolean | undefined | Function
    ): this;
    /**
     * Sets the `selectedItem` association.
     *
     * @since 1.44
     *
     * @returns `this` to allow method chaining.
     */
    setSelectedItem(
      /**
       * New value for the `selectedItem` association. If an ID of a `sap.ui.core.Item` is given, the item with
       * this ID becomes the `selectedItem` association. Alternatively, a `sap.ui.core.Item` instance may be given
       * or `null` to clear the selection.
       */
      oItem?: ID | Item | null
    ): this;
    /**
     * Sets the `selectedKey` property.
     *
     * Default value is an empty string `""` or `undefined`.
     *
     * @since 1.44
     *
     * @returns `this` to allow method chaining.
     */
    setSelectedKey(
      /**
       * New value for property `selectedKey`. If the provided `sKey` is an empty string `""` or `undefined`,
       * the selection is cleared. If duplicate keys exist, the first item matching the key is selected.
       */
      sKey: string
    ): this;
    /**
     * Sets the `selectedRow` association. Default value is `null`.
     *
     * @since 1.44
     *
     * @returns `this` to allow method chaining.
     */
    setSelectedRow(
      /**
       * New value for the `selectedRow` association. If an ID of a `sap.m.ColumnListItem` is given, the item
       * with this ID becomes the `selectedRow` association. Alternatively, a `sap.m.ColumnListItem` instance
       * may be given or `null` to clear the selection.
       */
      oListItem: ID | ColumnListItem | null
    ): this;
    /**
     * Sets a new value for property {@link #getShowClearIcon showClearIcon}.
     *
     * Specifies whether clear icon is shown. Pressing the icon will clear input's value and fire the liveChange
     * event.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.94
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowClearIcon(
      /**
       * New value for property `showClearIcon`
       */
      bShowClearIcon?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowSuggestion showSuggestion}.
     *
     * If this is set to true, suggest event is fired when user types in the input. Changing the suggestItems
     * aggregation in suggest event listener will show suggestions within a popup. When runs on phone, input
     * will first open a dialog where the input and suggestions are shown. When runs on a tablet, the suggestions
     * are shown in a popup next to the input.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.16.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowSuggestion(
      /**
       * New value for property `showSuggestion`
       */
      bShowSuggestion?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowTableSuggestionValueHelp showTableSuggestionValueHelp}.
     *
     * For tabular suggestions, this flag will show/hide the button at the end of the suggestion table that
     * triggers the event "valueHelpRequest" when pressed. The default value is true.
     *
     * **Note:** If suggestions are not tabular or no suggestions are used, the button will not be displayed
     * and this flag is without effect.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.22.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowTableSuggestionValueHelp(
      /**
       * New value for property `showTableSuggestionValueHelp`
       */
      bShowTableSuggestionValueHelp?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowValueHelp showValueHelp}.
     *
     * If set to true, a value help indicator will be displayed inside the control. When clicked the event "valueHelpRequest"
     * will be fired.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowValueHelp(
      /**
       * New value for property `showValueHelp`
       */
      bShowValueHelp?: boolean
    ): this;
    /**
     * Setter for property `showValueStateMessage`.
     *
     * Default value is `true`
     *
     * @since 1.16
     *
     * @returns `this` to allow method chaining
     */
    setShowValueStateMessage(
      /**
       * new value for property `showValueStateMessage`
       */
      bShowValueStateMessage: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getStartSuggestion startSuggestion}.
     *
     * Minimum length of the entered text in input before suggest event is fired. The default value is 1 which
     * means the suggest event is fired after user types in input.
     *
     * **Note:** When it's set to 0, suggest event is fired when input with no text gets focus. In this case
     * no suggestion popup will open.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `1`.
     *
     * @since 1.21.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setStartSuggestion(
      /**
       * New value for property `startSuggestion`
       */
      iStartSuggestion?: int
    ): this;
    /**
     * Sets a new value for property {@link #getSuggestionRowValidator suggestionRowValidator}.
     *
     * Defines the validation callback function called when a suggestion row gets selected.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.44
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSuggestionRowValidator(
      /**
       * New value for property `suggestionRowValidator`
       */
      fnSuggestionRowValidator?: Function
    ): this;
    /**
     * Sets a new value for property {@link #getTextFormatMode textFormatMode}.
     *
     * Defines the display text format mode.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Value`.
     *
     * @since 1.44
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextFormatMode(
      /**
       * New value for property `textFormatMode`
       */
      sTextFormatMode?: InputTextFormatMode | keyof typeof InputTextFormatMode
    ): this;
    /**
     * Sets a new value for property {@link #getTextFormatter textFormatter}.
     *
     * Defines the display text formatter function.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.44
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextFormatter(
      /**
       * New value for property `textFormatter`
       */
      fnTextFormatter?: Function
    ): this;
    /**
     * Sets a new value for property {@link #getType type}.
     *
     * HTML type of the internal `input` tag (e.g. Text, Number, Email, Phone). The particular effect of this
     * property differs depending on the browser and the current language settings, especially for the type
     * Number.
     *  This parameter is intended to be used with touch devices that use different soft keyboard layouts depending
     * on the given input type.
     *  Only the default value `sap.m.InputType.Text` may be used in combination with data model formats. `sap.ui.model`
     * defines extended formats that are mostly incompatible with normal HTML representations for numbers and
     * dates.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Text`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setType(
      /**
       * New value for property `type`
       */
      sType?: InputType | keyof typeof InputType
    ): this;
    /**
     * Setter for property `value`.
     *
     * Default value is empty/`undefined`.
     *
     *
     * @returns `this` to allow method chaining.
     */
    setValue(
      /**
       * New value for property `value`.
       */
      sValue: string
    ): this;
    /**
     * Sets a new value for property {@link #getValueHelpIconSrc valueHelpIconSrc}.
     *
     * Set custom value help icon.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"sap-icon://value-help"`.
     *
     * @since 1.84.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueHelpIconSrc(
      /**
       * New value for property `valueHelpIconSrc`
       */
      sValueHelpIconSrc?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getValueHelpOnly valueHelpOnly}.
     *
     * If set to true, direct text input is disabled and the control will trigger the event "valueHelpRequest"
     * for all user interactions. The properties "showValueHelp", "editable", and "enabled" must be set to true,
     * otherwise the property will have no effect. In this scenario, the `showItems` API will not work.
     *
     *  **Note:** The property is deprecated, as it creates unnecessary usability and accessibility restrictions.
     * The decision to deprecate it is based on the fact that it serves no purpose to have an input field where
     * the user cannot type. This property restricts even the paste functionality, which can be useful, e.g.
     * the needed info is already in the clipboard. If the user's input needs to match specific predefined values,
     * the application should validate the input against the set of values and provide feedback to the user
     * or use other mechanism for selection, where freestyle input is not allowed by design (Select, SelectDialog,
     * etc). **Note:** Please note that there is no direct replacement for this property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.21.0
     * @deprecated As of version 1.119. The property valueHelpOnly should not be used anymore
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueHelpOnly(
      /**
       * New value for property `valueHelpOnly`
       */
      bValueHelpOnly?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getValueLiveUpdate valueLiveUpdate}.
     *
     * Indicates when the value gets updated with the user changes: At each keystroke (true) or first when the
     * user presses enter or tabs out (false).
     *
     * **Note:** When set to true and the value of the Input control is bound to a model, the change event becomes
     * obsolete and will not be fired, as the value in the model will be updated each time the user provides
     * input. In such cases, subscription to the liveChange event is more appropriate, as it corresponds to
     * the way the underlying model gets updated.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.24
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueLiveUpdate(
      /**
       * New value for property `valueLiveUpdate`
       */
      bValueLiveUpdate?: boolean
    ): this;
    /**
     * Setter for property `valueStateText`.
     *
     * Default value is empty/`undefined`
     *
     * @since 1.16
     *
     * @returns `this` to allow method chaining
     */
    setValueStateText(
      /**
       * new value for property `valueStateText`
       */
      sValueStateText: string
    ): this;
    /**
     * A helper function calculating if the SuggestionsPopover should be opened on mobile.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns If the popover should be opened.
     */
    shouldSuggetionsPopoverOpenOnMobile(
      /**
       * Ontap event.
       */
      oEvent: jQuery.Event
    ): boolean;
    /**
     * Opens the `SuggestionsPopover` with the available items. **Note:** When `valueHelpOnly` property is set
     * to true, the `SuggestionsPopover` will not open.
     *
     * @since 1.64
     */
    showItems(
      /**
       * Function to filter the items shown in the SuggestionsPopover
       */
      fnFilter: Function | undefined
    ): void;
    /**
     * Unbinds aggregation {@link #getSuggestionColumns suggestionColumns} from model data.
     *
     * @since 1.21.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindSuggestionColumns(): this;
    /**
     * Unbinds aggregation {@link #getSuggestionRows suggestionRows} from model data.
     *
     * @since 1.21.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindSuggestionRows(): this;
    /**
     * Updates the inner input field.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    updateInputField(
      /**
       * Dom value which will be set.
       */
      sNewValue: string
    ): void;
    /**
     * Update suggestion items.
     *
     *
     * @returns this Input instance for chaining.
     */
    updateSuggestionItems(): this;
  }
  /**
   * Describes the settings that can be provided to the Input constructor.
   */
  export interface $InputSettings extends $InputBaseSettings {
    /**
     * HTML type of the internal `input` tag (e.g. Text, Number, Email, Phone). The particular effect of this
     * property differs depending on the browser and the current language settings, especially for the type
     * Number.
     *  This parameter is intended to be used with touch devices that use different soft keyboard layouts depending
     * on the given input type.
     *  Only the default value `sap.m.InputType.Text` may be used in combination with data model formats. `sap.ui.model`
     * defines extended formats that are mostly incompatible with normal HTML representations for numbers and
     * dates.
     */
    type?:
      | (InputType | keyof typeof InputType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Maximum number of characters. Value '0' means the feature is switched off. This parameter is not compatible
     * with the input type `sap.m.InputType.Number`. If the input type is set to `Number`, the `maxLength` value
     * is ignored. If the `maxLength` is set after there is already a longer value, this value will not get
     * truncated. The `maxLength` property has effect only when the value is modified by user interaction.
     */
    maxLength?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Only used if type=date and no datepicker is available. The data is displayed and the user input is parsed
     * according to this format. **Note:** The value property is always of the form RFC 3339 (YYYY-MM-dd).
     *
     * @deprecated As of version 1.9.1. `sap.m.DatePicker`, `sap.m.TimePicker` or `sap.m.DateTimePicker` should
     * be used for date/time inputs and formating.
     */
    dateFormat?: string | PropertyBindingInfo;

    /**
     * If set to true, a value help indicator will be displayed inside the control. When clicked the event "valueHelpRequest"
     * will be fired.
     *
     * @since 1.16
     */
    showValueHelp?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Set custom value help icon.
     *
     * @since 1.84.0
     */
    valueHelpIconSrc?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * If this is set to true, suggest event is fired when user types in the input. Changing the suggestItems
     * aggregation in suggest event listener will show suggestions within a popup. When runs on phone, input
     * will first open a dialog where the input and suggestions are shown. When runs on a tablet, the suggestions
     * are shown in a popup next to the input.
     *
     * @since 1.16.1
     */
    showSuggestion?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * If set to true, direct text input is disabled and the control will trigger the event "valueHelpRequest"
     * for all user interactions. The properties "showValueHelp", "editable", and "enabled" must be set to true,
     * otherwise the property will have no effect. In this scenario, the `showItems` API will not work.
     *
     *  **Note:** The property is deprecated, as it creates unnecessary usability and accessibility restrictions.
     * The decision to deprecate it is based on the fact that it serves no purpose to have an input field where
     * the user cannot type. This property restricts even the paste functionality, which can be useful, e.g.
     * the needed info is already in the clipboard. If the user's input needs to match specific predefined values,
     * the application should validate the input against the set of values and provide feedback to the user
     * or use other mechanism for selection, where freestyle input is not allowed by design (Select, SelectDialog,
     * etc). **Note:** Please note that there is no direct replacement for this property.
     *
     * @since 1.21.0
     * @deprecated As of version 1.119. The property valueHelpOnly should not be used anymore
     */
    valueHelpOnly?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether to filter the provided suggestions before showing them to the user.
     */
    filterSuggests?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * If set, this parameter will control the horizontal size of the suggestion list to display more data.
     * By default, the suggestion list has a minimum width equal to the input field's width and a maximum width
     * of 640px. This property allows the suggestion list to contract or expand based on available space, potentially
     * exceeding 640px. **Note:** If the actual width of the input field exceeds the specified parameter value,
     * the value will be ignored.
     *
     * @since 1.21.1
     */
    maxSuggestionWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Minimum length of the entered text in input before suggest event is fired. The default value is 1 which
     * means the suggest event is fired after user types in input.
     *
     * **Note:** When it's set to 0, suggest event is fired when input with no text gets focus. In this case
     * no suggestion popup will open.
     *
     * @since 1.21.2
     */
    startSuggestion?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * For tabular suggestions, this flag will show/hide the button at the end of the suggestion table that
     * triggers the event "valueHelpRequest" when pressed. The default value is true.
     *
     * **Note:** If suggestions are not tabular or no suggestions are used, the button will not be displayed
     * and this flag is without effect.
     *
     * @since 1.22.1
     */
    showTableSuggestionValueHelp?:
      | boolean
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The description is a text after the input field, e.g. units of measurement, currencies.
     */
    description?: string | PropertyBindingInfo;

    /**
     * This property only takes effect if the description property is set. It controls the distribution of space
     * between the input field and the description text. The default value is 50% leaving the other 50% for
     * the description.
     */
    fieldWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates when the value gets updated with the user changes: At each keystroke (true) or first when the
     * user presses enter or tabs out (false).
     *
     * **Note:** When set to true and the value of the Input control is bound to a model, the change event becomes
     * obsolete and will not be fired, as the value in the model will be updated each time the user provides
     * input. In such cases, subscription to the liveChange event is more appropriate, as it corresponds to
     * the way the underlying model gets updated.
     *
     * @since 1.24
     */
    valueLiveUpdate?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the key of the selected item.
     *
     * **Note:** If duplicate keys exist, the first item matching the key is used.
     *
     * @since 1.44
     */
    selectedKey?: string | PropertyBindingInfo;

    /**
     * Defines the display text format mode.
     *
     * @since 1.44
     */
    textFormatMode?:
      | (InputTextFormatMode | keyof typeof InputTextFormatMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the display text formatter function.
     *
     * @since 1.44
     */
    textFormatter?: Function | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the validation callback function called when a suggestion row gets selected.
     *
     * @since 1.44
     */
    suggestionRowValidator?: Function | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies whether the suggestions highlighting is enabled. **Note:** Due to performance constraints,
     * the functionality will be disabled above 200 items. **Note:** Highlighting in table suggestions will
     * work only for cells containing sap.m.Label or sap.m.Text controls.
     *
     * @since 1.46
     */
    enableSuggestionsHighlighting?:
      | boolean
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Enables the `autoPopinMode` of `sap.m.Table`, when the input has tabular suggestions. **Note:** The `autoPopinMode`
     * overwrites the `demandPopin` and the `minScreenWidth` properties of the `sap.m.Column`. When setting,
     * `enableTableAutoPopinMode`, from true to false, the application must reconfigure the `demandPopin` and
     * `minScreenWidth` properties of the `sap.m.Column` control by itself.
     *
     * @since 1.89
     */
    enableTableAutoPopinMode?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies whether autocomplete is enabled. Works only if "showSuggestion" property is set to true. **Note:**
     * The autocomplete feature is disabled on Android devices due to a OS specific issue.
     *
     * @since 1.61
     */
    autocomplete?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies whether clear icon is shown. Pressing the icon will clear input's value and fire the liveChange
     * event.
     *
     * @since 1.94
     */
    showClearIcon?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the items displayed in the suggestion popup. Changing this aggregation (by calling `addSuggestionItem`,
     * `insertSuggestionItem`, `removeSuggestionItem`, `removeAllSuggestionItems`, or `destroySuggestionItems`)
     * after `Input` is rendered opens/closes the suggestion popup.
     *
     * To display suggestions with two text values, add `sap.ui.core.ListItem` as `SuggestionItems` (since 1.21.1).
     * For the selected `ListItem`, only the first value is returned to the input field.
     *
     * **Note:** Only `text` and `additionalText` property values of the item are displayed. For example, if
     * an `icon` is set, it is ignored. To display more information per item (including icons), you can use
     * the `suggestionRows` aggregation.
     *
     * **Note:** Disabled items are not visualized in the list with the suggestions, however they can still
     * be accessed through the aggregation. **Note:** If `suggestionItems` & `suggestionRows` are set in parallel,
     * the last aggeragtion to come would overwrite the previous ones.
     *
     * @since 1.16.1
     */
    suggestionItems?: Item[] | Item | AggregationBindingInfo | `{${string}}`;

    /**
     * The suggestionColumns and suggestionRows are for tabular input suggestions. This aggregation allows for
     * binding the table columns; for more details see the aggregation "suggestionRows".
     *
     * @since 1.21.1
     */
    suggestionColumns?:
      | Column[]
      | Column
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * The suggestionColumns and suggestionRows are for tabular input suggestions. This aggregation allows for
     * binding the table cells. The items of this aggregation are to be bound directly or to set in the suggest
     * event method. **Note:** If `suggestionItems` & `suggestionRows` are set in parallel, the last aggeragtion
     * to come would overwrite the previous ones.
     *
     * @since 1.21.1
     */
    suggestionRows?:
      | ITableItem[]
      | ITableItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Sets or retrieves the selected item from the suggestionItems.
     *
     * @since 1.44
     */
    selectedItem?: Item | string;

    /**
     * Sets or retrieves the selected row from the suggestionRows.
     *
     * @since 1.44
     */
    selectedRow?: ColumnListItem | string;

    /**
     * Fired when the value of the input is changed by user interaction - each keystroke, delete, paste, etc.
     *
     * **Note:** Browsing autocomplete suggestions does not fire the event.
     */
    liveChange?: (oEvent: Input$LiveChangeEvent) => void;

    /**
     * When the value help indicator is clicked, this event will be fired.
     *
     * @since 1.16
     */
    valueHelpRequest?: (oEvent: Input$ValueHelpRequestEvent) => void;

    /**
     * This event is fired when user types in the input and showSuggestion is set to true. Changing the suggestItems
     * aggregation will show the suggestions within a popup.
     *
     * @since 1.16.1
     */
    suggest?: (oEvent: Input$SuggestEvent) => void;

    /**
     * This event is fired when suggestionItem shown in suggestion popup are selected. This event is only fired
     * when showSuggestion is set to true and there are suggestionItems shown in the suggestion popup.
     *
     * @since 1.16.3
     */
    suggestionItemSelected?: (
      oEvent: Input$SuggestionItemSelectedEvent
    ) => void;

    /**
     * This event is fired when user presses the Enter key on the input.
     *
     * **Notes:**
     * 	 - The event is fired independent of whether there was a change before or not. If a change was performed,
     *     the event is fired after the change event.
     * 	 - The event is also fired when an item of the select list is selected via Enter.
     * 	 - The event is only fired on an input which allows text input (`editable`, `enabled` and not `valueHelpOnly`).
     *
     *
     * @since 1.33.0
     */
    submit?: (oEvent: Input$SubmitEvent) => void;
  }

  /**
   * Parameters of the Input#liveChange event.
   */
  export interface Input$LiveChangeEventParameters {
    /**
     * The current value of the input, after a live change event.
     */
    value?: string;

    /**
     * Indicates that ESC key triggered the event. **Note:** This parameter will not be sent unless the ESC
     * key is pressed.
     */
    escPressed?: boolean;

    /**
     * The value of the input before pressing ESC key. **Note:** This parameter will not be sent unless the
     * ESC key is pressed.
     */
    previousValue?: string;
  }

  /**
   * Event object of the Input#liveChange event.
   */
  export type Input$LiveChangeEvent = Event<
    Input$LiveChangeEventParameters,
    Input
  >;

  /**
   * Parameters of the Input#submit event.
   */
  export interface Input$SubmitEventParameters {
    /**
     * The new value of the input.
     */
    value?: string;
  }

  /**
   * Event object of the Input#submit event.
   */
  export type Input$SubmitEvent = Event<Input$SubmitEventParameters, Input>;

  /**
   * Parameters of the Input#suggest event.
   */
  export interface Input$SuggestEventParameters {
    /**
     * The current value which has been typed in the input.
     */
    suggestValue?: string;

    /**
     * The suggestion list is passed to this event for convenience. If you use list-based or tabular suggestions,
     * fill the suggestionList with the items you want to suggest. Otherwise, directly add the suggestions to
     * the "suggestionItems" aggregation of the input control.
     */
    suggestionColumns?: ListBase;
  }

  /**
   * Event object of the Input#suggest event.
   */
  export type Input$SuggestEvent = Event<Input$SuggestEventParameters, Input>;

  /**
   * Parameters of the Input#suggestionItemSelected event.
   */
  export interface Input$SuggestionItemSelectedEventParameters {
    /**
     * This is the item selected in the suggestion popup for one and two-value suggestions. For tabular suggestions,
     * this value will not be set.
     */
    selectedItem?: Item;

    /**
     * This is the row selected in the tabular suggestion popup represented as a ColumnListItem. For one and
     * two-value suggestions, this value will not be set.
     *
     * **Note:** The row result function to select a result value for the string is already executed at this
     * time. To pick different value for the input field or to do follow up steps after the item has been selected.
     */
    selectedRow?: ColumnListItem;
  }

  /**
   * Event object of the Input#suggestionItemSelected event.
   */
  export type Input$SuggestionItemSelectedEvent = Event<
    Input$SuggestionItemSelectedEventParameters,
    Input
  >;

  /**
   * Parameters of the Input#valueHelpRequest event.
   */
  export interface Input$ValueHelpRequestEventParameters {
    /**
     * The event parameter is set to true, when the button at the end of the suggestion table is clicked, otherwise
     * false. It can be used to determine whether the "value help" trigger or the "show all items" trigger has
     * been pressed.
     */
    fromSuggestions?: boolean;

    /**
     * The event parameter is set to true, when the event is fired after keyboard interaction, otherwise false.
     */
    fromKeyboard?: boolean;
  }

  /**
   * Event object of the Input#valueHelpRequest event.
   */
  export type Input$ValueHelpRequestEvent = Event<
    Input$ValueHelpRequestEventParameters,
    Input
  >;
}

declare module "sap/m/InputBase" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IFormContent,
    ISemanticFormContent,
    ILabelable,
    ID,
    FocusInfo,
    AccessibilityInfo,
    TextAlign,
    TextDirection,
    ValueState,
    CSSSize,
  } from "sap/ui/core/library";

  import { IToolbarInteractiveControl } from "sap/m/library";

  import Icon from "sap/ui/core/Icon";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import FormattedText from "sap/m/FormattedText";

  import Label from "sap/m/Label";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Event from "sap/ui/base/Event";

  /**
   * The `sap.m.InputBase` control provides a basic functionality for input controls.
   *
   * @since 1.12.0
   */
  export default class InputBase
    extends Control
    implements
      IFormContent,
      ISemanticFormContent,
      ILabelable,
      IToolbarInteractiveControl
  {
    __implements__sap_ui_core_IFormContent: boolean;
    __implements__sap_ui_core_ISemanticFormContent: boolean;
    __implements__sap_ui_core_ILabelable: boolean;
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new `sap.m.InputBase`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $InputBaseSettings
    );
    /**
     * Constructor for a new `sap.m.InputBase`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $InputBaseSettings
    );
    /**
     * Indicates whether the input field is in the rendering phase.
     *
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    bRenderingPhase: boolean;

    /**
     * Use labels as placeholder configuration. It can be necessary for the subclasses to overwrite this when
     * native placeholder usage causes undesired input events or when placeholder attribute is not supported
     * for the specified type. https://html.spec.whatwg.org/multipage/forms.html#input-type-attr-summary
     * See:
     * 	sap.m.InputBase#oninput
     *
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    bShowLabelAsPlaceholder: boolean;

    /**
     * Creates a new subclass of class sap.m.InputBase with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, InputBase>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.InputBase.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     * @since 1.90
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds an icon to the beginning of the input
     * See:
     * 	sap.ui.core.IconPool.createControlByURI
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    addBeginIcon(
      /**
       * settings for creating an icon
       */
      oIconSettings: object
    ): null | Icon;
    /**
     * Adds an icon to the end of the input
     * See:
     * 	sap.ui.core.IconPool.createControlByURI
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    addEndIcon(
      /**
       * settings for creating an icon
       */
      oIconSettings: object,
      /**
       * position to be inserted in the aggregation. If not provided, the icon gets inserted on last position.
       */
      iPosition: int
    ): null | Icon;
    /**
     * Applies the focus info. To be overwritten by subclasses.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Returns `this` to allow method chaining
     */
    applyFocusInfo(
      /**
       * An object representing the serialized focus information.
       */
      oFocusInfo: FocusInfo
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.InputBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.InputBase` itself.
     *
     * Is fired when the text in the input field has changed and the focus leaves the input field or the enter
     * key is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: InputBase$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.InputBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.InputBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.InputBase` itself.
     *
     * Is fired when the text in the input field has changed and the focus leaves the input field or the enter
     * key is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: InputBase$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.InputBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds property {@link #getValue value} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindProperty ManagedObject.bindProperty} for a detailed description
     * of the possible properties of `oBindingInfo`
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindValue(
      /**
       * The binding information
       */
      oBindingInfo: PropertyBindingInfo
    ): this;
    /**
     * Close value state message popup.
     *
     * @since 1.26
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    closeValueStateMessage(): void;
    /**
     * Destroys the formattedValueStateText in the aggregation {@link #getFormattedValueStateText formattedValueStateText}.
     *
     * @since 1.78
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyFormattedValueStateText(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:change change} event of this `sap.m.InputBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: InputBase$ChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:change change} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: InputBase$ChangeEventParameters
    ): this;
    /**
     * Fires the change event for the listeners
     *
     * @since 1.22.1
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    fireChangeEvent(
      /**
       * value of the input.
       */
      sValue: string,
      /**
       * extra event parameters.
       */
      oParams?: object
    ): void;
    /**
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The accessibility information for this `InputBase`
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     * @since 1.90
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets the DOM element reference where the message popup is attached.
     *
     * @since 1.26
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The DOM element reference where the message popup is attached
     */
    getDomRefForValueStateMessage(): Element;
    /**
     * Gets current value of property {@link #getEditable editable}.
     *
     * Defines whether the control can be modified by the user or not. **Note:** A user can tab to non-editable
     * control, highlight it, and copy the text from it.
     *
     * Default value is `true`.
     *
     * @since 1.12.0
     *
     * @returns Value of property `editable`
     */
    getEditable(): boolean;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Indicates whether the user can interact with the control or not. **Note:** Disabled controls cannot be
     * focused and they are out of the tab-chain.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Returns an object representing the serialized focus information. To be overwritten by subclasses.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns An object representing the serialized focus information.
     */
    getFocusInfo(): FocusInfo;
    /**
     * Gets content of aggregation {@link #getFormattedValueStateText formattedValueStateText}.
     *
     * Defines the formatted text that appears in the value state message pop-up. It can include links. If both
     * `valueStateText` and `formattedValueStateText` are set - the latter is shown.
     *
     * @since 1.78
     */
    getFormattedValueStateText(): FormattedText;
    /**
     * Gets the labels referencing this control.
     *
     * @since 1.48
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Array of objects which are the current targets of the `ariaLabelledBy` association and the labels
     * referencing this control.
     */
    getLabels(): Label[];
    /**
     * Gets the last value of the InputBase
     *
     * @since 1.78
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    getLastValue(): string;
    /**
     * Gets current value of property {@link #getName name}.
     *
     * The name to be used in the HTML code (for example, for HTML forms that send data to the server via submission).
     *
     *
     * @returns Value of property `name`
     */
    getName(): string;
    /**
     * Gets current value of property {@link #getPlaceholder placeholder}.
     *
     * Defines a short hint intended to aid the user with data entry when the control has no value.
     *
     *
     * @returns Value of property `placeholder`
     */
    getPlaceholder(): string;
    /**
     * Gets current value of property {@link #getRequired required}.
     *
     * Indicates that user input is required. This property is only needed for accessibility purposes when a
     * single relationship between the field and a label (see aggregation `labelFor` of `sap.m.Label`) cannot
     * be established (e.g. one label should label multiple fields).
     *
     * Default value is `false`.
     *
     * @since 1.38.4
     *
     * @returns Value of property `required`
     */
    getRequired(): boolean;
    /**
     * Retrieves the selected text. Only supported for input control's type of Text, Url, Tel and Password.
     *
     * @since 1.32
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The selected text.
     */
    getSelectedText(): string;
    /**
     * Gets current value of property {@link #getShowValueStateMessage showValueStateMessage}.
     *
     * Indicates whether the value state message should be shown or not.
     *
     * Default value is `true`.
     *
     * @since 1.26.0
     *
     * @returns Value of property `showValueStateMessage`
     */
    getShowValueStateMessage(): boolean;
    /**
     * Gets current value of property {@link #getTextAlign textAlign}.
     *
     * Defines the horizontal alignment of the text that is shown inside the input field.
     *
     * Default value is `Initial`.
     *
     * @since 1.26.0
     *
     * @returns Value of property `textAlign`
     */
    getTextAlign(): TextAlign;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * Defines the text directionality of the input field, e.g. `RTL`, `LTR`
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getValue value}.
     *
     * Defines the value of the control.
     *
     *
     * @returns Value of property `value`
     */
    getValue(): string;
    /**
     * Gets the value of the accessibility description info field.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The value of the accessibility description info
     */
    getValueDescriptionInfo(): string;
    /**
     * Gets current value of property {@link #getValueState valueState}.
     *
     * Visualizes the validation state of the control, e.g. `Error`, `Warning`, `Success`.
     *
     * Default value is `None`.
     *
     *
     * @returns Value of property `valueState`
     */
    getValueState(): ValueState;
    /**
     * Gets the ID of the hidden value state message related to value state links
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The ID of the hidden value state message related to value state links
     */
    getValueStateLinksShortcutsId(): string;
    /**
     * Returns the keyboard shortcuts announcement for the value state links
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The text for value state links shortcuts
     */
    getValueStateLinksShortcutsTextAcc(): string;
    /**
     * Gets current value of property {@link #getValueStateText valueStateText}.
     *
     * Defines the text that appears in the value state message pop-up. If this is not specified, a default
     * text is shown from the resource bundle.
     *
     * @since 1.26.0
     *
     * @returns Value of property `valueStateText`
     */
    getValueStateText(): string;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Defines the width of the control.
     *
     * **Note:** If the provided width is too small, the control gets stretched to its min width, which is needed
     * in order for the control to be usable and well aligned.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Returns if the control can be bound to a label
     *
     *
     * @returns `true` if the control can be bound to a label
     */
    hasLabelableHTMLElement(): boolean;
    /**
     * indicating if a character is currently composing.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not a character is composing. True if after "compositionstart" event and before "compositionend"
     * event.
     */
    isComposingCharacter(): boolean;
    /**
     * Indicates whether the control should use `sap.m.Dialog` or not.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Boolean.
     */
    isMobileDevice(): boolean;
    /**
     * Handles the change event.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns true when change event is fired
     */
    onChange(
      /**
       * The event
       */
      oEvent: jQuery.Event,
      /**
       * Additional event parameters to be passed in to the change event handler if the value has changed
       */
      mParameters: object,
      /**
       * Passed value on change
       */
      sNewValue: string
    ): boolean | undefined;
    /**
     * Handles the change event.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns true when change event is fired
     */
    onChange(
      /**
       * The event
       */
      oEvent: jQuery.Event,
      /**
       * Passed value on change
       */
      sNewValue: string
    ): boolean | undefined;
    /**
     * Hook method that gets called when the input value is reverted with hitting escape. It may require to
     * re-implement this method from sub classes for control specific behaviour.
     *
     * @since 1.26
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onValueRevertedByEscape(
      /**
       * Reverted value of the input.
       */
      sValue: string
    ): void;
    /**
     * Open value state message popup.
     *
     * @since 1.26
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    openValueStateMessage(): void;
    /**
     * Hook method to prevent the change event from being fired when the text input field loses focus.
     *
     * @since 1.46
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not the change event should be prevented.
     */
    preventChangeOnFocusLeave(
      /**
       * The event object.
       */
      oEvent?: jQuery.Event
    ): boolean;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     * @since 1.90
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     * @since 1.90
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Selects the text within the input field between the specified start and end positions. Only supported
     * for input control's type of Text, Url, Tel and Password.
     *
     * @since 1.22.1
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns `this` to allow method chaining.
     */
    selectText(
      /**
       * The index into the text at which the first selected character is located.
       */
      iSelectionStart: int,
      /**
       * The index into the text at which the last selected character is located.
       */
      iSelectionEnd: int
    ): this;
    /**
     * Sets a new value for property {@link #getEditable editable}.
     *
     * Defines whether the control can be modified by the user or not. **Note:** A user can tab to non-editable
     * control, highlight it, and copy the text from it.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.12.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEditable(
      /**
       * New value for property `editable`
       */
      bEditable?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Indicates whether the user can interact with the control or not. **Note:** Disabled controls cannot be
     * focused and they are out of the tab-chain.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getFormattedValueStateText formattedValueStateText}.
     *
     * @since 1.78
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFormattedValueStateText(
      /**
       * The formattedValueStateText to set
       */
      oFormattedValueStateText: FormattedText
    ): this;
    /**
     * Sets the last value of the InputBase
     *
     * @since 1.78
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    setLastValue(sValue: string): this;
    /**
     * Sets a new value for property {@link #getName name}.
     *
     * The name to be used in the HTML code (for example, for HTML forms that send data to the server via submission).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setName(
      /**
       * New value for property `name`
       */
      sName?: string
    ): this;
    /**
     * Sets a new value for property {@link #getPlaceholder placeholder}.
     *
     * Defines a short hint intended to aid the user with data entry when the control has no value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPlaceholder(
      /**
       * New value for property `placeholder`
       */
      sPlaceholder?: string
    ): this;
    /**
     * Sets the behavior of the control to prioritize user interaction over later model updates. When set to
     * `true`, it prevents the model from overwriting user input. Example: Input's value property is bound to
     * a model The user starts typing and due to this action, the model receives update from the backend, thus
     * forwarding it to the bound control property Result when `false`: User input is overwritten by the incoming
     * model update. Result when `true`: User input is not overwritten by the incoming model update - the model
     * update is skipped and the value remains unchanged.
     */
    setPreferUserInteraction(
      /**
       * True, if the user interaction is preferred
       */
      bPrefer: boolean
    ): void;
    /**
     * Sets a new value for property {@link #getRequired required}.
     *
     * Indicates that user input is required. This property is only needed for accessibility purposes when a
     * single relationship between the field and a label (see aggregation `labelFor` of `sap.m.Label`) cannot
     * be established (e.g. one label should label multiple fields).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.38.4
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRequired(
      /**
       * New value for property `required`
       */
      bRequired?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowValueStateMessage showValueStateMessage}.
     *
     * Indicates whether the value state message should be shown or not.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.26.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowValueStateMessage(
      /**
       * New value for property `showValueStateMessage`
       */
      bShowValueStateMessage?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getTextAlign textAlign}.
     *
     * Defines the horizontal alignment of the text that is shown inside the input field.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Initial`.
     *
     * @since 1.26.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextAlign(
      /**
       * New value for property `textAlign`
       */
      sTextAlign?: TextAlign | keyof typeof TextAlign
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * Defines the text directionality of the input field, e.g. `RTL`, `LTR`
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Setter for property `value`.
     *
     * Default value is empty/`undefined`.
     *
     *
     * @returns `this` to allow method chaining.
     */
    setValue(
      /**
       * New value for property `value`.
       */
      sValue: string
    ): this;
    /**
     * Sets a new value for property {@link #getValueState valueState}.
     *
     * Visualizes the validation state of the control, e.g. `Error`, `Warning`, `Success`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueState(
      /**
       * New value for property `valueState`
       */
      sValueState?: ValueState | keyof typeof ValueState
    ): this;
    /**
     * Sets a new value for property {@link #getValueStateText valueStateText}.
     *
     * Defines the text that appears in the value state message pop-up. If this is not specified, a default
     * text is shown from the resource bundle.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.26.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueStateText(
      /**
       * New value for property `valueStateText`
       */
      sValueStateText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Defines the width of the control.
     *
     * **Note:** If the provided width is too small, the control gets stretched to its min width, which is needed
     * in order for the control to be usable and well aligned.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Unbinds property {@link #getValue value} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindValue(): this;
    /**
     * Sets the DOM value of the input field and handles placeholder visibility.
     *
     * @since 1.22
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns `this` to allow method chaining.
     */
    updateDomValue(
      /**
       * value of the input field.
       */
      sValue: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the InputBase constructor.
   */
  export interface $InputBaseSettings extends $ControlSettings {
    /**
     * Defines the value of the control.
     */
    value?: string | PropertyBindingInfo;

    /**
     * Defines the width of the control.
     *
     * **Note:** If the provided width is too small, the control gets stretched to its min width, which is needed
     * in order for the control to be usable and well aligned.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether the user can interact with the control or not. **Note:** Disabled controls cannot be
     * focused and they are out of the tab-chain.
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Visualizes the validation state of the control, e.g. `Error`, `Warning`, `Success`.
     */
    valueState?:
      | (ValueState | keyof typeof ValueState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The name to be used in the HTML code (for example, for HTML forms that send data to the server via submission).
     */
    name?: string | PropertyBindingInfo;

    /**
     * Defines a short hint intended to aid the user with data entry when the control has no value.
     */
    placeholder?: string | PropertyBindingInfo;

    /**
     * Defines whether the control can be modified by the user or not. **Note:** A user can tab to non-editable
     * control, highlight it, and copy the text from it.
     *
     * @since 1.12.0
     */
    editable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the text that appears in the value state message pop-up. If this is not specified, a default
     * text is shown from the resource bundle.
     *
     * @since 1.26.0
     */
    valueStateText?: string | PropertyBindingInfo;

    /**
     * Indicates whether the value state message should be shown or not.
     *
     * @since 1.26.0
     */
    showValueStateMessage?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the horizontal alignment of the text that is shown inside the input field.
     *
     * @since 1.26.0
     */
    textAlign?:
      | (TextAlign | keyof typeof TextAlign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the text directionality of the input field, e.g. `RTL`, `LTR`
     *
     * @since 1.28.0
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Indicates that user input is required. This property is only needed for accessibility purposes when a
     * single relationship between the field and a label (see aggregation `labelFor` of `sap.m.Label`) cannot
     * be established (e.g. one label should label multiple fields).
     *
     * @since 1.38.4
     */
    required?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the formatted text that appears in the value state message pop-up. It can include links. If both
     * `valueStateText` and `formattedValueStateText` are set - the latter is shown.
     *
     * @since 1.78
     */
    formattedValueStateText?: FormattedText;

    /**
     * Association to controls / IDs that label this control (see WAI-ARIA attribute aria-labelledby).
     *
     * @since 1.27.0
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Association to controls / IDs that describe this control (see WAI-ARIA attribute aria-describedby).
     *
     * @since 1.90
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Is fired when the text in the input field has changed and the focus leaves the input field or the enter
     * key is pressed.
     */
    change?: (oEvent: InputBase$ChangeEvent) => void;
  }

  /**
   * Parameters of the InputBase#change event.
   */
  export interface InputBase$ChangeEventParameters {
    /**
     * The new `value` of the `control`.
     */
    value?: string;
  }

  /**
   * Event object of the InputBase#change event.
   */
  export type InputBase$ChangeEvent = Event<
    InputBase$ChangeEventParameters,
    InputBase
  >;
}

declare module "sap/m/InputBaseRenderer" {
  import RenderManager from "sap/ui/core/RenderManager";

  import InputBase from "sap/m/InputBase";

  import { InputBaseAccessibilityState } from "sap/m/library";

  import Icon from "sap/ui/core/Icon";

  /**
   * InputBase renderer.
   *
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  interface InputBaseRenderer {
    /**
     * This method is reserved for derived class to set width inline style
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    addControlWidth(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * Add cursor class to input container.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    addCursorClass(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * This method is reserved for derived classes to add extra classes for input element.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    addInnerClasses(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * This method is reserved for derived classes to add extra styles for input element.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    addInnerStyles(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * This method is reserved for derived classes to add extra classes for input container.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    addOuterClasses(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * This method is reserved for derived class to add extra styles for input container.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    addOuterStyles(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * Add a padding class to input container. May be overwritten by subclasses.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    addPaddingClass(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * Adds custom placeholder classes, if native placeholder is not used. To be overwritten by subclasses.
     * Note that this method should not be used anymore as native placeholder is used on all browsers
     *
     * @deprecated As of version 1.58.0. This method should not be used anymore as native placeholder is used
     * on all browsers.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    addPlaceholderClasses(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * This method is reserved for derived classes to add extra styles for the placeholder, if rendered as label.
     *
     * @deprecated As of version 1.58.0. This method should not be used anymore as native placeholder is used
     * on all browsers.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    addPlaceholderStyles(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * Add the CSS value state classes to the control's root element using the provided {@link sap.ui.core.RenderManager}.
     * To be overwritten by subclasses.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    addValueStateClasses(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * This method is reserved for derived classes to add extra styles for input element.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    addWrapperStyles(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * Write the closing tag name of the input.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    closeInputTag(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * Ends opened input tag.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    endInputTag(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * Returns the accessibility state of the control. Hook for the subclasses.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Accessibility state object
     */
    getAccessibilityState(
      /**
       * an object representation of the control.
       */
      oControl: InputBase
    ): InputBaseAccessibilityState;
    /**
     * Returns the inner aria describedby ids for the accessibility. Hook for the subclasses.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    getAriaDescribedBy(
      /**
       * an object representation of the control.
       */
      oControl: InputBase
    ): string | undefined;
    /**
     * Returns the inner aria labelledby ids for the accessibility. Hook for the subclasses.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    getAriaLabelledBy(
      /**
       * an object representation of the control.
       */
      oControl: InputBase
    ): string | undefined;
    /**
     * Returns aria accessibility role for the control. Hook for the subclasses.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    getAriaRole(
      /**
       * an object representation of the control
       */
      oControl: InputBase
    ): string;
    /**
     * Returns the inner aria describedby announcement texts for the accessibility. Hook for the subclasses.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    getDescribedByAnnouncement(
      /**
       * an object representation of the control.
       */
      oControl: InputBase
    ): string;
    /**
     * Defines the ID suffix of the inner element
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The inner element ID suffix.
     */
    getInnerSuffix(): string;
    /**
     * Returns the inner aria labelledby announcement texts for the accessibility. Hook for the subclasses.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    getLabelledByAnnouncement(
      /**
       * an object representation of the control.
       */
      oControl: InputBase
    ): string;
    /**
     * Write the opening tag name of the input.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    openInputTag(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * This method is reserved for derived classes to prepend inner content.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    prependInnerContent(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * Renders the hidden aria labelledby node for the accessibility. Hook for the subclasses.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    renderAriaDescribedBy(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * Renders the hidden aria labelledby node for the accessibility. Hook for the subclasses.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    renderAriaLabelledBy(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * Renders the hidden aria describedby and errormessage nodes for the accessibility.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    renderValueStateAccDom(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * Writes the accessibility state of the control. Hook for the subclasses.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    writeAccessibilityState(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * Write the decorations of the input - description and value-help icon.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    writeDecorations(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * Renders icons from the icon aggregations.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    writeIcons(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * List of icons to render
       */
      aIcons: Icon[]
    ): void;
    /**
     * This method is reserved for derived classes to add extra attributes for the input element.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    writeInnerAttributes(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * Write the value of the input.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    writeInnerContent(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * Write the value of the input.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    writeInnerValue(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
    /**
     * This method is reserved for derived class to add extra attributes for input container.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    writeOuterAttributes(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: InputBase
    ): void;
  }
  const InputBaseRenderer: InputBaseRenderer;
  export default InputBaseRenderer;
}

declare module "sap/m/InputListItem" {
  import {
    default as ListItemBase,
    $ListItemBaseSettings,
  } from "sap/m/ListItemBase";

  import Control from "sap/ui/core/Control";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import { InputListItemContentSize } from "sap/m/library";

  import { TextDirection } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * List item should be used for a label and an input field.
   */
  export default class InputListItem extends ListItemBase {
    /**
     * Constructor for a new InputListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:/input-list-item/ Input List Item}
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $InputListItemSettings
    );
    /**
     * Constructor for a new InputListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:/input-list-item/ Input List Item}
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $InputListItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.InputListItem with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ListItemBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, InputListItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.InputListItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some content to the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContent(
      /**
       * The content to add; if empty, nothing is inserted
       */
      oContent: Control
    ): this;
    /**
     * Binds aggregation {@link #getContent content} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindContent(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * Content controls can be added
     */
    getContent(): Control[];
    /**
     * Gets current value of property {@link #getContentSize contentSize}.
     *
     * Determines how much space is allocated for the input control.
     *
     * Default value is `L`.
     *
     * @since 1.130
     *
     * @returns Value of property `contentSize`
     */
    getContentSize(): InputListItemContentSize;
    /**
     * Gets current value of property {@link #getLabel label}.
     *
     * Label of the list item
     *
     *
     * @returns Value of property `label`
     */
    getLabel(): string;
    /**
     * Gets current value of property {@link #getLabelTextDirection labelTextDirection}.
     *
     * This property specifies the label text directionality with enumerated options. By default, the label
     * inherits text direction from the DOM.
     *
     * Default value is `Inherit`.
     *
     * @since 1.30.0
     *
     * @returns Value of property `labelTextDirection`
     */
    getLabelTextDirection(): TextDirection;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContent content}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContent(
      /**
       * The content whose index is looked for
       */
      oContent: Control
    ): int;
    /**
     * Inserts a content into the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContent(
      /**
       * The content to insert; if empty, nothing is inserted
       */
      oContent: Control,
      /**
       * The `0`-based index the content should be inserted at; for a negative value of `iIndex`, the content
       * is inserted at position 0; for a value greater than the current size of the aggregation, the content
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getContent content}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContent(): Control[];
    /**
     * Removes a content from the aggregation {@link #getContent content}.
     *
     *
     * @returns The removed content or `null`
     */
    removeContent(
      /**
       * The content to remove or its index or id
       */
      vContent: int | string | Control
    ): Control | null;
    /**
     * Sets a new value for property {@link #getContentSize contentSize}.
     *
     * Determines how much space is allocated for the input control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `L`.
     *
     * @since 1.130
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContentSize(
      /**
       * New value for property `contentSize`
       */
      sContentSize?:
        | InputListItemContentSize
        | keyof typeof InputListItemContentSize
    ): this;
    /**
     * Sets a new value for property {@link #getLabel label}.
     *
     * Label of the list item
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLabel(
      /**
       * New value for property `label`
       */
      sLabel?: string
    ): this;
    /**
     * Sets a new value for property {@link #getLabelTextDirection labelTextDirection}.
     *
     * This property specifies the label text directionality with enumerated options. By default, the label
     * inherits text direction from the DOM.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLabelTextDirection(
      /**
       * New value for property `labelTextDirection`
       */
      sLabelTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Unbinds aggregation {@link #getContent content} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindContent(): this;
  }
  /**
   * Describes the settings that can be provided to the InputListItem constructor.
   */
  export interface $InputListItemSettings extends $ListItemBaseSettings {
    /**
     * Label of the list item
     */
    label?: string | PropertyBindingInfo;

    /**
     * This property specifies the label text directionality with enumerated options. By default, the label
     * inherits text direction from the DOM.
     *
     * @since 1.30.0
     */
    labelTextDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines how much space is allocated for the input control.
     *
     * @since 1.130
     */
    contentSize?:
      | (InputListItemContentSize | keyof typeof InputListItemContentSize)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Content controls can be added
     */
    content?: Control[] | Control | AggregationBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/InputRenderer" {
  import RenderManager from "sap/ui/core/RenderManager";

  import Input from "sap/m/Input";

  /**
   * Input renderer.
   *
   * InputRenderer extends the InputBaseRenderer
   *
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  interface InputRenderer {
    /**
     * Adds inner css classes to the input field
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    addInnerClasses(
      /**
       * the RenderManager that can be used for writing to the render output buffer
       */
      oRm: RenderManager,
      /**
       * an object representation of the control that should be rendered
       */
      oControl: Input
    ): void;
    /**
     * Adds control specific class
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    addOuterClasses(
      /**
       * the RenderManager that can be used for writing to the render output buffer
       */
      oRm: RenderManager,
      /**
       * an object representation of the control that should be rendered
       */
      oControl: Input
    ): void;
    /**
     * Adds extra styles to the wrapper of the input field.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    addWrapperStyles(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: Input
    ): void;
    /**
     * Returns the inner aria describedby ids for the accessibility.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    getAriaDescribedBy(
      /**
       * an object representation of the control.
       */
      oControl: Input
    ): string | undefined;
    /**
     * Returns aria accessibility role for the control. Hook for the subclasses.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    getAriaRole(
      /**
       * an object representation of the control
       */
      oControl: Input
    ): string;
    /**
     * Write the decorations of the input - description and value-help icon.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    writeDecorations(
      /**
       * The RenderManager that can be used for writing to the render output buffer.
       */
      oRm: RenderManager,
      /**
       * An object representation of the control that should be rendered.
       */
      oControl: Input
    ): void;
    /**
     * add extra attributes to Input
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    writeInnerAttributes(
      /**
       * the RenderManager that can be used for writing to the render output buffer
       */
      oRm: RenderManager,
      /**
       * an object representation of the control that should be rendered
       */
      oControl: Input
    ): void;
  }
  const InputRenderer: InputRenderer;
  export default InputRenderer;
}

declare module "sap/m/InstanceManager" {
  import Control from "sap/ui/core/Control";

  import LightBox from "sap/m/LightBox";

  /**
   * Provides methods to manage instances. This is specifically designed for managing the opened Popover,
   * Dialog, ActionSheet, and it's possible to close all of the opened Popover, Dialog, ActionSheet in history
   * handling.
   *
   * Example:
   * ```javascript
   *
   *   sap.ui.define([
   *      "sap/m/InstanceManager"
   *   ], function(InstanceManager) {
   *     ...
   *     InstanceManager.closeAllPopovers();
   *     ...
   *   });
   * ```
   *
   *
   * @since 1.9.2
   */
  interface InstanceManager {
    /**
     * Adds a control to predefined dialog category in instance manager.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Enable method chaining.
     */
    addDialogInstance(
      /**
       * Dialog to be added to instance manager. Dialog which doesn't inherit from sap.m.Dialog can also be added
       * as long as it has a close method.
       */
      oDialog: Control
    ): this;
    /**
     * Adds an instance to the given category. If the instance is already added to the same category, it won't
     * be added again.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Enable method chaining.
     */
    addInstance(
      /**
       * The category's id.
       */
      sCategoryId: string,
      /**
       * The instance that will be added to the given category.
       */
      oInstance: object
    ): this;
    /**
     * Adds a control to predefined lightbox category in instance manager.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Enable method chaining.
     */
    addLightBoxInstance(
      /**
       * LightBox to be added to instance manager.
       */
      oLightBox: LightBox
    ): this;
    /**
     * Adds a control to predefined popover category in instance manager.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Enable method chaining.
     */
    addPopoverInstance(
      /**
       * Popover to be added to instance manager. Custom popover which doesn't inherit from sap.m.Popover can
       * also be added as long as it has a close method.
       */
      oPopover: Control
    ): this;
    /**
     * Closes all of the open dialogs.
     *
     *
     * @returns Enable method chaining.
     */
    closeAllDialogs(fnCallback: Function): this;
    /**
     * Closes all open lightboxes.
     *
     *
     * @returns Enable method chaining.
     */
    closeAllLightBoxes(): this;
    /**
     * Closes all open popovers.
     *
     *
     * @returns Enable method chaining.
     */
    closeAllPopovers(): this;
    /**
     * Returns an array of managed instances in the given category.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Managed instances in the given category.
     */
    getInstancesByCategoryId(
      /**
       * The category's id.
       */
      sCategoryId: string
    ): object[];
    /**
     * Gets all of the open dialogs. If there's no dialog open, an empty array is returned.
     *
     *
     * @returns The open dialogs.
     */
    getOpenDialogs(): Control[];
    /**
     * Gets all of the open LightBoxes. If there's no LightBox open, an empty array is returned.
     *
     *
     * @returns The opened LightBoxes.
     */
    getOpenLightBoxes(): LightBox[];
    /**
     * Gets all of the open popovers. If there's no popover open, an empty array is returned.
     *
     *
     * @returns The open popovers.
     */
    getOpenPopovers(): Control[];
    /**
     * Returns true if there's at least one dialog managed in the predefined dialog category, otherwise it returns
     * false.
     *
     *
     * @returns Whether there's dialog(s) open.
     */
    hasOpenDialog(): boolean;
    /**
     * Returns true if there's at least one LightBox managed in the predefined lightbox category, otherwise
     * it returns false.
     *
     *
     * @returns Whether there's LightBox(es) is/are open.
     */
    hasOpenLightBox(): boolean;
    /**
     * Returns true if there's at least one popover managed in the predefined popover category, otherwise it
     * returns false.
     *
     *
     * @returns Whether there's popover(s) open.
     */
    hasOpenPopover(): boolean;
    /**
     * Returns if there's no managed instance in the given category.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether the category is empty.
     */
    isCategoryEmpty(
      /**
       * The category's id.
       */
      sCategoryId: string
    ): boolean;
    /**
     * Checks if the given dialog instance is managed under the dialog category. For dialog instances, managed
     * means the dialog is open.
     *
     * This function is specially provided for customized controls which doesn't have the possibility to check
     * whether it's open. If the given dialog is an instance of sap.m.Dialog, sap.m.ActionSheet, the isOpen()
     * method on the instance is preferred to be called than this function.
     *
     *
     * @returns Whether the given dialog is open.
     */
    isDialogOpen(
      /**
       * The dialog that is checked for the openness.
       */
      oDialog: Control
    ): boolean;
    /**
     * Checks if an instance is managed under the given category.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether the instance is managed in the given category.
     */
    isInstanceManaged(
      /**
       * The category that the instance is supposed to be in.
       */
      sCategoryId: string,
      /**
       * The instance that needs to be checked.
       */
      oInstance: object
    ): boolean;
    /**
     * Check if the given LightBox instance is managed under the LightBox category. For LightBox instances,
     * 'managed' means the LightBox is open.
     *
     * This function is specially intended for controls that don't provide a way to check whether they're open.
     * If the given lightbox is an instance of `sap.m.LightBox`, its `isOpen()` should be called instead of
     * this function.
     *
     *
     * @returns Whether the given popover is open.
     */
    isLightBoxOpen(
      /**
       * The LightBox that is checked.
       */
      oLightBox: LightBox
    ): boolean;
    /**
     * Check if the given popover instance is managed under the popover category. For popover instances, managed
     * means the popover is open.
     *
     * This function is specially provided for customized controls which doesn't have the possibility to check
     * whether it's open. If the given popover is an instance of sap.m.Popover, sap.m.ActionSheet, the isOpen()
     * method on the instance is preferred to be called than this function.
     *
     *
     * @returns Whether the given popover is open.
     */
    isPopoverOpen(
      /**
       * The popover that is checked for the openness.
       */
      oPopover: Control
    ): boolean;
    /**
     * Removes control from predefined dialog category in instance manager.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The removed dialog, or `null` if the dialog isn't managed.
     */
    removeDialogInstance(
      /**
       * to be removed from instance manager.
       */
      oDialog: Control
    ): Control | null;
    /**
     * Removes a managed instance from the given category.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The removed instance, or `null` if the instance isn't managed.
     */
    removeInstance(
      /**
       * The category's id.
       */
      sCategoryId: string,
      /**
       * The instance that will be removed from the given category.
       */
      oInstance: object
    ): object | null;
    /**
     * Removes control from predefined lightbox category in instance manager.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The removed LightBox, or `null` if the LightBox isn't managed.
     */
    removeLightBoxInstance(
      /**
       * to be removed from instance manager.
       */
      oLightBox: LightBox
    ): LightBox | null;
    /**
     * Removes control from predefined popover category in instance manager.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The removed popover, or `null` if the popover isn't managed.
     */
    removePopoverInstance(
      /**
       * to be removed from instance manager.
       */
      oPopover: Control
    ): Control | null;
  }
  const InstanceManager: InstanceManager;
  export default InstanceManager;
}

declare module "sap/m/Label" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    Label as Label1,
    IShrinkable,
    IAccessKeySupport,
    ILabelable,
    AccessibilityInfo,
    ID,
    TextAlign,
    TextDirection,
    VerticalAlign,
    CSSSize,
  } from "sap/ui/core/library";

  import {
    IOverflowToolbarContent,
    IToolbarInteractiveControl,
    LabelDesign,
    OverflowToolbarConfig,
    WrappingType,
  } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Provides a textual label for other controls.
   *
   * Overview: Labels are used as titles for single controls or groups of controls. Labels for required fields
   * are marked with an asterisk.
   *
   * Label appearance can be influenced by properties, such as `textAlign`, `design`, `displayOnly`, `wrapping`
   * and `wrappingType`.
   *
   * As of version 1.50, the default value of the `wrapping` property is set to `false`.
   *
   * As of version 1.60, you can hyphenate the label's text with the use of the `wrappingType` property. For
   * more information, see {@link https://ui5.sap.com/#/topic/6322164936f047de941ec522b95d7b70 Text Controls Hyphenation}.
   *
   * Usage: When to use:
   * 	 - It's recommended to use the `Label` in Form controls.
   * 	 - Use title case for labels.  When not to use:
   * 	 -  It is not recommended to use labels in Bold.
   */
  export default class Label
    extends Control
    implements
      Label1,
      IShrinkable,
      IAccessKeySupport,
      ILabelable,
      IOverflowToolbarContent,
      IToolbarInteractiveControl
  {
    __implements__sap_ui_core_Label: boolean;
    __implements__sap_ui_core_IShrinkable: boolean;
    __implements__sap_ui_core_IAccessKeySupport: boolean;
    __implements__sap_ui_core_ILabelable: boolean;
    __implements__sap_m_IOverflowToolbarContent: boolean;
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new Label.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/label/ Label}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $LabelSettings
    );
    /**
     * Constructor for a new Label.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/label/ Label}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $LabelSettings
    );

    /**
     * Creates a new subclass of class sap.m.Label with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Label>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Label.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Provides the current accessibility state of the control.
     * See:
     * 	{@link sap.ui.core.Control#getAccessibilityInfo}.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns AccessibilityInfo of the `sap.m.Label`
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Gets current value of property {@link #getDesign design}.
     *
     * Sets the design of a Label to either Standard or Bold.
     *
     * Default value is `Standard`.
     *
     *
     * @returns Value of property `design`
     */
    getDesign(): LabelDesign;
    /**
     * Gets current value of property {@link #getDisplayOnly displayOnly}.
     *
     * Determines if the label is in displayOnly mode.
     *
     * **Note:** This property should be used only in Form controls in preview mode.
     *
     * Default value is `false`.
     *
     * @since 1.50.0
     *
     * @returns Value of property `displayOnly`
     */
    getDisplayOnly(): boolean;
    /**
     * ID of the element which is the current target of the association {@link #getLabelFor labelFor}, or `null`.
     */
    getLabelFor(): ID | null;
    /**
     * Enables the `sap.m.Label` to move inside the sap.m.OverflowToolbar. Required by the {@link sap.m.IOverflowToolbarContent }
     * interface.
     *
     *
     * @returns Configuration information for the `sap.m.IOverflowToolbarContent` interface.
     */
    getOverflowToolbarConfig(): OverflowToolbarConfig;
    /**
     * Gets current value of property {@link #getRequired required}.
     *
     * Indicates that user input is required for input control labeled by the sap.m.Label. When the property
     * is set to true and associated input field is empty an asterisk character is added to the label text.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `required`
     */
    getRequired(): boolean;
    /**
     * Gets current value of property {@link #getShowColon showColon}.
     *
     * Defines whether a colon (:) character is added to the label.
     *
     * **Note:** By default when the `Label` is in the `sap.ui.layout.form.Form` and `sap.ui.layout.form.SimpleForm`
     * controls the colon (:) character is displayed automatically regardless of the value of the `showColon`
     * property.
     *
     * Default value is `false`.
     *
     * @since 1.98
     *
     * @returns Value of property `showColon`
     */
    getShowColon(): boolean;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Determines the Label text to be displayed.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getTextAlign textAlign}.
     *
     * Available alignment settings are "Begin", "Center", "End", "Left", and "Right".
     *
     * Default value is `Begin`.
     *
     *
     * @returns Value of property `textAlign`
     */
    getTextAlign(): TextAlign;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * Options for the text direction are RTL and LTR. Alternatively, the control can inherit the text direction
     * from its parent container.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getVAlign vAlign}.
     *
     * Specifies the vertical alignment of the `Label` related to the tallest and lowest element on the line.
     *
     * Default value is `Inherit`.
     *
     * @since 1.54
     *
     * @returns Value of property `vAlign`
     */
    getVAlign(): VerticalAlign;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Determines the width of the label.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getWrapping wrapping}.
     *
     * Determines the wrapping of the text within the `Label`. When set to `false` (default), the label text
     * will be truncated and and an ellipsis will be added at the end. If set to `true`, the label text will
     * wrap.
     *
     * Default value is `false`.
     *
     * @since 1.50
     *
     * @returns Value of property `wrapping`
     */
    getWrapping(): boolean;
    /**
     * Gets current value of property {@link #getWrappingType wrappingType}.
     *
     * Defines the type of text wrapping to be used (hyphenated or normal).
     *
     * **Note:** This property takes effect only when the `wrapping` property is set to `true`.
     *
     * Default value is `Normal`.
     *
     * @since 1.60
     *
     * @returns Value of property `wrappingType`
     */
    getWrappingType(): WrappingType;
    /**
     * Returns if the control can be bound to a label
     *
     *
     * @returns `true` if the control can be bound to a label
     */
    hasLabelableHTMLElement(): boolean;
    /**
     * Sets a new value for property {@link #getDesign design}.
     *
     * Sets the design of a Label to either Standard or Bold.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Standard`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDesign(
      /**
       * New value for property `design`
       */
      sDesign?: LabelDesign | keyof typeof LabelDesign
    ): this;
    /**
     * Sets a new value for property {@link #getDisplayOnly displayOnly}.
     *
     * Determines if the label is in displayOnly mode.
     *
     * **Note:** This property should be used only in Form controls in preview mode.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.50.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisplayOnly(
      /**
       * New value for property `displayOnly`
       */
      bDisplayOnly?: boolean
    ): this;
    /**
     * Sets the associated {@link #getLabelFor labelFor}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLabelFor(
      /**
       * ID of an element which becomes the new target of this labelFor association; alternatively, an element
       * instance may be given
       */
      oLabelFor: ID | Control
    ): this;
    /**
     * Sets a new value for property {@link #getRequired required}.
     *
     * Indicates that user input is required for input control labeled by the sap.m.Label. When the property
     * is set to true and associated input field is empty an asterisk character is added to the label text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRequired(
      /**
       * New value for property `required`
       */
      bRequired?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowColon showColon}.
     *
     * Defines whether a colon (:) character is added to the label.
     *
     * **Note:** By default when the `Label` is in the `sap.ui.layout.form.Form` and `sap.ui.layout.form.SimpleForm`
     * controls the colon (:) character is displayed automatically regardless of the value of the `showColon`
     * property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.98
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowColon(
      /**
       * New value for property `showColon`
       */
      bShowColon?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Determines the Label text to be displayed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTextAlign textAlign}.
     *
     * Available alignment settings are "Begin", "Center", "End", "Left", and "Right".
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Begin`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextAlign(
      /**
       * New value for property `textAlign`
       */
      sTextAlign?: TextAlign | keyof typeof TextAlign
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * Options for the text direction are RTL and LTR. Alternatively, the control can inherit the text direction
     * from its parent container.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getVAlign vAlign}.
     *
     * Specifies the vertical alignment of the `Label` related to the tallest and lowest element on the line.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVAlign(
      /**
       * New value for property `vAlign`
       */
      sVAlign?: VerticalAlign | keyof typeof VerticalAlign
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Determines the width of the label.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getWrapping wrapping}.
     *
     * Determines the wrapping of the text within the `Label`. When set to `false` (default), the label text
     * will be truncated and and an ellipsis will be added at the end. If set to `true`, the label text will
     * wrap.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.50
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWrapping(
      /**
       * New value for property `wrapping`
       */
      bWrapping?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getWrappingType wrappingType}.
     *
     * Defines the type of text wrapping to be used (hyphenated or normal).
     *
     * **Note:** This property takes effect only when the `wrapping` property is set to `true`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Normal`.
     *
     * @since 1.60
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWrappingType(
      /**
       * New value for property `wrappingType`
       */
      sWrappingType?: WrappingType | keyof typeof WrappingType
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Label constructor.
   */
  export interface $LabelSettings extends $ControlSettings {
    /**
     * Sets the design of a Label to either Standard or Bold.
     */
    design?:
      | (LabelDesign | keyof typeof LabelDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the Label text to be displayed.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Available alignment settings are "Begin", "Center", "End", "Left", and "Right".
     */
    textAlign?:
      | (TextAlign | keyof typeof TextAlign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Options for the text direction are RTL and LTR. Alternatively, the control can inherit the text direction
     * from its parent container.
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the width of the label.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates that user input is required for input control labeled by the sap.m.Label. When the property
     * is set to true and associated input field is empty an asterisk character is added to the label text.
     */
    required?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines if the label is in displayOnly mode.
     *
     * **Note:** This property should be used only in Form controls in preview mode.
     *
     * @since 1.50.0
     */
    displayOnly?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the wrapping of the text within the `Label`. When set to `false` (default), the label text
     * will be truncated and and an ellipsis will be added at the end. If set to `true`, the label text will
     * wrap.
     *
     * @since 1.50
     */
    wrapping?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the type of text wrapping to be used (hyphenated or normal).
     *
     * **Note:** This property takes effect only when the `wrapping` property is set to `true`.
     *
     * @since 1.60
     */
    wrappingType?:
      | (WrappingType | keyof typeof WrappingType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies the vertical alignment of the `Label` related to the tallest and lowest element on the line.
     *
     * @since 1.54
     */
    vAlign?:
      | (VerticalAlign | keyof typeof VerticalAlign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines whether a colon (:) character is added to the label.
     *
     * **Note:** By default when the `Label` is in the `sap.ui.layout.form.Form` and `sap.ui.layout.form.SimpleForm`
     * controls the colon (:) character is displayed automatically regardless of the value of the `showColon`
     * property.
     *
     * @since 1.98
     */
    showColon?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Association to the labelled control. By default, the label sets the for attribute to the ID of the labelled
     * control. This can be changed by implementing the function getIdForLabel on the labelled control.
     */
    labelFor?: Control | string;
  }
}

declare module "sap/m/LightBox" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { PopupInterface } from "sap/ui/core/library";

  import LightBoxItem from "sap/m/LightBoxItem";

  import {
    AggregationBindingInfo,
    default as ManagedObject,
  } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * Represents a popup containing an image and a footer.
   *
   * Overview:
   *
   * The purpose of the control is to display an image in its original size as long as this is possible. On
   * smaller screens images are scaled down to fit.
   *
   * **Notes:**
   * 	 - If the image doesn't load in 10 seconds, an error is displayed.
   * 	 - Setting the `imageContent` aggregation of the control as well as the source of the image and the
   *     title of the image is mandatory. If the image source is not set, the control will not open.
   *     Structure:
   *
   * Each LightBox holds a {@link sap.m.LightBoxItem LightBoxItem} which keeps the properties of the image:
   *
   * 	 -  imageSrc - The source URI of the image
   * 	 -  title - The title of the image
   * 	 -  subtitle - The subtitle of the image
   * 	 -  alt - The alt text of the image   Usage:
   *
   * The most common use case is to click on an image thumbnail to view it in bigger size. When the image
   * that should be displayed in the control cannot be loaded, an error is displayed in the popup.
   *
   * Responsive Behavior:
   *
   * On a mobile device, flipping the device to landscape will flip the lightbox and the image will be adjusted
   * to fit the new dimensions.
   *
   * Additional Information:
   *
   * Check out the {@link sap.m.LightBoxItem API Reference}.
   */
  export default class LightBox extends Control implements PopupInterface {
    __implements__sap_ui_core_PopupInterface: boolean;
    /**
     * Constructor for a new LightBox.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/lightbox/ Light Box}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $LightBoxSettings
    );
    /**
     * Constructor for a new LightBox.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/lightbox/ Light Box}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $LightBoxSettings
    );

    /**
     * Creates a new subclass of class sap.m.LightBox with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, LightBox>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.LightBox.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some imageContent to the aggregation {@link #getImageContent imageContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addImageContent(
      /**
       * The imageContent to add; if empty, nothing is inserted
       */
      oImageContent: LightBoxItem
    ): this;
    /**
     * Binds aggregation {@link #getImageContent imageContent} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindImageContent(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Closes the LightBox.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    close(): this;
    /**
     * Destroys all the imageContent in the aggregation {@link #getImageContent imageContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyImageContent(): this;
    /**
     * Detaches all handlers and destroys the instance.
     */
    exit(): void;
    /**
     * Gets content of aggregation {@link #getImageContent imageContent}.
     *
     * Aggregation which holds data about the image and its description. Although multiple LightBoxItems may
     * be added to this aggregation only the first one in the list will be taken into account.
     */
    getImageContent(): LightBoxItem[];
    /**
     * Checks for the provided `sap.m.LightBoxItem` in the aggregation {@link #getImageContent imageContent}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfImageContent(
      /**
       * The imageContent whose index is looked for
       */
      oImageContent: LightBoxItem
    ): int;
    /**
     * Sets up the initial values of the control.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    init(): void;
    /**
     * Inserts a imageContent into the aggregation {@link #getImageContent imageContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertImageContent(
      /**
       * The imageContent to insert; if empty, nothing is inserted
       */
      oImageContent: LightBoxItem,
      /**
       * The `0`-based index the imageContent should be inserted at; for a negative value of `iIndex`, the imageContent
       * is inserted at position 0; for a value greater than the current size of the aggregation, the imageContent
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Invalidates the LightBox.
     *
     *
     * @returns this LightBox reference for chaining.
     */
    invalidate(
      /**
       * Origin of the invalidation.
       */
      oOrigin: ManagedObject
    ): this;
    /**
     * Returns if the LightBox is open.
     *
     *
     * @returns Is the LightBox open
     */
    isOpen(): boolean;
    /**
     * Overwrites the onAfterRendering.
     */
    onAfterRendering(): void;
    /**
     * Overwrites the onBeforeRendering.
     */
    onBeforeRendering(): void;
    /**
     * Opens the LightBox.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    open(): this;
    /**
     * Removes all the controls from the aggregation {@link #getImageContent imageContent}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllImageContent(): LightBoxItem[];
    /**
     * Removes a imageContent from the aggregation {@link #getImageContent imageContent}.
     *
     *
     * @returns The removed imageContent or `null`
     */
    removeImageContent(
      /**
       * The imageContent to remove or its index or id
       */
      vImageContent: int | string | LightBoxItem
    ): LightBoxItem | null;
    /**
     * Unbinds aggregation {@link #getImageContent imageContent} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindImageContent(): this;
  }
  /**
   * Describes the settings that can be provided to the LightBox constructor.
   */
  export interface $LightBoxSettings extends $ControlSettings {
    /**
     * Aggregation which holds data about the image and its description. Although multiple LightBoxItems may
     * be added to this aggregation only the first one in the list will be taken into account.
     */
    imageContent?:
      | LightBoxItem[]
      | LightBoxItem
      | AggregationBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/LightBoxItem" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import { URI } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Represents an item which is displayed within an sap.m.LightBox. This item holds all properties of the
   * image as well as the title and subtitle.
   *
   * @since 1.42
   */
  export default class LightBoxItem extends UI5Element {
    /**
     * Constructor for a new LightBoxItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $LightBoxItemSettings
    );
    /**
     * Constructor for a new LightBoxItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $LightBoxItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.LightBoxItem with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, LightBoxItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.LightBoxItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getAlt alt}.
     *
     * Alt value for the image.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `alt`
     */
    getAlt(): string;
    /**
     * Gets current value of property {@link #getImageSrc imageSrc}.
     *
     * Source for the image. This property is mandatory. If not set the popup will not open.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `imageSrc`
     */
    getImageSrc(): URI;
    /**
     * Gets current value of property {@link #getSubtitle subtitle}.
     *
     * Subtitle text for the image.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `subtitle`
     */
    getSubtitle(): string;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Title text for the image. This property is mandatory.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Sets the alt text of the image.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    setAlt(
      /**
       * The alt text
       */
      alt: string
    ): this;
    /**
     * Sets the source of the image.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    setImageSrc(
      /**
       * The image URI
       */
      sImageSrc: URI
    ): this;
    /**
     * Sets the subtitle of the image.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    setSubtitle(
      /**
       * The image subtitle
       */
      sSubtitleText: string
    ): this;
    /**
     * Sets the title of the image.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    setTitle(
      /**
       * The image title
       */
      title: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the LightBoxItem constructor.
   */
  export interface $LightBoxItemSettings extends $ElementSettings {
    /**
     * Source for the image. This property is mandatory. If not set the popup will not open.
     */
    imageSrc?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Alt value for the image.
     */
    alt?: string | PropertyBindingInfo;

    /**
     * Title text for the image. This property is mandatory.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Subtitle text for the image.
     */
    subtitle?: string | PropertyBindingInfo;
  }
}

declare module "sap/m/Link" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IShrinkable,
    IFormContent,
    ISemanticFormContent,
    ITitleContent,
    IAccessKeySupport,
    ILabelable,
    ID,
    AccessibilityInfo,
    aria,
    URI,
    TextAlign,
    TextDirection,
    CSSSize,
  } from "sap/ui/core/library";

  import {
    IToolbarInteractiveControl,
    LinkAccessibleRole,
    EmptyIndicatorMode,
    ReactiveAreaMode,
  } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * A hyperlink control used to navigate to other apps and web pages or to trigger actions.
   *
   * Overview:
   *
   * The `Link` control is a clickable text element visualized in such a way that it stands out from the standard
   * text. On hover, it changes its style to underlined text to provide additional feedback to the user.
   *
   * Usage:
   *
   * You can set the `Link` to be enabled or disabled.
   *
   * To create a visual hierarchy in large lists of links, you can set the less important links as `subtle`
   * or the more important ones as `emphasized`.
   *
   * To specify where the linked content is opened, you can use the `target` property.
   *
   * Responsive behavior:
   *
   * If there is not enough space, the text of the `Link` becomes truncated. If the `wrapping` property is
   * set to `true`, the text will be displayed on several lines, instead of being truncated.
   *
   * @since 1.12
   */
  export default class Link
    extends Control
    implements
      IShrinkable,
      IFormContent,
      ISemanticFormContent,
      ITitleContent,
      IAccessKeySupport,
      ILabelable,
      IToolbarInteractiveControl
  {
    __implements__sap_ui_core_IShrinkable: boolean;
    __implements__sap_ui_core_IFormContent: boolean;
    __implements__sap_ui_core_ISemanticFormContent: boolean;
    __implements__sap_ui_core_ITitleContent: boolean;
    __implements__sap_ui_core_IAccessKeySupport: boolean;
    __implements__sap_ui_core_ILabelable: boolean;
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new `Link`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/link/ Link}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $LinkSettings
    );
    /**
     * Constructor for a new `Link`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/link/ Link}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $LinkSettings
    );

    /**
     * Creates a new subclass of class sap.m.Link with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Link>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Link.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.Link`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Link` itself.
     *
     * Event is fired when the user triggers the link control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Link$PressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Link` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.Link`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Link` itself.
     *
     * Event is fired when the user triggers the link control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Link$PressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Link` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.Link`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Link$PressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Link$PressEventParameters
    ): boolean;
    /**
     * Returns the `sap.m.Link` accessibility information.
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The `sap.m.Link` accessibility information
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Gets current value of property {@link #getAccessibleRole accessibleRole}.
     *
     * Describes the accessibility role of the link:
     * 	 - `LinkAccessibleRole.Default` - a navigation is expected to the location given in `href` property
     *
     * 	 - `LinkAccessibleRole.Button` - there will be `role` attribute with value "Button" rendered. In this
     *     scenario the `href` property value shouldn't be set as navigation isn't expected to occur.
     *
     * Default value is `Default`.
     *
     * @since 1.104.0
     *
     * @returns Value of property `accessibleRole`
     */
    getAccessibleRole(): LinkAccessibleRole;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Gets current value of property {@link #getAriaHasPopup ariaHasPopup}.
     *
     * Specifies the value of the `aria-haspopup` attribute
     *
     * If the value is `None`, the attribute will not be rendered. Otherwise it will be rendered according to
     * the selected value.
     *
     * NOTE: Use this property only when a link is related to a popover/popup. The value needs to be equal to
     * the main/root role of the popup - e.g. dialog, menu or list (examples: if you have dialog -> dialog,
     * if you have menu -> menu; if you have list -> list; if you have dialog containing a list -> dialog).
     * Do not use it, if you open a standard sap.m.Dialog, MessageBox or other type of dialogs displayed as
     * on overlay over the application.
     *
     * Default value is `None`.
     *
     * @since 1.86.0
     *
     * @returns Value of property `ariaHasPopup`
     */
    getAriaHasPopup(): aria.HasPopup;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getEmphasized emphasized}.
     *
     * Emphasized links look visually more important than regular links.
     *
     * Default value is `false`.
     *
     * @since 1.22
     *
     * @returns Value of property `emphasized`
     */
    getEmphasized(): boolean;
    /**
     * Gets current value of property {@link #getEmptyIndicatorMode emptyIndicatorMode}.
     *
     * Specifies if an empty indicator should be displayed when there is no text.
     *
     * Default value is `Off`.
     *
     * @since 1.89
     *
     * @returns Value of property `emptyIndicatorMode`
     */
    getEmptyIndicatorMode(): EmptyIndicatorMode;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Determines whether the link can be triggered by the user.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets current value of property {@link #getEndIcon endIcon}.
     *
     * Defines the icon to be displayed as graphical element in the end of the `Link`. It can be an icon from
     * the icon font. **Note:** Usage of icon-only link is not supported, the link must always have a text.
     * **Note:** We recommend using аn icon in the beginning or the end only, and always with text. **Note:**
     * Using an image instead of icon is not supported.
     *
     * Default value is `empty string`.
     *
     * @since 1.128.0
     *
     * @returns Value of property `endIcon`
     */
    getEndIcon(): URI;
    /**
     * Gets current value of property {@link #getHref href}.
     *
     * Defines the link target URI. Supports standard hyperlink behavior. **Note:** Don't set `href` property
     * if an action should be triggered by the link. Instead set `accessibleRole` property to `LinkAccessibleRole.Button`
     * and register a `press` event handler.
     *
     *
     * @returns Value of property `href`
     */
    getHref(): URI;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Defines the icon to be displayed as graphical element in the beginning of the `Link`. It can be an icon
     * from the icon font. **Note:** Usage of icon-only link is not supported, the link must always have a text.
     * **Note:** We recommend using аn icon in the beginning or the end only, and always with text. **Note:**
     * Using an image instead of icon is not supported.
     *
     * Default value is `empty string`.
     *
     * @since 1.128.0
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getReactiveAreaMode reactiveAreaMode}.
     *
     * Defines the size of the reactive area of the link:
     * 	 - `ReactiveAreaMode.Inline` - The link is displayed as part of a sentence.
     * 	 - `ReactiveAreaMode.Overlay` - The link is displayed as an overlay on top of other interactive parts
     *     of the page.
     *
     * **Note:**It is designed to make links easier to activate and helps meet the WCAG 2.2 Target Size requirement.
     * It is applicable only for the SAP Horizon themes. **Note:**The Reactive area size is sufficiently large
     * to help users avoid accidentally selecting (clicking or tapping) on unintented UI elements. UI elements
     * positioned over other parts of the page may need an invisible active touch area. This will ensure that
     * no elements beneath are activated accidentally when the user tries to interact with the overlay element.
     *
     * Default value is `Inline`.
     *
     * @since 1.133.0
     *
     * @returns Value of property `reactiveAreaMode`
     */
    getReactiveAreaMode(): ReactiveAreaMode;
    /**
     * Gets current value of property {@link #getRel rel}.
     *
     * Specifies the value of the HTML `rel` attribute.
     *
     * **Note:** A default value of `noopener noreferrer` is set only to links that have a cross-origin URL
     * and a specified `target` with value other than `_self`.
     *
     * @since 1.84
     *
     * @returns Value of property `rel`
     */
    getRel(): string;
    /**
     * Gets current value of property {@link #getSubtle subtle}.
     *
     * Subtle links look more like standard text than like links. They should only be used to help with visual
     * hierarchy between large data lists of important and less important links. Subtle links should not be
     * used in any other use case.
     *
     * Default value is `false`.
     *
     * @since 1.22
     *
     * @returns Value of property `subtle`
     */
    getSubtle(): boolean;
    /**
     * Gets current value of property {@link #getTarget target}.
     *
     * Specifies a target where the linked content will open.
     *
     * Options are the standard values for window.open() supported by browsers: `_self`, `_top`, `_blank`, `_parent`,
     * `_search`. Alternatively, a frame name can be entered. This property is only used when the `href` property
     * is set.
     *
     *
     * @returns Value of property `target`
     */
    getTarget(): string;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Defines the displayed link text.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getTextAlign textAlign}.
     *
     * Determines the horizontal alignment of the text.
     *
     * Default value is `Initial`.
     *
     * @since 1.28.0
     *
     * @returns Value of property `textAlign`
     */
    getTextAlign(): TextAlign;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * This property specifies the element's text directionality with enumerated options. By default, the control
     * inherits text direction from the parent DOM.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getValidateUrl validateUrl}.
     *
     * Defines whether the link target URI should be validated.
     *
     * If validation fails, the value of the `href` property will still be set, but will not be applied to the
     * DOM.
     *
     * **Note:** Additional URLs are allowed through {@link module:sap/base/security/URLListValidator URLListValidator}.
     *
     * Default value is `false`.
     *
     * @since 1.54.0
     *
     * @returns Value of property `validateUrl`
     */
    getValidateUrl(): boolean;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Determines the width of the link (CSS-size such as % or px). When it is set, this is the exact size.
     * When left blank, the text defines the size.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getWrapping wrapping}.
     *
     * Determines whether the link text is allowed to wrap when there is no sufficient space.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `wrapping`
     */
    getWrapping(): boolean;
    /**
     * Returns if the control can be bound to a label
     *
     *
     * @returns `true` if the control can be bound to a label
     */
    hasLabelableHTMLElement(): boolean;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getAccessibleRole accessibleRole}.
     *
     * Describes the accessibility role of the link:
     * 	 - `LinkAccessibleRole.Default` - a navigation is expected to the location given in `href` property
     *
     * 	 - `LinkAccessibleRole.Button` - there will be `role` attribute with value "Button" rendered. In this
     *     scenario the `href` property value shouldn't be set as navigation isn't expected to occur.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Default`.
     *
     * @since 1.104.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAccessibleRole(
      /**
       * New value for property `accessibleRole`
       */
      sAccessibleRole?: LinkAccessibleRole | keyof typeof LinkAccessibleRole
    ): this;
    /**
     * Sets a new value for property {@link #getAriaHasPopup ariaHasPopup}.
     *
     * Specifies the value of the `aria-haspopup` attribute
     *
     * If the value is `None`, the attribute will not be rendered. Otherwise it will be rendered according to
     * the selected value.
     *
     * NOTE: Use this property only when a link is related to a popover/popup. The value needs to be equal to
     * the main/root role of the popup - e.g. dialog, menu or list (examples: if you have dialog -> dialog,
     * if you have menu -> menu; if you have list -> list; if you have dialog containing a list -> dialog).
     * Do not use it, if you open a standard sap.m.Dialog, MessageBox or other type of dialogs displayed as
     * on overlay over the application.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     * @since 1.86.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAriaHasPopup(
      /**
       * New value for property `ariaHasPopup`
       */
      sAriaHasPopup?: aria.HasPopup | keyof typeof aria.HasPopup
    ): this;
    /**
     * Sets a new value for property {@link #getEmphasized emphasized}.
     *
     * Emphasized links look visually more important than regular links.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.22
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEmphasized(
      /**
       * New value for property `emphasized`
       */
      bEmphasized?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEmptyIndicatorMode emptyIndicatorMode}.
     *
     * Specifies if an empty indicator should be displayed when there is no text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Off`.
     *
     * @since 1.89
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEmptyIndicatorMode(
      /**
       * New value for property `emptyIndicatorMode`
       */
      sEmptyIndicatorMode?: EmptyIndicatorMode | keyof typeof EmptyIndicatorMode
    ): this;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Determines whether the link can be triggered by the user.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEndIcon endIcon}.
     *
     * Defines the icon to be displayed as graphical element in the end of the `Link`. It can be an icon from
     * the icon font. **Note:** Usage of icon-only link is not supported, the link must always have a text.
     * **Note:** We recommend using аn icon in the beginning or the end only, and always with text. **Note:**
     * Using an image instead of icon is not supported.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.128.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEndIcon(
      /**
       * New value for property `endIcon`
       */
      sEndIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getHref href}.
     *
     * Defines the link target URI. Supports standard hyperlink behavior. **Note:** Don't set `href` property
     * if an action should be triggered by the link. Instead set `accessibleRole` property to `LinkAccessibleRole.Button`
     * and register a `press` event handler.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHref(
      /**
       * New value for property `href`
       */
      sHref?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Defines the icon to be displayed as graphical element in the beginning of the `Link`. It can be an icon
     * from the icon font. **Note:** Usage of icon-only link is not supported, the link must always have a text.
     * **Note:** We recommend using аn icon in the beginning or the end only, and always with text. **Note:**
     * Using an image instead of icon is not supported.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.128.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getReactiveAreaMode reactiveAreaMode}.
     *
     * Defines the size of the reactive area of the link:
     * 	 - `ReactiveAreaMode.Inline` - The link is displayed as part of a sentence.
     * 	 - `ReactiveAreaMode.Overlay` - The link is displayed as an overlay on top of other interactive parts
     *     of the page.
     *
     * **Note:**It is designed to make links easier to activate and helps meet the WCAG 2.2 Target Size requirement.
     * It is applicable only for the SAP Horizon themes. **Note:**The Reactive area size is sufficiently large
     * to help users avoid accidentally selecting (clicking or tapping) on unintented UI elements. UI elements
     * positioned over other parts of the page may need an invisible active touch area. This will ensure that
     * no elements beneath are activated accidentally when the user tries to interact with the overlay element.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inline`.
     *
     * @since 1.133.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setReactiveAreaMode(
      /**
       * New value for property `reactiveAreaMode`
       */
      sReactiveAreaMode?: ReactiveAreaMode | keyof typeof ReactiveAreaMode
    ): this;
    /**
     * Sets a new value for property {@link #getRel rel}.
     *
     * Specifies the value of the HTML `rel` attribute.
     *
     * **Note:** A default value of `noopener noreferrer` is set only to links that have a cross-origin URL
     * and a specified `target` with value other than `_self`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.84
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRel(
      /**
       * New value for property `rel`
       */
      sRel?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSubtle subtle}.
     *
     * Subtle links look more like standard text than like links. They should only be used to help with visual
     * hierarchy between large data lists of important and less important links. Subtle links should not be
     * used in any other use case.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.22
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSubtle(
      /**
       * New value for property `subtle`
       */
      bSubtle?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getTarget target}.
     *
     * Specifies a target where the linked content will open.
     *
     * Options are the standard values for window.open() supported by browsers: `_self`, `_top`, `_blank`, `_parent`,
     * `_search`. Alternatively, a frame name can be entered. This property is only used when the `href` property
     * is set.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTarget(
      /**
       * New value for property `target`
       */
      sTarget?: string
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Defines the displayed link text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTextAlign textAlign}.
     *
     * Determines the horizontal alignment of the text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Initial`.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextAlign(
      /**
       * New value for property `textAlign`
       */
      sTextAlign?: TextAlign | keyof typeof TextAlign
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * This property specifies the element's text directionality with enumerated options. By default, the control
     * inherits text direction from the parent DOM.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getValidateUrl validateUrl}.
     *
     * Defines whether the link target URI should be validated.
     *
     * If validation fails, the value of the `href` property will still be set, but will not be applied to the
     * DOM.
     *
     * **Note:** Additional URLs are allowed through {@link module:sap/base/security/URLListValidator URLListValidator}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.54.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValidateUrl(
      /**
       * New value for property `validateUrl`
       */
      bValidateUrl?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Determines the width of the link (CSS-size such as % or px). When it is set, this is the exact size.
     * When left blank, the text defines the size.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getWrapping wrapping}.
     *
     * Determines whether the link text is allowed to wrap when there is no sufficient space.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWrapping(
      /**
       * New value for property `wrapping`
       */
      bWrapping?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Link constructor.
   */
  export interface $LinkSettings extends $ControlSettings {
    /**
     * Defines the displayed link text.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Defines the icon to be displayed as graphical element in the beginning of the `Link`. It can be an icon
     * from the icon font. **Note:** Usage of icon-only link is not supported, the link must always have a text.
     * **Note:** We recommend using аn icon in the beginning or the end only, and always with text. **Note:**
     * Using an image instead of icon is not supported.
     *
     * @since 1.128.0
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the icon to be displayed as graphical element in the end of the `Link`. It can be an icon from
     * the icon font. **Note:** Usage of icon-only link is not supported, the link must always have a text.
     * **Note:** We recommend using аn icon in the beginning or the end only, and always with text. **Note:**
     * Using an image instead of icon is not supported.
     *
     * @since 1.128.0
     */
    endIcon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the link can be triggered by the user.
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies a target where the linked content will open.
     *
     * Options are the standard values for window.open() supported by browsers: `_self`, `_top`, `_blank`, `_parent`,
     * `_search`. Alternatively, a frame name can be entered. This property is only used when the `href` property
     * is set.
     */
    target?: string | PropertyBindingInfo;

    /**
     * Specifies the value of the HTML `rel` attribute.
     *
     * **Note:** A default value of `noopener noreferrer` is set only to links that have a cross-origin URL
     * and a specified `target` with value other than `_self`.
     *
     * @since 1.84
     */
    rel?: string | PropertyBindingInfo;

    /**
     * Determines the width of the link (CSS-size such as % or px). When it is set, this is the exact size.
     * When left blank, the text defines the size.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the link target URI. Supports standard hyperlink behavior. **Note:** Don't set `href` property
     * if an action should be triggered by the link. Instead set `accessibleRole` property to `LinkAccessibleRole.Button`
     * and register a `press` event handler.
     */
    href?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether the link target URI should be validated.
     *
     * If validation fails, the value of the `href` property will still be set, but will not be applied to the
     * DOM.
     *
     * **Note:** Additional URLs are allowed through {@link module:sap/base/security/URLListValidator URLListValidator}.
     *
     * @since 1.54.0
     */
    validateUrl?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the link text is allowed to wrap when there is no sufficient space.
     */
    wrapping?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the horizontal alignment of the text.
     *
     * @since 1.28.0
     */
    textAlign?:
      | (TextAlign | keyof typeof TextAlign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * This property specifies the element's text directionality with enumerated options. By default, the control
     * inherits text direction from the parent DOM.
     *
     * @since 1.28.0
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Subtle links look more like standard text than like links. They should only be used to help with visual
     * hierarchy between large data lists of important and less important links. Subtle links should not be
     * used in any other use case.
     *
     * @since 1.22
     */
    subtle?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Emphasized links look visually more important than regular links.
     *
     * @since 1.22
     */
    emphasized?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the value of the `aria-haspopup` attribute
     *
     * If the value is `None`, the attribute will not be rendered. Otherwise it will be rendered according to
     * the selected value.
     *
     * NOTE: Use this property only when a link is related to a popover/popup. The value needs to be equal to
     * the main/root role of the popup - e.g. dialog, menu or list (examples: if you have dialog -> dialog,
     * if you have menu -> menu; if you have list -> list; if you have dialog containing a list -> dialog).
     * Do not use it, if you open a standard sap.m.Dialog, MessageBox or other type of dialogs displayed as
     * on overlay over the application.
     *
     * @since 1.86.0
     */
    ariaHasPopup?:
      | (aria.HasPopup | keyof typeof aria.HasPopup)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Describes the accessibility role of the link:
     * 	 - `LinkAccessibleRole.Default` - a navigation is expected to the location given in `href` property
     *
     * 	 - `LinkAccessibleRole.Button` - there will be `role` attribute with value "Button" rendered. In this
     *     scenario the `href` property value shouldn't be set as navigation isn't expected to occur.
     *
     * @since 1.104.0
     */
    accessibleRole?:
      | (LinkAccessibleRole | keyof typeof LinkAccessibleRole)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the size of the reactive area of the link:
     * 	 - `ReactiveAreaMode.Inline` - The link is displayed as part of a sentence.
     * 	 - `ReactiveAreaMode.Overlay` - The link is displayed as an overlay on top of other interactive parts
     *     of the page.
     *
     * **Note:**It is designed to make links easier to activate and helps meet the WCAG 2.2 Target Size requirement.
     * It is applicable only for the SAP Horizon themes. **Note:**The Reactive area size is sufficiently large
     * to help users avoid accidentally selecting (clicking or tapping) on unintented UI elements. UI elements
     * positioned over other parts of the page may need an invisible active touch area. This will ensure that
     * no elements beneath are activated accidentally when the user tries to interact with the overlay element.
     *
     * @since 1.133.0
     */
    reactiveAreaMode?:
      | (ReactiveAreaMode | keyof typeof ReactiveAreaMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies if an empty indicator should be displayed when there is no text.
     *
     * @since 1.89
     */
    emptyIndicatorMode?:
      | (EmptyIndicatorMode | keyof typeof EmptyIndicatorMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Association to controls / ids which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Event is fired when the user triggers the link control.
     */
    press?: (oEvent: Link$PressEvent) => void;
  }

  /**
   * Parameters of the Link#press event.
   */
  export interface Link$PressEventParameters {
    /**
     * Indicates whether the CTRL key was pressed when the link was selected.
     */
    ctrlKey?: boolean;

    /**
     * Indicates whether the "meta" key was pressed when the link was selected.
     *
     * On Macintosh keyboards, this is the command key (⌘). On Windows keyboards, this is the windows key (⊞).
     */
    metaKey?: boolean;
  }

  /**
   * Event object of the Link#press event.
   */
  export type Link$PressEvent = Event<Link$PressEventParameters, Link>;
}

declare module "sap/m/LinkTileContent" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import { URI } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * This element is used within the GenericTile control that generates a combination of an icon and a linkl
   *
   * @since 1.120
   */
  export default class LinkTileContent extends UI5Element {
    /**
     * Constructor for a new LinkTileContent.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control.
       */
      mSettings?: $LinkTileContentSettings
    );
    /**
     * Constructor for a new LinkTileContent.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, it is generated automatically if an ID is not provided.
       */
      sId?: string,
      /**
       * Initial settings for the new control.
       */
      mSettings?: $LinkTileContentSettings
    );

    /**
     * Creates a new subclass of class sap.m.LinkTileContent with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, LinkTileContent>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.LinkTileContent.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:linkPress linkPress} event of this `sap.m.LinkTileContent`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.LinkTileContent` itself.
     *
     * Event is fired when the user triggers the link control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLinkPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: LinkTileContent$LinkPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.LinkTileContent` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:linkPress linkPress} event of this `sap.m.LinkTileContent`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.LinkTileContent` itself.
     *
     * Event is fired when the user triggers the link control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLinkPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: LinkTileContent$LinkPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.LinkTileContent` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:linkPress linkPress} event of this `sap.m.LinkTileContent`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLinkPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: LinkTileContent$LinkPressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:linkPress linkPress} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireLinkPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: LinkTileContent$LinkPressEventParameters
    ): boolean;
    /**
     * Gets current value of property {@link #getIconSrc iconSrc}.
     *
     * This property can be set by following options:
     *
     * **Option 1:**
     *  The value has to be matched by following pattern `sap-icon://collection-name/icon-name` where `collection-name`
     * and `icon-name` have to be replaced by the desired values. In case the default UI5 icons are used the
     * `collection-name` can be omited.
     *  Example: `sap-icon://accept`
     *
     * **Option 2:** The value is determined by using {@link sap.ui.core.IconPool.getIconURI} with an Icon name
     * parameter and an optional collection parameter which is required when using application extended Icons.
     *  Example: `IconPool.getIconURI("accept")`
     *
     *
     * @returns Value of property `iconSrc`
     */
    getIconSrc(): URI;
    /**
     * Gets current value of property {@link #getLinkHref linkHref}.
     *
     * Defines the link target URI. Supports standard hyperlink behavior. **Note:** Don't set `href` property
     * if an action should be triggered by the link. Instead set `accessibleRole` property to `LinkAccessibleRole.Button`
     * and register a `press` event handler.
     *
     *
     * @returns Value of property `linkHref`
     */
    getLinkHref(): URI;
    /**
     * Gets current value of property {@link #getLinkText linkText}.
     *
     * Defines the displayed link text.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `linkText`
     */
    getLinkText(): string;
    /**
     * Returns the current element instance
     */
    getLinkTileContentInstance(): Record<string, LinkTileContent>;
    /**
     * Sets a new value for property {@link #getIconSrc iconSrc}.
     *
     * This property can be set by following options:
     *
     * **Option 1:**
     *  The value has to be matched by following pattern `sap-icon://collection-name/icon-name` where `collection-name`
     * and `icon-name` have to be replaced by the desired values. In case the default UI5 icons are used the
     * `collection-name` can be omited.
     *  Example: `sap-icon://accept`
     *
     * **Option 2:** The value is determined by using {@link sap.ui.core.IconPool.getIconURI} with an Icon name
     * parameter and an optional collection parameter which is required when using application extended Icons.
     *  Example: `IconPool.getIconURI("accept")`
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconSrc(
      /**
       * New value for property `iconSrc`
       */
      sIconSrc?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getLinkHref linkHref}.
     *
     * Defines the link target URI. Supports standard hyperlink behavior. **Note:** Don't set `href` property
     * if an action should be triggered by the link. Instead set `accessibleRole` property to `LinkAccessibleRole.Button`
     * and register a `press` event handler.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLinkHref(
      /**
       * New value for property `linkHref`
       */
      sLinkHref?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getLinkText linkText}.
     *
     * Defines the displayed link text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLinkText(
      /**
       * New value for property `linkText`
       */
      sLinkText?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the LinkTileContent constructor.
   */
  export interface $LinkTileContentSettings extends $ElementSettings {
    /**
     * This property can be set by following options:
     *
     * **Option 1:**
     *  The value has to be matched by following pattern `sap-icon://collection-name/icon-name` where `collection-name`
     * and `icon-name` have to be replaced by the desired values. In case the default UI5 icons are used the
     * `collection-name` can be omited.
     *  Example: `sap-icon://accept`
     *
     * **Option 2:** The value is determined by using {@link sap.ui.core.IconPool.getIconURI} with an Icon name
     * parameter and an optional collection parameter which is required when using application extended Icons.
     *  Example: `IconPool.getIconURI("accept")`
     */
    iconSrc?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the displayed link text.
     */
    linkText?: string | PropertyBindingInfo;

    /**
     * Defines the link target URI. Supports standard hyperlink behavior. **Note:** Don't set `href` property
     * if an action should be triggered by the link. Instead set `accessibleRole` property to `LinkAccessibleRole.Button`
     * and register a `press` event handler.
     */
    linkHref?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Event is fired when the user triggers the link control.
     */
    linkPress?: (oEvent: LinkTileContent$LinkPressEvent) => void;
  }

  /**
   * Parameters of the LinkTileContent#linkPress event.
   */
  export interface LinkTileContent$LinkPressEventParameters {
    /**
     * Indicates whether the CTRL key was pressed when the link was selected.
     */
    ctrlKey?: boolean;

    /**
     * Indicates whether the "meta" key was pressed when the link was selected.
     *
     * On Macintosh keyboards, this is the command key (⌘). On Windows keyboards, this is the windows key (⊞).
     */
    metaKey?: boolean;
  }

  /**
   * Event object of the LinkTileContent#linkPress event.
   */
  export type LinkTileContent$LinkPressEvent = Event<
    LinkTileContent$LinkPressEventParameters,
    LinkTileContent
  >;
}

declare module "sap/m/List" {
  import { default as ListBase, $ListBaseSettings } from "sap/m/ListBase";

  import { BackgroundDesign } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The List control provides a container for all types of list items. For mobile devices, the recommended
   * limit of list items is 100 to assure proper performance. To improve initial rendering of large lists,
   * use the "growing" feature. Please refer to the SAPUI5 Developer Guide for more information..
   *
   * See section "{@link https://ui5.sap.com/#/topic/1da158152f644ba1ad408a3e982fd3df Lists}" in the documentation
   * for an introduction to `sap.m.List` control.
   */
  export default class List extends ListBase {
    /**
     * Constructor for a new List.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:/list-overview/ List}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ListSettings
    );
    /**
     * Constructor for a new List.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:/list-overview/ List}
     */
    constructor(
      /**
       * Id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ListSettings
    );

    /**
     * Creates a new subclass of class sap.m.List with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ListBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, List>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.List.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Sets the background style of the list. Depending on the theme, you can change the state of the background
     * from `Solid` to `Translucent` or to `Transparent`.
     *
     * Default value is `Solid`.
     *
     * @since 1.14
     *
     * @returns Value of property `backgroundDesign`
     */
    getBackgroundDesign(): BackgroundDesign;
    /**
     * Sets a new value for property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Sets the background style of the list. Depending on the theme, you can change the state of the background
     * from `Solid` to `Translucent` or to `Transparent`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Solid`.
     *
     * @since 1.14
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundDesign(
      /**
       * New value for property `backgroundDesign`
       */
      sBackgroundDesign?: BackgroundDesign | keyof typeof BackgroundDesign
    ): this;
  }
  /**
   * Describes the settings that can be provided to the List constructor.
   */
  export interface $ListSettings extends $ListBaseSettings {
    /**
     * Sets the background style of the list. Depending on the theme, you can change the state of the background
     * from `Solid` to `Translucent` or to `Transparent`.
     *
     * @since 1.14
     */
    backgroundDesign?:
      | (BackgroundDesign | keyof typeof BackgroundDesign)
      | PropertyBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/ListBase" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { ID, IContextMenu, TitleLevel, CSSSize } from "sap/ui/core/library";

  import ListItemBase from "sap/m/ListItemBase";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import {
    ListGrowingDirection,
    ListHeaderDesign,
    ListKeyboardMode,
    ListMode,
    MultiSelectMode,
    ListSeparators,
    Sticky,
    SwipeDirection,
  } from "sap/m/library";

  import Toolbar from "sap/m/Toolbar";

  import ItemNavigation from "sap/ui/core/delegate/ItemNavigation";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Context from "sap/ui/model/Context";

  import Event from "sap/ui/base/Event";

  /**
   * The `sap.m.ListBase` control provides a base functionality of the `sap.m.List` and `sap.m.Table` controls.
   * Selection, deletion, unread states and inset style are also maintained in `sap.m.ListBase`.
   *
   * See section "{@link https://ui5.sap.com/#/topic/295e44b2d0144318bcb7bdd56bfa5189 List, List Item, and Table}"
   * in the documentation for an introduction to subclasses of `sap.m.ListBase` control. More information
   * on how to use binding-related functionality, such as {@link https://ui5.sap.com/#/topic/ec79a5d5918f4f7f9cbc2150e66778cc Sorting, Grouping, and Filtering},
   * is also available in the documentation.
   *
   * **Note:** The ListBase including all contained items may be completely re-rendered when the data of a
   * bound model is changed. Due to the limited hardware resources of mobile devices this can lead to longer
   * delays for lists that contain many items. As such the usage of a list is not recommended for these use
   * cases.
   *
   * @since 1.16
   */
  export default class ListBase extends Control {
    /**
     * Constructor for a new ListBase.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ListBaseSettings
    );
    /**
     * Constructor for a new ListBase.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ListBaseSettings
    );

    /**
     * Creates a new subclass of class sap.m.ListBase with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ListBase>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ListBase.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: ListItemBase
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpenContextMenu beforeOpenContextMenu }
     * event of this `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fired when the context menu is opened. When the context menu is opened, the binding context of the item
     * is set to the given `contextMenu`.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpenContextMenu(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$BeforeOpenContextMenuEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpenContextMenu beforeOpenContextMenu }
     * event of this `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fired when the context menu is opened. When the context menu is opened, the binding context of the item
     * is set to the given `contextMenu`.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpenContextMenu(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$BeforeOpenContextMenuEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:delete delete} event of this `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fires when delete icon is pressed by user.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDelete(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$DeleteEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:delete delete} event of this `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fires when delete icon is pressed by user.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDelete(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$DeleteEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:growingFinished growingFinished} event of this
     * `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fires after the new growing chunk has been fetched from the model and processed by the control.
     *
     * @since 1.16
     * @deprecated As of version 1.16.3. Instead, use "updateFinished" event.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachGrowingFinished(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$GrowingFinishedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:growingFinished growingFinished} event of this
     * `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fires after the new growing chunk has been fetched from the model and processed by the control.
     *
     * @since 1.16
     * @deprecated As of version 1.16.3. Instead, use "updateFinished" event.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachGrowingFinished(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$GrowingFinishedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:growingStarted growingStarted} event of this
     * `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fires before the new growing chunk is requested from the model.
     *
     * @since 1.16
     * @deprecated As of version 1.16.3. Instead, use `updateStarted` event with listening `changeReason`.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachGrowingStarted(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$GrowingStartedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:growingStarted growingStarted} event of this
     * `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fires before the new growing chunk is requested from the model.
     *
     * @since 1.16
     * @deprecated As of version 1.16.3. Instead, use `updateStarted` event with listening `changeReason`.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachGrowingStarted(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$GrowingStartedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemPress itemPress} event of this `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fires when an item is pressed unless the item's `type` property is `Inactive`.
     *
     * @since 1.20
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$ItemPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemPress itemPress} event of this `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fires when an item is pressed unless the item's `type` property is `Inactive`.
     *
     * @since 1.20
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$ItemPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:select select} event of this `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fires when selection is changed via user interaction. In `MultiSelect` mode, this event is also fired
     * on deselection.
     *
     * @deprecated As of version 1.16. Use the `selectionChange` event instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$SelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:select select} event of this `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fires when selection is changed via user interaction. In `MultiSelect` mode, this event is also fired
     * on deselection.
     *
     * @deprecated As of version 1.16. Use the `selectionChange` event instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$SelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionChange selectionChange} event of this
     * `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fires when selection is changed via user interaction inside the control.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$SelectionChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionChange selectionChange} event of this
     * `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fires when selection is changed via user interaction inside the control.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$SelectionChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:swipe swipe} event of this `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fires after user's swipe action and before the `swipeContent` is shown. On the `swipe` event handler,
     * `swipeContent` can be changed according to the swiped item. Calling the `preventDefault` method of the
     * event cancels the swipe action.
     *
     * **Note:** There is no accessible alternative provided by the control for swiping. Applications that use
     * this functionality must provide an accessible alternative UI to perform the same action.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSwipe(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$SwipeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:swipe swipe} event of this `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fires after user's swipe action and before the `swipeContent` is shown. On the `swipe` event handler,
     * `swipeContent` can be changed according to the swiped item. Calling the `preventDefault` method of the
     * event cancels the swipe action.
     *
     * **Note:** There is no accessible alternative provided by the control for swiping. Applications that use
     * this functionality must provide an accessible alternative UI to perform the same action.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSwipe(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$SwipeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:updateFinished updateFinished} event of this
     * `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fires after `items` binding is updated and processed by the control.
     *
     * @since 1.16.3
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUpdateFinished(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$UpdateFinishedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:updateFinished updateFinished} event of this
     * `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fires after `items` binding is updated and processed by the control.
     *
     * @since 1.16.3
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUpdateFinished(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$UpdateFinishedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:updateStarted updateStarted} event of this `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fires before `items` binding is updated (e.g. sorting, filtering)
     *
     * **Note:** Event handler should not invalidate the control.
     *
     * @since 1.16.3
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUpdateStarted(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$UpdateStartedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:updateStarted updateStarted} event of this `sap.m.ListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListBase` itself.
     *
     * Fires before `items` binding is updated (e.g. sorting, filtering)
     *
     * **Note:** Event handler should not invalidate the control.
     *
     * @since 1.16.3
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUpdateStarted(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ListBase$UpdateStartedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getItems items} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys the contextMenu in the aggregation {@link #getContextMenu contextMenu}.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContextMenu(): this;
    /**
     * Destroys the headerToolbar in the aggregation {@link #getHeaderToolbar headerToolbar}.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyHeaderToolbar(): this;
    /**
     * Destroys the infoToolbar in the aggregation {@link #getInfoToolbar infoToolbar}.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyInfoToolbar(): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Destroys the noData in the aggregation {@link #getNoData noData}.
     *
     * @since 1.101
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyNoData(): this;
    /**
     * Destroys the swipeContent in the aggregation {@link #getSwipeContent swipeContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySwipeContent(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeOpenContextMenu beforeOpenContextMenu }
     * event of this `sap.m.ListBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeOpenContextMenu(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ListBase$BeforeOpenContextMenuEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:delete delete} event of this `sap.m.ListBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachDelete(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ListBase$DeleteEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:growingFinished growingFinished} event of
     * this `sap.m.ListBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.16
     * @deprecated As of version 1.16.3. Instead, use "updateFinished" event.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachGrowingFinished(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ListBase$GrowingFinishedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:growingStarted growingStarted} event of this
     * `sap.m.ListBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.16
     * @deprecated As of version 1.16.3. Instead, use `updateStarted` event with listening `changeReason`.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachGrowingStarted(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ListBase$GrowingStartedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:itemPress itemPress} event of this `sap.m.ListBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.20
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachItemPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ListBase$ItemPressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:select select} event of this `sap.m.ListBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @deprecated As of version 1.16. Use the `selectionChange` event instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ListBase$SelectEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:selectionChange selectionChange} event of
     * this `sap.m.ListBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelectionChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ListBase$SelectionChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:swipe swipe} event of this `sap.m.ListBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSwipe(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ListBase$SwipeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:updateFinished updateFinished} event of this
     * `sap.m.ListBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.16.3
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUpdateFinished(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ListBase$UpdateFinishedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:updateStarted updateStarted} event of this
     * `sap.m.ListBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.16.3
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUpdateStarted(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ListBase$UpdateStartedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:beforeOpenContextMenu beforeOpenContextMenu} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @since 1.54
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireBeforeOpenContextMenu(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ListBase$BeforeOpenContextMenuEventParameters
    ): boolean;
    /**
     * Fires event {@link #event:delete delete} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireDelete(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ListBase$DeleteEventParameters
    ): this;
    /**
     * Fires event {@link #event:growingFinished growingFinished} to attached listeners.
     *
     * @since 1.16
     * @deprecated As of version 1.16.3. Instead, use "updateFinished" event.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireGrowingFinished(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ListBase$GrowingFinishedEventParameters
    ): this;
    /**
     * Fires event {@link #event:growingStarted growingStarted} to attached listeners.
     *
     * @since 1.16
     * @deprecated As of version 1.16.3. Instead, use `updateStarted` event with listening `changeReason`.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireGrowingStarted(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ListBase$GrowingStartedEventParameters
    ): this;
    /**
     * Fires event {@link #event:itemPress itemPress} to attached listeners.
     *
     * @since 1.20
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireItemPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ListBase$ItemPressEventParameters
    ): this;
    /**
     * Fires event {@link #event:select select} to attached listeners.
     *
     * @deprecated As of version 1.16. Use the `selectionChange` event instead.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ListBase$SelectEventParameters
    ): this;
    /**
     * Fires event {@link #event:selectionChange selectionChange} to attached listeners.
     *
     * @since 1.16
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelectionChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ListBase$SelectionChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:swipe swipe} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireSwipe(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ListBase$SwipeEventParameters
    ): boolean;
    /**
     * Fires event {@link #event:updateFinished updateFinished} to attached listeners.
     *
     * @since 1.16.3
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUpdateFinished(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ListBase$UpdateFinishedEventParameters
    ): this;
    /**
     * Fires event {@link #event:updateStarted updateStarted} to attached listeners.
     *
     * @since 1.16.3
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUpdateStarted(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ListBase$UpdateStartedEventParameters
    ): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.28.0
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets content of aggregation {@link #getContextMenu contextMenu}.
     *
     * Defines the context menu of the items.
     *
     * @since 1.54
     */
    getContextMenu(): IContextMenu;
    /**
     * Gets current value of property {@link #getEnableBusyIndicator enableBusyIndicator}.
     *
     * When this property is set to `true`, the control will automatically display a busy indicator when it
     * detects that data is being loaded. This busy indicator blocks the interaction with the items until data
     * loading is finished. By default, the busy indicator will be shown after one second. This behavior can
     * be customized by setting the `busyIndicatorDelay` property.
     *
     * Default value is `true`.
     *
     * @since 1.20.2
     *
     * @returns Value of property `enableBusyIndicator`
     */
    getEnableBusyIndicator(): boolean;
    /**
     * Gets current value of property {@link #getFooterText footerText}.
     *
     * Defines the footer text that appears in the control.
     *
     *
     * @returns Value of property `footerText`
     */
    getFooterText(): string;
    /**
     * Gets current value of property {@link #getGrowing growing}.
     *
     * If set to `true`, enables the growing feature of the control to load more items by requesting from the
     * model. **Note:**: This feature only works when an `items` aggregation is bound. Growing must not be used
     * together with two-way binding.
     *
     * Default value is `false`.
     *
     * @since 1.16.0
     *
     * @returns Value of property `growing`
     */
    getGrowing(): boolean;
    /**
     * Gets current value of property {@link #getGrowingDirection growingDirection}.
     *
     * Defines the direction of the growing feature. If set to `Downwards` the user has to scroll down to load
     * more items or the growing button is displayed at the bottom. If set to `Upwards` the user has to scroll
     * up to load more items or the growing button is displayed at the top.
     *
     * Default value is `Downwards`.
     *
     * @since 1.40.0
     *
     * @returns Value of property `growingDirection`
     */
    getGrowingDirection(): ListGrowingDirection;
    /**
     * Returns growing information as object with "actual" and "total" keys. Note: This function returns "null"
     * if "growing" feature is disabled.
     *
     * @since 1.16
     */
    getGrowingInfo(): {
      actual: int;

      total: int;
    } | null;
    /**
     * Gets current value of property {@link #getGrowingScrollToLoad growingScrollToLoad}.
     *
     * If set to true, the user can scroll down/up to load more items. Otherwise a growing button is displayed
     * at the bottom/top of the control. **Note:** This property can only be used if the `growing` property
     * is set to `true` and only if there is one instance of `sap.m.List` or `sap.m.Table` inside the scrollable
     * scroll container (e.g `sap.m.Page`).
     *
     * Default value is `false`.
     *
     * @since 1.16.0
     *
     * @returns Value of property `growingScrollToLoad`
     */
    getGrowingScrollToLoad(): boolean;
    /**
     * Gets current value of property {@link #getGrowingThreshold growingThreshold}.
     *
     * Defines the number of items to be requested from the model for each grow. This property can only be used
     * if the `growing` property is set to `true`.
     *
     * Default value is `20`.
     *
     * @since 1.16.0
     *
     * @returns Value of property `growingThreshold`
     */
    getGrowingThreshold(): int;
    /**
     * Gets current value of property {@link #getGrowingTriggerText growingTriggerText}.
     *
     * Defines the text displayed on the growing button. The default is a translated text ("More") coming from
     * the message bundle. This property can only be used if the `growing` property is set to `true`.
     *
     * @since 1.16.0
     *
     * @returns Value of property `growingTriggerText`
     */
    getGrowingTriggerText(): string;
    /**
     * Gets current value of property {@link #getHeaderDesign headerDesign}.
     *
     * Defines the header style of the control. Possible values are `Standard` and `Plain`.
     *
     * Default value is `Standard`.
     *
     * @since 1.14
     * @deprecated As of version 1.16. No longer has any functionality.
     *
     * @returns Value of property `headerDesign`
     */
    getHeaderDesign(): ListHeaderDesign;
    /**
     * Gets current value of property {@link #getHeaderLevel headerLevel}.
     *
     * Defines the semantic header level of the header text (see {@link #getHeaderText headerText} property}).
     * This information is, for example, used by assistive technologies, such as screenreaders, to create a
     * hierarchical site map for faster navigation. Depending on this setting, either the ARIA equivalent of
     * an HTML h1-h6 element is used or, when using the `Auto` level, no explicit level information is used.
     *
     * **Note:** If the `headerToolbar` aggregation is set, then this property is ignored. If this is the case,
     * use, for example, a `sap.m.Title` control in the toolbar to define a header.
     *
     * Default value is `Auto`.
     *
     * @since 1.117.0
     *
     * @returns Value of property `headerLevel`
     */
    getHeaderLevel(): TitleLevel;
    /**
     * Gets current value of property {@link #getHeaderText headerText}.
     *
     * Defines the header text that appears in the control. **Note:** If the `headerToolbar` aggregation is
     * set, then this property is ignored. If this is the case, use, for example, a `sap.m.Title` control in
     * the toolbar to define a header.
     *
     *
     * @returns Value of property `headerText`
     */
    getHeaderText(): string;
    /**
     * Gets content of aggregation {@link #getHeaderToolbar headerToolbar}.
     *
     * The header area can be used as a toolbar to add extra controls for user interactions. **Note:** When
     * set, this overwrites the `headerText` property.
     *
     * @since 1.16
     */
    getHeaderToolbar(): Toolbar;
    /**
     * Gets current value of property {@link #getIncludeItemInSelection includeItemInSelection}.
     *
     * Defines whether the items are selectable by clicking on the item itself (`true`) rather than having to
     * set the selection control first. **Note:** The `SingleSelectMaster` mode also provides this functionality
     * by default.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `includeItemInSelection`
     */
    getIncludeItemInSelection(): boolean;
    /**
     * Gets content of aggregation {@link #getInfoToolbar infoToolbar}.
     *
     * A toolbar that is placed below the header to show extra information to the user.
     *
     * @since 1.16
     */
    getInfoToolbar(): Toolbar;
    /**
     * Gets current value of property {@link #getInset inset}.
     *
     * Defines the indentation of the container. Setting it to `true` indents the list.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `inset`
     */
    getInset(): boolean;
    /**
     * Returns the ItemNavigation delegate of the list
     *
     * @since 1.16.5
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    getItemNavigation(): ItemNavigation | undefined;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * Defines the items contained within this control.
     */
    getItems(): ListItemBase[];
    /**
     * Gets current value of property {@link #getKeyboardMode keyboardMode}.
     *
     * Defines keyboard handling behavior of the control.
     *
     * Default value is `"Navigation"`.
     *
     * @since 1.38.0
     *
     * @returns Value of property `keyboardMode`
     */
    getKeyboardMode(): ListKeyboardMode;
    /**
     * Returns the last list mode, the mode that is rendered This can be used to detect mode changes during
     * rendering
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    getLastMode(): void;
    /**
     * Gets current value of property {@link #getMode mode}.
     *
     * Defines the mode of the control (e.g. `None`, `SingleSelect`, `MultiSelect`, `Delete`).
     *
     * Default value is `None`.
     *
     *
     * @returns Value of property `mode`
     */
    getMode(): ListMode;
    /**
     * Gets current value of property {@link #getModeAnimationOn modeAnimationOn}.
     *
     * Defines if animations will be shown while switching between modes.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `modeAnimationOn`
     */
    getModeAnimationOn(): boolean;
    /**
     * Gets current value of property {@link #getMultiSelectMode multiSelectMode}.
     *
     * Defines the multi-selection mode for the control.
     *
     * If the property is set to `ClearAll`, then selecting items via the keyboard shortcut CTRL + A
     * and via the `selectAll` method is not possible. See {@link #selectAll selectAll} for more details. A
     * selection of multiple items is still possible using the range selection feature. For more information
     * about the range selection, see {@link https://ui5.sap.com/#/topic/8a0d4efa29d44ef39219c18d832012da Keyboard Handling for Item Selection}.
     *
     * **Only relevant for `sap.m.Table`:** If `ClearAll` is set, the table renders a Deselect All icon in the
     * column header, otherwise a Select All checkbox is shown. The Select All checkbox allows the user to select
     * all the items in the control, and the Deselect All icon deselects the items.
     *
     * **Note:** This property must be used with the `MultiSelect` mode.
     *
     * Default value is `Default`.
     *
     * @since 1.93
     *
     * @returns Value of property `multiSelectMode`
     */
    getMultiSelectMode(): MultiSelectMode;
    /**
     * Gets content of aggregation {@link #getNoData noData}.
     *
     * Defines the custom visualization if there is no data available. **Note:** If both a `noDataText` property
     * and a `noData` aggregation are provided, the `noData` aggregation takes priority. If the `noData` aggregation
     * is undefined or set to null, the `noDataText` property is used instead.
     *
     * @since 1.101
     */
    getNoData(): Control | string;
    /**
     * Gets current value of property {@link #getNoDataText noDataText}.
     *
     * This text is displayed if the control contains no items. **Note:** If both a `noDataText` property and
     * a `noData` aggregation are provided, the `noData` aggregation takes priority. If the `noData` aggregation
     * is undefined or set to null, the `noDataText` property is used instead.
     *
     *
     * @returns Value of property `noDataText`
     */
    getNoDataText(): string;
    /**
     * Gets current value of property {@link #getRememberSelections rememberSelections}.
     *
     * If set to true, this control remembers and retains the selection of the items after a binding update
     * has been performed (e.g. sorting, filtering). **Note:** This feature works only if two-way data binding
     * for the `selected` property of the item is not used. It also needs to be turned off if the binding context
     * of the item does not always point to the same entry in the model, for example, if the order of the data
     * in the `JSONModel` is changed. **Note:** This feature leverages the built-in selection mechanism of the
     * corresponding binding context when the OData V4 model is used. Therefore, all binding-relevant limitations
     * apply in this context as well. For more details, see the {@link sap.ui.model.odata.v4.Context#setSelected setSelected},
     * the {@link sap.ui.model.odata.v4.ODataModel#bindList bindList}, and the {@link sap.ui.model.odata.v4.ODataMetaModel#requestValueListInfo requestValueListInfo }
     * API documentation. Do not enable this feature when `$$SharedRequests` or `$$clearSelectionOnFilter` is
     * active. **Note:** If this property is set to `false`, a possible binding context update of items (for
     * example, filtering or sorting the list binding) would clear the selection of the items.
     *
     * Default value is `true`.
     *
     * @since 1.16.6
     *
     * @returns Value of property `rememberSelections`
     */
    getRememberSelections(): boolean;
    /**
     * Returns the binding contexts of the selected items. Note: This method returns an empty array if no databinding
     * is used.
     *
     * @since 1.18.6
     */
    getSelectedContexts(
      /**
       * Set true to include even invisible selected items(e.g. the selections from the previous filters). Note:
       * In single selection modes, only the last selected item's binding context is returned in array.
       */
      bAll?: boolean
    ): Context[];
    /**
     * Returns selected list item. When no item is selected, "null" is returned. When "multi-selection" is enabled
     * and multiple items are selected, only the up-most selected item is returned.
     */
    getSelectedItem(): ListItemBase;
    /**
     * Returns an array containing the selected list items. If no items are selected, an empty array is returned.
     */
    getSelectedItems(): ListItemBase[];
    /**
     * Gets current value of property {@link #getShowNoData showNoData}.
     *
     * Defines whether or not the text specified in the `noDataText` property is displayed.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showNoData`
     */
    getShowNoData(): boolean;
    /**
     * Gets current value of property {@link #getShowSeparators showSeparators}.
     *
     * Defines which item separator style will be used.
     *
     * Default value is `All`.
     *
     *
     * @returns Value of property `showSeparators`
     */
    getShowSeparators(): ListSeparators;
    /**
     * Gets current value of property {@link #getShowUnread showUnread}.
     *
     * Activates the unread indicator for all items, if set to `true`.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showUnread`
     */
    getShowUnread(): boolean;
    /**
     * Gets current value of property {@link #getSticky sticky}.
     *
     * Defines the section of the control that remains fixed at the top of the page during vertical scrolling
     * as long as the control is in the viewport.
     *
     * **Note:** Enabling sticky column headers in List controls will not have any effect.
     *
     * There are some known restrictions. A few are given below:
     * 	 - If the control is placed in layout containers that have the `overflow: hidden` or `overflow: auto`
     *     style definition, this can prevent the sticky elements of the control from becoming fixed at the top
     *     of the viewport.
     * 	 - If sticky column headers are enabled in the `sap.m.Table` control, setting focus on the column headers
     *     will let the table scroll to the top.
     * 	 - A transparent toolbar design is not supported for sticky bars. The toolbar will automatically get
     *     an intransparent background color.
     * 	 - This feature supports only the default height of the toolbar control.
     *
     * @since 1.58
     *
     * @returns Value of property `sticky`
     */
    getSticky(): Sticky[];
    /**
     * Gets content of aggregation {@link #getSwipeContent swipeContent}.
     *
     * User can swipe to bring in this control on the right hand side of an item. **Note:**
     * 	 - For non-touch screen devices, this functionality is ignored.
     * 	 - There is no accessible alternative provided by the control for swiping. Applications that use this
     *     functionality must provide an accessible alternative UI to perform the same action.
     */
    getSwipeContent(): Control;
    /**
     * Gets current value of property {@link #getSwipeDirection swipeDirection}.
     *
     * Defines the direction of the swipe movement (e.g LeftToRight, RightToLeft, Both) to display the control
     * defined in the `swipeContent` aggregation.
     *
     * Default value is `Both`.
     *
     *
     * @returns Value of property `swipeDirection`
     */
    getSwipeDirection(): SwipeDirection;
    /**
     * Returns swiped list item. When no item is swiped, "null" is returned.
     */
    getSwipedItem(): ListItemBase;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Sets the width of the control.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Checks for the provided `sap.m.ListItemBase` in the aggregation {@link #getItems items}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: ListItemBase
    ): int;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: ListItemBase,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.28.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): ListItemBase[];
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.28.0
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | ListItemBase
    ): ListItemBase | null;
    /**
     * Removes visible selections of the current selection mode.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    removeSelections(
      /**
       * If the `rememberSelection` property is set to `true`, this control preserves selections after filtering
       * or sorting. Set this parameter to `true` to remove all selections (as of version 1.16)
       */
      bAll?: boolean,
      /**
       * Determines whether the `selectionChange` event is fired by this method call (as of version 1.121)
       */
      bFireEvent?: boolean
    ): this;
    /**
     * Requests a specified number of items from the back end to load more data in the list. If the number of
     * items are not specified, the `growingThreshold` value is used to request more data.
     *
     * **Note:** To use this method, the `growing` feature must be enabled.
     *
     * See {@link #getGrowing growing} and {@link #getGrowingThreshold growingThreshold} for more information.
     *
     * @since 1.92
     */
    requestItems(
      /**
       * A positive number of items to be requested
       */
      iItems?: int
    ): void;
    /**
     * Scrolls the list so that the item with the given index is in the viewport. If the index is -1, it scrolls
     * to the bottom of the list. If the growing feature is enabled, the list is scrolled to the last available
     * item.
     *
     * Growing in combination with `growingScrollToLoad=true` can result in loading of new items when scrolling
     * to the bottom of the list.
     *  **Note:** This method only works if the control is placed inside a scrollable container (for example,
     * `sap.m.Page`). Calling this method if the `ListBase` control is placed outside the container, will reject
     * the `Promise` by throwing an error.
     *
     * @since 1.76
     *
     * @returns A `Promise` that resolves after the table scrolls to the row with the given index.
     */
    scrollToIndex(
      /**
       * The list item index that must be scrolled into the viewport
       */
      iIndex: number
    ): Promise<any>;
    /**
     * Selects all items in the `MultiSelection` mode.
     *
     * **Note:** If `growing` is enabled, only the visible items in the list are selected. Since version 1.93,
     * the items are not selected if `getMultiSelectMode=ClearAll`.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    selectAll(
      /**
       * Determines whether the `selectionChange` event is fired by this method call (as of version 1.121)
       */
      bFireEvent?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getContextMenu contextMenu}.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContextMenu(
      /**
       * The contextMenu to set
       */
      oContextMenu: IContextMenu
    ): this;
    /**
     * Sets a new value for property {@link #getEnableBusyIndicator enableBusyIndicator}.
     *
     * When this property is set to `true`, the control will automatically display a busy indicator when it
     * detects that data is being loaded. This busy indicator blocks the interaction with the items until data
     * loading is finished. By default, the busy indicator will be shown after one second. This behavior can
     * be customized by setting the `busyIndicatorDelay` property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.20.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableBusyIndicator(
      /**
       * New value for property `enableBusyIndicator`
       */
      bEnableBusyIndicator?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getFooterText footerText}.
     *
     * Defines the footer text that appears in the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFooterText(
      /**
       * New value for property `footerText`
       */
      sFooterText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getGrowing growing}.
     *
     * If set to `true`, enables the growing feature of the control to load more items by requesting from the
     * model. **Note:**: This feature only works when an `items` aggregation is bound. Growing must not be used
     * together with two-way binding.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.16.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGrowing(
      /**
       * New value for property `growing`
       */
      bGrowing?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getGrowingDirection growingDirection}.
     *
     * Defines the direction of the growing feature. If set to `Downwards` the user has to scroll down to load
     * more items or the growing button is displayed at the bottom. If set to `Upwards` the user has to scroll
     * up to load more items or the growing button is displayed at the top.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Downwards`.
     *
     * @since 1.40.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGrowingDirection(
      /**
       * New value for property `growingDirection`
       */
      sGrowingDirection?:
        | ListGrowingDirection
        | keyof typeof ListGrowingDirection
    ): this;
    /**
     * Sets a new value for property {@link #getGrowingScrollToLoad growingScrollToLoad}.
     *
     * If set to true, the user can scroll down/up to load more items. Otherwise a growing button is displayed
     * at the bottom/top of the control. **Note:** This property can only be used if the `growing` property
     * is set to `true` and only if there is one instance of `sap.m.List` or `sap.m.Table` inside the scrollable
     * scroll container (e.g `sap.m.Page`).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.16.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGrowingScrollToLoad(
      /**
       * New value for property `growingScrollToLoad`
       */
      bGrowingScrollToLoad?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getGrowingThreshold growingThreshold}.
     *
     * Defines the number of items to be requested from the model for each grow. This property can only be used
     * if the `growing` property is set to `true`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `20`.
     *
     * @since 1.16.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGrowingThreshold(
      /**
       * New value for property `growingThreshold`
       */
      iGrowingThreshold?: int
    ): this;
    /**
     * Sets a new value for property {@link #getGrowingTriggerText growingTriggerText}.
     *
     * Defines the text displayed on the growing button. The default is a translated text ("More") coming from
     * the message bundle. This property can only be used if the `growing` property is set to `true`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.16.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGrowingTriggerText(
      /**
       * New value for property `growingTriggerText`
       */
      sGrowingTriggerText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getHeaderDesign headerDesign}.
     *
     * Defines the header style of the control. Possible values are `Standard` and `Plain`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Standard`.
     *
     * @since 1.14
     * @deprecated As of version 1.16. No longer has any functionality.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeaderDesign(
      /**
       * New value for property `headerDesign`
       */
      sHeaderDesign?: ListHeaderDesign | keyof typeof ListHeaderDesign
    ): this;
    /**
     * Sets a new value for property {@link #getHeaderLevel headerLevel}.
     *
     * Defines the semantic header level of the header text (see {@link #getHeaderText headerText} property}).
     * This information is, for example, used by assistive technologies, such as screenreaders, to create a
     * hierarchical site map for faster navigation. Depending on this setting, either the ARIA equivalent of
     * an HTML h1-h6 element is used or, when using the `Auto` level, no explicit level information is used.
     *
     * **Note:** If the `headerToolbar` aggregation is set, then this property is ignored. If this is the case,
     * use, for example, a `sap.m.Title` control in the toolbar to define a header.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     * @since 1.117.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeaderLevel(
      /**
       * New value for property `headerLevel`
       */
      sHeaderLevel?: TitleLevel | keyof typeof TitleLevel
    ): this;
    /**
     * Sets a new value for property {@link #getHeaderText headerText}.
     *
     * Defines the header text that appears in the control. **Note:** If the `headerToolbar` aggregation is
     * set, then this property is ignored. If this is the case, use, for example, a `sap.m.Title` control in
     * the toolbar to define a header.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeaderText(
      /**
       * New value for property `headerText`
       */
      sHeaderText?: string
    ): this;
    /**
     * Sets the aggregated {@link #getHeaderToolbar headerToolbar}.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeaderToolbar(
      /**
       * The headerToolbar to set
       */
      oHeaderToolbar: Toolbar
    ): this;
    /**
     * Sets a new value for property {@link #getIncludeItemInSelection includeItemInSelection}.
     *
     * Defines whether the items are selectable by clicking on the item itself (`true`) rather than having to
     * set the selection control first. **Note:** The `SingleSelectMaster` mode also provides this functionality
     * by default.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIncludeItemInSelection(
      /**
       * New value for property `includeItemInSelection`
       */
      bIncludeItemInSelection?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getInfoToolbar infoToolbar}.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInfoToolbar(
      /**
       * The infoToolbar to set
       */
      oInfoToolbar: Toolbar
    ): this;
    /**
     * Sets a new value for property {@link #getInset inset}.
     *
     * Defines the indentation of the container. Setting it to `true` indents the list.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInset(
      /**
       * New value for property `inset`
       */
      bInset?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getKeyboardMode keyboardMode}.
     *
     * Defines keyboard handling behavior of the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Navigation"`.
     *
     * @since 1.38.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setKeyboardMode(
      /**
       * New value for property `keyboardMode`
       */
      sKeyboardMode?: ListKeyboardMode | keyof typeof ListKeyboardMode
    ): this;
    /**
     * Sets a new value for property {@link #getMode mode}.
     *
     * Defines the mode of the control (e.g. `None`, `SingleSelect`, `MultiSelect`, `Delete`).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMode(
      /**
       * New value for property `mode`
       */
      sMode?: ListMode | keyof typeof ListMode
    ): this;
    /**
     * Sets a new value for property {@link #getModeAnimationOn modeAnimationOn}.
     *
     * Defines if animations will be shown while switching between modes.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setModeAnimationOn(
      /**
       * New value for property `modeAnimationOn`
       */
      bModeAnimationOn?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getMultiSelectMode multiSelectMode}.
     *
     * Defines the multi-selection mode for the control.
     *
     * If the property is set to `ClearAll`, then selecting items via the keyboard shortcut CTRL + A
     * and via the `selectAll` method is not possible. See {@link #selectAll selectAll} for more details. A
     * selection of multiple items is still possible using the range selection feature. For more information
     * about the range selection, see {@link https://ui5.sap.com/#/topic/8a0d4efa29d44ef39219c18d832012da Keyboard Handling for Item Selection}.
     *
     * **Only relevant for `sap.m.Table`:** If `ClearAll` is set, the table renders a Deselect All icon in the
     * column header, otherwise a Select All checkbox is shown. The Select All checkbox allows the user to select
     * all the items in the control, and the Deselect All icon deselects the items.
     *
     * **Note:** This property must be used with the `MultiSelect` mode.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Default`.
     *
     * @since 1.93
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMultiSelectMode(
      /**
       * New value for property `multiSelectMode`
       */
      sMultiSelectMode?: MultiSelectMode | keyof typeof MultiSelectMode
    ): this;
    /**
     * Sets the aggregated {@link #getNoData noData}.
     *
     * @since 1.101
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNoData(
      /**
       * The noData to set
       */
      vNoData: Control | string
    ): this;
    /**
     * Sets a new value for property {@link #getNoDataText noDataText}.
     *
     * This text is displayed if the control contains no items. **Note:** If both a `noDataText` property and
     * a `noData` aggregation are provided, the `noData` aggregation takes priority. If the `noData` aggregation
     * is undefined or set to null, the `noDataText` property is used instead.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNoDataText(
      /**
       * New value for property `noDataText`
       */
      sNoDataText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getRememberSelections rememberSelections}.
     *
     * If set to true, this control remembers and retains the selection of the items after a binding update
     * has been performed (e.g. sorting, filtering). **Note:** This feature works only if two-way data binding
     * for the `selected` property of the item is not used. It also needs to be turned off if the binding context
     * of the item does not always point to the same entry in the model, for example, if the order of the data
     * in the `JSONModel` is changed. **Note:** This feature leverages the built-in selection mechanism of the
     * corresponding binding context when the OData V4 model is used. Therefore, all binding-relevant limitations
     * apply in this context as well. For more details, see the {@link sap.ui.model.odata.v4.Context#setSelected setSelected},
     * the {@link sap.ui.model.odata.v4.ODataModel#bindList bindList}, and the {@link sap.ui.model.odata.v4.ODataMetaModel#requestValueListInfo requestValueListInfo }
     * API documentation. Do not enable this feature when `$$SharedRequests` or `$$clearSelectionOnFilter` is
     * active. **Note:** If this property is set to `false`, a possible binding context update of items (for
     * example, filtering or sorting the list binding) would clear the selection of the items.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.16.6
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRememberSelections(
      /**
       * New value for property `rememberSelections`
       */
      bRememberSelections?: boolean
    ): this;
    /**
     * Selects or deselects the given list item.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSelectedItem(
      /**
       * The list item whose selection is changed
       */
      oListItem: ListItemBase,
      /**
       * Sets selected status of the list item provided
       */
      bSelect?: boolean,
      /**
       * Determines whether the `selectionChange` event is fired by this method call (as of version 1.121)
       */
      bFireEvent?: boolean
    ): this;
    /**
     * Sets a list item to be selected by id. In single mode the method removes the previous selection.
     */
    setSelectedItemById(
      /**
       * The id of the list item whose selection to be changed.
       */
      sId: string,
      /**
       * Sets selected status of the list item
       */
      bSelect?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowNoData showNoData}.
     *
     * Defines whether or not the text specified in the `noDataText` property is displayed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowNoData(
      /**
       * New value for property `showNoData`
       */
      bShowNoData?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowSeparators showSeparators}.
     *
     * Defines which item separator style will be used.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `All`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowSeparators(
      /**
       * New value for property `showSeparators`
       */
      sShowSeparators?: ListSeparators | keyof typeof ListSeparators
    ): this;
    /**
     * Sets a new value for property {@link #getShowUnread showUnread}.
     *
     * Activates the unread indicator for all items, if set to `true`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowUnread(
      /**
       * New value for property `showUnread`
       */
      bShowUnread?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getSticky sticky}.
     *
     * Defines the section of the control that remains fixed at the top of the page during vertical scrolling
     * as long as the control is in the viewport.
     *
     * **Note:** Enabling sticky column headers in List controls will not have any effect.
     *
     * There are some known restrictions. A few are given below:
     * 	 - If the control is placed in layout containers that have the `overflow: hidden` or `overflow: auto`
     *     style definition, this can prevent the sticky elements of the control from becoming fixed at the top
     *     of the viewport.
     * 	 - If sticky column headers are enabled in the `sap.m.Table` control, setting focus on the column headers
     *     will let the table scroll to the top.
     * 	 - A transparent toolbar design is not supported for sticky bars. The toolbar will automatically get
     *     an intransparent background color.
     * 	 - This feature supports only the default height of the toolbar control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.58
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSticky(
      /**
       * New value for property `sticky`
       */
      sSticky: Array<Sticky | keyof typeof Sticky>
    ): this;
    /**
     * Sets the aggregated {@link #getSwipeContent swipeContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSwipeContent(
      /**
       * The swipeContent to set
       */
      oSwipeContent: Control
    ): this;
    /**
     * Sets a new value for property {@link #getSwipeDirection swipeDirection}.
     *
     * Defines the direction of the swipe movement (e.g LeftToRight, RightToLeft, Both) to display the control
     * defined in the `swipeContent` aggregation.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Both`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSwipeDirection(
      /**
       * New value for property `swipeDirection`
       */
      sSwipeDirection?: SwipeDirection | keyof typeof SwipeDirection
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Sets the width of the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * After swipeContent is shown, user can interact with this control(e.g Tap). After interaction is done,
     * you can/should use this method to hide swipeContent from screen. Note: If users try to tap inside of
     * the list but outside of the swipeContent then control hides automatically.
     */
    swipeOut(
      /**
       * This callback function is called with two parameters(swipedListItem and swipedContent) after swipe-out
       * animation is finished.
       */
      callback: Function
    ): this;
    /**
     * Unbinds aggregation {@link #getItems items} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindItems(): this;
  }
  /**
   * Describes the settings that can be provided to the ListBase constructor.
   */
  export interface $ListBaseSettings extends $ControlSettings {
    /**
     * Defines the indentation of the container. Setting it to `true` indents the list.
     */
    inset?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the header text that appears in the control. **Note:** If the `headerToolbar` aggregation is
     * set, then this property is ignored. If this is the case, use, for example, a `sap.m.Title` control in
     * the toolbar to define a header.
     */
    headerText?: string | PropertyBindingInfo;

    /**
     * Defines the semantic header level of the header text (see {@link #getHeaderText headerText} property}).
     * This information is, for example, used by assistive technologies, such as screenreaders, to create a
     * hierarchical site map for faster navigation. Depending on this setting, either the ARIA equivalent of
     * an HTML h1-h6 element is used or, when using the `Auto` level, no explicit level information is used.
     *
     * **Note:** If the `headerToolbar` aggregation is set, then this property is ignored. If this is the case,
     * use, for example, a `sap.m.Title` control in the toolbar to define a header.
     *
     * @since 1.117.0
     */
    headerLevel?:
      | (TitleLevel | keyof typeof TitleLevel)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the header style of the control. Possible values are `Standard` and `Plain`.
     *
     * @since 1.14
     * @deprecated As of version 1.16. No longer has any functionality.
     */
    headerDesign?:
      | (ListHeaderDesign | keyof typeof ListHeaderDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the footer text that appears in the control.
     */
    footerText?: string | PropertyBindingInfo;

    /**
     * Defines the mode of the control (e.g. `None`, `SingleSelect`, `MultiSelect`, `Delete`).
     */
    mode?:
      | (ListMode | keyof typeof ListMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Sets the width of the control.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether the items are selectable by clicking on the item itself (`true`) rather than having to
     * set the selection control first. **Note:** The `SingleSelectMaster` mode also provides this functionality
     * by default.
     */
    includeItemInSelection?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Activates the unread indicator for all items, if set to `true`.
     */
    showUnread?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This text is displayed if the control contains no items. **Note:** If both a `noDataText` property and
     * a `noData` aggregation are provided, the `noData` aggregation takes priority. If the `noData` aggregation
     * is undefined or set to null, the `noDataText` property is used instead.
     */
    noDataText?: string | PropertyBindingInfo;

    /**
     * Defines whether or not the text specified in the `noDataText` property is displayed.
     */
    showNoData?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * When this property is set to `true`, the control will automatically display a busy indicator when it
     * detects that data is being loaded. This busy indicator blocks the interaction with the items until data
     * loading is finished. By default, the busy indicator will be shown after one second. This behavior can
     * be customized by setting the `busyIndicatorDelay` property.
     *
     * @since 1.20.2
     */
    enableBusyIndicator?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines if animations will be shown while switching between modes.
     */
    modeAnimationOn?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines which item separator style will be used.
     */
    showSeparators?:
      | (ListSeparators | keyof typeof ListSeparators)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the direction of the swipe movement (e.g LeftToRight, RightToLeft, Both) to display the control
     * defined in the `swipeContent` aggregation.
     */
    swipeDirection?:
      | (SwipeDirection | keyof typeof SwipeDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * If set to `true`, enables the growing feature of the control to load more items by requesting from the
     * model. **Note:**: This feature only works when an `items` aggregation is bound. Growing must not be used
     * together with two-way binding.
     *
     * @since 1.16.0
     */
    growing?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the number of items to be requested from the model for each grow. This property can only be used
     * if the `growing` property is set to `true`.
     *
     * @since 1.16.0
     */
    growingThreshold?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the text displayed on the growing button. The default is a translated text ("More") coming from
     * the message bundle. This property can only be used if the `growing` property is set to `true`.
     *
     * @since 1.16.0
     */
    growingTriggerText?: string | PropertyBindingInfo;

    /**
     * If set to true, the user can scroll down/up to load more items. Otherwise a growing button is displayed
     * at the bottom/top of the control. **Note:** This property can only be used if the `growing` property
     * is set to `true` and only if there is one instance of `sap.m.List` or `sap.m.Table` inside the scrollable
     * scroll container (e.g `sap.m.Page`).
     *
     * @since 1.16.0
     */
    growingScrollToLoad?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the direction of the growing feature. If set to `Downwards` the user has to scroll down to load
     * more items or the growing button is displayed at the bottom. If set to `Upwards` the user has to scroll
     * up to load more items or the growing button is displayed at the top.
     *
     * @since 1.40.0
     */
    growingDirection?:
      | (ListGrowingDirection | keyof typeof ListGrowingDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * If set to true, this control remembers and retains the selection of the items after a binding update
     * has been performed (e.g. sorting, filtering). **Note:** This feature works only if two-way data binding
     * for the `selected` property of the item is not used. It also needs to be turned off if the binding context
     * of the item does not always point to the same entry in the model, for example, if the order of the data
     * in the `JSONModel` is changed. **Note:** This feature leverages the built-in selection mechanism of the
     * corresponding binding context when the OData V4 model is used. Therefore, all binding-relevant limitations
     * apply in this context as well. For more details, see the {@link sap.ui.model.odata.v4.Context#setSelected setSelected},
     * the {@link sap.ui.model.odata.v4.ODataModel#bindList bindList}, and the {@link sap.ui.model.odata.v4.ODataMetaModel#requestValueListInfo requestValueListInfo }
     * API documentation. Do not enable this feature when `$$SharedRequests` or `$$clearSelectionOnFilter` is
     * active. **Note:** If this property is set to `false`, a possible binding context update of items (for
     * example, filtering or sorting the list binding) would clear the selection of the items.
     *
     * @since 1.16.6
     */
    rememberSelections?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines keyboard handling behavior of the control.
     *
     * @since 1.38.0
     */
    keyboardMode?:
      | (ListKeyboardMode | keyof typeof ListKeyboardMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the section of the control that remains fixed at the top of the page during vertical scrolling
     * as long as the control is in the viewport.
     *
     * **Note:** Enabling sticky column headers in List controls will not have any effect.
     *
     * There are some known restrictions. A few are given below:
     * 	 - If the control is placed in layout containers that have the `overflow: hidden` or `overflow: auto`
     *     style definition, this can prevent the sticky elements of the control from becoming fixed at the top
     *     of the viewport.
     * 	 - If sticky column headers are enabled in the `sap.m.Table` control, setting focus on the column headers
     *     will let the table scroll to the top.
     * 	 - A transparent toolbar design is not supported for sticky bars. The toolbar will automatically get
     *     an intransparent background color.
     * 	 - This feature supports only the default height of the toolbar control.
     *
     * @since 1.58
     */
    sticky?:
      | Array<Sticky | keyof typeof Sticky>
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the multi-selection mode for the control.
     *
     * If the property is set to `ClearAll`, then selecting items via the keyboard shortcut CTRL + A
     * and via the `selectAll` method is not possible. See {@link #selectAll selectAll} for more details. A
     * selection of multiple items is still possible using the range selection feature. For more information
     * about the range selection, see {@link https://ui5.sap.com/#/topic/8a0d4efa29d44ef39219c18d832012da Keyboard Handling for Item Selection}.
     *
     * **Only relevant for `sap.m.Table`:** If `ClearAll` is set, the table renders a Deselect All icon in the
     * column header, otherwise a Select All checkbox is shown. The Select All checkbox allows the user to select
     * all the items in the control, and the Deselect All icon deselects the items.
     *
     * **Note:** This property must be used with the `MultiSelect` mode.
     *
     * @since 1.93
     */
    multiSelectMode?:
      | (MultiSelectMode | keyof typeof MultiSelectMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the items contained within this control.
     */
    items?:
      | ListItemBase[]
      | ListItemBase
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * User can swipe to bring in this control on the right hand side of an item. **Note:**
     * 	 - For non-touch screen devices, this functionality is ignored.
     * 	 - There is no accessible alternative provided by the control for swiping. Applications that use this
     *     functionality must provide an accessible alternative UI to perform the same action.
     */
    swipeContent?: Control;

    /**
     * The header area can be used as a toolbar to add extra controls for user interactions. **Note:** When
     * set, this overwrites the `headerText` property.
     *
     * @since 1.16
     */
    headerToolbar?: Toolbar;

    /**
     * A toolbar that is placed below the header to show extra information to the user.
     *
     * @since 1.16
     */
    infoToolbar?: Toolbar;

    /**
     * Defines the context menu of the items.
     *
     * @since 1.54
     */
    contextMenu?: IContextMenu;

    /**
     * Defines the custom visualization if there is no data available. **Note:** If both a `noDataText` property
     * and a `noData` aggregation are provided, the `noData` aggregation takes priority. If the `noData` aggregation
     * is undefined or set to null, the `noDataText` property is used instead.
     *
     * @since 1.101
     */
    noData?: string | Control | PropertyBindingInfo;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledby).
     *
     * @since 1.28.0
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Fires when selection is changed via user interaction. In `MultiSelect` mode, this event is also fired
     * on deselection.
     *
     * @deprecated As of version 1.16. Use the `selectionChange` event instead.
     */
    select?: (oEvent: ListBase$SelectEvent) => void;

    /**
     * Fires when selection is changed via user interaction inside the control.
     *
     * @since 1.16
     */
    selectionChange?: (oEvent: ListBase$SelectionChangeEvent) => void;

    /**
     * Fires when delete icon is pressed by user.
     */
    delete?: (oEvent: ListBase$DeleteEvent) => void;

    /**
     * Fires after user's swipe action and before the `swipeContent` is shown. On the `swipe` event handler,
     * `swipeContent` can be changed according to the swiped item. Calling the `preventDefault` method of the
     * event cancels the swipe action.
     *
     * **Note:** There is no accessible alternative provided by the control for swiping. Applications that use
     * this functionality must provide an accessible alternative UI to perform the same action.
     */
    swipe?: (oEvent: ListBase$SwipeEvent) => void;

    /**
     * Fires before the new growing chunk is requested from the model.
     *
     * @since 1.16
     * @deprecated As of version 1.16.3. Instead, use `updateStarted` event with listening `changeReason`.
     */
    growingStarted?: (oEvent: ListBase$GrowingStartedEvent) => void;

    /**
     * Fires after the new growing chunk has been fetched from the model and processed by the control.
     *
     * @since 1.16
     * @deprecated As of version 1.16.3. Instead, use "updateFinished" event.
     */
    growingFinished?: (oEvent: ListBase$GrowingFinishedEvent) => void;

    /**
     * Fires before `items` binding is updated (e.g. sorting, filtering)
     *
     * **Note:** Event handler should not invalidate the control.
     *
     * @since 1.16.3
     */
    updateStarted?: (oEvent: ListBase$UpdateStartedEvent) => void;

    /**
     * Fires after `items` binding is updated and processed by the control.
     *
     * @since 1.16.3
     */
    updateFinished?: (oEvent: ListBase$UpdateFinishedEvent) => void;

    /**
     * Fires when an item is pressed unless the item's `type` property is `Inactive`.
     *
     * @since 1.20
     */
    itemPress?: (oEvent: ListBase$ItemPressEvent) => void;

    /**
     * Fired when the context menu is opened. When the context menu is opened, the binding context of the item
     * is set to the given `contextMenu`.
     *
     * @since 1.54
     */
    beforeOpenContextMenu?: (
      oEvent: ListBase$BeforeOpenContextMenuEvent
    ) => void;
  }

  /**
   * Parameters of the ListBase#beforeOpenContextMenu event.
   */
  export interface ListBase$BeforeOpenContextMenuEventParameters {
    /**
     * Item in which the context menu was opened.
     */
    listItem?: ListItemBase;
  }

  /**
   * Event object of the ListBase#beforeOpenContextMenu event.
   */
  export type ListBase$BeforeOpenContextMenuEvent = Event<
    ListBase$BeforeOpenContextMenuEventParameters,
    ListBase
  >;

  /**
   * Parameters of the ListBase#delete event.
   */
  export interface ListBase$DeleteEventParameters {
    /**
     * The item which fired the delete event.
     */
    listItem?: ListItemBase;
  }

  /**
   * Event object of the ListBase#delete event.
   */
  export type ListBase$DeleteEvent = Event<
    ListBase$DeleteEventParameters,
    ListBase
  >;

  /**
   * Parameters of the ListBase#growingFinished event.
   *
   * @deprecated As of version 1.16.3. Instead, use "updateFinished" event.
   */
  export interface ListBase$GrowingFinishedEventParameters {
    /**
     * Actual number of items.
     */
    actual?: int;

    /**
     * Total number of items.
     */
    total?: int;
  }

  /**
   * Event object of the ListBase#growingFinished event.
   *
   * @deprecated As of version 1.16.3. Instead, use "updateFinished" event.
   */
  export type ListBase$GrowingFinishedEvent = Event<
    ListBase$GrowingFinishedEventParameters,
    ListBase
  >;

  /**
   * Parameters of the ListBase#growingStarted event.
   *
   * @deprecated As of version 1.16.3. Instead, use `updateStarted` event with listening `changeReason`.
   */
  export interface ListBase$GrowingStartedEventParameters {
    /**
     * Actual number of items.
     */
    actual?: int;

    /**
     * Total number of items.
     */
    total?: int;
  }

  /**
   * Event object of the ListBase#growingStarted event.
   *
   * @deprecated As of version 1.16.3. Instead, use `updateStarted` event with listening `changeReason`.
   */
  export type ListBase$GrowingStartedEvent = Event<
    ListBase$GrowingStartedEventParameters,
    ListBase
  >;

  /**
   * Parameters of the ListBase#itemPress event.
   */
  export interface ListBase$ItemPressEventParameters {
    /**
     * The item which fired the pressed event.
     */
    listItem?: ListItemBase;

    /**
     * The control which caused the press event within the container.
     */
    srcControl?: Control;
  }

  /**
   * Event object of the ListBase#itemPress event.
   */
  export type ListBase$ItemPressEvent = Event<
    ListBase$ItemPressEventParameters,
    ListBase
  >;

  /**
   * Parameters of the ListBase#select event.
   *
   * @deprecated As of version 1.16. Use the `selectionChange` event instead.
   */
  export interface ListBase$SelectEventParameters {
    /**
     * The item which fired the select event.
     */
    listItem?: ListItemBase;
  }

  /**
   * Event object of the ListBase#select event.
   *
   * @deprecated As of version 1.16. Use the `selectionChange` event instead.
   */
  export type ListBase$SelectEvent = Event<
    ListBase$SelectEventParameters,
    ListBase
  >;

  /**
   * Parameters of the ListBase#selectionChange event.
   */
  export interface ListBase$SelectionChangeEventParameters {
    /**
     * The item whose selection has changed. In `MultiSelect` mode, only the up-most selected item is returned.
     * This parameter can be used for single-selection modes.
     */
    listItem?: ListItemBase;

    /**
     * Array of items whose selection has changed. This parameter can be used for `MultiSelect` mode.
     */
    listItems?: ListItemBase[];

    /**
     * Indicates whether the `listItem` parameter is selected or not.
     */
    selected?: boolean;

    /**
     * Indicates whether the select all action is triggered or not.
     */
    selectAll?: boolean;
  }

  /**
   * Event object of the ListBase#selectionChange event.
   */
  export type ListBase$SelectionChangeEvent = Event<
    ListBase$SelectionChangeEventParameters,
    ListBase
  >;

  /**
   * Parameters of the ListBase#swipe event.
   */
  export interface ListBase$SwipeEventParameters {
    /**
     * The item which fired the swipe.
     */
    listItem?: ListItemBase;

    /**
     * Aggregated `swipeContent` control that is shown on the right hand side of the item.
     */
    swipeContent?: Control;

    /**
     * Holds which control caused the swipe event within the item.
     */
    srcControl?: Control;

    /**
     * Shows in which direction the user swipes and can have the value `BeginToEnd` (left to right in LTR languages
     * and right to left in RTL languages) or `EndToBegin` (right to left in LTR languages and left to right
     * in RTL languages)
     */
    swipeDirection?: SwipeDirection | keyof typeof SwipeDirection;
  }

  /**
   * Event object of the ListBase#swipe event.
   */
  export type ListBase$SwipeEvent = Event<
    ListBase$SwipeEventParameters,
    ListBase
  >;

  /**
   * Parameters of the ListBase#updateFinished event.
   */
  export interface ListBase$UpdateFinishedEventParameters {
    /**
     * The reason of the update, e.g. Binding, Filter, Sort, Growing, Change, Refresh, Context.
     */
    reason?: string;

    /**
     * Actual number of items.
     */
    actual?: int;

    /**
     * The total count of bound items. This can be used if the `growing` property is set to `true`.
     */
    total?: int;
  }

  /**
   * Event object of the ListBase#updateFinished event.
   */
  export type ListBase$UpdateFinishedEvent = Event<
    ListBase$UpdateFinishedEventParameters,
    ListBase
  >;

  /**
   * Parameters of the ListBase#updateStarted event.
   */
  export interface ListBase$UpdateStartedEventParameters {
    /**
     * The reason of the update, e.g. Binding, Filter, Sort, Growing, Change, Refresh, Context.
     */
    reason?: string;

    /**
     * Actual number of items.
     */
    actual?: int;

    /**
     * The total count of bound items. This can be used if the `growing` property is set to `true`.
     */
    total?: int;
  }

  /**
   * Event object of the ListBase#updateStarted event.
   */
  export type ListBase$UpdateStartedEvent = Event<
    ListBase$UpdateStartedEventParameters,
    ListBase
  >;
}

declare module "sap/m/ListItemBase" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { ID } from "sap/ui/core/library";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { ListType } from "sap/m/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * ListItemBase contains the base features of all specific list items. **Note:** If not mentioned otherwise
   * in the individual subclasses, list items must only be used in the `items` aggregation of `sap.m.ListBase`
   * controls.
   */
  export default class ListItemBase extends Control {
    /**
     * Constructor for a new ListItemBase.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ListItemBaseSettings
    );
    /**
     * Constructor for a new ListItemBase.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ListItemBaseSettings
    );

    /**
     * Creates a new subclass of class sap.m.ListItemBase with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ListItemBase>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ListItemBase.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:detailPress detailPress} event of this `sap.m.ListItemBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListItemBase` itself.
     *
     * Fires when the user clicks on the detail button of the control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDetailPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListItemBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:detailPress detailPress} event of this `sap.m.ListItemBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListItemBase` itself.
     *
     * Fires when the user clicks on the detail button of the control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDetailPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListItemBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:detailTap detailTap} event of this `sap.m.ListItemBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListItemBase` itself.
     *
     * Fires when the user taps on the detail button of the control.
     *
     * @deprecated As of version 1.20.0. Instead, use `detailPress` event.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDetailTap(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListItemBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:detailTap detailTap} event of this `sap.m.ListItemBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListItemBase` itself.
     *
     * Fires when the user taps on the detail button of the control.
     *
     * @deprecated As of version 1.20.0. Instead, use `detailPress` event.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDetailTap(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListItemBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.ListItemBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListItemBase` itself.
     *
     * Fires when the user clicks on the control. **Note:** This event is not fired when the parent `mode` is
     * `SingleSelectMaster` or when the `includeItemInSelection` property is set to `true`. If there is an interactive
     * element that handles its own `press` event then the list item's `press` event is not fired. Also see
     * {@link sap.m.ListBase#attachItemPress}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListItemBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.ListItemBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListItemBase` itself.
     *
     * Fires when the user clicks on the control. **Note:** This event is not fired when the parent `mode` is
     * `SingleSelectMaster` or when the `includeItemInSelection` property is set to `true`. If there is an interactive
     * element that handles its own `press` event then the list item's `press` event is not fired. Also see
     * {@link sap.m.ListBase#attachItemPress}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListItemBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tap tap} event of this `sap.m.ListItemBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListItemBase` itself.
     *
     * Fires when the user taps on the control.
     *
     * @deprecated As of version 1.20.0. Instead, use `press` event.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTap(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListItemBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tap tap} event of this `sap.m.ListItemBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ListItemBase` itself.
     *
     * Fires when the user taps on the control.
     *
     * @deprecated As of version 1.20.0. Instead, use `press` event.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTap(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ListItemBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:detailPress detailPress} event of this `sap.m.ListItemBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachDetailPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:detailTap detailTap} event of this `sap.m.ListItemBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @deprecated As of version 1.20.0. Instead, use `detailPress` event.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachDetailTap(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.ListItemBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:tap tap} event of this `sap.m.ListItemBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @deprecated As of version 1.20.0. Instead, use `press` event.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachTap(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:detailPress detailPress} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireDetailPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:detailTap detailTap} to attached listeners.
     *
     * @deprecated As of version 1.20.0. Instead, use `detailPress` event.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireDetailTap(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:tap tap} to attached listeners.
     *
     * @deprecated As of version 1.20.0. Instead, use `press` event.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireTap(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.28.0
     */
    getAriaLabelledBy(): ID[];
    /**
     * Returns the accessibility announcement for the content.
     *
     * Hook for the subclasses.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    getContentAnnouncement(): string;
    /**
     * Gets current value of property {@link #getCounter counter}.
     *
     * Defines the counter value of the list items.
     *
     *
     * @returns Value of property `counter`
     */
    getCounter(): int;
    /**
     * Gets current value of property {@link #getHighlight highlight}.
     *
     * Defines the highlight state of the list items.
     *
     * Valid values for the `highlight` property are values of the enumerations {@link module:sap/ui/core/message/MessageType }
     * or {@link sap.ui.core.IndicationColor} (only values of `Indication01` to `Indication10` are supported
     * for accessibility contrast reasons).
     *
     * Accessibility support is provided through the associated {@link sap.m.ListItemBase#setHighlightText highlightText }
     * property. If the `highlight` property is set to a value of {@link module:sap/ui/core/message/MessageType},
     * the `highlightText` property does not need to be set because a default text is used. However, the default
     * text can be overridden by setting the `highlightText` property. In all other cases the `highlightText`
     * property must be set.
     *
     * Default value is `"None"`.
     *
     * @since 1.44.0
     *
     * @returns Value of property `highlight`
     */
    getHighlight(): string;
    /**
     * Gets current value of property {@link #getHighlightText highlightText}.
     *
     * Defines the semantics of the {@link sap.m.ListItemBase#setHighlight highlight} property for accessibility
     * purposes.
     *
     * Default value is `empty string`.
     *
     * @since 1.62
     *
     * @returns Value of property `highlightText`
     */
    getHighlightText(): string;
    /**
     * Gets current value of property {@link #getNavigated navigated}.
     *
     * The navigated state of the list item.
     *
     * If set to `true`, a navigation indicator is displayed at the end of the list item. **Note:** This property
     * must be set for **one** list item only.
     *
     * Default value is `false`.
     *
     * @since 1.72
     *
     * @returns Value of property `navigated`
     */
    getNavigated(): boolean;
    /**
     * Gets current value of property {@link #getSelected selected}.
     *
     * Defines the selected state of the list items. **Note:** Binding the `selected` property in single selection
     * modes may cause unwanted results if you have more than one selected items in your binding.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `selected`
     */
    getSelected(): boolean;
    /**
     * Returns the tabbable DOM elements as a jQuery collection
     *
     * @since 1.26
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns jQuery object
     */
    getTabbables(
      /**
       * Whether only tabbables of the content area
       */
      bContentOnly?: undefined
    ): jQuery;
    /**
     * Gets current value of property {@link #getType type}.
     *
     * Defines the visual indication and behavior of the list items, e.g. `Active`, `Navigation`, `Detail`.
     *
     * Default value is `Inactive`.
     *
     *
     * @returns Value of property `type`
     */
    getType(): ListType;
    /**
     * Gets current value of property {@link #getUnread unread}.
     *
     * Activates the unread indicator for the list item, if set to `true`. **Note:** This flag is ignored when
     * the `showUnread` property of the parent is set to `false`.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `unread`
     */
    getUnread(): boolean;
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * Whether the control should be visible on the screen. If set to false, a placeholder is rendered instead
     * of the real control.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Returns the state of the item selection as a boolean
     *
     * @deprecated As of version 1.10.2. API Change makes this method unnecessary. Use the {@link #getSelected }
     * method instead.
     */
    isSelected(): boolean;
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.28.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.28.0
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getCounter counter}.
     *
     * Defines the counter value of the list items.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCounter(
      /**
       * New value for property `counter`
       */
      iCounter?: int
    ): this;
    /**
     * Sets a new value for property {@link #getHighlight highlight}.
     *
     * Defines the highlight state of the list items.
     *
     * Valid values for the `highlight` property are values of the enumerations {@link module:sap/ui/core/message/MessageType }
     * or {@link sap.ui.core.IndicationColor} (only values of `Indication01` to `Indication10` are supported
     * for accessibility contrast reasons).
     *
     * Accessibility support is provided through the associated {@link sap.m.ListItemBase#setHighlightText highlightText }
     * property. If the `highlight` property is set to a value of {@link module:sap/ui/core/message/MessageType},
     * the `highlightText` property does not need to be set because a default text is used. However, the default
     * text can be overridden by setting the `highlightText` property. In all other cases the `highlightText`
     * property must be set.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"None"`.
     *
     * @since 1.44.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHighlight(
      /**
       * New value for property `highlight`
       */
      sHighlight?: string
    ): this;
    /**
     * Sets a new value for property {@link #getHighlightText highlightText}.
     *
     * Defines the semantics of the {@link sap.m.ListItemBase#setHighlight highlight} property for accessibility
     * purposes.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.62
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHighlightText(
      /**
       * New value for property `highlightText`
       */
      sHighlightText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getNavigated navigated}.
     *
     * The navigated state of the list item.
     *
     * If set to `true`, a navigation indicator is displayed at the end of the list item. **Note:** This property
     * must be set for **one** list item only.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.72
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNavigated(
      /**
       * New value for property `navigated`
       */
      bNavigated?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getSelected selected}.
     *
     * Defines the selected state of the list items. **Note:** Binding the `selected` property in single selection
     * modes may cause unwanted results if you have more than one selected items in your binding.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSelected(
      /**
       * New value for property `selected`
       */
      bSelected?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getType type}.
     *
     * Defines the visual indication and behavior of the list items, e.g. `Active`, `Navigation`, `Detail`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inactive`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setType(
      /**
       * New value for property `type`
       */
      sType?: ListType | keyof typeof ListType
    ): this;
    /**
     * Sets a new value for property {@link #getUnread unread}.
     *
     * Activates the unread indicator for the list item, if set to `true`. **Note:** This flag is ignored when
     * the `showUnread` property of the parent is set to `false`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUnread(
      /**
       * New value for property `unread`
       */
      bUnread?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * Whether the control should be visible on the screen. If set to false, a placeholder is rendered instead
     * of the real control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ListItemBase constructor.
   */
  export interface $ListItemBaseSettings extends $ControlSettings {
    /**
     * Defines the visual indication and behavior of the list items, e.g. `Active`, `Navigation`, `Detail`.
     */
    type?:
      | (ListType | keyof typeof ListType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Whether the control should be visible on the screen. If set to false, a placeholder is rendered instead
     * of the real control.
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Activates the unread indicator for the list item, if set to `true`. **Note:** This flag is ignored when
     * the `showUnread` property of the parent is set to `false`.
     */
    unread?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the selected state of the list items. **Note:** Binding the `selected` property in single selection
     * modes may cause unwanted results if you have more than one selected items in your binding.
     */
    selected?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the counter value of the list items.
     */
    counter?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the highlight state of the list items.
     *
     * Valid values for the `highlight` property are values of the enumerations {@link module:sap/ui/core/message/MessageType }
     * or {@link sap.ui.core.IndicationColor} (only values of `Indication01` to `Indication10` are supported
     * for accessibility contrast reasons).
     *
     * Accessibility support is provided through the associated {@link sap.m.ListItemBase#setHighlightText highlightText }
     * property. If the `highlight` property is set to a value of {@link module:sap/ui/core/message/MessageType},
     * the `highlightText` property does not need to be set because a default text is used. However, the default
     * text can be overridden by setting the `highlightText` property. In all other cases the `highlightText`
     * property must be set.
     *
     * @since 1.44.0
     */
    highlight?: string | PropertyBindingInfo;

    /**
     * Defines the semantics of the {@link sap.m.ListItemBase#setHighlight highlight} property for accessibility
     * purposes.
     *
     * @since 1.62
     */
    highlightText?: string | PropertyBindingInfo;

    /**
     * The navigated state of the list item.
     *
     * If set to `true`, a navigation indicator is displayed at the end of the list item. **Note:** This property
     * must be set for **one** list item only.
     *
     * @since 1.72
     */
    navigated?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledby).
     *
     * @since 1.28.0
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Fires when the user taps on the control.
     *
     * @deprecated As of version 1.20.0. Instead, use `press` event.
     */
    tap?: (oEvent: Event) => void;

    /**
     * Fires when the user taps on the detail button of the control.
     *
     * @deprecated As of version 1.20.0. Instead, use `detailPress` event.
     */
    detailTap?: (oEvent: Event) => void;

    /**
     * Fires when the user clicks on the control. **Note:** This event is not fired when the parent `mode` is
     * `SingleSelectMaster` or when the `includeItemInSelection` property is set to `true`. If there is an interactive
     * element that handles its own `press` event then the list item's `press` event is not fired. Also see
     * {@link sap.m.ListBase#attachItemPress}.
     */
    press?: (oEvent: Event) => void;

    /**
     * Fires when the user clicks on the detail button of the control.
     */
    detailPress?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the ListItemBase#detailPress event.
   */
  export interface ListItemBase$DetailPressEventParameters {}

  /**
   * Event object of the ListItemBase#detailPress event.
   */
  export type ListItemBase$DetailPressEvent = Event<
    ListItemBase$DetailPressEventParameters,
    ListItemBase
  >;

  /**
   * Parameters of the ListItemBase#detailTap event.
   *
   * @deprecated As of version 1.20.0. Instead, use `detailPress` event.
   */
  export interface ListItemBase$DetailTapEventParameters {}

  /**
   * Event object of the ListItemBase#detailTap event.
   *
   * @deprecated As of version 1.20.0. Instead, use `detailPress` event.
   */
  export type ListItemBase$DetailTapEvent = Event<
    ListItemBase$DetailTapEventParameters,
    ListItemBase
  >;

  /**
   * Parameters of the ListItemBase#press event.
   */
  export interface ListItemBase$PressEventParameters {}

  /**
   * Event object of the ListItemBase#press event.
   */
  export type ListItemBase$PressEvent = Event<
    ListItemBase$PressEventParameters,
    ListItemBase
  >;

  /**
   * Parameters of the ListItemBase#tap event.
   *
   * @deprecated As of version 1.20.0. Instead, use `press` event.
   */
  export interface ListItemBase$TapEventParameters {}

  /**
   * Event object of the ListItemBase#tap event.
   *
   * @deprecated As of version 1.20.0. Instead, use `press` event.
   */
  export type ListItemBase$TapEvent = Event<
    ListItemBase$TapEventParameters,
    ListItemBase
  >;
}

declare module "sap/m/MaskInput" {
  import { default as InputBase, $InputBaseSettings } from "sap/m/InputBase";

  import MaskInputRule from "sap/m/MaskInputRule";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * The `sap.m.MaskInput` control allows users to easily enter data in a certain format and in a fixed-width
   * input (for example: date, time, phone number, credit card number, currency, IP address, MAC address,
   * and others).
   *
   * When focused, the masked input field is formatted and prefilled. The `placeholderSymbol` property value
   * is reserved for a placeholder. The value that has to be entered in this field is in the `mask` property
   * value format where every symbol corresponds to a rule. A rule is a set of characters that are allowed
   * for their particular position. Symbols that do not have a rule are immutable characters and are part
   * of the value formatting.
   *
   *  Descriptive text as `placeholder` property value should be added, in order guide users what
   * input is expected based on the particular control configuration.
   *
   * @since 1.34.0
   */
  export default class MaskInput extends InputBase {
    /**
     * Constructor for a new MaskInput.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/generic-mask-input/ Mask Input}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $MaskInputSettings
    );
    /**
     * Constructor for a new MaskInput.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/generic-mask-input/ Mask Input}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $MaskInputSettings
    );

    /**
     * Creates a new subclass of class sap.m.MaskInput with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.InputBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, MaskInput>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.MaskInput.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some rule to the aggregation {@link #getRules rules}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addRule(
      /**
       * The rule to add; if empty, nothing is inserted
       */
      oRule: MaskInputRule
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.MaskInput`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MaskInput` itself.
     *
     * Fired when the value of the `MaskInput` is changed by user interaction - each keystroke, delete, paste,
     * etc.
     *
     * **Note:** Browsing autocomplete suggestions doesn't fire the event.
     *
     * @since 1.104.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MaskInput$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MaskInput` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.MaskInput`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MaskInput` itself.
     *
     * Fired when the value of the `MaskInput` is changed by user interaction - each keystroke, delete, paste,
     * etc.
     *
     * **Note:** Browsing autocomplete suggestions doesn't fire the event.
     *
     * @since 1.104.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MaskInput$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MaskInput` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:submit submit} event of this `sap.m.MaskInput`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MaskInput` itself.
     *
     * This event is fired when user presses the Enter key on the Mask input.
     *
     * **Notes:**
     * 	 - The event is fired independent of whether there was a change before or not. If a change was performed,
     *     the event is fired after the change event.
     * 	 - The event is only fired on an input which allows text input (`editable` and `enabled`).
     *
     * @since 1.131.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSubmit(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MaskInput$SubmitEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MaskInput` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:submit submit} event of this `sap.m.MaskInput`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MaskInput` itself.
     *
     * This event is fired when user presses the Enter key on the Mask input.
     *
     * **Notes:**
     * 	 - The event is fired independent of whether there was a change before or not. If a change was performed,
     *     the event is fired after the change event.
     * 	 - The event is only fired on an input which allows text input (`editable` and `enabled`).
     *
     * @since 1.131.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSubmit(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MaskInput$SubmitEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MaskInput` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the rules in the aggregation {@link #getRules rules}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyRules(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:liveChange liveChange} event of this `sap.m.MaskInput`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.104.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLiveChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MaskInput$LiveChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:submit submit} event of this `sap.m.MaskInput`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.131.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSubmit(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MaskInput$SubmitEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:liveChange liveChange} to attached listeners.
     *
     * @since 1.104.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLiveChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MaskInput$LiveChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:submit submit} to attached listeners.
     *
     * @since 1.131.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSubmit(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MaskInput$SubmitEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getMask mask}.
     *
     * Mask defined by its characters type (respectively, by its length). You should consider the following
     * important facts: 1. The mask characters normally correspond to an existing rule (one rule per unique
     * char). Characters which don't, are considered immutable characters (for example, the mask '2099', where
     * '9' corresponds to a rule for digits, has the characters '2' and '0' as immutable). 2. Adding a rule
     * corresponding to the `placeholderSymbol` is not recommended and would lead to an unpredictable behavior.
     * 3. You can use the special escape character '^' called "Caret" prepending a rule character to make it
     * immutable. Use the double escape '^^' if you want to make use of the escape character as an immutable
     * one.
     *
     *
     * @returns Value of property `mask`
     */
    getMask(): string;
    /**
     * Gets current value of property {@link #getPlaceholderSymbol placeholderSymbol}.
     *
     * Defines a placeholder symbol. Shown at the position where there is no user input yet.
     *
     * Default value is `"_"`.
     *
     *
     * @returns Value of property `placeholderSymbol`
     */
    getPlaceholderSymbol(): string;
    /**
     * Gets content of aggregation {@link #getRules rules}.
     *
     * A list of validation rules (one rule per mask character).
     */
    getRules(): MaskInputRule[];
    /**
     * Gets current value of property {@link #getShowClearIcon showClearIcon}.
     *
     * Specifies whether a clear icon is shown. Pressing the icon will clear input's value and fire the change
     * event.
     *
     * Default value is `false`.
     *
     * @since 1.96
     *
     * @returns Value of property `showClearIcon`
     */
    getShowClearIcon(): boolean;
    /**
     * Checks for the provided `sap.m.MaskInputRule` in the aggregation {@link #getRules rules}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfRule(
      /**
       * The rule whose index is looked for
       */
      oRule: MaskInputRule
    ): int;
    /**
     * Inserts a rule into the aggregation {@link #getRules rules}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertRule(
      /**
       * The rule to insert; if empty, nothing is inserted
       */
      oRule: MaskInputRule,
      /**
       * The `0`-based index the rule should be inserted at; for a negative value of `iIndex`, the rule is inserted
       * at position 0; for a value greater than the current size of the aggregation, the rule is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getRules rules}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllRules(): MaskInputRule[];
    /**
     * Removes a rule from the aggregation {@link #getRules rules}.
     *
     *
     * @returns The removed rule or `null`
     */
    removeRule(
      /**
       * The rule to remove or its index or id
       */
      vRule: int | string | MaskInputRule
    ): MaskInputRule | null;
    /**
     * Sets a new value for property {@link #getMask mask}.
     *
     * Mask defined by its characters type (respectively, by its length). You should consider the following
     * important facts: 1. The mask characters normally correspond to an existing rule (one rule per unique
     * char). Characters which don't, are considered immutable characters (for example, the mask '2099', where
     * '9' corresponds to a rule for digits, has the characters '2' and '0' as immutable). 2. Adding a rule
     * corresponding to the `placeholderSymbol` is not recommended and would lead to an unpredictable behavior.
     * 3. You can use the special escape character '^' called "Caret" prepending a rule character to make it
     * immutable. Use the double escape '^^' if you want to make use of the escape character as an immutable
     * one.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMask(
      /**
       * New value for property `mask`
       */
      sMask?: string
    ): this;
    /**
     * Sets a new value for property {@link #getPlaceholderSymbol placeholderSymbol}.
     *
     * Defines a placeholder symbol. Shown at the position where there is no user input yet.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"_"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPlaceholderSymbol(
      /**
       * New value for property `placeholderSymbol`
       */
      sPlaceholderSymbol?: string
    ): this;
    /**
     * Sets a new value for property {@link #getShowClearIcon showClearIcon}.
     *
     * Specifies whether a clear icon is shown. Pressing the icon will clear input's value and fire the change
     * event.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.96
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowClearIcon(
      /**
       * New value for property `showClearIcon`
       */
      bShowClearIcon?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the MaskInput constructor.
   */
  export interface $MaskInputSettings extends $InputBaseSettings {
    /**
     * Defines a placeholder symbol. Shown at the position where there is no user input yet.
     */
    placeholderSymbol?: string | PropertyBindingInfo;

    /**
     * Mask defined by its characters type (respectively, by its length). You should consider the following
     * important facts: 1. The mask characters normally correspond to an existing rule (one rule per unique
     * char). Characters which don't, are considered immutable characters (for example, the mask '2099', where
     * '9' corresponds to a rule for digits, has the characters '2' and '0' as immutable). 2. Adding a rule
     * corresponding to the `placeholderSymbol` is not recommended and would lead to an unpredictable behavior.
     * 3. You can use the special escape character '^' called "Caret" prepending a rule character to make it
     * immutable. Use the double escape '^^' if you want to make use of the escape character as an immutable
     * one.
     */
    mask?: string | PropertyBindingInfo;

    /**
     * Specifies whether a clear icon is shown. Pressing the icon will clear input's value and fire the change
     * event.
     *
     * @since 1.96
     */
    showClearIcon?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * A list of validation rules (one rule per mask character).
     */
    rules?:
      | MaskInputRule[]
      | MaskInputRule
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Fired when the value of the `MaskInput` is changed by user interaction - each keystroke, delete, paste,
     * etc.
     *
     * **Note:** Browsing autocomplete suggestions doesn't fire the event.
     *
     * @since 1.104.0
     */
    liveChange?: (oEvent: MaskInput$LiveChangeEvent) => void;

    /**
     * This event is fired when user presses the Enter key on the Mask input.
     *
     * **Notes:**
     * 	 - The event is fired independent of whether there was a change before or not. If a change was performed,
     *     the event is fired after the change event.
     * 	 - The event is only fired on an input which allows text input (`editable` and `enabled`).
     *
     * @since 1.131.0
     */
    submit?: (oEvent: MaskInput$SubmitEvent) => void;
  }

  /**
   * Parameters of the MaskInput#liveChange event.
   */
  export interface MaskInput$LiveChangeEventParameters {
    /**
     * The current value of the input, after a live change event.
     */
    value?: string;

    /**
     * The previous value of the input, before the last user interaction.
     */
    previousValue?: string;
  }

  /**
   * Event object of the MaskInput#liveChange event.
   */
  export type MaskInput$LiveChangeEvent = Event<
    MaskInput$LiveChangeEventParameters,
    MaskInput
  >;

  /**
   * Parameters of the MaskInput#submit event.
   */
  export interface MaskInput$SubmitEventParameters {
    /**
     * The new value of the Mask input.
     */
    value?: string;
  }

  /**
   * Event object of the MaskInput#submit event.
   */
  export type MaskInput$SubmitEvent = Event<
    MaskInput$SubmitEventParameters,
    MaskInput
  >;
}

declare module "sap/m/MaskInputRule" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The `sap.m.MaskInputRule` control holds the mapping of a single `maskFormatSymbol` to the regular expression
   * `regex` that defines the allowed characters for the rule.
   *
   * @since 1.34.0
   */
  export default class MaskInputRule extends UI5Element {
    /**
     * Constructor for a new MaskInputRule.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $MaskInputRuleSettings
    );
    /**
     * Constructor for a new MaskInputRule.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $MaskInputRuleSettings
    );

    /**
     * Creates a new subclass of class sap.m.MaskInputRule with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, MaskInputRule>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.MaskInputRule.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getMaskFormatSymbol maskFormatSymbol}.
     *
     * Defines the symbol used in the mask format which will accept a certain range of characters.
     *
     * Default value is `"*"`.
     *
     *
     * @returns Value of property `maskFormatSymbol`
     */
    getMaskFormatSymbol(): string;
    /**
     * Gets current value of property {@link #getRegex regex}.
     *
     * Defines the allowed characters as a regular expression.
     *
     * Default value is `"[a-zA-Z0-9]"`.
     *
     *
     * @returns Value of property `regex`
     */
    getRegex(): string;
    /**
     * Sets a new value for property {@link #getMaskFormatSymbol maskFormatSymbol}.
     *
     * Defines the symbol used in the mask format which will accept a certain range of characters.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"*"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaskFormatSymbol(
      /**
       * New value for property `maskFormatSymbol`
       */
      sMaskFormatSymbol?: string
    ): this;
    /**
     * Sets a new value for property {@link #getRegex regex}.
     *
     * Defines the allowed characters as a regular expression.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"[a-zA-Z0-9]"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRegex(
      /**
       * New value for property `regex`
       */
      sRegex?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the MaskInputRule constructor.
   */
  export interface $MaskInputRuleSettings extends $ElementSettings {
    /**
     * Defines the symbol used in the mask format which will accept a certain range of characters.
     */
    maskFormatSymbol?: string | PropertyBindingInfo;

    /**
     * Defines the allowed characters as a regular expression.
     */
    regex?: string | PropertyBindingInfo;
  }
}

declare module "sap/m/Menu" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { IContextMenu } from "sap/ui/core/library";

  import { IMenuItem } from "sap/m/library";

  import Event from "sap/ui/base/Event";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import UI5Element from "sap/ui/core/Element";

  import Popup from "sap/ui/core/Popup";

  import MenuItem from "sap/m/MenuItem";

  /**
   * The `sap.m.Menu` control represents a hierarchical menu. When opened on mobile devices it occupies the
   * whole screen.
   *
   * **Note:** The application developer should add dependency to `sap.ui.unified` library on application
   * level to ensure that the library is loaded before the module dependencies will be required. If the `sap.ui.unified`
   * library is not loaded in advance, this could lead to CSP compliance issues and adds an additional waiting
   * time. To prevent this, ensure that the `sap.ui.unified` library is loaded in advance.
   */
  export default class Menu extends Control implements IContextMenu {
    __implements__sap_ui_core_IContextMenu: boolean;
    /**
     * Constructor for a new Menu.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $MenuSettings
    );
    /**
     * Constructor for a new Menu.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $MenuSettings
    );

    /**
     * Creates a new subclass of class sap.m.Menu with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Menu>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Menu.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: IMenuItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.Menu`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Menu` itself.
     *
     * Fired before the menu is closed. This event can be prevented which effectively prevents the menu from
     * closing.
     *
     * @since 1.131
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Menu` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.Menu`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Menu` itself.
     *
     * Fired before the menu is closed. This event can be prevented which effectively prevents the menu from
     * closing.
     *
     * @since 1.131
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Menu` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:closed closed} event of this `sap.m.Menu`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Menu` itself.
     *
     * Fired when the menu is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachClosed(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Menu` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:closed closed} event of this `sap.m.Menu`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Menu` itself.
     *
     * Fired when the menu is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachClosed(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Menu` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemSelected itemSelected} event of this `sap.m.Menu`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Menu` itself.
     *
     * Fired when a `MenuItem` is selected.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemSelected(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Menu$ItemSelectedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Menu` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemSelected itemSelected} event of this `sap.m.Menu`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Menu` itself.
     *
     * Fired when a `MenuItem` is selected.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemSelected(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Menu$ItemSelectedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Menu` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getItems items} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Closes the `Menu`.
     */
    close(): void;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeClose beforeClose} event of this `sap.m.Menu`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.131
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:closed closed} event of this `sap.m.Menu`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachClosed(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:itemSelected itemSelected} event of this `sap.m.Menu`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachItemSelected(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Menu$ItemSelectedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:beforeClose beforeClose} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @since 1.131
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireBeforeClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): boolean;
    /**
     * Fires event {@link #event:closed closed} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireClosed(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:itemSelected itemSelected} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireItemSelected(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Menu$ItemSelectedEventParameters
    ): this;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * Defines the items contained within this control.
     */
    getItems(): IMenuItem[];
    /**
     * Returns an array containing the selected menu items. **Note:** Only items with `selected` property set
     * that are members of `MenuItemGroup` with `ItemSelectionMode` property set to {@link sap.ui.core.ItemSelectionMode.SingleSelect }
     * or {@link sap.ui.unified.ItemSelectionMode.MultiSelect}> are taken into account.
     *
     * @since 1.127.0
     *
     * @returns Array of all selected items
     */
    getSelectedItems(): any[];
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Defines the `Menu` title.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Checks for the provided `sap.m.IMenuItem` in the aggregation {@link #getItems items}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: IMenuItem
    ): int;
    /**
     * Initializes the control.
     */
    init(): void;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: IMenuItem,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Returns whether the `Menu` is currently open.
     *
     *
     * @returns true if menu is open
     */
    isOpen(): boolean;
    /**
     * Opens the menu as a context menu.
     */
    openAsContextMenu(
      /**
       * The event object or an object containing offsetX, offsetY values and left, top values of the element's
       * position
       */
      oEvent: jQuery.Event | object,
      /**
       * The reference of the opener
       */
      oOpenerRef: UI5Element | HTMLElement
    ): void;
    /**
     * Opens the `Menu` next to the given control.
     */
    openBy(
      /**
       * The control that defines the position for the menu
       */
      oControl: Control,
      /**
       * Whether the menu is opened with a shortcut or not
       */
      bWithKeyboard: boolean,
      /**
       * The reference docking location of the `Menu` for positioning the menu on the screen
       */
      sDockMy?: typeof Popup.Dock | keyof typeof Popup.Dock,
      /**
       * The `oControl` reference docking location for positioning the menu on the screen
       */
      sDockAt?: typeof Popup.Dock | keyof typeof Popup.Dock,
      /**
       * The offset relative to the docking point, specified as a string with space-separated pixel values (e.g.
       * "0 10" to move the popup 10 pixels to the right). If the docking of both "my" and "at" is RTL-sensitive
       * ("begin" or "end"), this offset is automatically mirrored in the RTL case as well.
       */
      sOffset?: string
    ): void;
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): IMenuItem[];
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | IMenuItem
    ): IMenuItem | null;
    /**
     * Sets the title of the `Menu`.
     *
     *
     * @returns `this` to allow method chaining
     */
    setTitle(
      /**
       * The new title of the `Menu`
       */
      sTitle: string
    ): this;
    /**
     * Unbinds aggregation {@link #getItems items} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindItems(): this;
  }
  /**
   * Describes the settings that can be provided to the Menu constructor.
   */
  export interface $MenuSettings extends $ControlSettings {
    /**
     * Defines the `Menu` title.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Defines the items contained within this control.
     */
    items?: IMenuItem[] | IMenuItem | AggregationBindingInfo | `{${string}}`;

    /**
     * Fired when a `MenuItem` is selected.
     */
    itemSelected?: (oEvent: Menu$ItemSelectedEvent) => void;

    /**
     * Fired when the menu is closed.
     */
    closed?: (oEvent: Event) => void;

    /**
     * Fired before the menu is closed. This event can be prevented which effectively prevents the menu from
     * closing.
     *
     * @since 1.131
     */
    beforeClose?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the Menu#beforeClose event.
   */
  export interface Menu$BeforeCloseEventParameters {}

  /**
   * Event object of the Menu#beforeClose event.
   */
  export type Menu$BeforeCloseEvent = Event<
    Menu$BeforeCloseEventParameters,
    Menu
  >;

  /**
   * Parameters of the Menu#closed event.
   */
  export interface Menu$ClosedEventParameters {}

  /**
   * Event object of the Menu#closed event.
   */
  export type Menu$ClosedEvent = Event<Menu$ClosedEventParameters, Menu>;

  /**
   * Parameters of the Menu#itemSelected event.
   */
  export interface Menu$ItemSelectedEventParameters {
    /**
     * The `MenuItem` which was selected.
     */
    item?: MenuItem;
  }

  /**
   * Event object of the Menu#itemSelected event.
   */
  export type Menu$ItemSelectedEvent = Event<
    Menu$ItemSelectedEventParameters,
    Menu
  >;
}

declare module "sap/m/MenuButton" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IToolbarInteractiveControl,
    MenuButtonMode,
    ButtonType,
  } from "sap/m/library";

  import { ID, URI, TextDirection, CSSSize } from "sap/ui/core/library";

  import Event from "sap/ui/base/Event";

  import Menu from "sap/m/Menu";

  import Popup from "sap/ui/core/Popup";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import TooltipBase from "sap/ui/core/TooltipBase";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The `sap.m.MenuButton` control enables the user to show a hierarchical menu.
   */
  export default class MenuButton
    extends Control
    implements IToolbarInteractiveControl
  {
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new MenuButton.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/menu-button/ Menu Button}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $MenuButtonSettings
    );
    /**
     * Constructor for a new MenuButton.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/menu-button/ Menu Button}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $MenuButtonSettings
    );

    /**
     * Creates a new subclass of class sap.m.MenuButton with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, MenuButton>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.MenuButton.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeMenuOpen beforeMenuOpen} event of this
     * `sap.m.MenuButton`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MenuButton` itself.
     *
     * In `Regular` button mode – fires when the user presses the button. Alternatively, if the `buttonMode`
     * is set to `Split` - fires when the user presses the arrow button.
     *
     * @since 1.94.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeMenuOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MenuButton` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeMenuOpen beforeMenuOpen} event of this
     * `sap.m.MenuButton`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MenuButton` itself.
     *
     * In `Regular` button mode – fires when the user presses the button. Alternatively, if the `buttonMode`
     * is set to `Split` - fires when the user presses the arrow button.
     *
     * @since 1.94.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeMenuOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MenuButton` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:defaultAction defaultAction} event of this `sap.m.MenuButton`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MenuButton` itself.
     *
     * Fired when the `buttonMode` is set to `Split` and the user presses the main button unless `useDefaultActionOnly`
     * is set to `false` and another action from the menu has been selected previously.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDefaultAction(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MenuButton` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:defaultAction defaultAction} event of this `sap.m.MenuButton`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MenuButton` itself.
     *
     * Fired when the `buttonMode` is set to `Split` and the user presses the main button unless `useDefaultActionOnly`
     * is set to `false` and another action from the menu has been selected previously.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDefaultAction(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MenuButton` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys the menu in the aggregation {@link #getMenu menu}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyMenu(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeMenuOpen beforeMenuOpen} event of this
     * `sap.m.MenuButton`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.94.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeMenuOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:defaultAction defaultAction} event of this
     * `sap.m.MenuButton`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachDefaultAction(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:beforeMenuOpen beforeMenuOpen} to attached listeners.
     *
     * @since 1.94.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforeMenuOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:defaultAction defaultAction} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireDefaultAction(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getActiveIcon activeIcon}.
     *
     * The source property of an alternative icon for the active (pressed) state of the button. Both active
     * and default icon properties should be defined and of the same type - image or icon font. If the `icon`
     * property is not set or has a different type, the active icon is not displayed.
     *
     *
     * @returns Value of property `activeIcon`
     */
    getActiveIcon(): URI;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getButtonMode buttonMode}.
     *
     * Defines whether the `MenuButton` is set to `Regular` or `Split` mode.
     *
     * Default value is `Regular`.
     *
     *
     * @returns Value of property `buttonMode`
     */
    getButtonMode(): MenuButtonMode;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Boolean property to enable the control (default is `true`).
     * **Note:** Depending on custom settings, the buttons that are disabled have other colors than the enabled
     * ones.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Defines the icon to be displayed as a graphical element within the button. It can be an image or an icon
     * from the icon font.
     *
     * Note: If only an icon (without text) is provided when `buttonMode` is set to `Split`, please provide
     * icons for all menu items. Otherwise the action button will be displayed with no icon or text after item
     * selection since there is not enough space for a text.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getIconDensityAware iconDensityAware}.
     *
     * When set to `true` (default), one or more requests are sent trying to get the density perfect version
     * of image if this version of image doesn't exist on the server. If only one version of image is provided,
     * set this value to `false` to avoid the attempt of fetching density perfect image.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `iconDensityAware`
     */
    getIconDensityAware(): boolean;
    /**
     * Returns the DOMNode Id to be used for the "labelFor" attribute of the label.
     *
     * By default, this is the Id of the control itself.
     *
     *
     * @returns Id to be used for the `labelFor`
     */
    getIdForLabel(): string;
    /**
     * Gets content of aggregation {@link #getMenu menu}.
     *
     * Defines the menu that opens for this button.
     */
    getMenu(): Menu;
    /**
     * Gets current value of property {@link #getMenuPosition menuPosition}.
     *
     * Specifies the position of the popup menu with enumerated options. By default, the control opens the menu
     * at its bottom left side.
     *
     * **Note:** In the case that the menu has no space to show itself in the view port of the current window
     * it tries to open itself to the inverted direction.
     *
     * Default value is `BeginBottom`.
     *
     * @since 1.56.0
     *
     * @returns Value of property `menuPosition`
     */
    getMenuPosition(): typeof Popup.Dock;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Defines the text of the `MenuButton`.
     * **Note:** In `Split` `buttonMode` with `useDefaultActionOnly` set to `false`, the text is changed to
     * display the last selected item's text, while in `Regular` `buttonMode` the text stays unchanged.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * Specifies the element's text directionality with enumerated options. By default, the control inherits
     * text direction from the DOM.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getType type}.
     *
     * Defines the type of the `MenuButton` (for example, Default, Accept, Reject, Back, etc.)
     *
     * **Note:** Not all existing types are valid for the control. See {@link sap.m.ButtonType} documentation.
     *
     * Default value is `Default`.
     *
     *
     * @returns Value of property `type`
     */
    getType(): ButtonType;
    /**
     * Gets current value of property {@link #getUseDefaultActionOnly useDefaultActionOnly}.
     *
     * Controls whether the default action handler is invoked always or it is invoked only until a menu item
     * is selected. Usable only if `buttonMode` is set to `Split`.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `useDefaultActionOnly`
     */
    getUseDefaultActionOnly(): boolean;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Defines the width of the `MenuButton`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Initializes the control.
     */
    init(): void;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getActiveIcon activeIcon}.
     *
     * The source property of an alternative icon for the active (pressed) state of the button. Both active
     * and default icon properties should be defined and of the same type - image or icon font. If the `icon`
     * property is not set or has a different type, the active icon is not displayed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setActiveIcon(
      /**
       * New value for property `activeIcon`
       */
      sActiveIcon?: URI
    ): this;
    /**
     * Sets the `buttonMode` of the control.
     *
     *
     * @returns This instance
     */
    setButtonMode(
      /**
       * The new button mode
       */
      sMode: MenuButtonMode | keyof typeof MenuButtonMode
    ): this;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Boolean property to enable the control (default is `true`).
     * **Note:** Depending on custom settings, the buttons that are disabled have other colors than the enabled
     * ones.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Defines the icon to be displayed as a graphical element within the button. It can be an image or an icon
     * from the icon font.
     *
     * Note: If only an icon (without text) is provided when `buttonMode` is set to `Split`, please provide
     * icons for all menu items. Otherwise the action button will be displayed with no icon or text after item
     * selection since there is not enough space for a text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getIconDensityAware iconDensityAware}.
     *
     * When set to `true` (default), one or more requests are sent trying to get the density perfect version
     * of image if this version of image doesn't exist on the server. If only one version of image is provided,
     * set this value to `false` to avoid the attempt of fetching density perfect image.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconDensityAware(
      /**
       * New value for property `iconDensityAware`
       */
      bIconDensityAware?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getMenu menu}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMenu(
      /**
       * The menu to set
       */
      oMenu: Menu
    ): this;
    /**
     * Sets a new value for property {@link #getMenuPosition menuPosition}.
     *
     * Specifies the position of the popup menu with enumerated options. By default, the control opens the menu
     * at its bottom left side.
     *
     * **Note:** In the case that the menu has no space to show itself in the view port of the current window
     * it tries to open itself to the inverted direction.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `BeginBottom`.
     *
     * @since 1.56.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMenuPosition(
      /**
       * New value for property `menuPosition`
       */
      sMenuPosition?: typeof Popup.Dock | keyof typeof Popup.Dock
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Defines the text of the `MenuButton`.
     * **Note:** In `Split` `buttonMode` with `useDefaultActionOnly` set to `false`, the text is changed to
     * display the last selected item's text, while in `Regular` `buttonMode` the text stays unchanged.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * Specifies the element's text directionality with enumerated options. By default, the control inherits
     * text direction from the DOM.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets the tooltip for the `MenuButton`. Can either be an instance of a TooltipBase subclass or a simple
     * string.
     *
     *
     * @returns this instance
     */
    setTooltip(
      /**
       * The tooltip that should be shown.
       */
      vTooltip: TooltipBase
    ): any;
    /**
     * Sets a new value for property {@link #getType type}.
     *
     * Defines the type of the `MenuButton` (for example, Default, Accept, Reject, Back, etc.)
     *
     * **Note:** Not all existing types are valid for the control. See {@link sap.m.ButtonType} documentation.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Default`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setType(
      /**
       * New value for property `type`
       */
      sType?: ButtonType | keyof typeof ButtonType
    ): this;
    /**
     * Sets a new value for property {@link #getUseDefaultActionOnly useDefaultActionOnly}.
     *
     * Controls whether the default action handler is invoked always or it is invoked only until a menu item
     * is selected. Usable only if `buttonMode` is set to `Split`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUseDefaultActionOnly(
      /**
       * New value for property `useDefaultActionOnly`
       */
      bUseDefaultActionOnly?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Defines the width of the `MenuButton`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
  }
  /**
   * Describes the settings that can be provided to the MenuButton constructor.
   */
  export interface $MenuButtonSettings extends $ControlSettings {
    /**
     * Defines the text of the `MenuButton`.
     * **Note:** In `Split` `buttonMode` with `useDefaultActionOnly` set to `false`, the text is changed to
     * display the last selected item's text, while in `Regular` `buttonMode` the text stays unchanged.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Defines the type of the `MenuButton` (for example, Default, Accept, Reject, Back, etc.)
     *
     * **Note:** Not all existing types are valid for the control. See {@link sap.m.ButtonType} documentation.
     */
    type?:
      | (ButtonType | keyof typeof ButtonType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the width of the `MenuButton`.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Boolean property to enable the control (default is `true`).
     * **Note:** Depending on custom settings, the buttons that are disabled have other colors than the enabled
     * ones.
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the icon to be displayed as a graphical element within the button. It can be an image or an icon
     * from the icon font.
     *
     * Note: If only an icon (without text) is provided when `buttonMode` is set to `Split`, please provide
     * icons for all menu items. Otherwise the action button will be displayed with no icon or text after item
     * selection since there is not enough space for a text.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * The source property of an alternative icon for the active (pressed) state of the button. Both active
     * and default icon properties should be defined and of the same type - image or icon font. If the `icon`
     * property is not set or has a different type, the active icon is not displayed.
     */
    activeIcon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * When set to `true` (default), one or more requests are sent trying to get the density perfect version
     * of image if this version of image doesn't exist on the server. If only one version of image is provided,
     * set this value to `false` to avoid the attempt of fetching density perfect image.
     */
    iconDensityAware?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the element's text directionality with enumerated options. By default, the control inherits
     * text direction from the DOM.
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines whether the `MenuButton` is set to `Regular` or `Split` mode.
     */
    buttonMode?:
      | (MenuButtonMode | keyof typeof MenuButtonMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies the position of the popup menu with enumerated options. By default, the control opens the menu
     * at its bottom left side.
     *
     * **Note:** In the case that the menu has no space to show itself in the view port of the current window
     * it tries to open itself to the inverted direction.
     *
     * @since 1.56.0
     */
    menuPosition?:
      | (typeof Popup.Dock | keyof typeof Popup.Dock)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Controls whether the default action handler is invoked always or it is invoked only until a menu item
     * is selected. Usable only if `buttonMode` is set to `Split`.
     */
    useDefaultActionOnly?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the menu that opens for this button.
     */
    menu?: Menu;

    /**
     * Association to controls / ids which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Fired when the `buttonMode` is set to `Split` and the user presses the main button unless `useDefaultActionOnly`
     * is set to `false` and another action from the menu has been selected previously.
     */
    defaultAction?: (oEvent: Event) => void;

    /**
     * In `Regular` button mode – fires when the user presses the button. Alternatively, if the `buttonMode`
     * is set to `Split` - fires when the user presses the arrow button.
     *
     * @since 1.94.0
     */
    beforeMenuOpen?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the MenuButton#beforeMenuOpen event.
   */
  export interface MenuButton$BeforeMenuOpenEventParameters {}

  /**
   * Event object of the MenuButton#beforeMenuOpen event.
   */
  export type MenuButton$BeforeMenuOpenEvent = Event<
    MenuButton$BeforeMenuOpenEventParameters,
    MenuButton
  >;

  /**
   * Parameters of the MenuButton#defaultAction event.
   */
  export interface MenuButton$DefaultActionEventParameters {}

  /**
   * Event object of the MenuButton#defaultAction event.
   */
  export type MenuButton$DefaultActionEvent = Event<
    MenuButton$DefaultActionEventParameters,
    MenuButton
  >;
}

declare module "sap/m/MenuItem" {
  import { default as Item, $ItemSettings } from "sap/ui/core/Item";

  import { IMenuItem } from "sap/m/library";

  import Control from "sap/ui/core/Control";

  import Event from "sap/ui/base/Event";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * The `MenuItem` control is used for creating items for the `sap.m.Menu`. It is derived from a core `sap.ui.core.Item`.
   *
   * @since 1.38
   */
  export default class MenuItem extends Item implements IMenuItem {
    __implements__sap_m_IMenuItem: boolean;
    /**
     * Constructor for a new `MenuItem`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $MenuItemSettings
    );
    /**
     * Constructor for a new `MenuItem`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $MenuItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.MenuItem with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Item.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, MenuItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.MenuItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some endContent to the aggregation {@link #getEndContent endContent}.
     *
     * @since 1.131
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addEndContent(
      /**
       * The endContent to add; if empty, nothing is inserted
       */
      oEndContent: Control
    ): this;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: IMenuItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:aggregationChanged aggregationChanged} event
     * of this `sap.m.MenuItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MenuItem` itself.
     *
     * Fired when aggregation of the item changes.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAggregationChanged(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MenuItem$AggregationChangedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MenuItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:aggregationChanged aggregationChanged} event
     * of this `sap.m.MenuItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MenuItem` itself.
     *
     * Fired when aggregation of the item changes.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAggregationChanged(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MenuItem$AggregationChangedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MenuItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.MenuItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MenuItem` itself.
     *
     * Fired after the item has been pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MenuItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.MenuItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MenuItem` itself.
     *
     * Fired after the item has been pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MenuItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:propertyChanged propertyChanged} event of this
     * `sap.m.MenuItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MenuItem` itself.
     *
     * Fired when a property of the item changes.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPropertyChanged(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MenuItem$PropertyChangedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MenuItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:propertyChanged propertyChanged} event of this
     * `sap.m.MenuItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MenuItem` itself.
     *
     * Fired when a property of the item changes.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPropertyChanged(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MenuItem$PropertyChangedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MenuItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getItems items} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the endContent in the aggregation {@link #getEndContent endContent}.
     *
     * @since 1.131
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyEndContent(): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:aggregationChanged aggregationChanged} event
     * of this `sap.m.MenuItem`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAggregationChanged(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MenuItem$AggregationChangedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.MenuItem`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:propertyChanged propertyChanged} event of
     * this `sap.m.MenuItem`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPropertyChanged(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MenuItem$PropertyChangedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:aggregationChanged aggregationChanged} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAggregationChanged(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MenuItem$AggregationChangedEventParameters
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:propertyChanged propertyChanged} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePropertyChanged(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MenuItem$PropertyChangedEventParameters
    ): this;
    /**
     * Gets content of aggregation {@link #getEndContent endContent}.
     *
     * Defines the content that is displayed at the end of a menu item. This aggregation allows for the addition
     * of custom elements, such as icons and buttons.
     *
     * @since 1.131
     */
    getEndContent(): Control[];
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Defines the icon, which belongs to the item. This can be a URI to an image or an icon font URI.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): string;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * Defines the sub-items contained within this element.
     */
    getItems(): IMenuItem[];
    /**
     * Gets current value of property {@link #getSelected selected}.
     *
     * Determines whether the `MenuItem` is selected. A selected `MenuItem` has a check mark rendered at its
     * end. **Note: ** selection functionality works only if the menu item is a member of `MenuItemGroup` with
     * `itemSelectionMode` set to {@link sap.ui.core.ItemSelectionMode.SingleSelect} or {@link sap.ui.unified.ItemSelectionMode.MultiSelect}.
     *
     * Default value is `false`.
     *
     * @since 1.127.0
     *
     * @returns Value of property `selected`
     */
    getSelected(): boolean;
    /**
     * Gets current value of property {@link #getShortcutText shortcutText}.
     *
     * Defines the shortcut text that should be displayed on the menu item on non-mobile devices. **Note:**
     * The text is only displayed and set as а value of the `aria-keyshortcuts` attribute.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `shortcutText`
     */
    getShortcutText(): string;
    /**
     * Gets current value of property {@link #getStartsSection startsSection}.
     *
     * Defines whether a visual separator should be rendered before the item. **Note:** If an item is invisible
     * its separator is also not displayed.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `startsSection`
     */
    getStartsSection(): boolean;
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * Defines whether the item should be visible on the screen. If set to `false`, a placeholder is rendered
     * instead of the real item.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getEndContent endContent}. and
     * returns its index if found or -1 otherwise.
     *
     * @since 1.131
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfEndContent(
      /**
       * The endContent whose index is looked for
       */
      oEndContent: Control
    ): int;
    /**
     * Checks for the provided `sap.m.IMenuItem` in the aggregation {@link #getItems items}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: IMenuItem
    ): int;
    /**
     * Inserts a endContent into the aggregation {@link #getEndContent endContent}.
     *
     * @since 1.131
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertEndContent(
      /**
       * The endContent to insert; if empty, nothing is inserted
       */
      oEndContent: Control,
      /**
       * The `0`-based index the endContent should be inserted at; for a negative value of `iIndex`, the endContent
       * is inserted at position 0; for a value greater than the current size of the aggregation, the endContent
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: IMenuItem,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getEndContent endContent}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.131
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllEndContent(): Control[];
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): IMenuItem[];
    /**
     * Removes a endContent from the aggregation {@link #getEndContent endContent}.
     *
     * @since 1.131
     *
     * @returns The removed endContent or `null`
     */
    removeEndContent(
      /**
       * The endContent to remove or its index or id
       */
      vEndContent: int | string | Control
    ): Control | null;
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | IMenuItem
    ): IMenuItem | null;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Defines the icon, which belongs to the item. This can be a URI to an image or an icon font URI.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: string
    ): this;
    /**
     * Sets a new value for property {@link #getShortcutText shortcutText}.
     *
     * Defines the shortcut text that should be displayed on the menu item on non-mobile devices. **Note:**
     * The text is only displayed and set as а value of the `aria-keyshortcuts` attribute.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShortcutText(
      /**
       * New value for property `shortcutText`
       */
      sShortcutText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getStartsSection startsSection}.
     *
     * Defines whether a visual separator should be rendered before the item. **Note:** If an item is invisible
     * its separator is also not displayed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setStartsSection(
      /**
       * New value for property `startsSection`
       */
      bStartsSection?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * Defines whether the item should be visible on the screen. If set to `false`, a placeholder is rendered
     * instead of the real item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible?: boolean
    ): this;
    /**
     * Unbinds aggregation {@link #getItems items} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindItems(): this;
  }
  /**
   * Describes the settings that can be provided to the MenuItem constructor.
   */
  export interface $MenuItemSettings extends $ItemSettings {
    /**
     * Defines the icon, which belongs to the item. This can be a URI to an image or an icon font URI.
     */
    icon?: string | PropertyBindingInfo;

    /**
     * Defines whether the item should be visible on the screen. If set to `false`, a placeholder is rendered
     * instead of the real item.
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the `MenuItem` is selected. A selected `MenuItem` has a check mark rendered at its
     * end. **Note: ** selection functionality works only if the menu item is a member of `MenuItemGroup` with
     * `itemSelectionMode` set to {@link sap.ui.core.ItemSelectionMode.SingleSelect} or {@link sap.ui.unified.ItemSelectionMode.MultiSelect}.
     *
     * @since 1.127.0
     */
    selected?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the shortcut text that should be displayed on the menu item on non-mobile devices. **Note:**
     * The text is only displayed and set as а value of the `aria-keyshortcuts` attribute.
     */
    shortcutText?: string | PropertyBindingInfo;

    /**
     * Defines whether a visual separator should be rendered before the item. **Note:** If an item is invisible
     * its separator is also not displayed.
     */
    startsSection?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the sub-items contained within this element.
     */
    items?: IMenuItem[] | IMenuItem | AggregationBindingInfo | `{${string}}`;

    /**
     * Defines the content that is displayed at the end of a menu item. This aggregation allows for the addition
     * of custom elements, such as icons and buttons.
     *
     * @since 1.131
     */
    endContent?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * Fired after the item has been pressed.
     */
    press?: (oEvent: Event) => void;

    /**
     * Fired when a property of the item changes.
     */
    propertyChanged?: (oEvent: MenuItem$PropertyChangedEvent) => void;

    /**
     * Fired when aggregation of the item changes.
     */
    aggregationChanged?: (oEvent: MenuItem$AggregationChangedEvent) => void;
  }

  /**
   * Parameters of the MenuItem#aggregationChanged event.
   */
  export interface MenuItem$AggregationChangedEventParameters {
    /**
     * The aggregation name of the changed aggregation.
     */
    aggregationName?: string;

    /**
     * Which method changed the aggregation.
     */
    methodName?: string;

    /**
     * What parameters were used to change the aggregation.
     */
    methodParams?: object;
  }

  /**
   * Event object of the MenuItem#aggregationChanged event.
   */
  export type MenuItem$AggregationChangedEvent = Event<
    MenuItem$AggregationChangedEventParameters,
    MenuItem
  >;

  /**
   * Parameters of the MenuItem#press event.
   */
  export interface MenuItem$PressEventParameters {}

  /**
   * Event object of the MenuItem#press event.
   */
  export type MenuItem$PressEvent = Event<
    MenuItem$PressEventParameters,
    MenuItem
  >;

  /**
   * Parameters of the MenuItem#propertyChanged event.
   */
  export interface MenuItem$PropertyChangedEventParameters {
    /**
     * The property name to be changed.
     */
    propertyKey?: string;

    /**
     * The new property value.
     */
    propertyValue?: any;
  }

  /**
   * Event object of the MenuItem#propertyChanged event.
   */
  export type MenuItem$PropertyChangedEvent = Event<
    MenuItem$PropertyChangedEventParameters,
    MenuItem
  >;
}

declare module "sap/m/MenuItemGroup" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import { IMenuItem } from "sap/m/library";

  import { ItemSelectionMode } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * Group item to be used inside a menu. Represents a collection of menu items that can have the same selection
   * mode (e.g. {@link sap.ui.core.ItemSelectionMode.None}, {@link sap.ui.core.ItemSelectionMode.SingleSelect},
   * or {@link sap.ui.unified.ItemSelectionMode.MultiSelect}).
   *
   * @since 1.127.0
   */
  export default class MenuItemGroup extends UI5Element implements IMenuItem {
    __implements__sap_m_IMenuItem: boolean;
    /**
     * Constructor for a new MenuItemGroup element.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $MenuItemGroupSettings
    );
    /**
     * Constructor for a new MenuItemGroup element.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $MenuItemGroupSettings
    );

    /**
     * Creates a new subclass of class sap.m.MenuItemGroup with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, MenuItemGroup>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.MenuItemGroup.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds an item to `items` aggregation.
     *
     *
     * @returns `this` to allow method chaining
     */
    addItem(
      /**
       * Menu item to be added
       */
      oItem: IMenuItem,
      /**
       * Whether to suppress the invalidation of the control
       */
      bSuppressInvalidate: boolean
    ): this;
    /**
     * Destroys all items from `items` aggregation.
     *
     *
     * @returns `this` to allow method chaining
     */
    destroyItems(
      /**
       * Whether to suppress the invalidation of the control
       */
      bSuppressInvalidate: boolean
    ): this;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * The available items of the menu. **Note:** Adding MenuItemGroup as an item to the MenuItemGroup is not
     * supported.
     */
    getItems(): IMenuItem[];
    /**
     * Gets current value of property {@link #getItemSelectionMode itemSelectionMode}.
     *
     * Defines the selection mode of the child items (e.g. `None`, `SingleSelect`, `MultiSelect`)
     *
     * Default value is `None`.
     *
     *
     * @returns Value of property `itemSelectionMode`
     */
    getItemSelectionMode(): ItemSelectionMode;
    /**
     * Checks for the provided `sap.m.IMenuItem` in the aggregation {@link #getItems items}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: IMenuItem
    ): int;
    /**
     * Inserts an item to the specified position in `items` aggregation.
     *
     *
     * @returns `this` to allow method chaining
     */
    insertItem(
      /**
       * Menu item to be added
       */
      oItem: IMenuItem,
      /**
       * Index at which the item should be inserted
       */
      iIndex: int,
      /**
       * Whether to suppress the invalidation of the control
       */
      bSuppressInvalidate: boolean
    ): this;
    /**
     * Removes all items from `items` aggregation.
     *
     *
     * @returns array containing the removed items, or `null` if there are no items to remove
     */
    removeAllItems(
      /**
       * Whether to suppress the invalidation of the control
       */
      bSuppressInvalidate: boolean
    ): any[] | null;
    /**
     * Removes an item from `items` aggregation.
     *
     *
     * @returns the removed object, or `null` if there are no items to remove
     */
    removeItem(
      /**
       * Menu item to be removed (as index, ID or object)
       */
      vItem: int | string | IMenuItem,
      /**
       * Whether to suppress the invalidation of the control
       */
      bSuppressInvalidate: boolean
    ): IMenuItem | null;
    /**
     * Override of the default setter that also ensures single selection if necessary.
     *
     *
     * @returns `this` to allow method chaining
     */
    setItemSelectionMode(
      /**
       * item selection mode to be set
       */
      sSelectionMode: string,
      /**
       * Whether to suppress the invalidation of the control
       */
      bSuppressInvalidate: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the MenuItemGroup constructor.
   */
  export interface $MenuItemGroupSettings extends $ElementSettings {
    /**
     * Defines the selection mode of the child items (e.g. `None`, `SingleSelect`, `MultiSelect`)
     */
    itemSelectionMode?: ItemSelectionMode | PropertyBindingInfo | `{${string}}`;

    /**
     * The available items of the menu. **Note:** Adding MenuItemGroup as an item to the MenuItemGroup is not
     * supported.
     */
    items?: IMenuItem[] | IMenuItem | AggregationBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/MessageBox" {
  import { TextDirection, CSSSize } from "sap/ui/core/library";

  import UI5Element from "sap/ui/core/Element";

  /**
   * Provides easier methods to create sap.m.Dialog with type sap.m.DialogType.Message, such as standard alerts,
   * confirmation dialogs, or arbitrary message dialogs.
   *
   * MessageBox provides several functions:
   * 	 - `show()` - This is the generic way to open a message dialog. You can customize its contents through
   *     the `mOptions` parameter described below.
   * 	 - `alert()`, `confirm()`, `error()`, `information()`, `success()` and `warning()` - predefined templates
   *     of message dialogs. Each value type is coming with action buttons and an icon that are corresponding
   *     to its semantic. Although the full set of `mOptions` (applicable to `show()`) are available to them,
   *     it is recommended to only use the documented options.
   *
   * **Note:** All options of show() are available for the other template functions as well, but it is recommended
   * to use show() only in more specific scenarios. **Note:** Due to the static nature of the `MessageBox`
   * class, you cannot expect data binding support from its helper functions. If this is required you can
   * use the `sap.m.Dialog` instead. **Note:** When using the `MessageBox.Error` method, there is no
   * emphasized action by design.
   *
   * Example:
   * ```javascript
   *
   * sap.ui.define(["sap/m/MessageBox"], function (MessageBox) {
   * 	MessageBox.show(
   * 		"This message should appear in the message box.", {
   * 			icon: MessageBox.Icon.INFORMATION,
   * 			title: "My message box title",
   * 			actions: [MessageBox.Action.YES, MessageBox.Action.NO],
   * 			emphasizedAction: MessageBox.Action.YES,
   * 			onClose: function (oAction) { / * do something * / }
   * 		}
   * 	);
   * });
   * ```
   *
   *
   * When using the `sap.m.MessageBox` in SAP Quartz and Horizon themes, the breakpoints and layout paddings
   * could be determined by the MessageBox' width. To enable this concept and add responsive paddings to an
   * element of the MessageBox control, you have to add the following classes depending on your use case:
   * `sapUiResponsivePadding--header`, `sapUiResponsivePadding--content`, `sapUiResponsivePadding--footer`.
   * See:
   * 	{@link fiori:https://experience.sap.com/fiori-design-web/message-box/ Message Box}
   *
   * @since 1.21.2
   */
  interface MessageBox {
    /**
     * Enumeration of supported actions in a MessageBox.
     *
     * Each action is represented as a button in the message box. The values of this enumeration are used for
     * both, specifying the set of allowed actions as well as reporting back the user choice.
     *
     * This enum is part of the 'sap/m/MessageBox' module export and must be accessed by the property 'Action'.
     */
    Action: typeof Action;

    /**
     * Enumeration of the pre-defined icons that can be used in a MessageBox.
     *
     * This enum is part of the 'sap/m/MessageBox' module export and must be accessed by the property 'Icon'.
     */
    Icon: typeof Icon;

    /**
     * Displays an alert dialog with the given message and an OK button (no icons).
     *
     *
     * ```javascript
     *
     * sap.m.MessageBox.alert("This message should appear in the alert", {
     *     title: "Alert",                                      // default
     *     onClose: null,                                       // default
     *     styleClass: "",                                      // default
     *     actions: sap.m.MessageBox.Action.OK,                 // default
     *     emphasizedAction: sap.m.MessageBox.Action.OK,        // default
     *     initialFocus: null,                                  // default
     *     textDirection: sap.ui.core.TextDirection.Inherit,    // default
     *     dependentOn: null                                    // default
     * });
     * ```
     *
     *
     * If a callback is given, it is called after the alert dialog has been closed by the user via the OK button.
     * The callback is called with the following signature:
     *
     *
     * ```javascript
     *
     *   function (oAction)
     * ```
     *
     *
     * where `oAction` can be either sap.m.MessageBox.Action.OK when the alert dialog is closed by tapping on
     * the OK button or null when the alert dialog is closed by calling `sap.m.InstanceManager.closeAllDialogs()`.
     *
     * The alert dialog opened by this method is processed asynchronously. Applications have to use `fnCallback`
     * to continue work after the user closed the alert dialog.
     */
    alert(
      /**
       * Message to be displayed in the alert dialog. The usage of sap.core.Control as vMessage is deprecated
       * since version 1.30.4.
       */
      vMessage: string,
      /**
       * Other options (optional)
       */
      mOptions?: {
        /**
         * callback function to be called when the user closes the dialog
         */
        onClose?: Function;
        /**
         * Title to be displayed in the alert dialog
         */
        title?: string;
        /**
         * Either a single action, or an array of actions. If no action(s) are given, the single action MessageBox.Action.OK
         * is taken as a default for the parameter. Custom action(s) string or an array can be provided, and then
         * the translation of custom actions needs to be done by the application.
         */
        actions?:
          | (Action | keyof typeof Action)
          | Array<Action | keyof typeof Action>
          | string
          | string[];
        /**
         * Added since version 1.75.0. Specifies which action of the created dialog will be emphasized. EmphasizedAction
         * will apply only if the property `actions` is provided.
         */
        emphasizedAction?: (Action | keyof typeof Action) | string;
        /**
         * ID to be used for the alert dialog. Intended for test scenarios, not recommended for productive apps
         */
        id?: string;
        /**
         * Added since version 1.21.2. CSS style class which is added to the alert dialog's root DOM node. The compact
         * design can be activated by setting this to "sapUiSizeCompact"
         */
        styleClass?: string;
        /**
         * Added since version 1.28.0. initialFocus, this option sets the action name, the text of the button or
         * the control that gets the focus as first focusable element after the MessageBox is opened. The usage
         * of sap.ui.core.Control to set initialFocus is deprecated since version 1.30.4.
         */
        initialFocus?: string | (Action | keyof typeof Action);
        /**
         * Added since version 1.28. Specifies the element's text directionality with enumerated options. By default,
         * the control inherits text direction from the DOM.
         */
        textDirection?: TextDirection | keyof typeof TextDirection;
        /**
         * verticalScrolling is deprecated since version 1.30.4. VerticalScrolling, this option indicates if the
         * user can scroll vertically inside the MessageBox when the content is larger than the content area.
         */
        verticalScrolling?: boolean;
        /**
         * horizontalScrolling is deprecated since version 1.30.4. HorizontalScrolling, this option indicates if
         * the user can scroll horizontally inside the MessageBox when the content is larger than the content area.
         */
        horizontalScrolling?: boolean;
        /**
         * Added since version 1.28.0. If set, a link to view details is added. When the user clicks the link, the
         * text area containing 'details' information is displayed. The initial visibility is not configurable and
         * the details are hidden by default.
         *  The following details can be used:
         * 	 - `string` - text in HTML format. For full list of supported HTML tags see {@link sap.m.FormattedText }
         *
         * 	 - `object` - JSON object that will be serialized using `JSON.stringify`
         * 	 - `function` - since version 1.103, a callback function that fetches the details asynchronously. It
         *     should return a promise that resolves with a `string` value or an `object`, or rejects - in this case
         *     a default error message will be displayed
         */
        details?: string | object | (() => Promise<string | object>);
        /**
         * The width of the MessageBox
         */
        contentWidth?: CSSSize;
        /**
         * Added since version 1.72.0. Whether the MessageBox will be closed automatically when a routing navigation
         * occurs.
         */
        closeOnNavigation?: boolean;
        /**
         * Added since version 1.124.0. Specifies an element to which the dialog will be added as a dependent.
         */
        dependentOn?: UI5Element;
      }
    ): void;
    /**
     * Displays a confirmation dialog with the given message, a QUESTION icon, an OK button and a Cancel button.
     * If a callback is given, it is called after the confirmation box has been closed by the user with one
     * of the buttons.
     *
     *
     * ```javascript
     *
     * sap.m.MessageBox.confirm("This message should appear in the confirmation", {
     *     title: "Confirm",                                    // default
     *     onClose: null,                                       // default
     *     styleClass: "",                                      // default
     *     actions: [ sap.m.MessageBox.Action.OK,
     *                sap.m.MessageBox.Action.CANCEL ],         // default
     *     emphasizedAction: sap.m.MessageBox.Action.OK,        // default
     *     initialFocus: null,                                  // default
     *     textDirection: sap.ui.core.TextDirection.Inherit,    // default
     *     dependentOn: null                                    // default
     * });
     * ```
     *
     *
     * The callback is called with the following signature
     *
     *
     * ```javascript
     *
     *   function(oAction)
     * ```
     *
     *
     * where oAction is set by one of the following three values: 1. sap.m.MessageBox.Action.OK: OK (confirmed)
     * button is tapped. 2. sap.m.MessageBox.Action.CANCEL: Cancel (unconfirmed) button is tapped. 3. null:
     * Confirm dialog is closed by calling `sap.m.InstanceManager.closeAllDialogs()`
     *
     * The confirmation dialog opened by this method is processed asynchronously. Applications have to use `fnCallback`
     * to continue work after the user closed the confirmation dialog
     */
    confirm(
      /**
       * Message to be displayed in the alert dialog. The usage of sap.core.Control as vMessage is deprecated
       * since version 1.30.4.
       */
      vMessage: string,
      /**
       * Other options (optional)
       */
      mOptions?: {
        /**
         * Callback to be called when the user closes the dialog
         */
        onClose?: Function;
        /**
         * Title to display in the confirmation dialog
         */
        title?: string;
        /**
         * Either a single action, or an array of actions. If no action(s) are given, the single action MessageBox.Action.OK
         * is taken as a default for the parameter. Custom action(s) string or an array can be provided, and then
         * the translation of custom actions needs to be done by the application.
         */
        actions?:
          | (Action | keyof typeof Action)
          | Array<Action | keyof typeof Action>
          | string
          | string[];
        /**
         * Added since version 1.75.0. Specifies which action of the created dialog will be emphasized. EmphasizedAction
         * will apply only if the property `actions` is provided.
         */
        emphasizedAction?: (Action | keyof typeof Action) | string;
        /**
         * ID to be used for the confirmation dialog. Intended for test scenarios, not recommended for productive
         * apps
         */
        id?: string;
        /**
         * Added since version 1.21.2. CSS style class which is added to the confirmation dialog's root DOM node.
         * The compact design can be activated by setting this to "sapUiSizeCompact"
         */
        styleClass?: string;
        /**
         * Added since version 1.28.0. initialFocus, this option sets the action name, the text of the button or
         * the control that gets the focus as first focusable element after the MessageBox is opened. The usage
         * of sap.ui.core.Control to set initialFocus is deprecated since version 1.30.4.
         */
        initialFocus?: string | (Action | keyof typeof Action);
        /**
         * Added since version 1.28. Specifies the element's text directionality with enumerated options. By default,
         * the control inherits text direction from the DOM.
         */
        textDirection?: TextDirection | keyof typeof TextDirection;
        /**
         * verticalScrolling is deprecated since version 1.30.4. VerticalScrolling, this option indicates if the
         * user can scroll vertically inside the MessageBox when the content is larger than the content area.
         */
        verticalScrolling?: boolean;
        /**
         * horizontalScrolling is deprecated since version 1.30.4. HorizontalScrolling, this option indicates if
         * the user can scroll horizontally inside the MessageBox when the content is larger than the content area.
         */
        horizontalScrolling?: boolean;
        /**
         * Added since version 1.28.0. If set, a link to view details is added. When the user clicks the link, the
         * text area containing 'details' information is displayed. The initial visibility is not configurable and
         * the details are hidden by default.
         *  The following details can be used:
         * 	 - `string` - text in HTML format. For full list of supported HTML tags see {@link sap.m.FormattedText }
         *
         * 	 - `object` - JSON object that will be serialized using `JSON.stringify`
         * 	 - `function` - since version 1.103, a callback function that fetches the details asynchronously. It
         *     should return a promise that resolves with a `string` value or an `object`, or rejects - in this case
         *     a default error message will be displayed
         */
        details?: string | object | (() => Promise<string | object>);
        /**
         * The width of the MessageBox
         */
        contentWidth?: CSSSize;
        /**
         * Added since version 1.72.0. Whether the MessageBox will be closed automatically when a routing navigation
         * occurs.
         */
        closeOnNavigation?: boolean;
        /**
         * Added since version 1.124.0. Specifies an element to which the dialog will be added as a dependent.
         */
        dependentOn?: UI5Element;
      }
    ): void;
    /**
     * Displays an error dialog with the given message, an ERROR icon, a CLOSE button.. If a callback is given,
     * it is called after the error box has been closed by the user with one of the buttons.
     *
     *
     * ```javascript
     *
     * sap.m.MessageBox.error("This message should appear in the error message box", {
     *     title: "Error",                                      // default
     *     onClose: null,                                       // default
     *     styleClass: "",                                      // default
     *     actions: sap.m.MessageBox.Action.CLOSE,              // default
     *     emphasizedAction: null,                              // default
     *     initialFocus: null,                                  // default
     *     textDirection: sap.ui.core.TextDirection.Inherit,    // default
     *     dependentOn: null                                    // default
     * });
     * ```
     *
     *
     * The callback is called with the following signature
     *
     *
     * ```javascript
     *
     *   function (oAction)
     * ```
     *
     *
     * The error dialog opened by this method is processed asynchronously. Applications have to use `fnCallback`
     * to continue work after the user closed the error dialog.
     *
     * @since 1.30
     */
    error(
      /**
       * Message to be displayed in the alert dialog. The usage of sap.core.Control as vMessage is deprecated
       * since version 1.30.4.
       */
      vMessage: string,
      /**
       * Other options (optional)
       */
      mOptions?: {
        /**
         * Callback when the user closes the dialog
         */
        onClose?: Function;
        /**
         * Title of the error dialog
         */
        title?: string;
        /**
         * Either a single action, or an array of actions. If no action(s) are given, the single action MessageBox.Action.OK
         * is taken as a default for the parameter. Custom action(s) string or an array can be provided, and then
         * the translation of custom actions needs to be done by the application.
         */
        actions?:
          | (Action | keyof typeof Action)
          | Array<Action | keyof typeof Action>
          | string
          | string[];
        /**
         * Added since version 1.75.0. Specifies which action of the created dialog will be emphasized. EmphasizedAction
         * will apply only if the property `actions` is provided.
         */
        emphasizedAction?: (Action | keyof typeof Action) | string;
        /**
         * ID for the error dialog. Intended for test scenarios, not recommended for productive apps
         */
        id?: string;
        /**
         * CSS style class which is added to the error dialog's root DOM node. The compact design can be activated
         * by setting this to "sapUiSizeCompact"
         */
        styleClass?: string;
        /**
         * This option sets the action name, the text of the button or the control that gets the focus as first
         * focusable element after the MessageBox is opened. The usage of sap.ui.core.Control to set initialFocus
         * is deprecated since version 1.30.4.
         */
        initialFocus?: string | (Action | keyof typeof Action);
        /**
         * Specifies the element's text directionality with enumerated options. By default, the control inherits
         * text direction from the DOM.
         */
        textDirection?: TextDirection | keyof typeof TextDirection;
        /**
         * verticalScrolling is deprecated since version 1.30.4. VerticalScrolling, this option indicates if the
         * user can scroll vertically inside the MessageBox when the content is larger than the content area.
         */
        verticalScrolling?: boolean;
        /**
         * horizontalScrolling is deprecated since version 1.30.4. HorizontalScrolling, this option indicates if
         * the user can scroll horizontally inside the MessageBox when the content is larger than the content area.
         */
        horizontalScrolling?: boolean;
        /**
         * Added since version 1.28.0. If set, a link to view details is added. When the user clicks the link, the
         * text area containing 'details' information is displayed. The initial visibility is not configurable and
         * the details are hidden by default.
         *  The following details can be used:
         * 	 - `string` - text in HTML format. For full list of supported HTML tags see {@link sap.m.FormattedText }
         *
         * 	 - `object` - JSON object that will be serialized using `JSON.stringify`
         * 	 - `function` - since version 1.103, a callback function that fetches the details asynchronously. It
         *     should return a promise that resolves with a `string` value or an `object`, or rejects - in this case
         *     a default error message will be displayed
         */
        details?: string | object | (() => Promise<string | object>);
        /**
         * The width of the MessageBox
         */
        contentWidth?: CSSSize;
        /**
         * Added since version 1.72.0. Whether the MessageBox will be closed automatically when a routing navigation
         * occurs.
         */
        closeOnNavigation?: boolean;
        /**
         * Added since version 1.124.0. Specifies an element to which the dialog will be added as a dependent.
         */
        dependentOn?: UI5Element;
      }
    ): void;
    /**
     * Displays an information dialog with the given message, an INFO icon, an OK button. If a callback is given,
     * it is called after the info box has been closed by the user with one of the buttons.
     *
     *
     * ```javascript
     *
     * sap.m.MessageBox.information("This message should appear in the information message box", {
     *     title: "Information",                                // default
     *     onClose: null,                                       // default
     *     styleClass: "",                                      // default
     *     actions: sap.m.MessageBox.Action.OK,                 // default
     *     emphasizedAction: sap.m.MessageBox.Action.OK,        // default
     *     initialFocus: null,                                  // default
     *     textDirection: sap.ui.core.TextDirection.Inherit,    // default
     *     dependentOn: null                                    // default
     * });
     * ```
     *
     *
     * The callback is called with the following signature
     * ```javascript
     *
     *   function (oAction)
     * ```
     *
     *
     * The information dialog opened by this method is processed asynchronously. Applications have to use `fnCallback`
     * to continue work after the user closed the information dialog
     *
     * @since 1.30
     */
    information(
      /**
       * Message to be displayed in the alert dialog. The usage of sap.core.Control as vMessage is deprecated
       * since version 1.30.4.
       */
      vMessage: string,
      /**
       * Other options (optional)
       */
      mOptions?: {
        /**
         * Callback when the user closes the dialog
         */
        onClose?: Function;
        /**
         * Title of the information dialog
         */
        title?: string;
        /**
         * Either a single action, or an array of actions. If no action(s) are given, the single action MessageBox.Action.OK
         * is taken as a default for the parameter. Custom action(s) string or an array can be provided, and then
         * the translation of custom actions needs to be done by the application.
         */
        actions?:
          | (Action | keyof typeof Action)
          | Array<Action | keyof typeof Action>
          | string
          | string[];
        /**
         * Added since version 1.75.0. Specifies which action of the created dialog will be emphasized. EmphasizedAction
         * will apply only if the property `actions` is provided.
         */
        emphasizedAction?: (Action | keyof typeof Action) | string;
        /**
         * ID for the information dialog. Intended for test scenarios, not recommended for productive apps
         */
        id?: string;
        /**
         * CSS style class which is added to the information dialog's root DOM node. The compact design can be activated
         * by setting this to "sapUiSizeCompact"
         */
        styleClass?: string;
        /**
         * This option sets the action name, the text of the button or the control that gets the focus as first
         * focusable element after the MessageBox is opened. The usage of sap.ui.core.Control to set initialFocus
         * is deprecated since version 1.30.4.
         */
        initialFocus?: string | (Action | keyof typeof Action);
        /**
         * Specifies the element's text directionality with enumerated options. By default, the control inherits
         * text direction from the DOM.
         */
        textDirection?: TextDirection | keyof typeof TextDirection;
        /**
         * verticalScrolling is deprecated since version 1.30.4. VerticalScrolling, this option indicates if the
         * user can scroll vertically inside the MessageBox when the content is larger than the content area.
         */
        verticalScrolling?: boolean;
        /**
         * horizontalScrolling is deprecated since version 1.30.4. HorizontalScrolling, this option indicates if
         * the user can scroll horizontally inside the MessageBox when the content is larger than the content area.
         */
        horizontalScrolling?: boolean;
        /**
         * Added since version 1.28.0. If set, a link to view details is added. When the user clicks the link, the
         * text area containing 'details' information is displayed. The initial visibility is not configurable and
         * the details are hidden by default.
         *  The following details can be used:
         * 	 - `string` - text in HTML format. For full list of supported HTML tags see {@link sap.m.FormattedText }
         *
         * 	 - `object` - JSON object that will be serialized using `JSON.stringify`
         * 	 - `function` - since version 1.103, a callback function that fetches the details asynchronously. It
         *     should return a promise that resolves with a `string` value or an `object`, or rejects - in this case
         *     a default error message will be displayed
         */
        details?: string | object | (() => Promise<string | object>);
        /**
         * The width of the MessageBox
         */
        contentWidth?: CSSSize;
        /**
         * Added since version 1.72.0. Whether the MessageBox will be closed automatically when a routing navigation
         * occurs.
         */
        closeOnNavigation?: boolean;
        /**
         * Added since version 1.124.0. Specifies an element to which the dialog will be added as a dependent.
         */
        dependentOn?: UI5Element;
      }
    ): void;
    /**
     * Creates and displays an sap.m.Dialog with type sap.m.DialogType.Message with the given text and buttons,
     * and optionally other parts. After the user has tapped a button, the `onClose` function is invoked when
     * given.
     *
     * The only mandatory parameter is `vMessage`.
     *
     *
     * ```javascript
     *
     * sap.m.MessageBox.show("This message should appear in the message box", {
     *     icon: sap.m.MessageBox.Icon.NONE,                    // default
     *     title: "",                                           // default
     *     actions: sap.m.MessageBox.Action.OK,                 // default
     *     emphasizedAction: sap.m.MessageBox.Action.OK,        // default
     *     onClose: null,                                       // default
     *     styleClass: "",                                      // default
     *     initialFocus: null,                                  // default
     *     textDirection: sap.ui.core.TextDirection.Inherit,    // default
     *     dependentOn: null                                    // default
     * });
     * ```
     *
     *
     * The created dialog is executed asynchronously. When it has been created and registered for rendering,
     * this function returns without waiting for a user reaction.
     *
     * When applications have to react on the users choice, they have to provide a callback function and postpone
     * any reaction on the user choice until that callback is triggered.
     *
     * The signature of the callback is
     *
     * function (oAction);
     *
     * where `oAction` is the button that the user has tapped. For example, when the user has pressed the close
     * button, an sap.m.MessageBox.Action.CLOSE is returned.
     */
    show(
      /**
       * Message to be displayed in the alert dialog. The usage of sap.core.Control as vMessage is deprecated
       * since version 1.30.4.
       */
      vMessage: string,
      /**
       * Other options (optional)
       */
      mOptions?: {
        /**
         * The icon to be displayed.
         */
        icon?: Icon;
        /**
         * The title of the message box.
         */
        title?: string;
        /**
         * Either a single action, or an array of actions. If no action(s) are given, the single action MessageBox.Action.OK
         * is taken as a default for the parameter. Custom action(s) string or an array can be provided, and then
         * the translation of custom actions needs to be done by the application.
         */
        actions?:
          | (Action | keyof typeof Action)
          | Array<Action | keyof typeof Action>
          | string
          | string[];
        /**
         * Added since version 1.75.0. Specifies which action of the created dialog will be emphasized. EmphasizedAction
         * will apply only if the property `actions` is provided.
         */
        emphasizedAction?: (Action | keyof typeof Action) | string;
        /**
         * Function to be called when the user taps a button or closes the message box.
         */
        onClose?: Function;
        /**
         * ID to be used for the dialog. Intended for test scenarios, not recommended for productive apps
         */
        id?: string;
        /**
         * Added since version 1.21.2. CSS style class which is added to the dialog's root DOM node. The compact
         * design can be activated by setting this to "sapUiSizeCompact"
         */
        styleClass?: string;
        /**
         * Added since version 1.28.0. initialFocus, this option sets the action name, the text of the button or
         * the control that gets the focus as first focusable element after the MessageBox is opened. The usage
         * of sap.ui.core.Control to set initialFocus is deprecated since version 1.30.4.
         */
        initialFocus?: string | (Action | keyof typeof Action);
        /**
         * Added since version 1.28. Specifies the element's text directionality with enumerated options. By default,
         * the control inherits text direction from the DOM.
         */
        textDirection?: TextDirection | keyof typeof TextDirection;
        /**
         * verticalScrolling is deprecated since version 1.30.4. VerticalScrolling, this option indicates if the
         * user can scroll vertically inside the MessageBox when the content is larger than the content area.
         */
        verticalScrolling?: boolean;
        /**
         * horizontalScrolling is deprecated since version 1.30.4. HorizontalScrolling, this option indicates if
         * the user can scroll horizontally inside the MessageBox when the content is larger than the content area.
         */
        horizontalScrolling?: boolean;
        /**
         * Added since version 1.28.0. If set, a link to view details is added. When the user clicks the link, the
         * text area containing 'details' information is displayed. The initial visibility is not configurable and
         * the details are hidden by default.
         *  The following details can be used:
         * 	 - `string` - text in HTML format. For full list of supported HTML tags see {@link sap.m.FormattedText }
         *
         * 	 - `object` - JSON object that will be serialized using `JSON.stringify`
         * 	 - `function` - since version 1.103, a callback function that fetches the details asynchronously. It
         *     should return a promise that resolves with a `string` value or an `object`, or rejects - in this case
         *     a default error message will be displayed
         */
        details?: string | object | (() => Promise<string | object>);
        /**
         * The width of the MessageBox
         */
        contentWidth?: CSSSize;
        /**
         * Added since version 1.72.0. Whether the MessageBox will be closed automatically when a routing navigation
         * occurs.
         */
        closeOnNavigation?: boolean;
        /**
         * Added since version 1.124.0. Specifies an element to which the dialog will be added as a dependent.
         */
        dependentOn?: UI5Element;
      }
    ): void;
    /**
     * Displays a success dialog with the given message, a SUCCESS icon, an OK button. If a callback is given,
     * it is called after the success box has been closed by the user with one of the buttons.
     *
     *
     * ```javascript
     *
     * sap.m.MessageBox.success("This message should appear in the success message box", {
     *     title: "Success",                                    // default
     *     onClose: null,                                       // default
     *     styleClass: "",                                      // default
     *     actions: sap.m.MessageBox.Action.OK,                 // default
     *     emphasizedAction: sap.m.MessageBox.Action.OK,        // default
     *     initialFocus: null,                                  // default
     *     textDirection: sap.ui.core.TextDirection.Inherit,    // default
     *     dependentOn: null                                    // default
     * });
     * ```
     *
     *
     * The callback is called with the following signature
     * ```javascript
     *
     *   function(oAction)
     * ```
     *
     *
     * The success dialog opened by this method is processed asynchronously. Applications have to use `fnCallback`
     * to continue work after the user closed the success dialog
     *
     * @since 1.30
     */
    success(
      /**
       * Message to be displayed in the alert dialog. The usage of sap.core.Control as vMessage is deprecated
       * since version 1.30.4.
       */
      vMessage: string,
      /**
       * Other options (optional)
       */
      mOptions?: {
        /**
         * Callback when the user closes the dialog
         */
        onClose?: Function;
        /**
         * Title of the success dialog
         */
        title?: string;
        /**
         * Either a single action, or an array of actions. If no action(s) are given, the single action MessageBox.Action.OK
         * is taken as a default for the parameter. Custom action(s) string or an array can be provided, and then
         * the translation of custom actions needs to be done by the application.
         */
        actions?:
          | (Action | keyof typeof Action)
          | Array<Action | keyof typeof Action>
          | string
          | string[];
        /**
         * Added since version 1.75.0. Specifies which action of the created dialog will be emphasized. EmphasizedAction
         * will apply only if the property `actions` is provided.
         */
        emphasizedAction?: (Action | keyof typeof Action) | string;
        /**
         * ID for the success dialog. Intended for test scenarios, not recommended for productive apps
         */
        id?: string;
        /**
         * CSS style class which is added to the success dialog's root DOM node. The compact design can be activated
         * by setting this to "sapUiSizeCompact"
         */
        styleClass?: string;
        /**
         * This option sets the action name, the text of the button or the control that gets the focus as first
         * focusable element after the MessageBox is opened. The usage of sap.ui.core.Control to set initialFocus
         * is deprecated since version 1.30.4.
         */
        initialFocus?: string | (Action | keyof typeof Action);
        /**
         * Specifies the element's text directionality with enumerated options. By default, the control inherits
         * text direction from the DOM.
         */
        textDirection?: TextDirection | keyof typeof TextDirection;
        /**
         * verticalScrolling is deprecated since version 1.30.4. VerticalScrolling, this option indicates if the
         * user can scroll vertically inside the MessageBox when the content is larger than the content area.
         */
        verticalScrolling?: boolean;
        /**
         * horizontalScrolling is deprecated since version 1.30.4. HorizontalScrolling, this option indicates if
         * the user can scroll horizontally inside the MessageBox when the content is larger than the content area.
         */
        horizontalScrolling?: boolean;
        /**
         * Added since version 1.28.0. If set, a link to view details is added. When the user clicks the link, the
         * text area containing 'details' information is displayed. The initial visibility is not configurable and
         * the details are hidden by default.
         *  The following details can be used:
         * 	 - `string` - text in HTML format. For full list of supported HTML tags see {@link sap.m.FormattedText }
         *
         * 	 - `object` - JSON object that will be serialized using `JSON.stringify`
         * 	 - `function` - since version 1.103, a callback function that fetches the details asynchronously. It
         *     should return a promise that resolves with a `string` value or an `object`, or rejects - in this case
         *     a default error message will be displayed
         */
        details?: string | object | (() => Promise<string | object>);
        /**
         * The width of the MessageBox
         */
        contentWidth?: CSSSize;
        /**
         * Added since version 1.72.0. Whether the MessageBox will be closed automatically when a routing navigation
         * occurs.
         */
        closeOnNavigation?: boolean;
        /**
         * Added since version 1.124.0. Specifies an element to which the dialog will be added as a dependent.
         */
        dependentOn?: UI5Element;
      }
    ): void;
    /**
     * Displays a warning dialog with the given message, a WARNING icon, an OK button. If a callback is given,
     * it is called after the warning box has been closed by the user with one of the buttons.
     *
     *
     * ```javascript
     *
     * sap.m.MessageBox.warning("This message should appear in the warning message box", {
     *     title: "Warning",                                    // default
     *     onClose: null,                                       // default
     *     styleClass: "",                                      // default
     *     actions: sap.m.MessageBox.Action.OK,                 // default
     *     emphasizedAction: sap.m.MessageBox.Action.OK,        // default
     *     initialFocus: null,                                  // default
     *     textDirection: sap.ui.core.TextDirection.Inherit,    // default
     *     dependentOn: null                                    // default
     * });
     * ```
     *
     *
     * The callback is called with the following signature
     * ```javascript
     *
     *   function (oAction)
     * ```
     *
     *
     * The warning dialog opened by this method is processed asynchronously. Applications have to use `fnCallback`
     * to continue work after the user closed the warning dialog
     *
     * @since 1.30
     */
    warning(
      /**
       * Message to be displayed in the alert dialog. The usage of sap.core.Control as vMessage is deprecated
       * since version 1.30.4.
       */
      vMessage: string,
      /**
       * Other options (optional)
       */
      mOptions?: {
        /**
         * Callback when the user closes the dialog
         */
        onClose?: Function;
        /**
         * Title of the warning dialog
         */
        title?: string;
        /**
         * Either a single action, or an array of actions. If no action(s) are given, the single action MessageBox.Action.OK
         * is taken as a default for the parameter. Custom action(s) string or an array can be provided, and then
         * the translation of custom actions needs to be done by the application.
         */
        actions?:
          | (Action | keyof typeof Action)
          | Array<Action | keyof typeof Action>
          | string
          | string[];
        /**
         * Added since version 1.75.0. Specifies which action of the created dialog will be emphasized. EmphasizedAction
         * will apply only if the property `actions` is provided.
         */
        emphasizedAction?: (Action | keyof typeof Action) | string;
        /**
         * ID to for the warning dialog. Intended for test scenarios, not recommended for productive apps
         */
        id?: string;
        /**
         * CSS style class which is added to the warning dialog's root DOM node. The compact design can be activated
         * by setting this to "sapUiSizeCompact"
         */
        styleClass?: string;
        /**
         * This option sets the action name, the text of the button or the control that gets the focus as first
         * focusable element after the MessageBox is opened. The usage of sap.ui.core.Control to set initialFocus
         * is deprecated since version 1.30.4.
         */
        initialFocus?: string | (Action | keyof typeof Action);
        /**
         * Specifies the element's text directionality with enumerated options. By default, the control inherits
         * text direction from the DOM.
         */
        textDirection?: TextDirection | keyof typeof TextDirection;
        /**
         * verticalScrolling is deprecated since version 1.30.4. VerticalScrolling, this option indicates if the
         * user can scroll vertically inside the MessageBox when the content is larger than the content area.
         */
        verticalScrolling?: boolean;
        /**
         * horizontalScrolling is deprecated since version 1.30.4. HorizontalScrolling, this option indicates if
         * the user can scroll horizontally inside the MessageBox when the content is larger than the content area.
         */
        horizontalScrolling?: boolean;
        /**
         * Added since version 1.28.0. If set, a link to view details is added. When the user clicks the link, the
         * text area containing 'details' information is displayed. The initial visibility is not configurable and
         * the details are hidden by default.
         *  The following details can be used:
         * 	 - `string` - text in HTML format. For full list of supported HTML tags see {@link sap.m.FormattedText }
         *
         * 	 - `object` - JSON object that will be serialized using `JSON.stringify`
         * 	 - `function` - since version 1.103, a callback function that fetches the details asynchronously. It
         *     should return a promise that resolves with a `string` value or an `object`, or rejects - in this case
         *     a default error message will be displayed
         */
        details?: string | object | (() => Promise<string | object>);
        /**
         * The width of the MessageBox
         */
        contentWidth?: CSSSize;
        /**
         * Added since version 1.72.0. Whether the MessageBox will be closed automatically when a routing navigation
         * occurs.
         */
        closeOnNavigation?: boolean;
        /**
         * Added since version 1.124.0. Specifies an element to which the dialog will be added as a dependent.
         */
        dependentOn?: UI5Element;
      }
    ): void;
  }
  const MessageBox: MessageBox;
  export default MessageBox;

  /**
   * Enumeration of supported actions in a MessageBox.
   *
   * Each action is represented as a button in the message box. The values of this enumeration are used for
   * both, specifying the set of allowed actions as well as reporting back the user choice.
   *
   * This enum is part of the 'sap/m/MessageBox' module export and must be accessed by the property 'Action'.
   */
  enum Action {
    /**
     * Adds an "Abort" button to the message box.
     */
    ABORT = "ABORT",
    /**
     * Adds a "Cancel" button to the message box.
     */
    CANCEL = "CANCEL",
    /**
     * Adds a "Close" button to the message box.
     */
    CLOSE = "CLOSE",
    /**
     * Adds a "Delete" button to the message box.
     */
    DELETE = "DELETE",
    /**
     * Adds an "Ignore" button to the message box.
     */
    IGNORE = "IGNORE",
    /**
     * Adds a "No" button to the message box.
     */
    NO = "NO",
    /**
     * Adds an "OK" button to the message box.
     */
    OK = "OK",
    /**
     * Adds a "Retry" button to the message box.
     */
    RETRY = "RETRY",
    /**
     * Adds a "Yes" button to the message box.
     */
    YES = "YES",
  }
  /**
   * Enumeration of the pre-defined icons that can be used in a MessageBox.
   *
   * This enum is part of the 'sap/m/MessageBox' module export and must be accessed by the property 'Icon'.
   */
  enum Icon {
    /**
     * Shows the error icon in the message box.
     */
    ERROR = "undefined",
    /**
     * Shows the information icon in the message box.
     */
    INFORMATION = "undefined",
    /**
     * Shows no icon in the message box.
     */
    NONE = "undefined",
    /**
     * Shows the question icon in the message box.
     */
    QUESTION = "undefined",
    /**
     * Shows the success icon in the message box.
     */
    SUCCESS = "undefined",
    /**
     * Shows the warning icon in the message box.
     */
    WARNING = "undefined",
  }
}

declare module "sap/m/MessageItem" {
  import { default as Item, $ItemSettings } from "sap/ui/core/Item";

  import Link from "sap/m/Link";

  import { URI } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import MessageType from "sap/ui/core/message/MessageType";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * A wrapper control used to hold different types of system messages. Structure: The message item holds
   * the basic set of properties for a system message:
   * 	 -  Type, title, subtitle and description
   * 	 -  If the description contains markup, the `markupDescription` needs to be set to true, to ensure it
   *     is interpreted correctly.
   * 	 -  If the long text description can be specified by a URL by setting, the `longtextUrl` property.
   *
   * 	 -  The message item can have a single {@link sap.m.Link} after the description. It is stored in the
   *     `link` aggregation.  Usage: **Note:** The MessageItem control replaces {@link sap.m.MessagePopoverItem }
   *     as a more generic wrapper for messages.
   *
   * @since 1.46
   */
  export default class MessageItem extends Item {
    /**
     * Constructor for a new MessageItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $MessageItemSettings
    );
    /**
     * Constructor for a new MessageItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $MessageItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.MessageItem with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Item.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, MessageItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.MessageItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Destroys the link in the aggregation {@link #getLink link}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyLink(): this;
    /**
     * Gets current value of property {@link #getActiveTitle activeTitle}.
     *
     * Defines whether the title of the item will be interactive.
     *
     * Default value is `false`.
     *
     * @since 1.58
     *
     * @returns Value of property `activeTitle`
     */
    getActiveTitle(): boolean;
    /**
     * Gets current value of property {@link #getCounter counter}.
     *
     * Defines the number of messages for a given message.
     *
     *
     * @returns Value of property `counter`
     */
    getCounter(): int;
    /**
     * Gets current value of property {@link #getDescription description}.
     *
     * Specifies detailed description of the message
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `description`
     */
    getDescription(): string;
    /**
     * Gets current value of property {@link #getGroupName groupName}.
     *
     * Name of a message group the current item belongs to.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `groupName`
     */
    getGroupName(): string;
    /**
     * Gets content of aggregation {@link #getLink link}.
     *
     * Adds an sap.m.Link control which will be displayed at the end of the description of a message.
     */
    getLink(): Link;
    /**
     * Gets current value of property {@link #getLongtextUrl longtextUrl}.
     *
     * Specifies long text description location URL
     *
     *
     * @returns Value of property `longtextUrl`
     */
    getLongtextUrl(): URI;
    /**
     * Gets current value of property {@link #getMarkupDescription markupDescription}.
     *
     * Specifies if description should be interpreted as markup
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `markupDescription`
     */
    getMarkupDescription(): boolean;
    /**
     * Gets current value of property {@link #getSubtitle subtitle}.
     *
     * Specifies the subtitle of the message **Note:** This is only visible when the `title` property is not
     * empty.
     *
     *
     * @returns Value of property `subtitle`
     */
    getSubtitle(): string;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Specifies the title of the message
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getType type}.
     *
     * Specifies the type of the message
     *
     * Default value is `Error`.
     *
     *
     * @returns Value of property `type`
     */
    getType(): MessageType;
    /**
     * Sets a new value for property {@link #getActiveTitle activeTitle}.
     *
     * Defines whether the title of the item will be interactive.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.58
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setActiveTitle(
      /**
       * New value for property `activeTitle`
       */
      bActiveTitle?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getCounter counter}.
     *
     * Defines the number of messages for a given message.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCounter(
      /**
       * New value for property `counter`
       */
      iCounter?: int
    ): this;
    /**
     * Sets a new value for property {@link #getDescription description}.
     *
     * Specifies detailed description of the message
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDescription(
      /**
       * New value for property `description`
       */
      sDescription?: string
    ): this;
    /**
     * Sets a new value for property {@link #getGroupName groupName}.
     *
     * Name of a message group the current item belongs to.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGroupName(
      /**
       * New value for property `groupName`
       */
      sGroupName?: string
    ): this;
    /**
     * Sets the aggregated {@link #getLink link}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLink(
      /**
       * The link to set
       */
      oLink: Link
    ): this;
    /**
     * Sets a new value for property {@link #getLongtextUrl longtextUrl}.
     *
     * Specifies long text description location URL
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLongtextUrl(
      /**
       * New value for property `longtextUrl`
       */
      sLongtextUrl?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getMarkupDescription markupDescription}.
     *
     * Specifies if description should be interpreted as markup
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMarkupDescription(
      /**
       * New value for property `markupDescription`
       */
      bMarkupDescription?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getSubtitle subtitle}.
     *
     * Specifies the subtitle of the message **Note:** This is only visible when the `title` property is not
     * empty.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSubtitle(
      /**
       * New value for property `subtitle`
       */
      sSubtitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Specifies the title of the message
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
    /**
     * Sets type of the MessageItem. **Note:** if you set the type to None it will be handled and rendered as
     * Information.
     *
     *
     * @returns The MessageItem
     */
    setType(
      /**
       * Type of Message
       */
      sType: MessageType | keyof typeof MessageType
    ): this;
  }
  /**
   * Describes the settings that can be provided to the MessageItem constructor.
   */
  export interface $MessageItemSettings extends $ItemSettings {
    /**
     * Specifies the type of the message
     */
    type?:
      | (MessageType | keyof typeof MessageType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies the title of the message
     */
    title?: string | PropertyBindingInfo;

    /**
     * Specifies the subtitle of the message **Note:** This is only visible when the `title` property is not
     * empty.
     */
    subtitle?: string | PropertyBindingInfo;

    /**
     * Specifies detailed description of the message
     */
    description?: string | PropertyBindingInfo;

    /**
     * Specifies if description should be interpreted as markup
     */
    markupDescription?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies long text description location URL
     */
    longtextUrl?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the number of messages for a given message.
     */
    counter?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Name of a message group the current item belongs to.
     */
    groupName?: string | PropertyBindingInfo;

    /**
     * Defines whether the title of the item will be interactive.
     *
     * @since 1.58
     */
    activeTitle?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Adds an sap.m.Link control which will be displayed at the end of the description of a message.
     */
    link?: Link;
  }
}

declare module "sap/m/MessagePage" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { ID, URI, TextDirection, TitleLevel } from "sap/ui/core/library";

  import Button from "sap/m/Button";

  import Event from "sap/ui/base/Event";

  import Link from "sap/m/Link";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * Displays an empty page with an icon and a header when certain conditions are met. Overview: MessagePage
   * is displayed when there is no data or matching content. There are different use cases where a MessagePage
   * might be visualized, for example:
   * 	 - The search query returned no results
   * 	 - The app contains no items
   * 	 - There are too many items
   * 	 - The application is loading  The layout is unchanged but the text and icon vary depending on
   *     the use case. Usage: **Note:** The `MessagePage` is not intended to be used as a top-level control, but
   *     rather used within controls such as `NavContainer`, `App`, `Shell` or other container controls.
   *
   * @since 1.28
   * @deprecated As of version 1.112. Use the {@link sap.m.IllustratedMessage} instead.
   */
  export default class MessagePage extends Control {
    /**
     * Constructor for a new MessagePage.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/message-page/ Message Page}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $MessagePageSettings
    );
    /**
     * Constructor for a new MessagePage.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/message-page/ Message Page}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $MessagePageSettings
    );

    /**
     * Creates a new subclass of class sap.m.MessagePage with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, MessagePage>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.MessagePage.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds some button to the aggregation {@link #getButtons buttons}.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addButton(
      /**
       * The button to add; if empty, nothing is inserted
       */
      oButton: Button
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navButtonPress navButtonPress} event of this
     * `sap.m.MessagePage`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePage` itself.
     *
     * This event is fired when Nav Button is pressed.
     *
     * @since 1.28.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavButtonPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePage` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navButtonPress navButtonPress} event of this
     * `sap.m.MessagePage`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePage` itself.
     *
     * This event is fired when Nav Button is pressed.
     *
     * @since 1.28.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavButtonPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePage` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the buttons in the aggregation {@link #getButtons buttons}.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyButtons(): this;
    /**
     * Destroys the customDescription in the aggregation {@link #getCustomDescription customDescription}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCustomDescription(): this;
    /**
     * Destroys the customText in the aggregation {@link #getCustomText customText}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCustomText(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:navButtonPress navButtonPress} event of this
     * `sap.m.MessagePage`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.28.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachNavButtonPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:navButtonPress navButtonPress} to attached listeners.
     *
     * @since 1.28.1
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireNavButtonPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets content of aggregation {@link #getButtons buttons}.
     *
     * The buttons displayed under the description text.
     *
     * **Note:** Buttons added to this aggregation are both vertically and horizontally centered. Depending
     * on the available space, they may be rendered on several lines.
     *
     * @since 1.54
     */
    getButtons(): Button[];
    /**
     * Gets content of aggregation {@link #getCustomDescription customDescription}.
     *
     * The (optional) custom description control of this page. Use this aggregation when the "description" (sap.m.Text)
     * control needs to be replaced with an sap.m.Link control. "description" and "textDirection" setters can
     * be used for this aggregation.
     */
    getCustomDescription(): Link;
    /**
     * Gets content of aggregation {@link #getCustomText customText}.
     *
     * The (optional) custom Text control of this page. Use this aggregation when the "text" (sap.m.Text) control
     * needs to be replaced with an sap.m.Link control. "text" and "textDirection" setters can be used for this
     * aggregation.
     */
    getCustomText(): Link;
    /**
     * Gets current value of property {@link #getDescription description}.
     *
     * Determines the detailed description that shows additional information on the MessagePage.
     *
     * Default value is `"Check the filter settings."`.
     *
     *
     * @returns Value of property `description`
     */
    getDescription(): string;
    /**
     * Gets current value of property {@link #getEnableFormattedText enableFormattedText}.
     *
     * Defines whether the value set in the `description` property is displayed as formatted text in HTML format.
     *
     * For details regarding supported HTML tags, see {@link sap.m.FormattedText}
     *
     * Default value is `false`.
     *
     * @since 1.54
     *
     * @returns Value of property `enableFormattedText`
     */
    getEnableFormattedText(): boolean;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Determines the icon displayed on the MessagePage.
     *
     * Default value is `"sap-icon://documents"`.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getIconAlt iconAlt}.
     *
     * Defines the alt attribute of the icon displayed on the `MessagePage`.
     *
     * @since 1.52
     *
     * @returns Value of property `iconAlt`
     */
    getIconAlt(): string;
    /**
     * Gets current value of property {@link #getShowHeader showHeader}.
     *
     * Determines the visibility of the MessagePage header. Can be used to hide the header of the MessagePage
     * when it's embedded in another page.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showHeader`
     */
    getShowHeader(): boolean;
    /**
     * Gets current value of property {@link #getShowNavButton showNavButton}.
     *
     * Determines the visibility of the navigation button in MessagePage header.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showNavButton`
     */
    getShowNavButton(): boolean;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Determines the main text displayed on the MessagePage.
     *
     * Default value is `"No matching items found."`.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * Determines the element's text directionality with enumerated options. By default, the control inherits
     * text direction from the DOM.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Determines the title in the header of MessagePage.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getTitleLevel titleLevel}.
     *
     * Defines the semantic level of the title. When using `Auto`, no explicit level information is written.
     *
     * **Note:** Used for accessibility purposes only.
     *
     * Default value is `Auto`.
     *
     * @since 1.97
     *
     * @returns Value of property `titleLevel`
     */
    getTitleLevel(): TitleLevel;
    /**
     * Checks for the provided `sap.m.Button` in the aggregation {@link #getButtons buttons}. and returns its
     * index if found or -1 otherwise.
     *
     * @since 1.54
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfButton(
      /**
       * The button whose index is looked for
       */
      oButton: Button
    ): int;
    /**
     * Inserts a button into the aggregation {@link #getButtons buttons}.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertButton(
      /**
       * The button to insert; if empty, nothing is inserted
       */
      oButton: Button,
      /**
       * The `0`-based index the button should be inserted at; for a negative value of `iIndex`, the button is
       * inserted at position 0; for a value greater than the current size of the aggregation, the button is inserted
       * at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all the controls from the aggregation {@link #getButtons buttons}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.54
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllButtons(): Button[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes a button from the aggregation {@link #getButtons buttons}.
     *
     * @since 1.54
     *
     * @returns The removed button or `null`
     */
    removeButton(
      /**
       * The button to remove or its index or id
       */
      vButton: int | string | Button
    ): Button | null;
    /**
     * Sets the aggregated {@link #getCustomDescription customDescription}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomDescription(
      /**
       * The customDescription to set
       */
      oCustomDescription: Link
    ): this;
    /**
     * Sets the aggregated {@link #getCustomText customText}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomText(
      /**
       * The customText to set
       */
      oCustomText: Link
    ): this;
    /**
     * Sets a new value for property {@link #getDescription description}.
     *
     * Determines the detailed description that shows additional information on the MessagePage.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Check the filter settings."`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDescription(
      /**
       * New value for property `description`
       */
      sDescription?: string
    ): this;
    /**
     * Sets a new value for property {@link #getEnableFormattedText enableFormattedText}.
     *
     * Defines whether the value set in the `description` property is displayed as formatted text in HTML format.
     *
     * For details regarding supported HTML tags, see {@link sap.m.FormattedText}
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableFormattedText(
      /**
       * New value for property `enableFormattedText`
       */
      bEnableFormattedText?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Determines the icon displayed on the MessagePage.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"sap-icon://documents"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getIconAlt iconAlt}.
     *
     * Defines the alt attribute of the icon displayed on the `MessagePage`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.52
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconAlt(
      /**
       * New value for property `iconAlt`
       */
      sIconAlt?: string
    ): this;
    /**
     * Sets a new value for property {@link #getShowHeader showHeader}.
     *
     * Determines the visibility of the MessagePage header. Can be used to hide the header of the MessagePage
     * when it's embedded in another page.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowHeader(
      /**
       * New value for property `showHeader`
       */
      bShowHeader?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowNavButton showNavButton}.
     *
     * Determines the visibility of the navigation button in MessagePage header.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowNavButton(
      /**
       * New value for property `showNavButton`
       */
      bShowNavButton?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Determines the main text displayed on the MessagePage.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"No matching items found."`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * Determines the element's text directionality with enumerated options. By default, the control inherits
     * text direction from the DOM.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Determines the title in the header of MessagePage.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitleLevel titleLevel}.
     *
     * Defines the semantic level of the title. When using `Auto`, no explicit level information is written.
     *
     * **Note:** Used for accessibility purposes only.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     * @since 1.97
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleLevel(
      /**
       * New value for property `titleLevel`
       */
      sTitleLevel?: TitleLevel | keyof typeof TitleLevel
    ): this;
  }
  /**
   * Describes the settings that can be provided to the MessagePage constructor.
   *
   * @deprecated As of version 1.112. Use the {@link sap.m.IllustratedMessage} instead.
   */
  export interface $MessagePageSettings extends $ControlSettings {
    /**
     * Determines the main text displayed on the MessagePage.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Determines the detailed description that shows additional information on the MessagePage.
     */
    description?: string | PropertyBindingInfo;

    /**
     * Determines the title in the header of MessagePage.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Defines the semantic level of the title. When using `Auto`, no explicit level information is written.
     *
     * **Note:** Used for accessibility purposes only.
     *
     * @since 1.97
     */
    titleLevel?:
      | (TitleLevel | keyof typeof TitleLevel)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the visibility of the MessagePage header. Can be used to hide the header of the MessagePage
     * when it's embedded in another page.
     */
    showHeader?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the visibility of the navigation button in MessagePage header.
     */
    showNavButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the icon displayed on the MessagePage.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the alt attribute of the icon displayed on the `MessagePage`.
     *
     * @since 1.52
     */
    iconAlt?: string | PropertyBindingInfo;

    /**
     * Determines the element's text directionality with enumerated options. By default, the control inherits
     * text direction from the DOM.
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines whether the value set in the `description` property is displayed as formatted text in HTML format.
     *
     * For details regarding supported HTML tags, see {@link sap.m.FormattedText}
     *
     * @since 1.54
     */
    enableFormattedText?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The (optional) custom Text control of this page. Use this aggregation when the "text" (sap.m.Text) control
     * needs to be replaced with an sap.m.Link control. "text" and "textDirection" setters can be used for this
     * aggregation.
     */
    customText?: Link;

    /**
     * The (optional) custom description control of this page. Use this aggregation when the "description" (sap.m.Text)
     * control needs to be replaced with an sap.m.Link control. "description" and "textDirection" setters can
     * be used for this aggregation.
     */
    customDescription?: Link;

    /**
     * The buttons displayed under the description text.
     *
     * **Note:** Buttons added to this aggregation are both vertically and horizontally centered. Depending
     * on the available space, they may be rendered on several lines.
     *
     * @since 1.54
     */
    buttons?: Button[] | Button | AggregationBindingInfo | `{${string}}`;

    /**
     * Association to controls / ids which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * This event is fired when Nav Button is pressed.
     *
     * @since 1.28.1
     */
    navButtonPress?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the MessagePage#navButtonPress event.
   */
  export interface MessagePage$NavButtonPressEventParameters {}

  /**
   * Event object of the MessagePage#navButtonPress event.
   */
  export type MessagePage$NavButtonPressEvent = Event<
    MessagePage$NavButtonPressEventParameters,
    MessagePage
  >;
}

declare module "sap/m/MessagePopover" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import MessageItem from "sap/m/MessageItem";

  import Event from "sap/ui/base/Event";

  import Button from "sap/m/Button";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { VerticalPlacementType } from "sap/m/library";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import MessageType from "sap/ui/core/message/MessageType";

  /**
   * A `MessagePopover` is used to display a summarized list of different types of messages (error, warning,
   * success, and information messages).
   *
   * Overview:
   *
   * It provides a handy and systematized way to navigate and explore details for every message. It is adaptive
   * and responsive. It renders as a dialog with a Close button in the header on phones, and as a popover
   * on tablets and higher resolution devices. It also exposes an event {@link sap.m.MessagePopover#event:activeTitlePress},
   * which can be used for navigation from a message to the source of the issue. Notes::
   * 	 -  If your application changes its model between two interactions with the `MessagePopover`, this could
   *     lead to outdated messages being shown. To avoid this, you need to call `navigateBack` when the model
   *     is updated.
   * 	 -  Messages can have descriptions preformatted with HTML markup. In this case, the `markupDescription`
   *     has to be set to `true`.
   * 	 -  If the message cannot be fully displayed or includes a long description, the `MessagePopover` provides
   *     navigation to the detailed description.  Structure: The `MessagePopover` stores all messages in
   *     an aggregation of type {@link sap.m.MessageItem} named `items`.
   *
   * A set of properties determines how the items are rendered:
   * 	 -  counter - An integer that is used to indicate the number of errors for each type.
   * 	 -  type - The type of message.
   * 	 -  title/subtitle - The title and subtitle of the message.
   * 	 -  description - The long text description of the message.
   * 	 -  activeTitle - Determines whether the title of the item is interactive.  Usage: When to use::
   *
   * 	 - When you want to make sure that all content is visible on any device.
   * 	 - When you want a way to centrally manage messages and show them to the user without additional work
   *     for the developer. The `MessagePopover` is triggered from a messaging button in the footer toolbar. If
   *     an error has occurred at any validation point, the total number of messages should be incremented, but
   *     the user's work shouldn't be interrupted. Navigation between the message item and the source of the error
   *     can be created, if needed by the application. This can be done by setting the `activeTitle` property
   *     to `true` and providing a handler for the `activeTitlePress` event. In addition, you can achieve the
   *     same functionality inside a different container using the {@link sap.m.MessageView} control.  Responsive
   *     Behavior: On mobile phones, the `MessagePopover` is automatically shown in full screen mode.
   *  On desktop and tablet, the message popover opens in a popover.
   *  On desktop the opened popover is resizable, if it is placed in a {@link sap.m.Toolbar}, {@link sap.m.Bar},
   * or used in {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.28
   */
  export default class MessagePopover extends Control {
    /**
     * Constructor for a new MessagePopover.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/message-popover/ Message Popover}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $MessagePopoverSettings
    );
    /**
     * Constructor for a new MessagePopover.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/message-popover/ Message Popover}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $MessagePopoverSettings
    );

    /**
     * Creates a new subclass of class sap.m.MessagePopover with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, MessagePopover>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.MessagePopover.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Setter for default description and URL validation callbacks across all instances of MessagePopover
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    static setDefaultHandlers(
      /**
       * An object setting default callbacks
       */
      mDefaultHandlers: {
        /**
         * The description handler
         */
        asyncDescriptionHandler: Function;
        /**
         * The URL handler
         */
        asyncURLHandler: Function;
      }
    ): void;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: MessageItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:activeTitlePress activeTitlePress} event of
     * this `sap.m.MessagePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePopover` itself.
     *
     * Event fired when an active title of a `MessageItem` is clicked.
     *
     * @since 1.58
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachActiveTitlePress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessagePopover$ActiveTitlePressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:activeTitlePress activeTitlePress} event of
     * this `sap.m.MessagePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePopover` itself.
     *
     * Event fired when an active title of a `MessageItem` is clicked.
     *
     * @since 1.58
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachActiveTitlePress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessagePopover$ActiveTitlePressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterClose afterClose} event of this `sap.m.MessagePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePopover` itself.
     *
     * Event fired after the popover is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessagePopover$AfterCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterClose afterClose} event of this `sap.m.MessagePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePopover` itself.
     *
     * Event fired after the popover is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessagePopover$AfterCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterOpen afterOpen} event of this `sap.m.MessagePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePopover` itself.
     *
     * Event fired after the popover is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessagePopover$AfterOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterOpen afterOpen} event of this `sap.m.MessagePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePopover` itself.
     *
     * Event fired after the popover is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessagePopover$AfterOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.MessagePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePopover` itself.
     *
     * Event fired before the popover is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessagePopover$BeforeCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.MessagePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePopover` itself.
     *
     * Event fired before the popover is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessagePopover$BeforeCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.MessagePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePopover` itself.
     *
     * Event fired before the popover is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessagePopover$BeforeOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.MessagePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePopover` itself.
     *
     * Event fired before the popover is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessagePopover$BeforeOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemSelect itemSelect} event of this `sap.m.MessagePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePopover` itself.
     *
     * Event fired when description is shown.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessagePopover$ItemSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemSelect itemSelect} event of this `sap.m.MessagePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePopover` itself.
     *
     * Event fired when description is shown.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessagePopover$ItemSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:listSelect listSelect} event of this `sap.m.MessagePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePopover` itself.
     *
     * Event fired when one of the lists is shown when (not) filtered by type.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachListSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessagePopover$ListSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:listSelect listSelect} event of this `sap.m.MessagePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePopover` itself.
     *
     * Event fired when one of the lists is shown when (not) filtered by type.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachListSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessagePopover$ListSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:longtextLoaded longtextLoaded} event of this
     * `sap.m.MessagePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePopover` itself.
     *
     * Event fired when the long text description data from a remote URL is loaded.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLongtextLoaded(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:longtextLoaded longtextLoaded} event of this
     * `sap.m.MessagePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePopover` itself.
     *
     * Event fired when the long text description data from a remote URL is loaded.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLongtextLoaded(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:urlValidated urlValidated} event of this `sap.m.MessagePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePopover` itself.
     *
     * Event fired when a validation of a URL from long text description is ready.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUrlValidated(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:urlValidated urlValidated} event of this `sap.m.MessagePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessagePopover` itself.
     *
     * Event fired when a validation of a URL from long text description is ready.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUrlValidated(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessagePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Closes the MessagePopover
     *
     *
     * @returns Reference to the 'this' for chaining purposes
     */
    close(): this;
    /**
     * Destroys the headerButton in the aggregation {@link #getHeaderButton headerButton}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyHeaderButton(): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:activeTitlePress activeTitlePress} event of
     * this `sap.m.MessagePopover`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.58
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachActiveTitlePress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MessagePopover$ActiveTitlePressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterClose afterClose} event of this `sap.m.MessagePopover`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MessagePopover$AfterCloseEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterOpen afterOpen} event of this `sap.m.MessagePopover`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MessagePopover$AfterOpenEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeClose beforeClose} event of this `sap.m.MessagePopover`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MessagePopover$BeforeCloseEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeOpen beforeOpen} event of this `sap.m.MessagePopover`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MessagePopover$BeforeOpenEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:itemSelect itemSelect} event of this `sap.m.MessagePopover`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachItemSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MessagePopover$ItemSelectEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:listSelect listSelect} event of this `sap.m.MessagePopover`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachListSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MessagePopover$ListSelectEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:longtextLoaded longtextLoaded} event of this
     * `sap.m.MessagePopover`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLongtextLoaded(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:urlValidated urlValidated} event of this `sap.m.MessagePopover`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUrlValidated(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:activeTitlePress activeTitlePress} to attached listeners.
     *
     * @since 1.58
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireActiveTitlePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MessagePopover$ActiveTitlePressEventParameters
    ): this;
    /**
     * Fires event {@link #event:afterClose afterClose} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MessagePopover$AfterCloseEventParameters
    ): this;
    /**
     * Fires event {@link #event:afterOpen afterOpen} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MessagePopover$AfterOpenEventParameters
    ): this;
    /**
     * Fires event {@link #event:beforeClose beforeClose} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforeClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MessagePopover$BeforeCloseEventParameters
    ): this;
    /**
     * Fires event {@link #event:beforeOpen beforeOpen} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforeOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MessagePopover$BeforeOpenEventParameters
    ): this;
    /**
     * Fires event {@link #event:itemSelect itemSelect} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireItemSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MessagePopover$ItemSelectEventParameters
    ): this;
    /**
     * Fires event {@link #event:listSelect listSelect} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireListSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MessagePopover$ListSelectEventParameters
    ): this;
    /**
     * Fires event {@link #event:longtextLoaded longtextLoaded} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLongtextLoaded(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:urlValidated urlValidated} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUrlValidated(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getAsyncDescriptionHandler asyncDescriptionHandler}.
     *
     * Callback function for resolving a promise after description has been asynchronously loaded inside this
     * function. You can use this function in order to validate the description before displaying it.
     *
     *
     * @returns Value of property `asyncDescriptionHandler`
     */
    getAsyncDescriptionHandler(): Function;
    /**
     * Gets current value of property {@link #getAsyncURLHandler asyncURLHandler}.
     *
     * Callback function for resolving a promise after a link has been asynchronously validated inside this
     * function. You can use this function in order to validate URLs before displaying them inside the description.
     *
     *
     * @returns Value of property `asyncURLHandler`
     */
    getAsyncURLHandler(): Function;
    /**
     * Gets current value of property {@link #getGroupItems groupItems}.
     *
     * Defines whether the MessageItems are grouped or not.
     *
     * Default value is `false`.
     *
     * @since 1.73
     *
     * @returns Value of property `groupItems`
     */
    getGroupItems(): boolean;
    /**
     * Gets content of aggregation {@link #getHeaderButton headerButton}.
     *
     * Sets a custom header button.
     */
    getHeaderButton(): Button;
    /**
     * Gets current value of property {@link #getInitiallyExpanded initiallyExpanded}.
     *
     * Sets the initial state of the control - expanded or collapsed. By default the control opens as expanded.
     * Note: If there is only one message in the control, this state will be ignored and the details page of
     * the message will be shown.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `initiallyExpanded`
     */
    getInitiallyExpanded(): boolean;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * A list with message items.
     */
    getItems(): MessageItem[];
    /**
     * Gets current value of property {@link #getPlacement placement}.
     *
     * Determines the position, where the control will appear on the screen. The default value is `sap.m.VerticalPlacementType.Vertical`.
     * Setting this property while the control is open, will not cause any re-rendering and changing of the
     * position. Changes will only be applied with the next interaction.
     *
     * Default value is `"Vertical"`.
     *
     *
     * @returns Value of property `placement`
     */
    getPlacement(): VerticalPlacementType;
    /**
     * Checks for the provided `sap.m.MessageItem` in the aggregation {@link #getItems items}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: MessageItem
    ): int;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: MessageItem,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * The method checks if the MessagePopover is open. It returns true when the MessagePopover is currently
     * open (this includes opening and closing animations), otherwise it returns false
     *
     *
     * @returns Whether the MessagePopover is open
     */
    isOpen(): boolean;
    /**
     * Navigates back to the list page.
     */
    navigateBack(): void;
    /**
     * Opens the MessagePopover
     *
     *
     * @returns Reference to the 'this' for chaining purposes
     */
    openBy(
      /**
       * Control which opens the MessagePopover
       */
      oControl: Control
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): MessageItem[];
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | MessageItem
    ): MessageItem | null;
    /**
     * Sets a new value for property {@link #getAsyncDescriptionHandler asyncDescriptionHandler}.
     *
     * Callback function for resolving a promise after description has been asynchronously loaded inside this
     * function. You can use this function in order to validate the description before displaying it.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAsyncDescriptionHandler(
      /**
       * New value for property `asyncDescriptionHandler`
       */
      fnAsyncDescriptionHandler?: Function
    ): this;
    /**
     * Sets a new value for property {@link #getAsyncURLHandler asyncURLHandler}.
     *
     * Callback function for resolving a promise after a link has been asynchronously validated inside this
     * function. You can use this function in order to validate URLs before displaying them inside the description.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAsyncURLHandler(
      /**
       * New value for property `asyncURLHandler`
       */
      fnAsyncURLHandler?: Function
    ): this;
    /**
     * Sets a new value for property {@link #getGroupItems groupItems}.
     *
     * Defines whether the MessageItems are grouped or not.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.73
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGroupItems(
      /**
       * New value for property `groupItems`
       */
      bGroupItems?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getHeaderButton headerButton}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeaderButton(
      /**
       * The headerButton to set
       */
      oHeaderButton: Button
    ): this;
    /**
     * Sets a new value for property {@link #getInitiallyExpanded initiallyExpanded}.
     *
     * Sets the initial state of the control - expanded or collapsed. By default the control opens as expanded.
     * Note: If there is only one message in the control, this state will be ignored and the details page of
     * the message will be shown.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInitiallyExpanded(
      /**
       * New value for property `initiallyExpanded`
       */
      bInitiallyExpanded?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getPlacement placement}.
     *
     * Determines the position, where the control will appear on the screen. The default value is `sap.m.VerticalPlacementType.Vertical`.
     * Setting this property while the control is open, will not cause any re-rendering and changing of the
     * position. Changes will only be applied with the next interaction.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Vertical"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPlacement(
      /**
       * New value for property `placement`
       */
      sPlacement?: VerticalPlacementType | keyof typeof VerticalPlacementType
    ): this;
    /**
     * This method toggles between open and closed state of the MessagePopover instance. oControl parameter
     * is mandatory in the same way as in 'openBy' method
     *
     *
     * @returns Reference to the 'this' for chaining purposes
     */
    toggle(
      /**
       * Control which opens the MessagePopover
       */
      oControl: Control
    ): this;
  }
  /**
   * Describes the settings that can be provided to the MessagePopover constructor.
   */
  export interface $MessagePopoverSettings extends $ControlSettings {
    /**
     * Callback function for resolving a promise after description has been asynchronously loaded inside this
     * function. You can use this function in order to validate the description before displaying it.
     */
    asyncDescriptionHandler?: Function | PropertyBindingInfo | `{${string}}`;

    /**
     * Callback function for resolving a promise after a link has been asynchronously validated inside this
     * function. You can use this function in order to validate URLs before displaying them inside the description.
     */
    asyncURLHandler?: Function | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the position, where the control will appear on the screen. The default value is `sap.m.VerticalPlacementType.Vertical`.
     * Setting this property while the control is open, will not cause any re-rendering and changing of the
     * position. Changes will only be applied with the next interaction.
     */
    placement?:
      | (VerticalPlacementType | keyof typeof VerticalPlacementType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Sets the initial state of the control - expanded or collapsed. By default the control opens as expanded.
     * Note: If there is only one message in the control, this state will be ignored and the details page of
     * the message will be shown.
     */
    initiallyExpanded?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether the MessageItems are grouped or not.
     *
     * @since 1.73
     */
    groupItems?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * A list with message items.
     */
    items?:
      | MessageItem[]
      | MessageItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Sets a custom header button.
     */
    headerButton?: Button;

    /**
     * Event fired after the popover is opened.
     */
    afterOpen?: (oEvent: MessagePopover$AfterOpenEvent) => void;

    /**
     * Event fired after the popover is closed.
     */
    afterClose?: (oEvent: MessagePopover$AfterCloseEvent) => void;

    /**
     * Event fired before the popover is opened.
     */
    beforeOpen?: (oEvent: MessagePopover$BeforeOpenEvent) => void;

    /**
     * Event fired before the popover is closed.
     */
    beforeClose?: (oEvent: MessagePopover$BeforeCloseEvent) => void;

    /**
     * Event fired when description is shown.
     */
    itemSelect?: (oEvent: MessagePopover$ItemSelectEvent) => void;

    /**
     * Event fired when one of the lists is shown when (not) filtered by type.
     */
    listSelect?: (oEvent: MessagePopover$ListSelectEvent) => void;

    /**
     * Event fired when the long text description data from a remote URL is loaded.
     */
    longtextLoaded?: (oEvent: Event) => void;

    /**
     * Event fired when a validation of a URL from long text description is ready.
     */
    urlValidated?: (oEvent: Event) => void;

    /**
     * Event fired when an active title of a `MessageItem` is clicked.
     *
     * @since 1.58
     */
    activeTitlePress?: (oEvent: MessagePopover$ActiveTitlePressEvent) => void;
  }

  /**
   * Parameters of the MessagePopover#activeTitlePress event.
   */
  export interface MessagePopover$ActiveTitlePressEventParameters {
    /**
     * Refers to the message item that contains the activeTitle.
     */
    item?: MessageItem;
  }

  /**
   * Event object of the MessagePopover#activeTitlePress event.
   */
  export type MessagePopover$ActiveTitlePressEvent = Event<
    MessagePopover$ActiveTitlePressEventParameters,
    MessagePopover
  >;

  /**
   * Parameters of the MessagePopover#afterClose event.
   */
  export interface MessagePopover$AfterCloseEventParameters {
    /**
     * Refers to the control that opens the popover.
     */
    openBy?: Control;
  }

  /**
   * Event object of the MessagePopover#afterClose event.
   */
  export type MessagePopover$AfterCloseEvent = Event<
    MessagePopover$AfterCloseEventParameters,
    MessagePopover
  >;

  /**
   * Parameters of the MessagePopover#afterOpen event.
   */
  export interface MessagePopover$AfterOpenEventParameters {
    /**
     * Refers to the control that opens the popover.
     */
    openBy?: Control;
  }

  /**
   * Event object of the MessagePopover#afterOpen event.
   */
  export type MessagePopover$AfterOpenEvent = Event<
    MessagePopover$AfterOpenEventParameters,
    MessagePopover
  >;

  /**
   * Parameters of the MessagePopover#beforeClose event.
   */
  export interface MessagePopover$BeforeCloseEventParameters {
    /**
     * Refers to the control that opens the popover. See {@link module:sap/ui/core/message/MessageType} enum
     * values for types.
     */
    openBy?: Control;
  }

  /**
   * Event object of the MessagePopover#beforeClose event.
   */
  export type MessagePopover$BeforeCloseEvent = Event<
    MessagePopover$BeforeCloseEventParameters,
    MessagePopover
  >;

  /**
   * Parameters of the MessagePopover#beforeOpen event.
   */
  export interface MessagePopover$BeforeOpenEventParameters {
    /**
     * Refers to the control that opens the popover.
     */
    openBy?: Control;
  }

  /**
   * Event object of the MessagePopover#beforeOpen event.
   */
  export type MessagePopover$BeforeOpenEvent = Event<
    MessagePopover$BeforeOpenEventParameters,
    MessagePopover
  >;

  /**
   * Parameters of the MessagePopover#itemSelect event.
   */
  export interface MessagePopover$ItemSelectEventParameters {
    /**
     * Refers to the `MessagePopover` item that is being presented.
     */
    item?: MessageItem;

    /**
     * Refers to the type of messages being shown.
     */
    messageTypeFilter?: MessageType | keyof typeof MessageType;
  }

  /**
   * Event object of the MessagePopover#itemSelect event.
   */
  export type MessagePopover$ItemSelectEvent = Event<
    MessagePopover$ItemSelectEventParameters,
    MessagePopover
  >;

  /**
   * Parameters of the MessagePopover#listSelect event.
   */
  export interface MessagePopover$ListSelectEventParameters {
    /**
     * This parameter refers to the type of messages being shown.
     */
    messageTypeFilter?: MessageType | keyof typeof MessageType;
  }

  /**
   * Event object of the MessagePopover#listSelect event.
   */
  export type MessagePopover$ListSelectEvent = Event<
    MessagePopover$ListSelectEventParameters,
    MessagePopover
  >;

  /**
   * Parameters of the MessagePopover#longtextLoaded event.
   */
  export interface MessagePopover$LongtextLoadedEventParameters {}

  /**
   * Event object of the MessagePopover#longtextLoaded event.
   */
  export type MessagePopover$LongtextLoadedEvent = Event<
    MessagePopover$LongtextLoadedEventParameters,
    MessagePopover
  >;

  /**
   * Parameters of the MessagePopover#urlValidated event.
   */
  export interface MessagePopover$UrlValidatedEventParameters {}

  /**
   * Event object of the MessagePopover#urlValidated event.
   */
  export type MessagePopover$UrlValidatedEvent = Event<
    MessagePopover$UrlValidatedEventParameters,
    MessagePopover
  >;
}

declare module "sap/m/MessagePopoverItem" {
  import {
    default as MessageItem,
    $MessageItemSettings,
  } from "sap/m/MessageItem";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * Items provide information about Error Messages in the page.
   *
   * @since 1.28
   * @deprecated As of version 1.46. use MessageItem instead
   */
  export default class MessagePopoverItem extends MessageItem {
    /**
     * Constructor for a new MessagePopoverItem.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $MessagePopoverItemSettings
    );
    /**
     * Constructor for a new MessagePopoverItem.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $MessagePopoverItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.MessagePopoverItem with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.MessageItem.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, MessagePopoverItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.MessagePopoverItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the MessagePopoverItem constructor.
   *
   * @deprecated As of version 1.46. use MessageItem instead
   */
  export interface $MessagePopoverItemSettings extends $MessageItemSettings {}
}

declare module "sap/m/MessageStrip" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import Link from "sap/m/Link";

  import Event from "sap/ui/base/Event";

  import { URI } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import MessageType from "sap/ui/core/message/MessageType";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * MessageStrip is a control that enables the embedding of application-related messages in the application.
   * Overview: The message strip displays 4 types of messages, each with a corresponding semantic color and
   * icon: Information, Success, Warning and Error.
   *
   * Each message can have a close button, so that it can be removed from the UI if needed.
   *
   * You can use a limited set of formatting tags for the message text by setting `enableFormattedText`. The
   * allowed tags are: With version 1.50
   * 	 - <a>
   * 	 - <em>
   * 	 - <strong>
   * 	 - <u>  With version 1.85
   * 	 - <br>
   *
   * Dynamically generated Message Strip: To meet the accessibility requirements when using dynamically generated
   * Message Strip you must implement it alongside `sap.ui.core.InvisibleMessage`. This will allow screen
   * readers to announce it in real time. We suggest such dynamically generated message strips to be announced
   * as Information Bar, as shown in our “Dynamic Message Strip Generator sample.”
   *
   * Usage: When to use:
   * 	 - You want to provide information or status update within the detail area of an object  When not
   *     to use:
   * 	 - You want to display information within the object page header, within a control, in the master list,
   *     or above the page header.
   *
   * @since 1.30
   */
  export default class MessageStrip extends Control {
    /**
     * Constructor for a new MessageStrip.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/message-strip/ Message Strip}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $MessageStripSettings
    );
    /**
     * Constructor for a new MessageStrip.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/message-strip/ Message Strip}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $MessageStripSettings
    );

    /**
     * Creates a new subclass of class sap.m.MessageStrip with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, MessageStrip>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.MessageStrip.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some control to the aggregation {@link #getControls controls}.
     *
     * @since 1.129
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addControl(
      /**
       * The control to add; if empty, nothing is inserted
       */
      oControl: Link
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:close close} event of this `sap.m.MessageStrip`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessageStrip` itself.
     *
     * This event will be fired after the container is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessageStrip` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:close close} event of this `sap.m.MessageStrip`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessageStrip` itself.
     *
     * This event will be fired after the container is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessageStrip` itself
       */
      oListener?: object
    ): this;
    /**
     * Closes the MessageStrip. This method sets the visible property of the MessageStrip to false. The MessageStrip
     * can be shown again by setting the visible property to true.
     */
    close(): void;
    /**
     * Destroys all the controls in the aggregation {@link #getControls controls}.
     *
     * @since 1.129
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyControls(): this;
    /**
     * Destroys the link in the aggregation {@link #getLink link}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyLink(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:close close} event of this `sap.m.MessageStrip`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:close close} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets content of aggregation {@link #getControls controls}.
     *
     * List of `sap.m.Link` controls that replace the placeholders in the text. Placeholders are replaced according
     * to their indexes. The first link in the aggregation replaces the placeholder with index %%0, and so on.
     * **Note:** Placeholders are replaced if the `enableFormattedText` property is set to true.
     *
     * @since 1.129
     */
    getControls(): Link[];
    /**
     * Gets current value of property {@link #getCustomIcon customIcon}.
     *
     * Determines a custom icon which is displayed. If none is set, the default icon for this message type is
     * used.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `customIcon`
     */
    getCustomIcon(): URI;
    /**
     * Gets current value of property {@link #getEnableFormattedText enableFormattedText}.
     *
     * Determines the limited collection of HTML elements passed to the `text` property should be evaluated.
     * The `text` property value is set as `htmlText` to an internal instance of {@link sap.m.FormattedText}
     *
     * **Note:** If this property is set to true the string passed to `text` property can evaluate the following
     * list of limited HTML elements. All other HTML elements and their nested content will not be rendered
     * by the control:
     * 	 - `a`
     * 	 - `br`
     * 	 - `em`
     * 	 - `strong`
     * 	 - `u`
     *
     * Default value is `false`.
     *
     * @since 1.50
     *
     * @returns Value of property `enableFormattedText`
     */
    getEnableFormattedText(): boolean;
    /**
     * Gets content of aggregation {@link #getLink link}.
     *
     * Adds an sap.m.Link control which will be displayed at the end of the message.
     */
    getLink(): Link;
    /**
     * Gets current value of property {@link #getShowCloseButton showCloseButton}.
     *
     * Determines if the message has a close button in the upper right corner.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showCloseButton`
     */
    getShowCloseButton(): boolean;
    /**
     * Gets current value of property {@link #getShowIcon showIcon}.
     *
     * Determines if an icon is displayed for the message.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showIcon`
     */
    getShowIcon(): boolean;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Determines the text of the message.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getType type}.
     *
     * Determines the type of messages that are displayed in the MessageStrip. Possible values are: Information
     * (default), Success, Warning, Error. If None is passed, the value is set to Information and a warning
     * is displayed in the console.
     *
     * Default value is `Information`.
     *
     *
     * @returns Value of property `type`
     */
    getType(): MessageType;
    /**
     * Checks for the provided `sap.m.Link` in the aggregation {@link #getControls controls}. and returns its
     * index if found or -1 otherwise.
     *
     * @since 1.129
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfControl(
      /**
       * The control whose index is looked for
       */
      oControl: Link
    ): int;
    /**
     * Inserts a control into the aggregation {@link #getControls controls}.
     *
     * @since 1.129
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertControl(
      /**
       * The control to insert; if empty, nothing is inserted
       */
      oControl: Link,
      /**
       * The `0`-based index the control should be inserted at; for a negative value of `iIndex`, the control
       * is inserted at position 0; for a value greater than the current size of the aggregation, the control
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getControls controls}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.129
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllControls(): Link[];
    /**
     * Removes a control from the aggregation {@link #getControls controls}.
     *
     * @since 1.129
     *
     * @returns The removed control or `null`
     */
    removeControl(
      /**
       * The control to remove or its index or id
       */
      vControl: int | string | Link
    ): Link | null;
    /**
     * Sets a new value for property {@link #getCustomIcon customIcon}.
     *
     * Determines a custom icon which is displayed. If none is set, the default icon for this message type is
     * used.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomIcon(
      /**
       * New value for property `customIcon`
       */
      sCustomIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getEnableFormattedText enableFormattedText}.
     *
     * Determines the limited collection of HTML elements passed to the `text` property should be evaluated.
     * The `text` property value is set as `htmlText` to an internal instance of {@link sap.m.FormattedText}
     *
     * **Note:** If this property is set to true the string passed to `text` property can evaluate the following
     * list of limited HTML elements. All other HTML elements and their nested content will not be rendered
     * by the control:
     * 	 - `a`
     * 	 - `br`
     * 	 - `em`
     * 	 - `strong`
     * 	 - `u`
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.50
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableFormattedText(
      /**
       * New value for property `enableFormattedText`
       */
      bEnableFormattedText?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getLink link}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLink(
      /**
       * The link to set
       */
      oLink: Link
    ): this;
    /**
     * Sets a new value for property {@link #getShowCloseButton showCloseButton}.
     *
     * Determines if the message has a close button in the upper right corner.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowCloseButton(
      /**
       * New value for property `showCloseButton`
       */
      bShowCloseButton?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowIcon showIcon}.
     *
     * Determines if an icon is displayed for the message.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowIcon(
      /**
       * New value for property `showIcon`
       */
      bShowIcon?: boolean
    ): this;
    /**
     * Setter for property text. Default value is empty/undefined
     *
     *
     * @returns this to allow method chaining
     */
    setText(
      /**
       * new value for property text
       */
      sText: string
    ): this;
    /**
     * Sets a new value for property {@link #getType type}.
     *
     * Determines the type of messages that are displayed in the MessageStrip. Possible values are: Information
     * (default), Success, Warning, Error. If None is passed, the value is set to Information and a warning
     * is displayed in the console.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Information`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setType(
      /**
       * New value for property `type`
       */
      sType?: MessageType | keyof typeof MessageType
    ): this;
  }
  /**
   * Describes the settings that can be provided to the MessageStrip constructor.
   */
  export interface $MessageStripSettings extends $ControlSettings {
    /**
     * Determines the text of the message.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Determines the type of messages that are displayed in the MessageStrip. Possible values are: Information
     * (default), Success, Warning, Error. If None is passed, the value is set to Information and a warning
     * is displayed in the console.
     */
    type?:
      | (MessageType | keyof typeof MessageType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines a custom icon which is displayed. If none is set, the default icon for this message type is
     * used.
     */
    customIcon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines if an icon is displayed for the message.
     */
    showIcon?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines if the message has a close button in the upper right corner.
     */
    showCloseButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the limited collection of HTML elements passed to the `text` property should be evaluated.
     * The `text` property value is set as `htmlText` to an internal instance of {@link sap.m.FormattedText}
     *
     * **Note:** If this property is set to true the string passed to `text` property can evaluate the following
     * list of limited HTML elements. All other HTML elements and their nested content will not be rendered
     * by the control:
     * 	 - `a`
     * 	 - `br`
     * 	 - `em`
     * 	 - `strong`
     * 	 - `u`
     *
     * @since 1.50
     */
    enableFormattedText?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Adds an sap.m.Link control which will be displayed at the end of the message.
     */
    link?: Link;

    /**
     * List of `sap.m.Link` controls that replace the placeholders in the text. Placeholders are replaced according
     * to their indexes. The first link in the aggregation replaces the placeholder with index %%0, and so on.
     * **Note:** Placeholders are replaced if the `enableFormattedText` property is set to true.
     *
     * @since 1.129
     */
    controls?: Link[] | Link | AggregationBindingInfo | `{${string}}`;

    /**
     * This event will be fired after the container is closed.
     */
    close?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the MessageStrip#close event.
   */
  export interface MessageStrip$CloseEventParameters {}

  /**
   * Event object of the MessageStrip#close event.
   */
  export type MessageStrip$CloseEvent = Event<
    MessageStrip$CloseEventParameters,
    MessageStrip
  >;
}

declare module "sap/m/MessageToast" {
  import { CSSSize } from "sap/ui/core/library";

  import Popup from "sap/ui/core/Popup";

  import Control from "sap/ui/core/Control";

  /**
   * A small, non-disruptive popup for messages. Overview: A message toast is a small, non-disruptive popup
   * for success or information messages that disappears automatically after a few seconds. Toasts automatically
   * disappear after a timeout unless the user moves the mouse over the toast or taps on it. Notes::
   *
   * 	 - If the configured message contains HTML code or script tags, those will be escaped.
   * 	 - Line breaks (\r\n, \n\r, \r, \n) will be visualized.
   * 	 - Only one message toast can be shown at a time in the same place.  Example:: Here is an example
   *     of a MessageToast with all default options:
   * ```javascript
   *
   * sap.m.MessageToast.show("This message should appear in the message toast", {
   *     duration: 3000,                  // default
   *     width: "15em",                   // default
   *     my: "center bottom",             // default
   *     at: "center bottom",             // default
   *     of: window,                      // default
   *     offset: "0 0",                   // default
   *     collision: "fit fit",            // default
   *     onClose: null,                   // default
   *     autoClose: true,                 // default
   *     animationTimingFunction: "ease", // default
   *     animationDuration: 1000,         // default
   *     closeOnBrowserNavigation: true   // default
   * });
   * ```
   *  Usage: When to use::
   * 	 - You want to display a short success of information message.
   * 	 - You do not want to interrupt users while they are performing an action.
   * 	 - You want to confirm a successful action.  When not to use::
   * 	 - You want to display an error or warning message.
   * 	 - You want to interrupt users while they are performing an action.
   * 	 - You want to make sure that users read the message before they leave the page.
   * 	 - You want users to be able to copy some part of the message text. (In this case, show a success {@link sap.m.Dialog Message Dialog}.)
   *      Responsive Behavior: The message toast has the same behavior on all devices. However, you can adjust
   *     the width of the control, for example, for use on a desktop device.
   * See:
   * 	{@link fiori:https://experience.sap.com/fiori-design-web/message-toast/ Message Toast}
   *
   * @since 1.9.2
   */
  interface MessageToast {
    /**
     * Creates and displays a simple message toast notification message with the given text, and optionally
     * other options.
     *
     * The only mandatory parameter is `sMessage`.
     */
    show(
      /**
       * The message to be displayed.
       */
      sMessage: string,
      /**
       * Object which can contain all other options. Not all entries in this object are required. This property
       * is optional.
       */
      mOptions?: {
        /**
         * Time in milliseconds before the close animation starts. Needs to be a finite positive nonzero integer.
         */
        duration?: int;
        /**
         * The width of the message toast, this value can be provided in %, em, px and all possible CSS measures.
         */
        width?: CSSSize;
        /**
         * Specifies which point of the message toast should be aligned (e.g. `Dock.LeftTop` To use as align point
         * the left top corner of the message toast).
         */
        my?: typeof Popup.Dock | keyof typeof Popup.Dock;
        /**
         * Specifies the point of the reference element to which the message toast should be aligned (e.g. `Dock.RightBottom`
         * To position the message toast according to the bottom right corner of the reference element).
         */
        at?: typeof Popup.Dock | keyof typeof Popup.Dock;
        /**
         * Specifies the reference element to which the message toast should be aligned, by default it is aligned
         * to the browser visual viewport.
         */
        of?: Control | Element | jQuery | Window;
        /**
         * The offset relative to the docking point, specified as a string with space-separated pixel values (e.g.
         * "10 5" to move the message toast 10 pixels to the right and 5 pixels to the bottom).
         */
        offset?: string;
        /**
         * Specifies how the position of the message toast should be adjusted in case it overflows the screen in
         * some direction. Possible values “fit”, “flip”, “none”, or a pair for horizontal and vertical e.g. "fit
         * flip”, "fit none".
         */
        collision?: string;
        /**
         * Function to be called when the message toast closes.
         */
        onClose?: Function;
        /**
         * Specify whether the message toast should close as soon as the end user touches the screen.
         */
        autoClose?: boolean;
        /**
         * Describes how the close animation will progress. Possible values "ease", "linear", "ease-in", "ease-out",
         * "ease-in-out".
         */
        animationTimingFunction?: string;
        /**
         * Time in milliseconds that the close animation takes to complete. Needs to be a finite positive integer.
         * For not animation set to 0.
         */
        animationDuration?: int;
        /**
         * Specifies if the message toast closes on browser navigation.
         */
        closeOnBrowserNavigation?: boolean;
      }
    ): void;
  }
  const MessageToast: MessageToast;
  export default MessageToast;
}

declare module "sap/m/MessageView" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import MessageItem from "sap/m/MessageItem";

  import Event from "sap/ui/base/Event";

  import Button from "sap/m/Button";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import MessageType from "sap/ui/core/message/MessageType";

  /**
   * It is used to display a summarized list of different types of messages (error, warning, success, and
   * information messages).
   *
   * Overview: It is meant to be embedded into container controls (such as {@link sap.m.Popover}, {@link sap.m.ResponsivePopover},
   * {@link sap.m.Dialog}). It provides a handy and systematized way to navigate and explore details for every
   * message. If the `MessageView` contains only one item, which has either description, markupDescription
   * or longTextUrl, its details page will be displayed initially. It also exposes the {@link sap.m.MessageView#event:activeTitlePress }
   * event, which can be used for navigation from a message to its source. Notes::
   * 	 - If your application changes its model between two interactions with the `MessageView`, this could
   *     lead to outdated messages being shown. To avoid this, you need to call `navigateBack` on the `MessageView`
   *     BEFORE opening its container.
   * 	 -  Messages can have descriptions preformatted with HTML markup. In this case, the `markupDescription`
   *     has to be set to `true`.
   * 	 -  If the message cannot be fully displayed, or includes a long description, the `MessageView` provides
   *     navigation to the detailed description.   Structure: The `MessageView` stores all messages in an
   *     association of type {@link sap.m.MessageItem}, named `items`.
   *  A set of properties determines how the items are rendered:
   * 	 -  counter - An integer that is used to indicate the number of errors for each type.
   * 	 -  type - The type of message.
   * 	 -  title/subtitle - The title and subtitle of the message.
   * 	 -  description - The long text description of the message.
   * 	 -  activeTitle - Determines whether the title of the item is interactive.  Usage: When to use::
   *
   * 	 - When you want a way to centrally manage messages and show them to the user without additional work
   *     for the developer. If needed the navigation between the message item and the source of the error can
   *     be created by the application. This can be done by setting the `activeTitle` property to true and providing
   *     a handler for the `activeTitlePress` event.  Responsive Behavior: The responsiveness of the `MessageView`
   *     is determined by the container in which it is embedded. For that reason the control could not be visualized
   *     if the container’s sizes are not defined.
   *
   * @since 1.46
   */
  export default class MessageView extends Control {
    /**
     * Constructor for a new MessageView
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/message-view/ Message View}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $MessageViewSettings
    );
    /**
     * Constructor for a new MessageView
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/message-view/ Message View}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $MessageViewSettings
    );

    /**
     * Creates a new subclass of class sap.m.MessageView with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, MessageView>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.MessageView.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Setter for default description and URL validation callbacks across all instances of MessageView
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    static setDefaultHandlers(
      /**
       * An object setting default callbacks
       */
      mDefaultHandlers: {
        /**
         * The description handler
         */
        asyncDescriptionHandler: Function;
        /**
         * The URL handler
         */
        asyncURLHandler: Function;
      }
    ): void;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: MessageItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:activeTitlePress activeTitlePress} event of
     * this `sap.m.MessageView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessageView` itself.
     *
     * Event fired when an activeTitle of a MessageItem is pressed.
     *
     * @since 1.58
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachActiveTitlePress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessageView$ActiveTitlePressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessageView` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:activeTitlePress activeTitlePress} event of
     * this `sap.m.MessageView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessageView` itself.
     *
     * Event fired when an activeTitle of a MessageItem is pressed.
     *
     * @since 1.58
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachActiveTitlePress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessageView$ActiveTitlePressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessageView` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterOpen afterOpen} event of this `sap.m.MessageView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessageView` itself.
     *
     * Event fired after the popover is opened.
     *
     * @deprecated As of version 1.72. Use the appropriate event from the wrapper control, instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessageView$AfterOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessageView` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterOpen afterOpen} event of this `sap.m.MessageView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessageView` itself.
     *
     * Event fired after the popover is opened.
     *
     * @deprecated As of version 1.72. Use the appropriate event from the wrapper control, instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessageView$AfterOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessageView` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemSelect itemSelect} event of this `sap.m.MessageView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessageView` itself.
     *
     * Event fired when description is shown.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessageView$ItemSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessageView` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemSelect itemSelect} event of this `sap.m.MessageView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessageView` itself.
     *
     * Event fired when description is shown.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessageView$ItemSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessageView` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:listSelect listSelect} event of this `sap.m.MessageView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessageView` itself.
     *
     * Event fired when one of the lists is shown when (not) filtered by type.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachListSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessageView$ListSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessageView` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:listSelect listSelect} event of this `sap.m.MessageView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessageView` itself.
     *
     * Event fired when one of the lists is shown when (not) filtered by type.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachListSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MessageView$ListSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessageView` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:longtextLoaded longtextLoaded} event of this
     * `sap.m.MessageView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessageView` itself.
     *
     * Event fired when the long text description data from a remote URL is loaded.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLongtextLoaded(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessageView` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:longtextLoaded longtextLoaded} event of this
     * `sap.m.MessageView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessageView` itself.
     *
     * Event fired when the long text description data from a remote URL is loaded.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLongtextLoaded(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessageView` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:urlValidated urlValidated} event of this `sap.m.MessageView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessageView` itself.
     *
     * Event fired when a validation of a URL from long text description is ready.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUrlValidated(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessageView` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:urlValidated urlValidated} event of this `sap.m.MessageView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MessageView` itself.
     *
     * Event fired when a validation of a URL from long text description is ready.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUrlValidated(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MessageView` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys the headerButton in the aggregation {@link #getHeaderButton headerButton}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyHeaderButton(): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:activeTitlePress activeTitlePress} event of
     * this `sap.m.MessageView`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.58
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachActiveTitlePress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MessageView$ActiveTitlePressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterOpen afterOpen} event of this `sap.m.MessageView`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @deprecated As of version 1.72. Use the appropriate event from the wrapper control, instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MessageView$AfterOpenEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:itemSelect itemSelect} event of this `sap.m.MessageView`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachItemSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MessageView$ItemSelectEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:listSelect listSelect} event of this `sap.m.MessageView`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachListSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MessageView$ListSelectEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:longtextLoaded longtextLoaded} event of this
     * `sap.m.MessageView`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLongtextLoaded(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:urlValidated urlValidated} event of this `sap.m.MessageView`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUrlValidated(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:activeTitlePress activeTitlePress} to attached listeners.
     *
     * @since 1.58
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireActiveTitlePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MessageView$ActiveTitlePressEventParameters
    ): this;
    /**
     * Fires event {@link #event:afterOpen afterOpen} to attached listeners.
     *
     * @deprecated As of version 1.72. Use the appropriate event from the wrapper control, instead.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MessageView$AfterOpenEventParameters
    ): this;
    /**
     * Fires event {@link #event:itemSelect itemSelect} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireItemSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MessageView$ItemSelectEventParameters
    ): this;
    /**
     * Fires event {@link #event:listSelect listSelect} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireListSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MessageView$ListSelectEventParameters
    ): this;
    /**
     * Fires event {@link #event:longtextLoaded longtextLoaded} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLongtextLoaded(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:urlValidated urlValidated} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUrlValidated(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getAsyncDescriptionHandler asyncDescriptionHandler}.
     *
     * Callback function for resolving a promise after description has been asynchronously loaded inside this
     * function.
     *
     *
     * @returns Value of property `asyncDescriptionHandler`
     */
    getAsyncDescriptionHandler(): Function;
    /**
     * Gets current value of property {@link #getAsyncURLHandler asyncURLHandler}.
     *
     * Callback function for resolving a promise after a link has been asynchronously validated inside this
     * function.
     *
     *
     * @returns Value of property `asyncURLHandler`
     */
    getAsyncURLHandler(): Function;
    /**
     * Gets current value of property {@link #getGroupItems groupItems}.
     *
     * Defines whether the MessageItems are grouped or not.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `groupItems`
     */
    getGroupItems(): boolean;
    /**
     * Gets content of aggregation {@link #getHeaderButton headerButton}.
     *
     * Sets a custom header button.
     */
    getHeaderButton(): Button;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * A list with message items. If only one item is provided, the initial page will be the details page for
     * the item.
     */
    getItems(): MessageItem[];
    /**
     * Gets current value of property {@link #getShowDetailsPageHeader showDetailsPageHeader}.
     *
     * Defines whether the header of details page will be shown.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showDetailsPageHeader`
     */
    getShowDetailsPageHeader(): boolean;
    /**
     * Checks for the provided `sap.m.MessageItem` in the aggregation {@link #getItems items}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: MessageItem
    ): int;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: MessageItem,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Navigates back to the list page
     */
    navigateBack(): void;
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): MessageItem[];
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | MessageItem
    ): MessageItem | null;
    /**
     * Sets a new value for property {@link #getAsyncDescriptionHandler asyncDescriptionHandler}.
     *
     * Callback function for resolving a promise after description has been asynchronously loaded inside this
     * function.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAsyncDescriptionHandler(
      /**
       * New value for property `asyncDescriptionHandler`
       */
      fnAsyncDescriptionHandler?: Function
    ): this;
    /**
     * Sets a new value for property {@link #getAsyncURLHandler asyncURLHandler}.
     *
     * Callback function for resolving a promise after a link has been asynchronously validated inside this
     * function.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAsyncURLHandler(
      /**
       * New value for property `asyncURLHandler`
       */
      fnAsyncURLHandler?: Function
    ): this;
    /**
     * Sets a new value for property {@link #getGroupItems groupItems}.
     *
     * Defines whether the MessageItems are grouped or not.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGroupItems(
      /**
       * New value for property `groupItems`
       */
      bGroupItems?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getHeaderButton headerButton}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeaderButton(
      /**
       * The headerButton to set
       */
      oHeaderButton: Button
    ): this;
    /**
     * Sets a new value for property {@link #getShowDetailsPageHeader showDetailsPageHeader}.
     *
     * Defines whether the header of details page will be shown.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowDetailsPageHeader(
      /**
       * New value for property `showDetailsPageHeader`
       */
      bShowDetailsPageHeader?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the MessageView constructor.
   */
  export interface $MessageViewSettings extends $ControlSettings {
    /**
     * Callback function for resolving a promise after description has been asynchronously loaded inside this
     * function.
     */
    asyncDescriptionHandler?: Function | PropertyBindingInfo | `{${string}}`;

    /**
     * Callback function for resolving a promise after a link has been asynchronously validated inside this
     * function.
     */
    asyncURLHandler?: Function | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether the MessageItems are grouped or not.
     */
    groupItems?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether the header of details page will be shown.
     */
    showDetailsPageHeader?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * A list with message items. If only one item is provided, the initial page will be the details page for
     * the item.
     */
    items?:
      | MessageItem[]
      | MessageItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Sets a custom header button.
     */
    headerButton?: Button;

    /**
     * Event fired after the popover is opened.
     *
     * @deprecated As of version 1.72. Use the appropriate event from the wrapper control, instead.
     */
    afterOpen?: (oEvent: MessageView$AfterOpenEvent) => void;

    /**
     * Event fired when description is shown.
     */
    itemSelect?: (oEvent: MessageView$ItemSelectEvent) => void;

    /**
     * Event fired when one of the lists is shown when (not) filtered by type.
     */
    listSelect?: (oEvent: MessageView$ListSelectEvent) => void;

    /**
     * Event fired when the long text description data from a remote URL is loaded.
     */
    longtextLoaded?: (oEvent: Event) => void;

    /**
     * Event fired when a validation of a URL from long text description is ready.
     */
    urlValidated?: (oEvent: Event) => void;

    /**
     * Event fired when an activeTitle of a MessageItem is pressed.
     *
     * @since 1.58
     */
    activeTitlePress?: (oEvent: MessageView$ActiveTitlePressEvent) => void;
  }

  /**
   * Parameters of the MessageView#activeTitlePress event.
   */
  export interface MessageView$ActiveTitlePressEventParameters {
    /**
     * Refers to the message item that contains the activeTitle.
     */
    item?: MessageItem;
  }

  /**
   * Event object of the MessageView#activeTitlePress event.
   */
  export type MessageView$ActiveTitlePressEvent = Event<
    MessageView$ActiveTitlePressEventParameters,
    MessageView
  >;

  /**
   * Parameters of the MessageView#afterOpen event.
   *
   * @deprecated As of version 1.72. Use the appropriate event from the wrapper control, instead.
   */
  export interface MessageView$AfterOpenEventParameters {
    /**
     * This refers to the control which opens the popover.
     */
    openBy?: Control;
  }

  /**
   * Event object of the MessageView#afterOpen event.
   *
   * @deprecated As of version 1.72. Use the appropriate event from the wrapper control, instead.
   */
  export type MessageView$AfterOpenEvent = Event<
    MessageView$AfterOpenEventParameters,
    MessageView
  >;

  /**
   * Parameters of the MessageView#itemSelect event.
   */
  export interface MessageView$ItemSelectEventParameters {
    /**
     * Refers to the message item that is being presented.
     */
    item?: MessageItem;

    /**
     * Refers to the type of messages being shown.
     */
    messageTypeFilter?: MessageType | keyof typeof MessageType;
  }

  /**
   * Event object of the MessageView#itemSelect event.
   */
  export type MessageView$ItemSelectEvent = Event<
    MessageView$ItemSelectEventParameters,
    MessageView
  >;

  /**
   * Parameters of the MessageView#listSelect event.
   */
  export interface MessageView$ListSelectEventParameters {
    /**
     * This parameter refers to the type of messages being shown.
     */
    messageTypeFilter?: MessageType | keyof typeof MessageType;
  }

  /**
   * Event object of the MessageView#listSelect event.
   */
  export type MessageView$ListSelectEvent = Event<
    MessageView$ListSelectEventParameters,
    MessageView
  >;

  /**
   * Parameters of the MessageView#longtextLoaded event.
   */
  export interface MessageView$LongtextLoadedEventParameters {}

  /**
   * Event object of the MessageView#longtextLoaded event.
   */
  export type MessageView$LongtextLoadedEvent = Event<
    MessageView$LongtextLoadedEventParameters,
    MessageView
  >;

  /**
   * Parameters of the MessageView#urlValidated event.
   */
  export interface MessageView$UrlValidatedEventParameters {}

  /**
   * Event object of the MessageView#urlValidated event.
   */
  export type MessageView$UrlValidatedEvent = Event<
    MessageView$UrlValidatedEventParameters,
    MessageView
  >;
}

declare module "sap/m/MultiComboBox" {
  import {
    default as ComboBoxBase,
    $ComboBoxBaseSettings,
  } from "sap/m/ComboBoxBase";

  import { ID, AccessibilityInfo } from "sap/ui/core/library";

  import Item from "sap/ui/core/Item";

  import Popover from "sap/m/Popover";

  import Dialog from "sap/m/Dialog";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * The MultiComboBox control provides a list box with items and a text field allowing the user to either
   * type a value directly into the control or choose from the list of existing items.
   *
   * A drop-down list for selecting and filtering values. Overview: The MultiComboBox control is commonly
   * used to enable users to select one or more options from a predefined list. The control provides an editable
   * input field to filter the list, and a dropdown arrow of available options. The select options in the
   * list have checkboxes that permit multi-selection. Entered values are displayed as {@link sap.m.Token tokens}.
   *
   * When an invalid character is typed into the text field of the MultiComboBox control, the value state
   * is changed to `sap.ui.core.ValueState.Error` only for a second, as the invalid value is immediately deleted
   * from the input field. Structure: The MultiComboBox consists of the following elements:
   * 	 -  Input field - displays the selected option/s as token/s. Users can type to filter the list.
   *     Drop-down arrow - expands\collapses the option list.
   * 	 -  Option list - the list of available options. **Note:** Disabled items are not visualized in the
   *     list with the available options, however they can still be accessed through the `items` aggregation.
   *      Usage: When to use::
   * 	 - The user needs to select one or more options from a long list of options (maximum of approximately
   *     200).  When not to use::
   * 	 - The user needs to choose between two options such as ON or OFF and YES or NO. In this case, consider
   *     using a {@link sap.m.Switch switch} control instead
   * 	 - You need to display more that one attribute. In this case, consider using the {@link sap.m.SelectDialog select dialog }
   *     or value help dialog instead.
   * 	 - The user needs to search on multiple attributes. In this case, consider using the {@link sap.m.SelectDialog select dialog }
   *     or value help dialog instead.
   * 	 - Your use case requires all available options to be displayed right away, without any user interaction.
   *     In this case, consider using the {@link sap.m.CheckBox checkboxes} instead.  Responsive Behavior:
   *     If there are many tokens, the control shows only the last selected tokens that fit and for the others
   *     a label N-more is provided. In case the length of the last selected token is exceeding the width of the
   *     control, only a label N-Items is shown. In both cases, pressing on the label will show the tokens in
   *     a popup. On Phones:
   * 	 - A new full-screen dialog opens where all items from the option list are shown.
   * 	 - You can select and deselect items from the option list.
   * 	 - With the help of a toggle button you can switch between showing all tokens and only selected ones.
   *
   * 	 - You can filter the option list by entering a value in the input.  On Tablets:
   * 	 - The auto-complete suggestions appear below or above the input field.
   * 	 - You can review the tokens by swiping them to left or right.  On Desktop:
   * 	 - The auto-complete suggestions appear below or above the input field.
   * 	 - You can review the tokens by pressing the right or left arrows on the keyboard.
   * 	 - You can select single tokens or a range of tokens and you can copy/cut/delete them.
   *
   * @since 1.22.0
   */
  export default class MultiComboBox extends ComboBoxBase {
    /**
     * Constructor for a new MultiComboBox.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/multi-combobox/ Multi-Combo Box}
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $MultiComboBoxSettings
    );
    /**
     * Constructor for a new MultiComboBox.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/multi-combobox/ Multi-Combo Box}
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $MultiComboBoxSettings
    );

    /**
     * Creates a new subclass of class sap.m.MultiComboBox with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ComboBoxBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, MultiComboBox>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.MultiComboBox.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some item `oItem` to the association named `selectedItems`.
     *
     *
     * @returns `this` to allow method chaining.
     */
    addSelectedItem(
      /**
       * The selected item to add; if empty, nothing is added.
       */
      oItem: ID | Item
    ): this;
    /**
     * Adds selected items. Only items with valid keys are added as selected.
     *
     *
     * @returns `this` to allow method chaining.
     */
    addSelectedKeys(
      /**
       * An array of item keys that identifies the items to be added as selected
       */
      aKeys: string[]
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionChange selectionChange} event of this
     * `sap.m.MultiComboBox`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MultiComboBox` itself.
     *
     * Event is fired when selection of an item is changed. Note: please do not use the "change" event inherited
     * from sap.m.InputBase
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MultiComboBox$SelectionChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MultiComboBox` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionChange selectionChange} event of this
     * `sap.m.MultiComboBox`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MultiComboBox` itself.
     *
     * Event is fired when selection of an item is changed. Note: please do not use the "change" event inherited
     * from sap.m.InputBase
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MultiComboBox$SelectionChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MultiComboBox` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionFinish selectionFinish} event of this
     * `sap.m.MultiComboBox`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MultiComboBox` itself.
     *
     * Event is fired when user has finished a selection of items in a list box and list box has been closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionFinish(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MultiComboBox$SelectionFinishEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MultiComboBox` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionFinish selectionFinish} event of this
     * `sap.m.MultiComboBox`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MultiComboBox` itself.
     *
     * Event is fired when user has finished a selection of items in a list box and list box has been closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionFinish(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MultiComboBox$SelectionFinishEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MultiComboBox` itself
       */
      oListener?: object
    ): this;
    /**
     * Clones the `sap.m.MultiComboBox` control.
     *
     *
     * @returns The cloned `sap.m.MultiComboBox` control.
     */
    clone(
      /**
       * Suffix to be added to the ids of the new control and its internal objects.
       */
      sIdSuffix: string
    ): this;
    /**
     * `MultiComboBox` picker configuration
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    configPicker(
      /**
       * Picker instance
       */
      oPicker: Popover | Dialog
    ): void;
    /**
     * Destroys all the items in the aggregation named `items`.
     *
     *
     * @returns `this` to allow method chaining.
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:selectionChange selectionChange} event of
     * this `sap.m.MultiComboBox`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelectionChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MultiComboBox$SelectionChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:selectionFinish selectionFinish} event of
     * this `sap.m.MultiComboBox`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelectionFinish(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MultiComboBox$SelectionFinishEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:selectionChange selectionChange} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelectionChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MultiComboBox$SelectionChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:selectionFinish selectionFinish} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelectionFinish(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MultiComboBox$SelectionFinishEventParameters
    ): this;
    /**
     * Gets the accessibility info for the control
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The accessibility info
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Retrieves the selected item objects from the association named `selectedItems`.
     *
     *
     * @returns Array of sap.ui.core.Item instances. The current target of the `selectedItems` association.
     */
    getSelectedItems(): Item[];
    /**
     * Gets current value of property {@link #getSelectedKeys selectedKeys}.
     *
     * Keys of the selected items. If the key has no corresponding item, no changes will apply. If duplicate
     * keys exists the first item matching the key is used.
     *
     * Default value is `[]`.
     *
     *
     * @returns Value of property `selectedKeys`
     */
    getSelectedKeys(): string[];
    /**
     * Gets current value of property {@link #getShowSelectAll showSelectAll}.
     *
     * Determines if the select all checkbox is visible on top of suggestions.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showSelectAll`
     */
    getShowSelectAll(): boolean;
    /**
     * Checks whether an item is selected.
     *
     *
     * @returns True if the item is selected.
     */
    isItemSelected(
      /**
       * The item to check.
       */
      oItem: Item
    ): boolean;
    /**
     * This hook method is called after the MultiComboBox's Pop-up is rendered.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onAfterRenderingPicker(): void;
    /**
     * This hook method is called before the MultiComboBox is rendered.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onBeforeRendering(): void;
    /**
     * Handles control click event.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onclick(oEvent: undefined): void;
    /**
     * Opens the control's picker popup.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns `this` to allow method chaining.
     */
    open(): this;
    /**
     * Removes all the controls in the association named selectedItems.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllSelectedItems(): ID[];
    /**
     * Removes a selected item from the association named `selectedItems`.
     *
     *
     * @returns The removed item or `null`
     */
    removeSelectedItem(
      /**
       * The item to be removed or its ID
       */
      oItem: Item | ID
    ): Item | null;
    /**
     * Removes selected items. Only items with valid keys are removed.
     *
     *
     * @returns The removed items
     */
    removeSelectedKeys(
      /**
       * An array of item keys that identifies the items to be removed
       */
      aKeys: string[]
    ): Item[];
    /**
     * Setter for association `selectedItems`.
     *
     *
     * @returns `this` to allow method chaining.
     */
    setSelectedItems(
      /**
       * new values for association `selectedItems`. Array of sap.ui.core.Item Id which becomes the new target
       * of this `selectedItems` association. Alternatively, an array of sap.ui.core.Item instance may be given
       * or null.
       */
      aItems: string[] | Item[] | null
    ): this;
    /**
     * Sets a new value for property `selectedKeys`. Keys of the selected items. If the key has no corresponding
     * item, no changes will apply. If duplicate keys exists the first item matching the key is used. When called
     * with a value of null or undefined, the default value of the property will be restored. Default value
     * is [].
     *
     *
     * @returns `this` to allow method chaining.
     */
    setSelectedKeys(
      /**
       * Keys of items to be set as selected
       */
      aKeys: string[]
    ): this;
    /**
     * Sets a new value for property {@link #getShowSelectAll showSelectAll}.
     *
     * Determines if the select all checkbox is visible on top of suggestions.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowSelectAll(
      /**
       * New value for property `showSelectAll`
       */
      bShowSelectAll?: boolean
    ): this;
    /**
     * Creates picker if doesn't exist yet and sync with Control items
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The picker instance
     */
    syncPickerContent(
      /**
       * Force MultiComboBox to SuggestionPopover sync
       */
      bForceListSync?: boolean
    ): Dialog | Popover;
  }
  /**
   * Describes the settings that can be provided to the MultiComboBox constructor.
   */
  export interface $MultiComboBoxSettings extends $ComboBoxBaseSettings {
    /**
     * Keys of the selected items. If the key has no corresponding item, no changes will apply. If duplicate
     * keys exists the first item matching the key is used.
     */
    selectedKeys?: string[] | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines if the select all checkbox is visible on top of suggestions.
     */
    showSelectAll?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Provides getter and setter for the selected items from the aggregation named items.
     */
    selectedItems?: Array<Item | string>;

    /**
     * Event is fired when selection of an item is changed. Note: please do not use the "change" event inherited
     * from sap.m.InputBase
     */
    selectionChange?: (oEvent: MultiComboBox$SelectionChangeEvent) => void;

    /**
     * Event is fired when user has finished a selection of items in a list box and list box has been closed.
     */
    selectionFinish?: (oEvent: MultiComboBox$SelectionFinishEvent) => void;
  }

  /**
   * Parameters of the MultiComboBox#selectionChange event.
   */
  export interface MultiComboBox$SelectionChangeEventParameters {
    /**
     * Item which selection is changed
     */
    changedItem?: Item;

    /**
     * Array of items whose selection has changed.
     */
    changedItems?: Item[];

    /**
     * Selection state: true if item is selected, false if item is not selected
     */
    selected?: boolean;

    /**
     * Indicates whether the select all action is triggered or not.
     */
    selectAll?: boolean;
  }

  /**
   * Event object of the MultiComboBox#selectionChange event.
   */
  export type MultiComboBox$SelectionChangeEvent = Event<
    MultiComboBox$SelectionChangeEventParameters,
    MultiComboBox
  >;

  /**
   * Parameters of the MultiComboBox#selectionFinish event.
   */
  export interface MultiComboBox$SelectionFinishEventParameters {
    /**
     * The selected items which are selected after list box has been closed.
     */
    selectedItems?: Item[];
  }

  /**
   * Event object of the MultiComboBox#selectionFinish event.
   */
  export type MultiComboBox$SelectionFinishEvent = Event<
    MultiComboBox$SelectionFinishEventParameters,
    MultiComboBox
  >;
}

declare module "sap/m/MultiInput" {
  import { default as Input, $InputSettings } from "sap/m/Input";

  import Token from "sap/m/Token";

  import { AccessibilityInfo } from "sap/ui/core/library";

  import Title from "sap/m/Title";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * Overview: A multi-input field allows the user to enter multiple values, which are displayed as {@link sap.m.Token tokens}.
   * You can enable auto-complete suggestions or value help to help the user choose the correct entry. You
   * can define validator functions to define what token values are accepted.
   *
   * **Notes:**
   * 	 -  New valid tokens are created, when the user presses Enter, selects a value from the suggestions
   *     drop-down, or when the focus leaves the field.
   * 	 -  Creating tokens in the control does not automatically update the model to which the "tokens" aggregation
   *     of the control is bound, no matter if the binding mode is set to "TwoWay". This is left to the application
   *     logic (check the corresponding sample).
   * 	 -  When multiple values are copied and pasted in the field, separate tokens are created for each of
   *     them.
   * 	 -  When a single value is copied and pasted in the field, it is shown as a text value, as further editing
   *     might be required before it is converted into a token.
   * 	 -  Provide meaningful labels for all input fields. Do not use the placeholder as a replacement for
   *     the label.
   * 	 -  The `showValueHelp` property is overwritten and after initialization of the control, its value becomes
   *     `truthy`.  Usage: When to use::
   * 	 -  You need to provide the value help option to help users select or search multiple business objects.
   *
   * 	 -  The dataset to choose from is expected to increase over time (for example, to more than 200 values).
   *      When not to use::
   * 	 -  When you need to select only one value.
   * 	 -  When you want the user to select from a predefined set of options. Use {@link sap.m.MultiComboBox }
   *     instead.  Responsive Behavior: If there are many tokens, the control shows only the first selected
   *     tokens that fit and for the others a label N-more is provided. In case the length of the first
   *     selected token is exceeding the width of the control, only a label N-Items is shown. In both cases,
   *     pressing on the label will show the tokens in a popup. On Phones:
   * 	 -  Only the last entered token is displayed.
   * 	 -  A new full-screen dialog opens where the auto-complete suggestions can be selected.
   * 	 -  You can review the tokens by tapping on the token or the input field.   On Tablets:
   *
   * 	 -  The auto-complete suggestions appear below or above the multi-input field.
   * 	 -  You can review the tokens by swiping them to the left or right.  On Desktop:
   * 	 -  The auto-complete suggestions appear below or above the multi-input field.
   * 	 -  You can review the tokens by pressing the right or left arrows on the keyboard.
   * 	 -  You can select single tokens or a range of tokens and you can copy/cut/delete them.
   */
  export default class MultiInput extends Input {
    /**
     * Constructor for a new MultiInput.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/multiinput/ Multi-Input Field}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $MultiInputSettings
    );
    /**
     * Constructor for a new MultiInput.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/multiinput/ Multi-Input Field}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $MultiInputSettings
    );

    /**
     * Creates a new subclass of class sap.m.MultiInput with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.Input.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, MultiInput>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.MultiInput.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some token to the aggregation {@link #getTokens tokens}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addToken(
      /**
       * The token to add; if empty, nothing is inserted
       */
      oToken: Token
    ): this;
    /**
     * Function validates the given text and adds a new token if validation was successful.
     */
    addValidateToken(
      /**
       * Parameter bag containing the following fields:
       */
      oParameters: {
        /**
         * The source text {sap.m.Token}
         */
        text: string;
        /**
         * Suggested token
         */
        token?: object;
        /**
         * Any object used to find the suggested token
         */
        suggestionObject?: object;
        /**
         * Callback which gets called after validation has finished
         */
        validationCallback?: Function;
      },
      /**
       * [optional] Array of all validators to be used
       */
      aValidators: Function[]
    ): void;
    /**
     * Function adds a validation callback called before any new token gets added to the tokens aggregation.
     */
    addValidator(
      /**
       * The validation function
       */
      fValidator: Function
    ): void;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tokenChange tokenChange} event of this `sap.m.MultiInput`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MultiInput` itself.
     *
     * Fired when the tokens aggregation changed (add / remove token)
     *
     * @deprecated As of version 1.46. Please use the new event tokenUpdate.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTokenChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MultiInput$TokenChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MultiInput` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tokenChange tokenChange} event of this `sap.m.MultiInput`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MultiInput` itself.
     *
     * Fired when the tokens aggregation changed (add / remove token)
     *
     * @deprecated As of version 1.46. Please use the new event tokenUpdate.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTokenChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MultiInput$TokenChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MultiInput` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tokenUpdate tokenUpdate} event of this `sap.m.MultiInput`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MultiInput` itself.
     *
     * Fired when the tokens aggregation changed due to a user interaction (add / remove token)
     *
     * @since 1.46
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTokenUpdate(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MultiInput$TokenUpdateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MultiInput` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tokenUpdate tokenUpdate} event of this `sap.m.MultiInput`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.MultiInput` itself.
     *
     * Fired when the tokens aggregation changed due to a user interaction (add / remove token)
     *
     * @since 1.46
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTokenUpdate(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MultiInput$TokenUpdateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.MultiInput` itself
       */
      oListener?: object
    ): this;
    /**
     * Clones the `sap.m.MultiInput` control.
     *
     *
     * @returns reference to the newly created clone
     */
    clone(): this;
    /**
     * Close multi-line MultiInput in multi-line mode
     *
     * @since 1.28
     * @deprecated As of version 1.58. replaced by N-more/N-items labels.
     */
    closeMultiLine(): void;
    /**
     * Destroys all the tokens in the aggregation {@link #getTokens tokens}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyTokens(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:tokenChange tokenChange} event of this `sap.m.MultiInput`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @deprecated As of version 1.46. Please use the new event tokenUpdate.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachTokenChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MultiInput$TokenChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:tokenUpdate tokenUpdate} event of this `sap.m.MultiInput`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.46
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachTokenUpdate(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MultiInput$TokenUpdateEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:tokenChange tokenChange} to attached listeners.
     *
     * @deprecated As of version 1.46. Please use the new event tokenUpdate.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireTokenChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MultiInput$TokenChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:tokenUpdate tokenUpdate} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @since 1.46
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireTokenUpdate(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MultiInput$TokenUpdateEventParameters
    ): boolean;
    /**
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The accessibility object
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Gets the picker header title.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The title instance of the Picker
     */
    getDialogTitle(): Title | null;
    /**
     * Get the reference element which the message popup should dock to
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns DOM Element which the message popup should dock to
     */
    getDomRefForValueStateMessage(): Element;
    /**
     * Gets current value of property {@link #getEnableMultiLineMode enableMultiLineMode}.
     *
     * If set to true, the MultiInput will be displayed in multi-line display mode. In multi-line display mode,
     * all tokens can be fully viewed and easily edited in the MultiInput. The default value is false. **Note:**
     * This property does not take effect on smartphones or when the editable property is set to false. **Caution:**
     * Do not enable multi-line mode in tables and forms.
     *
     * Default value is `false`.
     *
     * @since 1.28
     * @deprecated As of version 1.58. Replaced with N-more/N-items labels, which work in all cases.
     *
     * @returns Value of property `enableMultiLineMode`
     */
    getEnableMultiLineMode(): boolean;
    /**
     * Gets current value of property {@link #getMaxTokens maxTokens}.
     *
     * The max number of tokens that is allowed in MultiInput.
     *
     * @since 1.36
     *
     * @returns Value of property `maxTokens`
     */
    getMaxTokens(): int;
    /**
     * Function returns domref which acts as reference point for the opening suggestion menu
     *
     *
     * @returns The domref at which to open the suggestion menu
     */
    getPopupAnchorDomRef(): Element;
    /**
     * Gets current value of property {@link #getShowSuggestion showSuggestion}.
     *
     * If this is set to true, suggest event is fired when user types in the input. Changing the suggestItems
     * aggregation in suggest event listener will show suggestions within a popup. When runs on phone, input
     * will first open a dialog where the input and suggestions are shown. When runs on a tablet, the suggestions
     * are shown in a popup next to the input. **Note:** Default value for this property is false for the {@link sap.m.Input}.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showSuggestion`
     */
    getShowSuggestion(): boolean;
    /**
     * Gets content of aggregation {@link #getTokens tokens}.
     *
     * The currently displayed tokens
     */
    getTokens(): Token[];
    /**
     * Function returns all validation callbacks.
     *
     *
     * @returns An array of token validation callbacks
     */
    getValidators(): Function[];
    /**
     *
     * @returns Indicates should token validator wait for asynchronous validation
     */
    getWaitForAsyncValidation(): string;
    /**
     * Checks for the provided `sap.m.Token` in the aggregation {@link #getTokens tokens}. and returns its index
     * if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfToken(
      /**
       * The token whose index is looked for
       */
      oToken: Token
    ): int;
    /**
     * Inserts a token into the aggregation {@link #getTokens tokens}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertToken(
      /**
       * The token to insert; if empty, nothing is inserted
       */
      oToken: Token,
      /**
       * The `0`-based index the token should be inserted at; for a negative value of `iIndex`, the token is inserted
       * at position 0; for a value greater than the current size of the aggregation, the token is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Gets the supported openers for the valueHelpOnly.
     *
     * @deprecated As of version 1.119. the property valueHelpOnly should not be used anymore
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Boolean indicating if the target is a valid opener.
     */
    isValueHelpOnlyOpener(
      /**
       * The target of the event.
       */
      oTarget: HTMLElement
    ): boolean;
    /**
     * Overwrites the change event handler of the {@link sap.m.InputBase}. In case of added token it will not
     * reset the value.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns true when change event is fired
     */
    onChange(
      /**
       * Event object
       */
      oEvent: jQuery.Event,
      /**
       * Additional event parameters to be passed in to the change event handler if * the value has changed
       */
      mParameters: object,
      /**
       * Passed value on change
       */
      sNewValue: string
    ): boolean | undefined;
    /**
     * Overwrites the change event handler of the {@link sap.m.InputBase}. In case of added token it will not
     * reset the value.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns true when change event is fired
     */
    onChange(
      /**
       * Event object
       */
      oEvent: jQuery.Event,
      /**
       * Passed value on change
       */
      sNewValue: string
    ): boolean | undefined;
    /**
     * Focus is on MultiInput
     */
    onfocusin(
      /**
       * The event object
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * When press ESC, deselect all tokens and all texts
     */
    onsapescape(
      /**
       * The event object
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * When tap on text field, deselect all tokens
     */
    ontap(
      /**
       * The event object
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * Expand multi-line MultiInput in multi-line mode
     *
     * @since 1.28
     * @deprecated As of version 1.58. replaced by N-more/N-items labels.
     */
    openMultiLine(): void;
    /**
     * Removes all the controls from the aggregation {@link #getTokens tokens}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllTokens(): Token[];
    /**
     * Function removes all validation callbacks.
     */
    removeAllValidators(): void;
    /**
     * Removes a token from the aggregation {@link #getTokens tokens}.
     *
     *
     * @returns The removed token or `null`
     */
    removeToken(
      /**
       * The token to remove or its index or id
       */
      vToken: int | string | Token
    ): Token | null;
    /**
     * Function removes a validation callback.
     */
    removeValidator(
      /**
       * The validation function
       */
      fValidator: Function
    ): void;
    /**
     * Sets a new value for property {@link #getEnableMultiLineMode enableMultiLineMode}.
     *
     * If set to true, the MultiInput will be displayed in multi-line display mode. In multi-line display mode,
     * all tokens can be fully viewed and easily edited in the MultiInput. The default value is false. **Note:**
     * This property does not take effect on smartphones or when the editable property is set to false. **Caution:**
     * Do not enable multi-line mode in tables and forms.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.28
     * @deprecated As of version 1.58. Replaced with N-more/N-items labels, which work in all cases.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableMultiLineMode(
      /**
       * New value for property `enableMultiLineMode`
       */
      bEnableMultiLineMode?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getMaxTokens maxTokens}.
     *
     * The max number of tokens that is allowed in MultiInput.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.36
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxTokens(
      /**
       * New value for property `maxTokens`
       */
      iMaxTokens: int
    ): this;
    /**
     * Sets a new value for property {@link #getShowSuggestion showSuggestion}.
     *
     * If this is set to true, suggest event is fired when user types in the input. Changing the suggestItems
     * aggregation in suggest event listener will show suggestions within a popup. When runs on phone, input
     * will first open a dialog where the input and suggestions are shown. When runs on a tablet, the suggestions
     * are shown in a popup next to the input. **Note:** Default value for this property is false for the {@link sap.m.Input}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowSuggestion(
      /**
       * New value for property `showSuggestion`
       */
      bShowSuggestion?: boolean
    ): this;
    /**
     * Function sets an array of tokens, existing tokens will get overridden
     *
     *
     * @returns Pointer to the control instance for chaining
     */
    setTokens(
      /**
       * The new token set
       */
      aTokens: Token[]
    ): this;
    /**
     * A helper function calculating if the SuggestionsPopover should be opened on mobile.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns If the popover should be opened.
     */
    shouldSuggetionsPopoverOpenOnMobile(
      /**
       * Ontap event.
       */
      oEvent: jQuery.Event
    ): boolean;
    /**
     * Updates the inner input field.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    updateInputField(
      /**
       * Dom value which will be set.
       */
      sNewValue: string
    ): void;
  }
  /**
   * Describes the settings that can be provided to the MultiInput constructor.
   */
  export interface $MultiInputSettings extends $InputSettings {
    /**
     * If set to true, the MultiInput will be displayed in multi-line display mode. In multi-line display mode,
     * all tokens can be fully viewed and easily edited in the MultiInput. The default value is false. **Note:**
     * This property does not take effect on smartphones or when the editable property is set to false. **Caution:**
     * Do not enable multi-line mode in tables and forms.
     *
     * @since 1.28
     * @deprecated As of version 1.58. Replaced with N-more/N-items labels, which work in all cases.
     */
    enableMultiLineMode?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The max number of tokens that is allowed in MultiInput.
     *
     * @since 1.36
     */
    maxTokens?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * If this is set to true, suggest event is fired when user types in the input. Changing the suggestItems
     * aggregation in suggest event listener will show suggestions within a popup. When runs on phone, input
     * will first open a dialog where the input and suggestions are shown. When runs on a tablet, the suggestions
     * are shown in a popup next to the input. **Note:** Default value for this property is false for the {@link sap.m.Input}.
     */
    showSuggestion?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The currently displayed tokens
     */
    tokens?: Token[] | Token | AggregationBindingInfo | `{${string}}`;

    /**
     * Fired when the tokens aggregation changed (add / remove token)
     *
     * @deprecated As of version 1.46. Please use the new event tokenUpdate.
     */
    tokenChange?: (oEvent: MultiInput$TokenChangeEvent) => void;

    /**
     * Fired when the tokens aggregation changed due to a user interaction (add / remove token)
     *
     * @since 1.46
     */
    tokenUpdate?: (oEvent: MultiInput$TokenUpdateEvent) => void;
  }

  /**
   * Parameters of the MultiInput#tokenChange event.
   *
   * @deprecated As of version 1.46. Please use the new event tokenUpdate.
   */
  export interface MultiInput$TokenChangeEventParameters {
    /**
     * Type of tokenChange event. There are four TokenChange types: "added", "removed", "removedAll", "tokensChanged".
     * Use sap.m.Tokenizer.TokenChangeType.Added for "added", sap.m.Tokenizer.TokenChangeType.Removed for "removed",
     * sap.m.Tokenizer.TokenChangeType.RemovedAll for "removedAll" and sap.m.Tokenizer.TokenChangeType.TokensChanged
     * for "tokensChanged".
     */
    type?: string;

    /**
     * The added token or removed token. This parameter is used when tokenChange type is "added" or "removed".
     */
    token?: Token;

    /**
     * The array of removed tokens. This parameter is used when tokenChange type is "removedAll".
     */
    tokens?: Token[];

    /**
     * The array of tokens that are added. This parameter is used when tokenChange type is "tokenChanged".
     */
    addedTokens?: Token[];

    /**
     * The array of tokens that are removed. This parameter is used when tokenChange type is "tokenChanged".
     */
    removedTokens?: Token[];
  }

  /**
   * Event object of the MultiInput#tokenChange event.
   *
   * @deprecated As of version 1.46. Please use the new event tokenUpdate.
   */
  export type MultiInput$TokenChangeEvent = Event<
    MultiInput$TokenChangeEventParameters,
    MultiInput
  >;

  /**
   * Parameters of the MultiInput#tokenUpdate event.
   */
  export interface MultiInput$TokenUpdateEventParameters {
    /**
     * Type of tokenChange event. There are two TokenUpdate types: "added", "removed" Use sap.m.Tokenizer.TokenUpdateType.Added
     * for "added" and sap.m.Tokenizer.TokenUpdateType.Removed for "removed".
     */
    type?: string;

    /**
     * The array of tokens that are added. This parameter is used when tokenUpdate type is "added".
     */
    addedTokens?: Token[];

    /**
     * The array of tokens that are removed. This parameter is used when tokenUpdate type is "removed".
     */
    removedTokens?: Token[];
  }

  /**
   * Event object of the MultiInput#tokenUpdate event.
   */
  export type MultiInput$TokenUpdateEvent = Event<
    MultiInput$TokenUpdateEventParameters,
    MultiInput
  >;
}

declare module "sap/m/NavContainer" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { IPlaceholderSupport, CSSSize, ID } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * Handles hierarchical navigation between Pages or other fullscreen controls.
   *
   * All children of this control receive navigation events, such as {@link sap.m.NavContainerChild#event:BeforeShow BeforeShow},
   * they are documented in the pseudo interface {@link sap.m.NavContainerChild sap.m.NavContainerChild}.
   */
  export default class NavContainer
    extends Control
    implements IPlaceholderSupport
  {
    __implements__sap_ui_core_IPlaceholderSupport: boolean;
    /**
     * Constructor for a new `NavContainer`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/a4afb138acf64a61a038aa5b91a4f082 Nav Container}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $NavContainerSettings
    );
    /**
     * Constructor for a new `NavContainer`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/a4afb138acf64a61a038aa5b91a4f082 Nav Container}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $NavContainerSettings
    );

    /**
     * Creates a new subclass of class sap.m.NavContainer with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, NavContainer>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.NavContainer.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds a custom transition to the NavContainer type (not to a particular instance!). The transition is
     * identified by a "name". Make sure to only use names that will not collide with transitions which may
     * be added to the NavContainer later. A suggestion is to use the prefix "c_" or "_" for your custom transitions
     * to ensure this.
     *
     * "to" and "back" are the transition functions for the forward and backward navigation. Both will be called
     * with the following parameters: - oFromPage: the Control which is currently being displayed by the NavContainer
     * - oToPage: the Control which should be displayed by the NavContainer after the transition - fCallback:
     * a function which MUST be called when the transition has completed - oTransitionParameters: a data object
     * that can be given by application code when triggering the transition by calling to() or back(); this
     * object could give additional information to the transition function, like the DOM element which triggered
     * the transition or the desired transition duration
     *
     * The contract for "to" and "back" is that they may do an animation of their choice, but it should not
     * take "too long". At the beginning of the transition the target page "oToPage" does have the CSS class
     * "sapMNavItemHidden" which initially hides the target page (visibility:hidden). The transition can do
     * any preparation (e.g. move that page out of the screen or make it transparent) and then should remove
     * this CSS class. After the animation the target page "oToPage" should cover the entire screen and the
     * source page "oFromPage" should not be visible anymore. This page should then have the CSS class "sapMNavItemHidden".
     * For adding/removing this or other CSS classes, the transition can use the addStyleClass/removeStyleClass
     * method: oFromPage.addStyleClass("sapMNavItemHidden"); When the transition is complete, it MUST call the
     * given fCallback method to inform the NavContainer that navigation has finished!
     *
     * Hint: if the target page of your transition stays black on iPhone, try wrapping the animation start into
     * a setTimeout(..., 0) block (delayed, but without waiting).
     *
     * This method can be called on any NavContainer instance or statically on the sap.m.NavContainer type.
     * However, the transition will always be registered for the type (and ALL instances), not for the single
     * instance on which this method was invoked.
     *
     * Returns the sap.m.NavContainer type if called statically, or "this" (to allow method chaining) if called
     * on a particular NavContainer instance.
     *
     *
     * @returns The `sap.m.NavContainer` instance
     */
    addCustomTransition(
      /**
       * The name of the transition. This name can be used by the application to choose this transition when navigating
       * "to()" or "back()": the "transitionName" parameter of "NavContainer.to()" corresponds to this name, the
       * back() navigation will automatically use the same transition.
       *
       * Make sure to only use names that will not collide with transitions which may be added to the NavContainer
       * later. A suggestion is to use the prefix "c_" or "_" for your custom transitions to ensure this.
       */
      sName: string,
      /**
       * The function which will be called by the NavContainer when the application navigates "to()", using this
       * animation's name. The NavContainer instance is the "this" context within the animation function.
       *
       * See the documentation of NavContainer.addCustomTransitions for more details about this function.
       */
      fTo: object,
      /**
       * The function which will be called by the NavContainer when the application navigates "back()" from a
       * page where it had navigated to using this animation's name. The NavContainer instance is the "this" context
       * within the animation function.
       *
       * See the documentation of NavContainer.addCustomTransitions for more details about this function.
       */
      fBack: object
    ): this;
    /**
     * Adds some page to the aggregation {@link #getPages pages}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addPage(
      /**
       * The page to add; if empty, nothing is inserted
       */
      oPage: Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterNavigate afterNavigate} event of this `sap.m.NavContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.NavContainer` itself.
     *
     * The event is fired when navigation between two pages has completed (once all events to the child controls
     * have been fired). In case of animated transitions this event is fired with some delay after the "navigate"
     * event. This event is only fired if the DOM ref of the `NavContainer` is available. If the DOM ref is
     * not available, the `navigationFinished` event should be used instead.
     *
     * @since 1.7.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterNavigate(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: NavContainer$AfterNavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.NavContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterNavigate afterNavigate} event of this `sap.m.NavContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.NavContainer` itself.
     *
     * The event is fired when navigation between two pages has completed (once all events to the child controls
     * have been fired). In case of animated transitions this event is fired with some delay after the "navigate"
     * event. This event is only fired if the DOM ref of the `NavContainer` is available. If the DOM ref is
     * not available, the `navigationFinished` event should be used instead.
     *
     * @since 1.7.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterNavigate(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: NavContainer$AfterNavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.NavContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navigate navigate} event of this `sap.m.NavContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.NavContainer` itself.
     *
     * The event is fired when navigation between two pages has been triggered (before any events to the child
     * controls are fired). The transition (if any) to the new page has not started yet. This event can be aborted
     * by the application with preventDefault(), which means that there will be no navigation.
     *
     * @since 1.7.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavigate(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: NavContainer$NavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.NavContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navigate navigate} event of this `sap.m.NavContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.NavContainer` itself.
     *
     * The event is fired when navigation between two pages has been triggered (before any events to the child
     * controls are fired). The transition (if any) to the new page has not started yet. This event can be aborted
     * by the application with preventDefault(), which means that there will be no navigation.
     *
     * @since 1.7.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavigate(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: NavContainer$NavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.NavContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navigationFinished navigationFinished} event
     * of this `sap.m.NavContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.NavContainer` itself.
     *
     * The event is fired when navigation between two pages has completed regardless of whether the DOM is ready
     * or not. This event is useful when performing navigation without/before rendering of the `NavContainer`.
     * Keep in mind that the DOM is not guaranteed to be ready when this event is fired.
     *
     * @since 1.111.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavigationFinished(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: NavContainer$NavigationFinishedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.NavContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navigationFinished navigationFinished} event
     * of this `sap.m.NavContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.NavContainer` itself.
     *
     * The event is fired when navigation between two pages has completed regardless of whether the DOM is ready
     * or not. This event is useful when performing navigation without/before rendering of the `NavContainer`.
     * Keep in mind that the DOM is not guaranteed to be ready when this event is fired.
     *
     * @since 1.111.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavigationFinished(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: NavContainer$NavigationFinishedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.NavContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Navigates back one level. If already on the initial page and there is no place to go back, nothing happens.
     *
     * Calling this navigation method triggers first the (cancelable) "navigate" event on the NavContainer,
     * then the "BeforeHide" pseudo event on the source page and "BeforeFirstShow" (if applicable) and"BeforeShow"
     * on the target page. Later - after the transition has completed - the "AfterShow" pseudo event is triggered
     * on the target page and "AfterHide" on the page which has been left. The given backData object is available
     * in the "BeforeFirstShow", "BeforeShow" and "AfterShow" event object as "data" property. The original
     * "data" object from the "to" navigation is also available in these event objects.
     *
     *
     * @returns The `sap.m.NavContainer` instance
     */
    back(
      /**
       * Since version 1.7.1. This optional object can carry any payload data which should be made available to
       * the target page of the back navigation. The event on the target page will contain this data object as
       * "backData" property. (The original data from the "to()" navigation will still be available as "data"
       * property.)
       *
       * In scenarios where the entity triggering the navigation can or should not directly initialize the target
       * page, it can fill this object and the target page itself (or a listener on it) can take over the initialization,
       * using the given data. For back navigation this can be used e.g. when returning from a detail page to
       * transfer any settings done there.
       *
       * When the `oTransitionParameters` parameter is used, this `backData` parameter must also be given (either
       * as object or as `null` or `undefined`) in order to have a proper parameter order.
       */
      backData?: object,
      /**
       * Since version 1.7.1. This optional object can give additional information to the transition function,
       * like the DOM element which triggered the transition or the desired transition duration. The animation
       * type can NOT be selected here - it is always the inverse of the "to" navigation.
       *
       * In order to use the `oTransitionParameters parameter, the backData` parameter must be used
       * (at least `null` or `undefined` must be given) for a proper parameter order.
       *
       * NOTE: it depends on the transition function how the object should be structured and which parameters
       * are actually used to influence the transition.
       */
      oTransitionParameters?: object
    ): this;
    /**
     * Navigates back to the nearest previous page in the NavContainer history with the given ID. If there is
     * no such page among the previous pages, nothing happens. The transition effect which had been used to
     * get to the current page is inverted and used for this navigation.
     *
     * Calling this navigation method triggers first the (cancelable) "navigate" event on the NavContainer,
     * then the "BeforeHide" pseudo event on the source page and "BeforeFirstShow" (if applicable) and"BeforeShow"
     * on the target page. Later - after the transition has completed - the "AfterShow" pseudo event is triggered
     * on the target page and "AfterHide" on the page which has been left. The given backData object is available
     * in the "BeforeFirstShow", "BeforeShow" and "AfterShow" event object as "data" property. The original
     * "data" object from the "to" navigation is also available in these event objects.
     *
     * @since 1.7.2
     *
     * @returns The `sap.m.NavContainer` instance
     */
    backToPage(
      /**
       * The ID of the screen to which back navigation should happen. The ID or the control itself can be given.
       * The nearest such page among the previous pages in the history stack will be used.
       */
      pageId: string,
      /**
       * This optional object can carry any payload data which should be made available to the target page of
       * the "backToPage" navigation. The event on the target page will contain this data object as "backData"
       * property.
       *
       * When the `oTransitionParameters` parameter is used, this `backData` parameter must also be given (either
       * as object or as `null` or `undefined`) in order to have a proper parameter order.
       */
      backData?: object,
      /**
       * This optional object can give additional information to the transition function, like the DOM element
       * which triggered the transition or the desired transition duration. The animation type can NOT be selected
       * here - it is always the inverse of the "to" navigation.
       *
       * In order to use the `oTransitionParameters parameter, the backData` parameter must be used
       * (at least `null` or `undefined` must be given) for a proper parameter order.
       *
       * NOTE: it depends on the transition function how the object should be structured and which parameters
       * are actually used to influence the transition.
       */
      oTransitionParameters?: object
    ): this;
    /**
     * Navigates back to the initial/top level (this is the element aggregated as "initialPage", or the first
     * added element). If already on the initial page, nothing happens. The transition effect which had been
     * used to get to the current page is inverted and used for this navigation.
     *
     * Calling this navigation method triggers first the (cancelable) "navigate" event on the NavContainer,
     * then the "BeforeHide" pseudo event on the source page and "BeforeFirstShow" (if applicable) and "BeforeShow"
     * on the target page. Later - after the transition has completed - the "AfterShow" pseudo event is triggered
     * on the target page and "AfterHide" on the page which has been left. The given backData object is available
     * in the "BeforeFirstShow", "BeforeShow" and "AfterShow" event object as "data" property.
     *
     * @since 1.7.1
     */
    backToTop(
      /**
       * This optional object can carry any payload data which should be made available to the target page of
       * the "backToTop" navigation. The event on the target page will contain this data object as "backData"
       * property.
       *
       * When the `oTransitionParameters` parameter is used, this `backData` parameter must also be given (either
       * as object or as `null` or `undefined`) in order to have a proper parameter order.
       */
      backData?: object,
      /**
       * This optional object can give additional information to the transition function, like the DOM element
       * which triggered the transition or the desired transition duration. The animation type can NOT be selected
       * here - it is always the inverse of the "to" navigation.
       *
       * In order to use the `oTransitionParameters parameter, the backData` parameter must be used
       * (at least `null` or `undefined` must be given) for a proper parameter order.
       *
       * NOTE: it depends on the transition function how the object should be structured and which parameters
       * are actually used to influence the transition.
       */
      oTransitionParameters?: object
    ): this;
    /**
     * Returns whether the current page is the top/initial page.
     *
     * **Note:** going to the initial page again with a row of "to" navigations causes the initial page to be
     * displayed again, but logically one is not at the top level, so this method returns "false" in this case.
     *
     *
     * @returns Whether the current page is a top page
     */
    currentPageIsTopPage(): boolean;
    /**
     * Destroys all the pages in the aggregation {@link #getPages pages}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyPages(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterNavigate afterNavigate} event of this
     * `sap.m.NavContainer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.7.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterNavigate(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: NavContainer$AfterNavigateEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:navigate navigate} event of this `sap.m.NavContainer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.7.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachNavigate(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: NavContainer$NavigateEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:navigationFinished navigationFinished} event
     * of this `sap.m.NavContainer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.111.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachNavigationFinished(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: NavContainer$NavigationFinishedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:afterNavigate afterNavigate} to attached listeners.
     *
     * @since 1.7.1
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterNavigate(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: NavContainer$AfterNavigateEventParameters
    ): this;
    /**
     * Fires event {@link #event:navigate navigate} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @since 1.7.1
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireNavigate(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: NavContainer$NavigateEventParameters
    ): boolean;
    /**
     * Fires event {@link #event:navigationFinished navigationFinished} to attached listeners.
     *
     * @since 1.111.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireNavigationFinished(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: NavContainer$NavigationFinishedEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getAutoFocus autoFocus}.
     *
     * Determines whether the initial focus is set automatically on first rendering and after navigating to
     * a new page. This is useful when on touch devices the keyboard pops out due to the focus being automatically
     * set on an input field. If necessary, the `AfterShow` event can be used to focus another element, only
     * if `autoFocus` is set to `false`.
     *
     * **Note:** The following scenarios are possible, depending on where the focus was before navigation to
     * a new page:
     * 	 - If `autoFocus` is set to `true` and the focus was inside the current page, the focus will be moved
     *     automatically on the new page.
     * 	 - If `autoFocus` is set to `false` and the focus was inside the current page, the focus will disappear.
     *     If the focus was outside the current page, after the navigation it will remain unchanged regardless
     *     of what is set to the `autoFocus` property.
     * 	 - If the `autoFocus` is set to `false` and at the same time another wrapping control has its own logic
     *     for focus restoring upon rerendering, the focus will still appear.
     *
     * Default value is `true`.
     *
     * @since 1.30
     *
     * @returns Value of property `autoFocus`
     */
    getAutoFocus(): boolean;
    /**
     * Returns the currently displayed page-level control.
     *
     * **Note:** Returns `undefined` if no page has been added yet, otherwise returns an instance of `sap.m.Page`,
     * `sap.ui.core.mvc.View`, `sap.m.Carousel` or whatever is aggregated.
     *
     *
     * @returns The current page
     */
    getCurrentPage(): Control;
    /**
     * Gets current value of property {@link #getDefaultTransitionName defaultTransitionName}.
     *
     * The type of the transition/animation to apply when "to()" is called without defining a transition type
     * to use. The default is "slide". Other options are: "baseSlide", "fade", "flip" and "show" - and the names
     * of any registered custom transitions.
     *
     * Default value is `"slide"`.
     *
     * @since 1.7.1
     *
     * @returns Value of property `defaultTransitionName`
     */
    getDefaultTransitionName(): string;
    /**
     * Gets current value of property {@link #getHeight height}.
     *
     * The height of the NavContainer. Can be changed when the NavContainer should not cover the whole available
     * area.
     *
     * Default value is `'100%'`.
     *
     *
     * @returns Value of property `height`
     */
    getHeight(): CSSSize;
    /**
     * ID of the element which is the current target of the association {@link #getInitialPage initialPage},
     * or `null`.
     */
    getInitialPage(): ID | null;
    /**
     * Returns the control with the given ID from the `pages` aggregation (if available).
     *
     *
     * @returns The control with the given ID or `null` if it doesn't exist
     */
    getPage(
      /**
       * The ID of the aggregated control to find
       */
      pageId: string
    ): Control | null;
    /**
     * Gets content of aggregation {@link #getPages pages}.
     *
     * The content entities between which this NavContainer navigates. These can be of type sap.m.Page, sap.ui.core.mvc.View,
     * sap.m.Carousel or any other control with fullscreen/page semantics.
     *
     * These aggregated controls will receive navigation events like {@link sap.m.NavContainerChild#event:BeforeShow BeforeShow},
     * they are documented in the pseudo interface {@link sap.m.NavContainerChild sap.m.NavContainerChild}
     */
    getPages(): Control[];
    /**
     * Returns the previous page (the page from which the user drilled down to the current page with "to()").
     *
     * **Note:** this is not the page which the user has seen before, but the page which is the target of the
     * next "back()" navigation. If there is no previous page, `undefined` is returned.
     *
     * @since 1.7.1
     *
     * @returns The previous page
     */
    getPreviousPage(): Control;
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * Whether the NavContainer is visible.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * The width of the NavContainer. Can be changed when the NavContainer should not cover the whole available
     * area.
     *
     * Default value is `'100%'`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getPages pages}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfPage(
      /**
       * The page whose index is looked for
       */
      oPage: Control
    ): int;
    /**
     * Inserts a page into the aggregation {@link #getPages pages}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertPage(
      /**
       * The page to insert; if empty, nothing is inserted
       */
      oPage: Control,
      /**
       * The `0`-based index the page should be inserted at; for a negative value of `iIndex`, the page is inserted
       * at position 0; for a value greater than the current size of the aggregation, the page is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts the page/control with the specified ID into the navigation history stack of the NavContainer.
     *
     * This can be used for deep-linking when the user directly reached a drilldown detail page using a bookmark
     * and then wants to navigate up in the drilldown hierarchy. Normally such a back navigation would not be
     * possible because there is no previous page in the NavContainer's history stack.
     *
     * @since 1.16.1
     *
     * @returns The `sap.m.NavContainer` instance
     */
    insertPreviousPage(
      /**
       * The ID of the control/page/screen which is inserted into the history stack. The respective control must
       * be aggregated by the NavContainer, otherwise this will cause an error.
       */
      pageId: string,
      /**
       * The type of the transition/animation which would have been used to navigate from the (inserted) previous
       * page to the current page. When navigating back, the inverse animation will be applied. Options are "slide"
       * (horizontal movement from the right), "baseSlide", "fade", "flip", and "show" and the names of any registered
       * custom transitions.
       */
      transitionName: string,
      /**
       * This optional object can carry any payload data which would have been given to the inserted previous
       * page if the user would have done a normal forward navigation to it.
       */
      data: object
    ): this;
    /**
     * Inserts the page/control with the specified ID into the navigation history stack of the NavContainer.
     *
     * This can be used for deep-linking when the user directly reached a drilldown detail page using a bookmark
     * and then wants to navigate up in the drilldown hierarchy. Normally such a back navigation would not be
     * possible because there is no previous page in the NavContainer's history stack.
     *
     * @since 1.16.1
     *
     * @returns The `sap.m.NavContainer` instance
     */
    insertPreviousPage(
      /**
       * The ID of the control/page/screen which is inserted into the history stack. The respective control must
       * be aggregated by the NavContainer, otherwise this will cause an error.
       */
      pageId: string,
      /**
       * This optional object can carry any payload data which would have been given to the inserted previous
       * page if the user would have done a normal forward navigation to it.
       */
      data: object
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getPages pages}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllPages(): Control[];
    /**
     * Removes a page.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns the removed page or `null`
     */
    removePage(
      /**
       * the position or ID of the `Control` that should be removed or that `Control` itself; if `vPage` is invalid,
       * a negative value or a value greater or equal than the current size of the aggregation, nothing is removed.
       */
      vPage: int | ID | Control
    ): Control | null;
    /**
     * Sets a new value for property {@link #getAutoFocus autoFocus}.
     *
     * Determines whether the initial focus is set automatically on first rendering and after navigating to
     * a new page. This is useful when on touch devices the keyboard pops out due to the focus being automatically
     * set on an input field. If necessary, the `AfterShow` event can be used to focus another element, only
     * if `autoFocus` is set to `false`.
     *
     * **Note:** The following scenarios are possible, depending on where the focus was before navigation to
     * a new page:
     * 	 - If `autoFocus` is set to `true` and the focus was inside the current page, the focus will be moved
     *     automatically on the new page.
     * 	 - If `autoFocus` is set to `false` and the focus was inside the current page, the focus will disappear.
     *     If the focus was outside the current page, after the navigation it will remain unchanged regardless
     *     of what is set to the `autoFocus` property.
     * 	 - If the `autoFocus` is set to `false` and at the same time another wrapping control has its own logic
     *     for focus restoring upon rerendering, the focus will still appear.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.30
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAutoFocus(
      /**
       * New value for property `autoFocus`
       */
      bAutoFocus?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getDefaultTransitionName defaultTransitionName}.
     *
     * The type of the transition/animation to apply when "to()" is called without defining a transition type
     * to use. The default is "slide". Other options are: "baseSlide", "fade", "flip" and "show" - and the names
     * of any registered custom transitions.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"slide"`.
     *
     * @since 1.7.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDefaultTransitionName(
      /**
       * New value for property `defaultTransitionName`
       */
      sDefaultTransitionName?: string
    ): this;
    /**
     * Sets a new value for property {@link #getHeight height}.
     *
     * The height of the NavContainer. Can be changed when the NavContainer should not cover the whole available
     * area.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `'100%'`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeight(
      /**
       * New value for property `height`
       */
      sHeight?: CSSSize
    ): this;
    /**
     * Sets the associated {@link #getInitialPage initialPage}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInitialPage(
      /**
       * ID of an element which becomes the new target of this initialPage association; alternatively, an element
       * instance may be given
       */
      oInitialPage: ID | Control
    ): this;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * Whether the NavContainer is visible.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * The width of the NavContainer. Can be changed when the NavContainer should not cover the whole available
     * area.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `'100%'`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Navigates to the next page (with drill-down semantic) with the given (or default) animation. This creates
     * a new history item inside the NavContainer and allows going back.
     *
     * Note that any modifications to the target page (like setting its title, or anything else that could cause
     * a re-rendering) should be done BEFORE calling to(), in order to avoid unwanted side effects, e.g. related
     * to the page animation.
     *
     * Available transitions currently include "slide" (default), "baseSlide", "fade", "flip", and "show". None
     * of these is currently making use of any given transitionParameters.
     *
     * Calling this navigation method triggers first the (cancelable) "navigate" event on the NavContainer,
     * then the "BeforeHide" pseudo event on the source page and "BeforeFirstShow" (if applicable) and"BeforeShow"
     * on the target page. Later - after the transition has completed - the "AfterShow" pseudo event is triggered
     * on the target page and "AfterHide" on the page which has been left. The given data object is available
     * in the "BeforeFirstShow", "BeforeShow" and "AfterShow" event object as "data" property.
     *
     *
     * @returns The `sap.m.NavContainer` instance
     */
    to(
      /**
       * The screen to which drilldown should happen. The ID or the control itself can be given.
       */
      vPageIdOrControl: string | Control,
      /**
       * The type of the transition/animation to apply. Options are "slide" (horizontal movement from the right),
       * "baseSlide", "fade", "flip", and "show" and the names of any registered custom transitions.
       *
       * None of the standard transitions is currently making use of any given transition parameters.
       */
      sTransitionName?: string,
      /**
       * Since version 1.7.1. This optional object can carry any payload data which should be made available to
       * the target page. The "BeforeShow" event on the target page will contain this data object as "data" property.
       * Use case: in scenarios where the entity triggering the navigation can or should not directly initialize
       * the target page, it can fill this object and the target page itself (or a listener on it) can take over
       * the initialization, using the given data.
       *
       * When the `oTransitionParameters` parameter is used, this `oData` parameter must also be given (either
       * as object or as `null` or `undefined`) in order to have a proper parameter order.
       */
      oData?: object,
      /**
       * Since version 1.7.1. This optional object can contain additional information for the transition function,
       * like the DOM element which triggered the transition or the desired transition duration.
       *
       * For a proper parameter order, the `oData` parameter must be given when the `oTransitionParameters` parameter
       * is used (it can be given as `null` or `undefined`).
       *
       * NOTE: it depends on the transition function how the object should be structured and which parameters
       * are actually used to influence the transition. The "show", "slide", "baseSlide" and "fade" transitions
       * do not use any parameter.
       */
      oTransitionParameters?: object
    ): this;
  }
  /**
   * sap.m.NavContainerChild is an artificial interface with the only purpose to bear the documentation of
   * pseudo events triggered by sap.m.NavContainer on its child controls when navigation occurs and child
   * controls are displayed/hidden.
   *
   * Interested parties outside the child control can listen to one or more of these events by registering
   * a Delegate:
   * ```javascript
   *
   * page1.addEventDelegate({
   *    onBeforeShow: function(evt) {
   *       // page1 is about to be shown; act accordingly - if required you can read event information from the evt object
   *    },
   *    onAfterHide: function(evt) {
   *       // ...
   *    }
   * });
   * ```
   */
  export interface NavContainerChild {
    __implements__sap_m_NavContainerChild: boolean;
  }

  /**
   * Describes the settings that can be provided to the NavContainer constructor.
   */
  export interface $NavContainerSettings extends $ControlSettings {
    /**
     * Determines whether the initial focus is set automatically on first rendering and after navigating to
     * a new page. This is useful when on touch devices the keyboard pops out due to the focus being automatically
     * set on an input field. If necessary, the `AfterShow` event can be used to focus another element, only
     * if `autoFocus` is set to `false`.
     *
     * **Note:** The following scenarios are possible, depending on where the focus was before navigation to
     * a new page:
     * 	 - If `autoFocus` is set to `true` and the focus was inside the current page, the focus will be moved
     *     automatically on the new page.
     * 	 - If `autoFocus` is set to `false` and the focus was inside the current page, the focus will disappear.
     *     If the focus was outside the current page, after the navigation it will remain unchanged regardless
     *     of what is set to the `autoFocus` property.
     * 	 - If the `autoFocus` is set to `false` and at the same time another wrapping control has its own logic
     *     for focus restoring upon rerendering, the focus will still appear.
     *
     * @since 1.30
     */
    autoFocus?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The height of the NavContainer. Can be changed when the NavContainer should not cover the whole available
     * area.
     */
    height?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * The width of the NavContainer. Can be changed when the NavContainer should not cover the whole available
     * area.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Whether the NavContainer is visible.
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The type of the transition/animation to apply when "to()" is called without defining a transition type
     * to use. The default is "slide". Other options are: "baseSlide", "fade", "flip" and "show" - and the names
     * of any registered custom transitions.
     *
     * @since 1.7.1
     */
    defaultTransitionName?: string | PropertyBindingInfo;

    /**
     * The content entities between which this NavContainer navigates. These can be of type sap.m.Page, sap.ui.core.mvc.View,
     * sap.m.Carousel or any other control with fullscreen/page semantics.
     *
     * These aggregated controls will receive navigation events like {@link sap.m.NavContainerChild#event:BeforeShow BeforeShow},
     * they are documented in the pseudo interface {@link sap.m.NavContainerChild sap.m.NavContainerChild}
     */
    pages?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * This association can be used to define which page is displayed initially. If the given page does not
     * exist or no page is given, the first page which has been added is considered as initial page. This value
     * should be set initially and not set/modified while the application is running.
     *
     * This could be used not only for the initial display, but also if the user wants to navigate "up to top",
     * so this page serves as a sort of "home/root page".
     */
    initialPage?: Control | string;

    /**
     * The event is fired when navigation between two pages has been triggered (before any events to the child
     * controls are fired). The transition (if any) to the new page has not started yet. This event can be aborted
     * by the application with preventDefault(), which means that there will be no navigation.
     *
     * @since 1.7.1
     */
    navigate?: (oEvent: NavContainer$NavigateEvent) => void;

    /**
     * The event is fired when navigation between two pages has completed (once all events to the child controls
     * have been fired). In case of animated transitions this event is fired with some delay after the "navigate"
     * event. This event is only fired if the DOM ref of the `NavContainer` is available. If the DOM ref is
     * not available, the `navigationFinished` event should be used instead.
     *
     * @since 1.7.1
     */
    afterNavigate?: (oEvent: NavContainer$AfterNavigateEvent) => void;

    /**
     * The event is fired when navigation between two pages has completed regardless of whether the DOM is ready
     * or not. This event is useful when performing navigation without/before rendering of the `NavContainer`.
     * Keep in mind that the DOM is not guaranteed to be ready when this event is fired.
     *
     * @since 1.111.0
     */
    navigationFinished?: (oEvent: NavContainer$NavigationFinishedEvent) => void;
  }

  /**
   * Parameters of the NavContainer#afterNavigate event.
   */
  export interface NavContainer$AfterNavigateEventParameters {
    /**
     * The page which had been shown before navigation.
     */
    from?: Control;

    /**
     * The ID of the page which had been shown before navigation.
     */
    fromId?: string;

    /**
     * The page which is now shown after navigation.
     */
    to?: Control;

    /**
     * The ID of the page which is now shown after navigation.
     */
    toId?: string;

    /**
     * Whether the "to" page (more precisely: a control with the ID of the page which has been navigated to)
     * had not been shown/navigated to before.
     */
    firstTime?: boolean;

    /**
     * Whether was a forward navigation, triggered by "to()".
     */
    isTo?: boolean;

    /**
     * Whether this was a back navigation, triggered by "back()".
     */
    isBack?: boolean;

    /**
     * Whether this was a navigation to the root page, triggered by "backToTop()".
     */
    isBackToTop?: boolean;

    /**
     * Whether this was a navigation to a specific page, triggered by "backToPage()".
     */
    isBackToPage?: boolean;

    /**
     * How the navigation was triggered, possible values are "to", "back", "backToPage", and "backToTop".
     */
    direction?: string;
  }

  /**
   * Event object of the NavContainer#afterNavigate event.
   */
  export type NavContainer$AfterNavigateEvent = Event<
    NavContainer$AfterNavigateEventParameters,
    NavContainer
  >;

  /**
   * Parameters of the NavContainer#navigate event.
   */
  export interface NavContainer$NavigateEventParameters {
    /**
     * The page which was shown before the current navigation.
     */
    from?: Control;

    /**
     * The ID of the page which was shown before the current navigation.
     */
    fromId?: string;

    /**
     * The page which will be shown after the current navigation.
     */
    to?: Control;

    /**
     * The ID of the page which will be shown after the current navigation.
     */
    toId?: string;

    /**
     * Whether the "to" page (more precisely: a control with the ID of the page which is currently navigated
     * to) has not been shown/navigated to before.
     */
    firstTime?: boolean;

    /**
     * Whether this is a forward navigation, triggered by "to()".
     */
    isTo?: boolean;

    /**
     * Whether this is a back navigation, triggered by "back()".
     */
    isBack?: boolean;

    /**
     * Whether this is a navigation to the root page, triggered by "backToTop()".
     */
    isBackToTop?: boolean;

    /**
     * Whether this was a navigation to a specific page, triggered by "backToPage()".
     */
    isBackToPage?: boolean;

    /**
     * How the navigation was triggered, possible values are "to", "back", "backToPage", and "backToTop".
     */
    direction?: string;
  }

  /**
   * Event object of the NavContainer#navigate event.
   */
  export type NavContainer$NavigateEvent = Event<
    NavContainer$NavigateEventParameters,
    NavContainer
  >;

  /**
   * Parameters of the NavContainer#navigationFinished event.
   */
  export interface NavContainer$NavigationFinishedEventParameters {
    /**
     * The page which had been shown before navigation.
     */
    from?: Control;

    /**
     * The ID of the page which had been shown before navigation.
     */
    fromId?: string;

    /**
     * The page which is now shown after navigation.
     */
    to?: Control;

    /**
     * The ID of the page which is now shown after navigation.
     */
    toId?: string;

    /**
     * Whether the "to" page (more precisely: a control with the ID of the page which has been navigated to)
     * had not been shown/navigated to before.
     */
    firstTime?: boolean;

    /**
     * Whether was a forward navigation, triggered by "to()".
     */
    isTo?: boolean;

    /**
     * Whether this was a back navigation, triggered by "back()".
     */
    isBack?: boolean;

    /**
     * Whether this was a navigation to the root page, triggered by "backToTop()".
     */
    isBackToTop?: boolean;

    /**
     * Whether this was a navigation to a specific page, triggered by "backToPage()".
     */
    isBackToPage?: boolean;

    /**
     * How the navigation was triggered, possible values are "to", "back", "backToPage", and "backToTop".
     */
    direction?: string;
  }

  /**
   * Event object of the NavContainer#navigationFinished event.
   */
  export type NavContainer$NavigationFinishedEvent = Event<
    NavContainer$NavigationFinishedEventParameters,
    NavContainer
  >;
}

declare module "sap/m/NewsContent" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { Size } from "sap/m/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * This control displays the news content text and subheader in a tile.
   *
   * @since 1.34
   */
  export default class NewsContent extends Control {
    /**
     * Constructor for a new sap.m.NewsContent control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $NewsContentSettings
    );
    /**
     * Constructor for a new sap.m.NewsContent control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $NewsContentSettings
    );

    /**
     * Creates a new subclass of class sap.m.NewsContent with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, NewsContent>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.NewsContent.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.NewsContent`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.NewsContent` itself.
     *
     * The event is triggered when the News Content is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.NewsContent` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.NewsContent`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.NewsContent` itself.
     *
     * The event is triggered when the News Content is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.NewsContent` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.NewsContent`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getContentText contentText}.
     *
     * The content text.
     *
     *
     * @returns Value of property `contentText`
     */
    getContentText(): string;
    /**
     * Gets current value of property {@link #getSize size}.
     *
     * Updates the size of the chart. If not set then the default size is applied based on the device tile.
     *
     * Default value is `"Auto"`.
     *
     * @deprecated As of version 1.38.0. The NewsContent control has now a fixed size, depending on the used
     * media (desktop, tablet or phone).
     *
     * @returns Value of property `size`
     */
    getSize(): Size;
    /**
     * Gets current value of property {@link #getSubheader subheader}.
     *
     * The subheader.
     *
     *
     * @returns Value of property `subheader`
     */
    getSubheader(): string;
    /**
     * Sets a new value for property {@link #getContentText contentText}.
     *
     * The content text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContentText(
      /**
       * New value for property `contentText`
       */
      sContentText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSize size}.
     *
     * Updates the size of the chart. If not set then the default size is applied based on the device tile.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Auto"`.
     *
     * @deprecated As of version 1.38.0. The NewsContent control has now a fixed size, depending on the used
     * media (desktop, tablet or phone).
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSize(
      /**
       * New value for property `size`
       */
      sSize?: Size | keyof typeof Size
    ): this;
    /**
     * Sets a new value for property {@link #getSubheader subheader}.
     *
     * The subheader.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSubheader(
      /**
       * New value for property `subheader`
       */
      sSubheader?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the NewsContent constructor.
   */
  export interface $NewsContentSettings extends $ControlSettings {
    /**
     * Updates the size of the chart. If not set then the default size is applied based on the device tile.
     *
     * @deprecated As of version 1.38.0. The NewsContent control has now a fixed size, depending on the used
     * media (desktop, tablet or phone).
     */
    size?: (Size | keyof typeof Size) | PropertyBindingInfo | `{${string}}`;

    /**
     * The content text.
     */
    contentText?: string | PropertyBindingInfo;

    /**
     * The subheader.
     */
    subheader?: string | PropertyBindingInfo;

    /**
     * The event is triggered when the News Content is pressed.
     */
    press?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the NewsContent#press event.
   */
  export interface NewsContent$PressEventParameters {}

  /**
   * Event object of the NewsContent#press event.
   */
  export type NewsContent$PressEvent = Event<
    NewsContent$PressEventParameters,
    NewsContent
  >;
}

declare module "sap/m/NotificationList" {
  import { default as ListBase, $ListBaseSettings } from "sap/m/ListBase";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * The NotificationList control provides a container for `NotificationListGroup` and `NotificationListItem`.
   *
   * @since 1.90
   */
  export default class NotificationList extends ListBase {
    /**
     * Constructor for a new NotificationList.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.ListBase#constructor sap.m.ListBase }
     * can be used.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $NotificationListSettings
    );
    /**
     * Constructor for a new NotificationList.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.ListBase#constructor sap.m.ListBase }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $NotificationListSettings
    );

    /**
     * Creates a new subclass of class sap.m.NotificationList with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ListBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, NotificationList>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.NotificationList.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the NotificationList constructor.
   */
  export interface $NotificationListSettings extends $ListBaseSettings {}
}

declare module "sap/m/NotificationListBase" {
  import {
    default as ListItemBase,
    $ListItemBaseSettings,
  } from "sap/m/ListItemBase";

  import Button from "sap/m/Button";

  import Event from "sap/ui/base/Event";

  import { URI, Priority } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * The NotificationListBase is the abstract base class for {@link sap.m.NotificationListItem} and {@link sap.m.NotificationListGroup}.
   *
   * The NotificationList controls are designed for the SAP Fiori notification center. Overview: NotificationListBase
   * defines the general structure of a notification item. Most of the behavioral logic is defined for the
   * single items or groups.
   *
   * Structure: The base holds properties for the following elements:
   * 	 - Author name
   * 	 - Author picture
   * 	 - Time stamp
   * 	 - Priority
   * 	 - Title  Additionally, by setting these properties you can determine if buttons are shown:
   *
   * 	 - `showButtons` - action buttons visibility
   * 	 - `showCloseButton` - close button visibility
   *
   * Note: There are several properties, that are inherited from `ListItemBase` and have no visual representation
   * in the Notifications - `counter`, `highlight`, `highlightText`, `navigated`, `selected`, `type`
   *
   * @since 1.38
   */
  export default abstract class NotificationListBase extends ListItemBase {
    /**
     * Constructor for a new `NotificationListBase`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $NotificationListBaseSettings
    );
    /**
     * Constructor for a new `NotificationListBase`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $NotificationListBaseSettings
    );

    /**
     * Creates a new subclass of class sap.m.NotificationListBase with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ListItemBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, NotificationListBase>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.NotificationListBase.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some button to the aggregation {@link #getButtons buttons}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addButton(
      /**
       * The button to add; if empty, nothing is inserted
       */
      oButton: Button
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:close close} event of this `sap.m.NotificationListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.NotificationListBase` itself.
     *
     * Fired when the close button of the notification is pressed.
     * **Note:** Pressing the close button doesn't destroy the notification automatically.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.NotificationListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:close close} event of this `sap.m.NotificationListBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.NotificationListBase` itself.
     *
     * Fired when the close button of the notification is pressed.
     * **Note:** Pressing the close button doesn't destroy the notification automatically.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.NotificationListBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Closes the NotificationListBase.
     */
    close(): void;
    /**
     * Destroys all the buttons in the aggregation {@link #getButtons buttons}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyButtons(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:close close} event of this `sap.m.NotificationListBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:close close} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getAuthorName authorName}.
     *
     * Determines the notification author name.
     *
     * Default value is `empty string`.
     *
     * @deprecated As of version 1.123. This property is available directly on {@link sap.m.NotificationListItem}.
     *
     * @returns Value of property `authorName`
     */
    getAuthorName(): string;
    /**
     * Gets current value of property {@link #getAuthorPicture authorPicture}.
     *
     * Determines the URL of the notification author picture.
     *
     * @deprecated As of version 1.123. This property is available directly on {@link sap.m.NotificationListItem}.
     *
     * @returns Value of property `authorPicture`
     */
    getAuthorPicture(): URI;
    /**
     * Gets content of aggregation {@link #getButtons buttons}.
     *
     * Action buttons.
     */
    getButtons(): Button[];
    /**
     * Gets current value of property {@link #getDatetime datetime}.
     *
     * The time stamp of the Notification.
     *
     * Default value is `empty string`.
     *
     * @deprecated As of version 1.123. this property is available directly on {@link sap.m.NotificationListItem}.
     *
     * @returns Value of property `datetime`
     */
    getDatetime(): string;
    /**
     * Gets current value of property {@link #getPriority priority}.
     *
     * Determines the priority of the Notification.
     *
     * Default value is `None`.
     *
     *
     * @returns Value of property `priority`
     */
    getPriority(): Priority;
    /**
     * Gets current value of property {@link #getShowButtons showButtons}.
     *
     * Determines the action buttons visibility.
     *
     * **Note:** Action buttons are not shown when Notification List Groups are collapsed.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showButtons`
     */
    getShowButtons(): boolean;
    /**
     * Gets current value of property {@link #getShowCloseButton showCloseButton}.
     *
     * Determines the visibility of the close button.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showCloseButton`
     */
    getShowCloseButton(): boolean;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Determines the title of the NotificationListBase item.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Checks for the provided `sap.m.Button` in the aggregation {@link #getButtons buttons}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfButton(
      /**
       * The button whose index is looked for
       */
      oButton: Button
    ): int;
    /**
     * Inserts a button into the aggregation {@link #getButtons buttons}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertButton(
      /**
       * The button to insert; if empty, nothing is inserted
       */
      oButton: Button,
      /**
       * The `0`-based index the button should be inserted at; for a negative value of `iIndex`, the button is
       * inserted at position 0; for a value greater than the current size of the aggregation, the button is inserted
       * at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getButtons buttons}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllButtons(): Button[];
    /**
     * Removes a button from the aggregation {@link #getButtons buttons}.
     *
     *
     * @returns The removed button or `null`
     */
    removeButton(
      /**
       * The button to remove or its index or id
       */
      vButton: int | string | Button
    ): Button | null;
    /**
     * Sets a new value for property {@link #getAuthorName authorName}.
     *
     * Determines the notification author name.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @deprecated As of version 1.123. This property is available directly on {@link sap.m.NotificationListItem}.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAuthorName(
      /**
       * New value for property `authorName`
       */
      sAuthorName?: string
    ): this;
    /**
     * Sets a new value for property {@link #getAuthorPicture authorPicture}.
     *
     * Determines the URL of the notification author picture.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @deprecated As of version 1.123. This property is available directly on {@link sap.m.NotificationListItem}.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAuthorPicture(
      /**
       * New value for property `authorPicture`
       */
      sAuthorPicture: URI
    ): this;
    /**
     * Sets a new value for property {@link #getDatetime datetime}.
     *
     * The time stamp of the Notification.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @deprecated As of version 1.123. this property is available directly on {@link sap.m.NotificationListItem}.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDatetime(
      /**
       * New value for property `datetime`
       */
      sDatetime?: string
    ): this;
    /**
     * Sets a new value for property {@link #getPriority priority}.
     *
     * Determines the priority of the Notification.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPriority(
      /**
       * New value for property `priority`
       */
      sPriority?: Priority | keyof typeof Priority
    ): this;
    /**
     * Sets a new value for property {@link #getShowButtons showButtons}.
     *
     * Determines the action buttons visibility.
     *
     * **Note:** Action buttons are not shown when Notification List Groups are collapsed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowButtons(
      /**
       * New value for property `showButtons`
       */
      bShowButtons?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowCloseButton showCloseButton}.
     *
     * Determines the visibility of the close button.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowCloseButton(
      /**
       * New value for property `showCloseButton`
       */
      bShowCloseButton?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Determines the title of the NotificationListBase item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the NotificationListBase constructor.
   */
  export interface $NotificationListBaseSettings extends $ListItemBaseSettings {
    /**
     * Determines the priority of the Notification.
     */
    priority?:
      | (Priority | keyof typeof Priority)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the title of the NotificationListBase item.
     */
    title?: string | PropertyBindingInfo;

    /**
     * The time stamp of the Notification.
     *
     * @deprecated As of version 1.123. this property is available directly on {@link sap.m.NotificationListItem}.
     */
    datetime?: string | PropertyBindingInfo;

    /**
     * Determines the action buttons visibility.
     *
     * **Note:** Action buttons are not shown when Notification List Groups are collapsed.
     */
    showButtons?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the visibility of the close button.
     */
    showCloseButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the notification author name.
     *
     * @deprecated As of version 1.123. This property is available directly on {@link sap.m.NotificationListItem}.
     */
    authorName?: string | PropertyBindingInfo;

    /**
     * Determines the URL of the notification author picture.
     *
     * @deprecated As of version 1.123. This property is available directly on {@link sap.m.NotificationListItem}.
     */
    authorPicture?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Action buttons.
     */
    buttons?: Button[] | Button | AggregationBindingInfo | `{${string}}`;

    /**
     * Fired when the close button of the notification is pressed.
     * **Note:** Pressing the close button doesn't destroy the notification automatically.
     */
    close?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the NotificationListBase#close event.
   */
  export interface NotificationListBase$CloseEventParameters {}

  /**
   * Event object of the NotificationListBase#close event.
   */
  export type NotificationListBase$CloseEvent = Event<
    NotificationListBase$CloseEventParameters,
    NotificationListBase
  >;
}

declare module "sap/m/NotificationListGroup" {
  import {
    default as NotificationListBase,
    $NotificationListBaseSettings,
  } from "sap/m/NotificationListBase";

  import NotificationListItem from "sap/m/NotificationListItem";

  import { URI } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * The `NotificationListGroup` control is used for grouping {@link sap.m.NotificationListItem notification items }
   * of the same type. Behavior: The group handles specific behavior for different use cases:
   * 	 - `autoPriority` - determines the group priority to the highest priority of an item in the group.
   * 	 - `enableCollapseButtonWhenEmpty` - determines if the collapse/expand button for an empty group is
   *     displayed.
   * 	 - `showEmptyGroup` - determines if the header/footer of an empty group is displayed.
   *
   * @since 1.34
   */
  export default class NotificationListGroup extends NotificationListBase {
    /**
     * Constructor for a new NotificationListGroup.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $NotificationListGroupSettings
    );
    /**
     * Constructor for a new NotificationListGroup.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $NotificationListGroupSettings
    );

    /**
     * Creates a new subclass of class sap.m.NotificationListGroup with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.NotificationListBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, NotificationListGroup>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.NotificationListGroup.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: NotificationListItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:onCollapse onCollapse} event of this `sap.m.NotificationListGroup`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.NotificationListGroup` itself.
     *
     * `onCollapse` event is called when collapse property value is changed
     *
     * @since 1.44
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachOnCollapse(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: NotificationListGroup$OnCollapseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.NotificationListGroup` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:onCollapse onCollapse} event of this `sap.m.NotificationListGroup`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.NotificationListGroup` itself.
     *
     * `onCollapse` event is called when collapse property value is changed
     *
     * @since 1.44
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachOnCollapse(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: NotificationListGroup$OnCollapseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.NotificationListGroup` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:onCollapse onCollapse} event of this `sap.m.NotificationListGroup`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.44
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachOnCollapse(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: NotificationListGroup$OnCollapseEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:onCollapse onCollapse} to attached listeners.
     *
     * @since 1.44
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireOnCollapse(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: NotificationListGroup$OnCollapseEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getAuthorName authorName}.
     *
     * Determines the notification group's author name.
     *
     * Default value is `empty string`.
     *
     * @deprecated As of version 1.73. the concept has been discarded.
     *
     * @returns Value of property `authorName`
     */
    getAuthorName(): string;
    /**
     * Gets current value of property {@link #getAuthorPicture authorPicture}.
     *
     * Determines the URL of the notification group's author picture.
     *
     * @deprecated As of version 1.73. the concept has been discarded.
     *
     * @returns Value of property `authorPicture`
     */
    getAuthorPicture(): URI;
    /**
     * Gets current value of property {@link #getAutoPriority autoPriority}.
     *
     * Determines if the group will automatically set the priority based on the highest priority of its notifications
     * or get its priority from the `priority` property.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `autoPriority`
     */
    getAutoPriority(): boolean;
    /**
     * Gets current value of property {@link #getCollapsed collapsed}.
     *
     * Determines if the group is collapsed or expanded.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `collapsed`
     */
    getCollapsed(): boolean;
    /**
     * Gets current value of property {@link #getDatetime datetime}.
     *
     * Determines the due date of the NotificationListGroup.
     *
     * Default value is `empty string`.
     *
     * @deprecated As of version 1.73. the concept has been discarded.
     *
     * @returns Value of property `datetime`
     */
    getDatetime(): string;
    /**
     * Gets current value of property {@link #getEnableCollapseButtonWhenEmpty enableCollapseButtonWhenEmpty}.
     *
     * Determines if the collapse/expand button for an empty group is displayed.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `enableCollapseButtonWhenEmpty`
     */
    getEnableCollapseButtonWhenEmpty(): boolean;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * The NotificationListItems inside the group.
     */
    getItems(): NotificationListItem[];
    /**
     * Gets current value of property {@link #getShowEmptyGroup showEmptyGroup}.
     *
     * Determines if the group header/footer of the empty group will be always shown. By default groups with
     * 0 notifications are not shown.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showEmptyGroup`
     */
    getShowEmptyGroup(): boolean;
    /**
     * Gets current value of property {@link #getShowItemsCounter showItemsCounter}.
     *
     * Determines if the items counter inside the group header will be visible.
     *
     * **Note:** Counter value represents the number of currently visible (loaded) items inside the group.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showItemsCounter`
     */
    getShowItemsCounter(): boolean;
    /**
     * Checks for the provided `sap.m.NotificationListItem` in the aggregation {@link #getItems items}. and
     * returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: NotificationListItem
    ): int;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: NotificationListItem,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): NotificationListItem[];
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | NotificationListItem
    ): NotificationListItem | null;
    /**
     * Sets a new value for property {@link #getAuthorName authorName}.
     *
     * Determines the notification group's author name.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @deprecated As of version 1.73. the concept has been discarded.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAuthorName(
      /**
       * New value for property `authorName`
       */
      sAuthorName?: string
    ): this;
    /**
     * Sets a new value for property {@link #getAuthorPicture authorPicture}.
     *
     * Determines the URL of the notification group's author picture.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @deprecated As of version 1.73. the concept has been discarded.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAuthorPicture(
      /**
       * New value for property `authorPicture`
       */
      sAuthorPicture: URI
    ): this;
    /**
     * Sets a new value for property {@link #getAutoPriority autoPriority}.
     *
     * Determines if the group will automatically set the priority based on the highest priority of its notifications
     * or get its priority from the `priority` property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAutoPriority(
      /**
       * New value for property `autoPriority`
       */
      bAutoPriority?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getCollapsed collapsed}.
     *
     * Determines if the group is collapsed or expanded.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCollapsed(
      /**
       * New value for property `collapsed`
       */
      bCollapsed?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getDatetime datetime}.
     *
     * Determines the due date of the NotificationListGroup.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @deprecated As of version 1.73. the concept has been discarded.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDatetime(
      /**
       * New value for property `datetime`
       */
      sDatetime?: string
    ): this;
    /**
     * Sets a new value for property {@link #getEnableCollapseButtonWhenEmpty enableCollapseButtonWhenEmpty}.
     *
     * Determines if the collapse/expand button for an empty group is displayed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableCollapseButtonWhenEmpty(
      /**
       * New value for property `enableCollapseButtonWhenEmpty`
       */
      bEnableCollapseButtonWhenEmpty?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowEmptyGroup showEmptyGroup}.
     *
     * Determines if the group header/footer of the empty group will be always shown. By default groups with
     * 0 notifications are not shown.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowEmptyGroup(
      /**
       * New value for property `showEmptyGroup`
       */
      bShowEmptyGroup?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowItemsCounter showItemsCounter}.
     *
     * Determines if the items counter inside the group header will be visible.
     *
     * **Note:** Counter value represents the number of currently visible (loaded) items inside the group.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowItemsCounter(
      /**
       * New value for property `showItemsCounter`
       */
      bShowItemsCounter?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the NotificationListGroup constructor.
   */
  export interface $NotificationListGroupSettings
    extends $NotificationListBaseSettings {
    /**
     * Determines if the group is collapsed or expanded.
     */
    collapsed?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines if the group will automatically set the priority based on the highest priority of its notifications
     * or get its priority from the `priority` property.
     */
    autoPriority?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines if the group header/footer of the empty group will be always shown. By default groups with
     * 0 notifications are not shown.
     */
    showEmptyGroup?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines if the collapse/expand button for an empty group is displayed.
     */
    enableCollapseButtonWhenEmpty?:
      | boolean
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines if the items counter inside the group header will be visible.
     *
     * **Note:** Counter value represents the number of currently visible (loaded) items inside the group.
     */
    showItemsCounter?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the notification group's author name.
     *
     * @deprecated As of version 1.73. the concept has been discarded.
     */
    authorName?: string | PropertyBindingInfo;

    /**
     * Determines the URL of the notification group's author picture.
     *
     * @deprecated As of version 1.73. the concept has been discarded.
     */
    authorPicture?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the due date of the NotificationListGroup.
     *
     * @deprecated As of version 1.73. the concept has been discarded.
     */
    datetime?: string | PropertyBindingInfo;

    /**
     * The NotificationListItems inside the group.
     */
    items?:
      | NotificationListItem[]
      | NotificationListItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * `onCollapse` event is called when collapse property value is changed
     *
     * @since 1.44
     */
    onCollapse?: (oEvent: NotificationListGroup$OnCollapseEvent) => void;
  }

  /**
   * Parameters of the NotificationListGroup#onCollapse event.
   */
  export interface NotificationListGroup$OnCollapseEventParameters {
    /**
     * Indicates exact collapse direction
     */
    collapsed?: boolean;
  }

  /**
   * Event object of the NotificationListGroup#onCollapse event.
   */
  export type NotificationListGroup$OnCollapseEvent = Event<
    NotificationListGroup$OnCollapseEventParameters,
    NotificationListGroup
  >;
}

declare module "sap/m/NotificationListItem" {
  import {
    default as NotificationListBase,
    $NotificationListBaseSettings,
  } from "sap/m/NotificationListBase";

  import AvatarColor from "sap/m/AvatarColor";

  import { URI } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import MessageStrip from "sap/m/MessageStrip";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The NotificationListItem control shows notification to the user. Structure: The notification item holds
   * properties for the following elements:
   * 	 - `description` - additional detail text.
   * 	 - `hideShowMoreButton` - visibility of the "Show More" button.
   * 	 - `truncate` - determines if title and description are truncated to the first two lines (usually needed
   *     on mobile devices).  For each item you can set some additional status information about the item
   *     processing by adding a {@link sap.m.MessageStrip} to the `processingMessage` aggregation.
   *
   * @since 1.34
   */
  export default class NotificationListItem extends NotificationListBase {
    /**
     * Constructor for a new NotificationListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $NotificationListItemSettings
    );
    /**
     * Constructor for a new NotificationListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $NotificationListItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.NotificationListItem with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.NotificationListBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, NotificationListItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.NotificationListItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Destroys the processingMessage in the aggregation {@link #getProcessingMessage processingMessage}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyProcessingMessage(): this;
    /**
     * Gets current value of property {@link #getAuthorAvatarColor authorAvatarColor}.
     *
     * Determines the background color of the avatar of the author.
     *
     * **Note:** By using background colors from the predefined sets, your colors can later be customized from
     * the Theme Designer.
     *
     * Default value is `Accent6`.
     *
     *
     * @returns Value of property `authorAvatarColor`
     */
    getAuthorAvatarColor(): AvatarColor;
    /**
     * Gets current value of property {@link #getAuthorInitials authorInitials}.
     *
     * Defines the displayed author initials.
     *
     *
     * @returns Value of property `authorInitials`
     */
    getAuthorInitials(): string;
    /**
     * Gets current value of property {@link #getAuthorName authorName}.
     *
     * Determines the notification author name.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `authorName`
     */
    getAuthorName(): string;
    /**
     * Gets current value of property {@link #getAuthorPicture authorPicture}.
     *
     * Determines the URL of the notification author picture.
     *
     *
     * @returns Value of property `authorPicture`
     */
    getAuthorPicture(): URI;
    /**
     * Gets current value of property {@link #getDatetime datetime}.
     *
     * The time stamp of the notification.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `datetime`
     */
    getDatetime(): string;
    /**
     * Gets current value of property {@link #getDescription description}.
     *
     * Determines the description of the NotificationListItem.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `description`
     */
    getDescription(): string;
    /**
     * Gets current value of property {@link #getHideShowMoreButton hideShowMoreButton}.
     *
     * Determines if the "Show More" button should be hidden.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `hideShowMoreButton`
     */
    getHideShowMoreButton(): boolean;
    /**
     * Gets content of aggregation {@link #getProcessingMessage processingMessage}.
     *
     * The sap.m.MessageStrip control that holds the information about any error that may occur when pressing
     * the notification buttons
     */
    getProcessingMessage(): MessageStrip;
    /**
     * Gets current value of property {@link #getTruncate truncate}.
     *
     * Determines if the text in the title and the description of the notification are truncated to the first
     * two lines.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `truncate`
     */
    getTruncate(): boolean;
    /**
     * Sets a new value for property {@link #getAuthorAvatarColor authorAvatarColor}.
     *
     * Determines the background color of the avatar of the author.
     *
     * **Note:** By using background colors from the predefined sets, your colors can later be customized from
     * the Theme Designer.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Accent6`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAuthorAvatarColor(
      /**
       * New value for property `authorAvatarColor`
       */
      sAuthorAvatarColor?: AvatarColor | keyof typeof AvatarColor
    ): this;
    /**
     * Sets a new value for property {@link #getAuthorInitials authorInitials}.
     *
     * Defines the displayed author initials.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAuthorInitials(
      /**
       * New value for property `authorInitials`
       */
      sAuthorInitials?: string
    ): this;
    /**
     * Sets a new value for property {@link #getAuthorName authorName}.
     *
     * Determines the notification author name.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAuthorName(
      /**
       * New value for property `authorName`
       */
      sAuthorName?: string
    ): this;
    /**
     * Sets a new value for property {@link #getAuthorPicture authorPicture}.
     *
     * Determines the URL of the notification author picture.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAuthorPicture(
      /**
       * New value for property `authorPicture`
       */
      sAuthorPicture: URI
    ): this;
    /**
     * Sets a new value for property {@link #getDatetime datetime}.
     *
     * The time stamp of the notification.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDatetime(
      /**
       * New value for property `datetime`
       */
      sDatetime?: string
    ): this;
    /**
     * Sets a new value for property {@link #getDescription description}.
     *
     * Determines the description of the NotificationListItem.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDescription(
      /**
       * New value for property `description`
       */
      sDescription?: string
    ): this;
    /**
     * Sets a new value for property {@link #getHideShowMoreButton hideShowMoreButton}.
     *
     * Determines if the "Show More" button should be hidden.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHideShowMoreButton(
      /**
       * New value for property `hideShowMoreButton`
       */
      bHideShowMoreButton?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getProcessingMessage processingMessage}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setProcessingMessage(
      /**
       * The processingMessage to set
       */
      oProcessingMessage: MessageStrip
    ): this;
    /**
     * Sets a new value for property {@link #getTruncate truncate}.
     *
     * Determines if the text in the title and the description of the notification are truncated to the first
     * two lines.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTruncate(
      /**
       * New value for property `truncate`
       */
      bTruncate?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the NotificationListItem constructor.
   */
  export interface $NotificationListItemSettings
    extends $NotificationListBaseSettings {
    /**
     * Determines the description of the NotificationListItem.
     */
    description?: string | PropertyBindingInfo;

    /**
     * Defines the displayed author initials.
     */
    authorInitials?: string | PropertyBindingInfo;

    /**
     * Determines if the text in the title and the description of the notification are truncated to the first
     * two lines.
     */
    truncate?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines if the "Show More" button should be hidden.
     */
    hideShowMoreButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the background color of the avatar of the author.
     *
     * **Note:** By using background colors from the predefined sets, your colors can later be customized from
     * the Theme Designer.
     */
    authorAvatarColor?:
      | (AvatarColor | keyof typeof AvatarColor)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the notification author name.
     */
    authorName?: string | PropertyBindingInfo;

    /**
     * Determines the URL of the notification author picture.
     */
    authorPicture?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * The time stamp of the notification.
     */
    datetime?: string | PropertyBindingInfo;

    /**
     * The sap.m.MessageStrip control that holds the information about any error that may occur when pressing
     * the notification buttons
     */
    processingMessage?: MessageStrip;
  }
}

declare module "sap/m/NumericContent" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import Event from "sap/ui/base/Event";

  import { URI, CSSSize } from "sap/ui/core/library";

  import {
    DeviationIndicator,
    Size,
    LoadState,
    ValueColor,
  } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Shows numeric values used for example in tiles colored according to their meaning and displays deviations.
   *
   * @since 1.34
   */
  export default class NumericContent extends Control {
    /**
     * Constructor for a new sap.m.GenericTile control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $NumericContentSettings
    );
    /**
     * Constructor for a new sap.m.GenericTile control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $NumericContentSettings
    );

    /**
     * Creates a new subclass of class sap.m.NumericContent with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, NumericContent>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.NumericContent.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.NumericContent`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.NumericContent` itself.
     *
     * The event is fired when the user chooses the numeric content.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.NumericContent` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.NumericContent`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.NumericContent` itself.
     *
     * The event is fired when the user chooses the numeric content.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.NumericContent` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.NumericContent`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getAdaptiveFontSize adaptiveFontSize}.
     *
     * If set to its default value true this property applies the appropriate font style class based on the
     * language. When set to false the font size will always be large
     *
     * Default value is `true`.
     *
     * @since 1.73
     * @experimental As of version 1.73. Disclaimer: this property is in a beta state - incompatible API changes
     * may be done before its official public release. Use at your own discretion.
     *
     * @returns Value of property `adaptiveFontSize`
     */
    getAdaptiveFontSize(): boolean;
    /**
     * Gets current value of property {@link #getAnimateTextChange animateTextChange}.
     *
     * If set to true, the change of the value will be animated.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `animateTextChange`
     */
    getAnimateTextChange(): boolean;
    /**
     * Gets current value of property {@link #getFormatterValue formatterValue}.
     *
     * If set to true, the value parameter contains a numeric value and scale. If set to false (default), the
     * value parameter contains a numeric value only.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `formatterValue`
     */
    getFormatterValue(): boolean;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * The icon to be displayed as a graphical element within the control. This can be an image or an icon from
     * the icon font.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getIconDescription iconDescription}.
     *
     * Description of an icon that is used in the tooltip.
     *
     *
     * @returns Value of property `iconDescription`
     */
    getIconDescription(): string;
    /**
     * Gets current value of property {@link #getIndicator indicator}.
     *
     * The indicator arrow that shows value deviation.
     *
     * Default value is `"None"`.
     *
     *
     * @returns Value of property `indicator`
     */
    getIndicator(): DeviationIndicator;
    /**
     * Gets current value of property {@link #getNullifyValue nullifyValue}.
     *
     * If set to true, the omitted value property is set to 0.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `nullifyValue`
     */
    getNullifyValue(): boolean;
    /**
     * Gets current value of property {@link #getScale scale}.
     *
     * The scaling prefix. Financial characters can be used for currencies and counters. The SI prefixes can
     * be used for units. If the scaling prefix contains more than three characters, only the first three characters
     * are displayed.
     *
     *
     * @returns Value of property `scale`
     */
    getScale(): string;
    /**
     * Gets current value of property {@link #getSize size}.
     *
     * Updates the size of the control. If not set, then the default size is applied based on the device tile.
     *
     * Default value is `"Auto"`.
     *
     * @deprecated As of version 1.38.0. The NumericContent control has now a fixed size, depending on the used
     * media (desktop, tablet or phone).
     *
     * @returns Value of property `size`
     */
    getSize(): Size;
    /**
     * Gets current value of property {@link #getState state}.
     *
     * Indicates the load status.
     *
     * Default value is `"Loaded"`.
     *
     *
     * @returns Value of property `state`
     */
    getState(): LoadState;
    /**
     * Gets current value of property {@link #getTruncateValueTo truncateValueTo}.
     *
     * The number of characters of the `value` property to display.
     *
     * **Note** If `adaptiveFontSize` is set to `true` the default value of this property will vary between
     * languages. If `adaptiveFontSize` is set to `false` the default value of this property is `4`.
     *
     *
     * @returns Value of property `truncateValueTo`
     */
    getTruncateValueTo(): int;
    /**
     * Gets current value of property {@link #getValue value}.
     *
     * The actual value.
     *
     *
     * @returns Value of property `value`
     */
    getValue(): string;
    /**
     * Gets current value of property {@link #getValueColor valueColor}.
     *
     * The semantic color of the value.
     *
     * Default value is `"Neutral"`.
     *
     *
     * @returns Value of property `valueColor`
     */
    getValueColor(): ValueColor;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * The width of the control. If it is not set, the size of the control is defined by the 'size' property.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getWithMargin withMargin}.
     *
     * If the value is set to false, the content is adjusted to the whole size of the control.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `withMargin`
     */
    getWithMargin(): boolean;
    /**
     * Sets a new value for property {@link #getAdaptiveFontSize adaptiveFontSize}.
     *
     * If set to its default value true this property applies the appropriate font style class based on the
     * language. When set to false the font size will always be large
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.73
     * @experimental As of version 1.73. Disclaimer: this property is in a beta state - incompatible API changes
     * may be done before its official public release. Use at your own discretion.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAdaptiveFontSize(
      /**
       * New value for property `adaptiveFontSize`
       */
      bAdaptiveFontSize?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getAnimateTextChange animateTextChange}.
     *
     * If set to true, the change of the value will be animated.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAnimateTextChange(
      /**
       * New value for property `animateTextChange`
       */
      bAnimateTextChange?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getFormatterValue formatterValue}.
     *
     * If set to true, the value parameter contains a numeric value and scale. If set to false (default), the
     * value parameter contains a numeric value only.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFormatterValue(
      /**
       * New value for property `formatterValue`
       */
      bFormatterValue?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * The icon to be displayed as a graphical element within the control. This can be an image or an icon from
     * the icon font.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getIconDescription iconDescription}.
     *
     * Description of an icon that is used in the tooltip.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconDescription(
      /**
       * New value for property `iconDescription`
       */
      sIconDescription?: string
    ): this;
    /**
     * Sets a new value for property {@link #getIndicator indicator}.
     *
     * The indicator arrow that shows value deviation.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"None"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIndicator(
      /**
       * New value for property `indicator`
       */
      sIndicator?: DeviationIndicator | keyof typeof DeviationIndicator
    ): this;
    /**
     * Sets a new value for property {@link #getNullifyValue nullifyValue}.
     *
     * If set to true, the omitted value property is set to 0.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNullifyValue(
      /**
       * New value for property `nullifyValue`
       */
      bNullifyValue?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getScale scale}.
     *
     * The scaling prefix. Financial characters can be used for currencies and counters. The SI prefixes can
     * be used for units. If the scaling prefix contains more than three characters, only the first three characters
     * are displayed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setScale(
      /**
       * New value for property `scale`
       */
      sScale?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSize size}.
     *
     * Updates the size of the control. If not set, then the default size is applied based on the device tile.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Auto"`.
     *
     * @deprecated As of version 1.38.0. The NumericContent control has now a fixed size, depending on the used
     * media (desktop, tablet or phone).
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSize(
      /**
       * New value for property `size`
       */
      sSize?: Size | keyof typeof Size
    ): this;
    /**
     * Sets a new value for property {@link #getState state}.
     *
     * Indicates the load status.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Loaded"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setState(
      /**
       * New value for property `state`
       */
      sState?: LoadState | keyof typeof LoadState
    ): this;
    /**
     * Sets a new value for property {@link #getTruncateValueTo truncateValueTo}.
     *
     * The number of characters of the `value` property to display.
     *
     * **Note** If `adaptiveFontSize` is set to `true` the default value of this property will vary between
     * languages. If `adaptiveFontSize` is set to `false` the default value of this property is `4`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTruncateValueTo(
      /**
       * New value for property `truncateValueTo`
       */
      iTruncateValueTo: int
    ): this;
    /**
     * Sets a new value for property {@link #getValue value}.
     *
     * The actual value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValue(
      /**
       * New value for property `value`
       */
      sValue?: string
    ): this;
    /**
     * Sets a new value for property {@link #getValueColor valueColor}.
     *
     * The semantic color of the value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Neutral"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueColor(
      /**
       * New value for property `valueColor`
       */
      sValueColor?: ValueColor | keyof typeof ValueColor
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * The width of the control. If it is not set, the size of the control is defined by the 'size' property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getWithMargin withMargin}.
     *
     * If the value is set to false, the content is adjusted to the whole size of the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWithMargin(
      /**
       * New value for property `withMargin`
       */
      bWithMargin?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the NumericContent constructor.
   */
  export interface $NumericContentSettings extends $ControlSettings {
    /**
     * If set to true, the change of the value will be animated.
     */
    animateTextChange?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * If set to true, the value parameter contains a numeric value and scale. If set to false (default), the
     * value parameter contains a numeric value only.
     */
    formatterValue?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The icon to be displayed as a graphical element within the control. This can be an image or an icon from
     * the icon font.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Description of an icon that is used in the tooltip.
     */
    iconDescription?: string | PropertyBindingInfo;

    /**
     * The indicator arrow that shows value deviation.
     */
    indicator?:
      | (DeviationIndicator | keyof typeof DeviationIndicator)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * If set to true, the omitted value property is set to 0.
     */
    nullifyValue?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The scaling prefix. Financial characters can be used for currencies and counters. The SI prefixes can
     * be used for units. If the scaling prefix contains more than three characters, only the first three characters
     * are displayed.
     */
    scale?: string | PropertyBindingInfo;

    /**
     * Updates the size of the control. If not set, then the default size is applied based on the device tile.
     *
     * @deprecated As of version 1.38.0. The NumericContent control has now a fixed size, depending on the used
     * media (desktop, tablet or phone).
     */
    size?: (Size | keyof typeof Size) | PropertyBindingInfo | `{${string}}`;

    /**
     * The number of characters of the `value` property to display.
     *
     * **Note** If `adaptiveFontSize` is set to `true` the default value of this property will vary between
     * languages. If `adaptiveFontSize` is set to `false` the default value of this property is `4`.
     */
    truncateValueTo?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * The actual value.
     */
    value?: string | PropertyBindingInfo;

    /**
     * The semantic color of the value.
     */
    valueColor?:
      | (ValueColor | keyof typeof ValueColor)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The width of the control. If it is not set, the size of the control is defined by the 'size' property.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * If the value is set to false, the content is adjusted to the whole size of the control.
     */
    withMargin?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates the load status.
     */
    state?:
      | (LoadState | keyof typeof LoadState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * If set to its default value true this property applies the appropriate font style class based on the
     * language. When set to false the font size will always be large
     *
     * @since 1.73
     * @experimental As of version 1.73. Disclaimer: this property is in a beta state - incompatible API changes
     * may be done before its official public release. Use at your own discretion.
     */
    adaptiveFontSize?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The event is fired when the user chooses the numeric content.
     */
    press?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the NumericContent#press event.
   */
  export interface NumericContent$PressEventParameters {}

  /**
   * Event object of the NumericContent#press event.
   */
  export type NumericContent$PressEvent = Event<
    NumericContent$PressEventParameters,
    NumericContent
  >;
}

declare module "sap/m/ObjectAttribute" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { aria, TextDirection } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { ReactiveAreaMode } from "sap/m/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * The `ObjectAttribute` control displays a text field that can be normal or active. The `ObjectAttribute`
   * fires a `press` event when the user chooses the active text.
   *
   * **Note:** If property `active` is set to `true`, only the value of the `text` property is styled and
   * acts as a link. In this case the `text` property must also be set, as otherwise there will be no link
   * displayed for the user.
   *
   * @since 1.12
   */
  export default class ObjectAttribute extends Control {
    /**
     * Constructor for a new `ObjectAttribute`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ObjectAttributeSettings
    );
    /**
     * Constructor for a new `ObjectAttribute`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ObjectAttributeSettings
    );

    /**
     * Creates a new subclass of class sap.m.ObjectAttribute with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ObjectAttribute>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ObjectAttribute.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.ObjectAttribute`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ObjectAttribute` itself.
     *
     * Fires when the user clicks on active text.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ObjectAttribute$PressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ObjectAttribute` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.ObjectAttribute`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ObjectAttribute` itself.
     *
     * Fires when the user clicks on active text.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ObjectAttribute$PressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ObjectAttribute` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys the customContent in the aggregation {@link #getCustomContent customContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCustomContent(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.ObjectAttribute`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ObjectAttribute$PressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ObjectAttribute$PressEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getActive active}.
     *
     * Indicates if the `ObjectAttribute` text is selectable for the user.
     *
     * **Note:** As of version 1.48, only the value of the `text` property becomes active (styled and acts like
     * a link) as opposed to both the `title` and `text` in the previous versions. If you set this property
     * to `true`, you have to also set the `text` property. **Note:** When `active` property is set to `true`,
     * and the text direction of the `title` or the `text` does not match the text direction of the application,
     * the `textDirection` property should be set to ensure correct display.
     *
     *
     * @returns Value of property `active`
     */
    getActive(): boolean;
    /**
     * Gets current value of property {@link #getAriaHasPopup ariaHasPopup}.
     *
     * Specifies the value of the `aria-haspopup` attribute
     *
     * If the value is `None`, the attribute will not be rendered. Otherwise it will be rendered with the selected
     * value.
     *
     * NOTE: Use this property only when an `sap.m.ObjectAttribute` instance is active and related to a popover/popup.
     * The value needs to be equal to the main/root role of the popup - e.g. dialog, menu or list (examples:
     * if you have dialog -> dialog, if you have menu -> menu; if you have list -> list; if you have dialog
     * containing a list -> dialog). Do not use it, if you open a standard sap.m.Dialog, MessageBox or other
     * type of modal dialogs.
     *
     * Default value is `None`.
     *
     * @since 1.97.0
     *
     * @returns Value of property `ariaHasPopup`
     */
    getAriaHasPopup(): aria.HasPopup;
    /**
     * Gets content of aggregation {@link #getCustomContent customContent}.
     *
     * When the aggregation is set, it replaces the `text`, `active` and `textDirection` properties. This also
     * ignores the press event. The provided control is displayed as an active link in case it is a sap.m.Link.
     * **Note:** It will only allow sap.m.Text and sap.m.Link controls.
     */
    getCustomContent(): Control;
    /**
     * See:
     * 	sap.ui.core.Element.prototype.getFocusDomRef
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Returns the DOM Element that should get the focus or `null`
     */
    getFocusDomRef(): Element | null;
    /**
     * Defines to which DOM reference the Popup should be docked.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The DOM reference that Popup should dock to
     */
    getPopupAnchorDomRef(): Element;
    /**
     * Gets current value of property {@link #getReactiveAreaMode reactiveAreaMode}.
     *
     * Defines the size of the reactive area of the link:
     * 	 - `ReactiveAreaMode.Inline` - The link is displayed as part of a sentence.
     * 	 - `ReactiveAreaMode.Overlay` - The link is displayed as an overlay on top of other interactive parts
     *     of the page.
     *
     * **Note:**It is designed to make links easier to activate and helps meet the WCAG 2.2 Target Size requirement.
     * It is applicable only for the SAP Horizon themes. **Note:**The Reactive area size is sufficiently large
     * to help users avoid accidentally selecting (clicking or tapping) on unintented UI elements. UI elements
     * positioned over other parts of the page may need an invisible active touch area. This will ensure that
     * no elements beneath are activated accidentally when the user tries to interact with the overlay element.
     *
     * Default value is `Inline`.
     *
     * @since 1.133.0
     *
     * @returns Value of property `reactiveAreaMode`
     */
    getReactiveAreaMode(): ReactiveAreaMode;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Defines the ObjectAttribute text.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * Determines the direction of the text. Available options for the text direction are LTR (left-to-right),
     * RTL (right-to-left), or Inherit. By default the control inherits the text direction from its parent control.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Defines the ObjectAttribute title.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Sets a new value for property {@link #getActive active}.
     *
     * Indicates if the `ObjectAttribute` text is selectable for the user.
     *
     * **Note:** As of version 1.48, only the value of the `text` property becomes active (styled and acts like
     * a link) as opposed to both the `title` and `text` in the previous versions. If you set this property
     * to `true`, you have to also set the `text` property. **Note:** When `active` property is set to `true`,
     * and the text direction of the `title` or the `text` does not match the text direction of the application,
     * the `textDirection` property should be set to ensure correct display.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setActive(
      /**
       * New value for property `active`
       */
      bActive?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getAriaHasPopup ariaHasPopup}.
     *
     * Specifies the value of the `aria-haspopup` attribute
     *
     * If the value is `None`, the attribute will not be rendered. Otherwise it will be rendered with the selected
     * value.
     *
     * NOTE: Use this property only when an `sap.m.ObjectAttribute` instance is active and related to a popover/popup.
     * The value needs to be equal to the main/root role of the popup - e.g. dialog, menu or list (examples:
     * if you have dialog -> dialog, if you have menu -> menu; if you have list -> list; if you have dialog
     * containing a list -> dialog). Do not use it, if you open a standard sap.m.Dialog, MessageBox or other
     * type of modal dialogs.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     * @since 1.97.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAriaHasPopup(
      /**
       * New value for property `ariaHasPopup`
       */
      sAriaHasPopup?: aria.HasPopup | keyof typeof aria.HasPopup
    ): this;
    /**
     * Sets the aggregated {@link #getCustomContent customContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomContent(
      /**
       * The customContent to set
       */
      oCustomContent: Control
    ): this;
    /**
     * Sets a new value for property {@link #getReactiveAreaMode reactiveAreaMode}.
     *
     * Defines the size of the reactive area of the link:
     * 	 - `ReactiveAreaMode.Inline` - The link is displayed as part of a sentence.
     * 	 - `ReactiveAreaMode.Overlay` - The link is displayed as an overlay on top of other interactive parts
     *     of the page.
     *
     * **Note:**It is designed to make links easier to activate and helps meet the WCAG 2.2 Target Size requirement.
     * It is applicable only for the SAP Horizon themes. **Note:**The Reactive area size is sufficiently large
     * to help users avoid accidentally selecting (clicking or tapping) on unintented UI elements. UI elements
     * positioned over other parts of the page may need an invisible active touch area. This will ensure that
     * no elements beneath are activated accidentally when the user tries to interact with the overlay element.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inline`.
     *
     * @since 1.133.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setReactiveAreaMode(
      /**
       * New value for property `reactiveAreaMode`
       */
      sReactiveAreaMode?: ReactiveAreaMode | keyof typeof ReactiveAreaMode
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Defines the ObjectAttribute text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * Determines the direction of the text. Available options for the text direction are LTR (left-to-right),
     * RTL (right-to-left), or Inherit. By default the control inherits the text direction from its parent control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Defines the ObjectAttribute title.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ObjectAttribute constructor.
   */
  export interface $ObjectAttributeSettings extends $ControlSettings {
    /**
     * Defines the ObjectAttribute title.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Defines the ObjectAttribute text.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Indicates if the `ObjectAttribute` text is selectable for the user.
     *
     * **Note:** As of version 1.48, only the value of the `text` property becomes active (styled and acts like
     * a link) as opposed to both the `title` and `text` in the previous versions. If you set this property
     * to `true`, you have to also set the `text` property. **Note:** When `active` property is set to `true`,
     * and the text direction of the `title` or the `text` does not match the text direction of the application,
     * the `textDirection` property should be set to ensure correct display.
     */
    active?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the size of the reactive area of the link:
     * 	 - `ReactiveAreaMode.Inline` - The link is displayed as part of a sentence.
     * 	 - `ReactiveAreaMode.Overlay` - The link is displayed as an overlay on top of other interactive parts
     *     of the page.
     *
     * **Note:**It is designed to make links easier to activate and helps meet the WCAG 2.2 Target Size requirement.
     * It is applicable only for the SAP Horizon themes. **Note:**The Reactive area size is sufficiently large
     * to help users avoid accidentally selecting (clicking or tapping) on unintented UI elements. UI elements
     * positioned over other parts of the page may need an invisible active touch area. This will ensure that
     * no elements beneath are activated accidentally when the user tries to interact with the overlay element.
     *
     * @since 1.133.0
     */
    reactiveAreaMode?:
      | (ReactiveAreaMode | keyof typeof ReactiveAreaMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the direction of the text. Available options for the text direction are LTR (left-to-right),
     * RTL (right-to-left), or Inherit. By default the control inherits the text direction from its parent control.
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies the value of the `aria-haspopup` attribute
     *
     * If the value is `None`, the attribute will not be rendered. Otherwise it will be rendered with the selected
     * value.
     *
     * NOTE: Use this property only when an `sap.m.ObjectAttribute` instance is active and related to a popover/popup.
     * The value needs to be equal to the main/root role of the popup - e.g. dialog, menu or list (examples:
     * if you have dialog -> dialog, if you have menu -> menu; if you have list -> list; if you have dialog
     * containing a list -> dialog). Do not use it, if you open a standard sap.m.Dialog, MessageBox or other
     * type of modal dialogs.
     *
     * @since 1.97.0
     */
    ariaHasPopup?:
      | (aria.HasPopup | keyof typeof aria.HasPopup)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * When the aggregation is set, it replaces the `text`, `active` and `textDirection` properties. This also
     * ignores the press event. The provided control is displayed as an active link in case it is a sap.m.Link.
     * **Note:** It will only allow sap.m.Text and sap.m.Link controls.
     */
    customContent?: Control;

    /**
     * Fires when the user clicks on active text.
     */
    press?: (oEvent: ObjectAttribute$PressEvent) => void;
  }

  /**
   * Parameters of the ObjectAttribute#press event.
   */
  export interface ObjectAttribute$PressEventParameters {
    /**
     * DOM reference of the ObjectAttribute's text to be used for positioning.
     */
    domRef?: string;
  }

  /**
   * Event object of the ObjectAttribute#press event.
   */
  export type ObjectAttribute$PressEvent = Event<
    ObjectAttribute$PressEventParameters,
    ObjectAttribute
  >;
}

declare module "sap/m/ObjectHeader" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import ObjectNumber from "sap/m/ObjectNumber";

  import {
    ID,
    URI,
    TextDirection,
    ValueState,
    TitleLevel,
  } from "sap/ui/core/library";

  import ObjectAttribute from "sap/m/ObjectAttribute";

  import ObjectMarker from "sap/m/ObjectMarker";

  import {
    BackgroundDesign,
    ObjectHeaderContainer,
    ObjectHeaderPictureShape,
  } from "sap/m/library";

  import ObjectStatus from "sap/m/ObjectStatus";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * `ObjectHeader` is a display control that enables the user to easily identify a specific object. The object
   * header title is the key identifier of the object and additional text and icons can be used to further
   * distinguish it from other objects.
   *
   * Responsive behavior:
   *
   * When using the `sap.m.ObjectHeader` in SAP Quartz theme, the breakpoints and layout paddings could be
   * automatically determined by the container's width. To enable this concept and implement responsive padding
   * to the `ObjectHeader` control, add the following class: `sapUiResponsivePadding--header`.
   *
   * @since 1.12
   */
  export default class ObjectHeader extends Control {
    /**
     * Constructor for a new ObjectHeader.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ObjectHeaderSettings
    );
    /**
     * Constructor for a new ObjectHeader.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ObjectHeaderSettings
    );

    /**
     * Creates a new subclass of class sap.m.ObjectHeader with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ObjectHeader>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ObjectHeader.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some additionalNumber to the aggregation {@link #getAdditionalNumbers additionalNumbers}.
     *
     * @since 1.38.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAdditionalNumber(
      /**
       * The additionalNumber to add; if empty, nothing is inserted
       */
      oAdditionalNumber: ObjectNumber
    ): this;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds some attribute to the aggregation {@link #getAttributes attributes}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAttribute(
      /**
       * The attribute to add; if empty, nothing is inserted
       */
      oAttribute: ObjectAttribute
    ): this;
    /**
     * Adds some marker to the aggregation {@link #getMarkers markers}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addMarker(
      /**
       * The marker to add; if empty, nothing is inserted
       */
      oMarker: ObjectMarker
    ): this;
    /**
     * Adds some status to the aggregation {@link #getStatuses statuses}.
     *
     * @since 1.16.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addStatus(
      /**
       * The status to add; if empty, nothing is inserted
       */
      oStatus: Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:iconPress iconPress} event of this `sap.m.ObjectHeader`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ObjectHeader` itself.
     *
     * Event is fired when the title icon is active and the user taps/clicks on it
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachIconPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ObjectHeader$IconPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ObjectHeader` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:iconPress iconPress} event of this `sap.m.ObjectHeader`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ObjectHeader` itself.
     *
     * Event is fired when the title icon is active and the user taps/clicks on it
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachIconPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ObjectHeader$IconPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ObjectHeader` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:introPress introPress} event of this `sap.m.ObjectHeader`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ObjectHeader` itself.
     *
     * Event is fired when the intro is active and the user taps/clicks on it
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachIntroPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ObjectHeader$IntroPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ObjectHeader` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:introPress introPress} event of this `sap.m.ObjectHeader`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ObjectHeader` itself.
     *
     * Event is fired when the intro is active and the user taps/clicks on it
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachIntroPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ObjectHeader$IntroPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ObjectHeader` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:titlePress titlePress} event of this `sap.m.ObjectHeader`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ObjectHeader` itself.
     *
     * Event is fired when the title is active and the user taps/clicks on it
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTitlePress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ObjectHeader$TitlePressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ObjectHeader` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:titlePress titlePress} event of this `sap.m.ObjectHeader`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ObjectHeader` itself.
     *
     * Event is fired when the title is active and the user taps/clicks on it
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTitlePress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ObjectHeader$TitlePressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ObjectHeader` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:titleSelectorPress titleSelectorPress} event
     * of this `sap.m.ObjectHeader`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ObjectHeader` itself.
     *
     * Event is fired when the object header title selector (down-arrow) is pressed
     *
     * @since 1.16.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTitleSelectorPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ObjectHeader$TitleSelectorPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ObjectHeader` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:titleSelectorPress titleSelectorPress} event
     * of this `sap.m.ObjectHeader`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ObjectHeader` itself.
     *
     * Event is fired when the object header title selector (down-arrow) is pressed
     *
     * @since 1.16.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTitleSelectorPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ObjectHeader$TitleSelectorPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ObjectHeader` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the additionalNumbers in the aggregation {@link #getAdditionalNumbers additionalNumbers}.
     *
     * @since 1.38.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyAdditionalNumbers(): this;
    /**
     * Destroys all the attributes in the aggregation {@link #getAttributes attributes}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyAttributes(): this;
    /**
     * Destroys the firstStatus in the aggregation {@link #getFirstStatus firstStatus}.
     *
     * @deprecated As of version 1.16.0. replaced by `statuses` aggregation
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyFirstStatus(): this;
    /**
     * Destroys the headerContainer in the aggregation {@link #getHeaderContainer headerContainer}.
     *
     * @since 1.21.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyHeaderContainer(): this;
    /**
     * Destroys all the markers in the aggregation {@link #getMarkers markers}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyMarkers(): this;
    /**
     * Destroys the secondStatus in the aggregation {@link #getSecondStatus secondStatus}.
     *
     * @deprecated As of version 1.16.0. replaced by `statuses` aggregation
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySecondStatus(): this;
    /**
     * Destroys all the statuses in the aggregation {@link #getStatuses statuses}.
     *
     * @since 1.16.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyStatuses(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:iconPress iconPress} event of this `sap.m.ObjectHeader`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachIconPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ObjectHeader$IconPressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:introPress introPress} event of this `sap.m.ObjectHeader`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachIntroPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ObjectHeader$IntroPressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:titlePress titlePress} event of this `sap.m.ObjectHeader`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachTitlePress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ObjectHeader$TitlePressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:titleSelectorPress titleSelectorPress} event
     * of this `sap.m.ObjectHeader`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.16.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachTitleSelectorPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ObjectHeader$TitleSelectorPressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:iconPress iconPress} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireIconPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ObjectHeader$IconPressEventParameters
    ): this;
    /**
     * Fires event {@link #event:introPress introPress} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireIntroPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ObjectHeader$IntroPressEventParameters
    ): this;
    /**
     * Fires event {@link #event:titlePress titlePress} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireTitlePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ObjectHeader$TitlePressEventParameters
    ): this;
    /**
     * Fires event {@link #event:titleSelectorPress titleSelectorPress} to attached listeners.
     *
     * @since 1.16.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireTitleSelectorPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ObjectHeader$TitleSelectorPressEventParameters
    ): this;
    /**
     * Gets content of aggregation {@link #getAdditionalNumbers additionalNumbers}.
     *
     * NOTE: Only applied if you set "responsive=false". Additional object numbers and units are managed in
     * this aggregation. The numbers are hidden on tablet and phone size screens. When only one number is provided,
     * it is rendered with additional separator from the main ObjectHeader number.
     *
     * @since 1.38.0
     */
    getAdditionalNumbers(): ObjectNumber[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets content of aggregation {@link #getAttributes attributes}.
     *
     * The list of Object Attributes
     */
    getAttributes(): ObjectAttribute[];
    /**
     * Gets current value of property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Determines the background color of the `ObjectHeader`.
     *
     * **Note:** The different types of `ObjectHeader` come with different default background:
     * 	 - non responsive - Transparent
     * 	 - responsive - Translucent
     * 	 - condensed - Solid
     *
     *
     * @returns Value of property `backgroundDesign`
     */
    getBackgroundDesign(): BackgroundDesign;
    /**
     * Gets current value of property {@link #getCondensed condensed}.
     *
     * `ObjectHeader` with title, one attribute, number, and number unit.
     *
     * **Note:** Only applied if the `responsive` property is set to `false`.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `condensed`
     */
    getCondensed(): boolean;
    /**
     * Gets content of aggregation {@link #getFirstStatus firstStatus}.
     *
     * First status shown on the right side of the attributes above the second status. If it is not set the
     * first attribute will expand to take the entire row.
     *
     * @deprecated As of version 1.16.0. replaced by `statuses` aggregation
     */
    getFirstStatus(): ObjectStatus;
    /**
     * Gets current value of property {@link #getFullScreenOptimized fullScreenOptimized}.
     *
     * Optimizes the display of the elements of the `ObjectHeader`.
     *
     * Set this property to `true` if your app uses a fullscreen layout (as opposed to a master-detail or other
     * split-screen layout).
     *
     * **Note**: Only applied if the `responsive` property is also set to `true`.
     *
     * If set to `true`, the following situations apply:
     * 	 - On desktop, 1-3 attributes/statuses - positioned as a third block on the right side of the Title/Number
     *     group
     * 	 - On desktop, 4+ attributes/statuses - 4 columns below the Title/Number
     * 	 - On tablet (portrait mode), always in 2 columns below the Title/Number
     * 	 - On tablet (landscape mode), 1-2 attributes/statuses - 2 columns below the Title/Number
     * 	 - On tablet (landscape mode), 3+ attributes/statuses - 3 columns below the Title/Number  On phone,
     *     the attributes and statuses are always positioned in 1 column below the Title/Number of the `ObjectHeader`.
     *
     * If set to `false`, the attributes and statuses are being positioned below the Title/Number of the `ObjectHeader`
     * in 2 or 3 columns depending on their number:
     * 	 - On desktop, 1-4 attributes/statuses - 2 columns
     * 	 - On desktop, 5+ attributes/statuses - 3 columns
     * 	 - On tablet, always in 2 columns
     *
     * Default value is `false`.
     *
     * @since 1.28
     *
     * @returns Value of property `fullScreenOptimized`
     */
    getFullScreenOptimized(): boolean;
    /**
     * Gets content of aggregation {@link #getHeaderContainer headerContainer}.
     *
     * This aggregation takes only effect when you set "responsive" to true. It can either be filled with an
     * sap.m.IconTabBar or an sap.suite.ui.commons.HeaderContainer control. Overflow handling must be taken
     * care of by the inner control. If used with an IconTabBar control, only the header will be displayed inside
     * the object header, the content will be displayed below the ObjectHeader.
     *
     * @since 1.21.1
     */
    getHeaderContainer(): ObjectHeaderContainer;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Defines the icon of the `ObjectHeader`.
     *
     * **Note:** Recursive resolution of binding expressions is not supported by the framework. It works only
     * in ObjectHeader, since it is a composite control and creates an Image control internally.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getIconActive iconActive}.
     *
     * Determines whether the `ObjectHeader` icon is clickable.
     *
     *
     * @returns Value of property `iconActive`
     */
    getIconActive(): boolean;
    /**
     * Gets current value of property {@link #getIconAlt iconAlt}.
     *
     * Determines the alternative text of the `ObjectHeader` icon. The text is displayed if the image for the
     * icon is not available, or cannot be displayed.
     *
     * **Note:** Provide an empty string value for the `iconAlt` property in case you want to use the icon for
     * decoration only.
     *
     *
     * @returns Value of property `iconAlt`
     */
    getIconAlt(): string;
    /**
     * Gets current value of property {@link #getIconDensityAware iconDensityAware}.
     *
     * By default, this is set to `true` but then one or more requests are sent trying to get the density perfect
     * version of image if this version of image doesn't exist on the server.
     *
     * If bandwidth is the key for the application, set this value to `false`.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `iconDensityAware`
     */
    getIconDensityAware(): boolean;
    /**
     * Gets current value of property {@link #getIconTooltip iconTooltip}.
     *
     * Determines the tooltip text of the `ObjectHeader` icon.
     *
     *
     * @returns Value of property `iconTooltip`
     */
    getIconTooltip(): string;
    /**
     * Gets current value of property {@link #getImageShape imageShape}.
     *
     * Determines whether the picture should be displayed in a square or with a circle-shaped mask just like
     * in {@link sap.uxap.ObjectPageHeader}.
     *
     * **Note:** This property takes effect only on Images and it is ignored for Icons.
     *
     * Default value is `Square`.
     *
     * @since 1.61
     *
     * @returns Value of property `imageShape`
     */
    getImageShape(): ObjectHeaderPictureShape;
    /**
     * Gets current value of property {@link #getIntro intro}.
     *
     * Determines the introductory text for the `ObjectHeader`.
     *
     *
     * @returns Value of property `intro`
     */
    getIntro(): string;
    /**
     * Gets current value of property {@link #getIntroActive introActive}.
     *
     * Determines whether the introductory text of the `ObjectHeader` is clickable.
     *
     *
     * @returns Value of property `introActive`
     */
    getIntroActive(): boolean;
    /**
     * Gets current value of property {@link #getIntroHref introHref}.
     *
     * Determines the intro link target URI. Supports standard hyperlink behavior. If an action should be triggered,
     * this should not be set, but instead an event handler for the `introPress` event should be registered.
     *
     * @since 1.28
     *
     * @returns Value of property `introHref`
     */
    getIntroHref(): URI;
    /**
     * Gets current value of property {@link #getIntroTarget introTarget}.
     *
     * Determines the `target` attribute for the intro link. Options are `_self`, `_top`, `_blank`, `_parent`,
     * `_search`. Alternatively, a frame name can be entered.
     *
     * @since 1.28
     *
     * @returns Value of property `introTarget`
     */
    getIntroTarget(): string;
    /**
     * Gets current value of property {@link #getIntroTextDirection introTextDirection}.
     *
     * Specifies the intro text directionality with enumerated options. By default, the control inherits text
     * direction from the DOM.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Value of property `introTextDirection`
     */
    getIntroTextDirection(): TextDirection;
    /**
     * Gets content of aggregation {@link #getMarkers markers}.
     *
     * List of markers (icon and/or text) that can be displayed for the `ObjectHeader`, such as favorite and
     * flagged.
     *
     *  **Note:** You should use either this aggregation or the already deprecated properties - `markFlagged`
     * and `markFavorite`. Using both can lead to unexpected results.
     */
    getMarkers(): ObjectMarker[];
    /**
     * Gets current value of property {@link #getMarkFavorite markFavorite}.
     *
     * Sets the favorite state for the `ObjectHeader`. The `showMarkers` property must be set to `true` for
     * this property to take effect.
     *
     * Default value is `false`.
     *
     * @since 1.16.0
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation. Add {@link sap.m.ObjectMarker} with
     * type `sap.m.ObjectMarkerType.Favorite`. You should use either this property or the `markers` aggregation,
     * using both may lead to unpredicted behavior.
     *
     * @returns Value of property `markFavorite`
     */
    getMarkFavorite(): boolean;
    /**
     * Gets current value of property {@link #getMarkFlagged markFlagged}.
     *
     * Sets the flagged state for the `ObjectHeader`. The `showMarkers` property must be set to `true` for this
     * property to take effect.
     *
     * Default value is `false`.
     *
     * @since 1.16.0
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation. Add {@link sap.m.ObjectMarker} with
     * type `sap.m.ObjectMarkerType.Flagged`. You should use either this property or the `markers` aggregation,
     * using both may lead to unpredicted behavior.
     *
     * @returns Value of property `markFlagged`
     */
    getMarkFlagged(): boolean;
    /**
     * Gets current value of property {@link #getNumber number}.
     *
     * Determines the displayed number of the `ObjectHeader` number field.
     *
     *
     * @returns Value of property `number`
     */
    getNumber(): string;
    /**
     * Gets current value of property {@link #getNumberState numberState}.
     *
     * Determines the value state of the `number` and `numberUnit` properties.
     *
     * Default value is `None`.
     *
     * @since 1.16.0
     *
     * @returns Value of property `numberState`
     */
    getNumberState(): ValueState;
    /**
     * Gets current value of property {@link #getNumberTextDirection numberTextDirection}.
     *
     * Specifies the number and unit text directionality with enumerated options. By default, the control inherits
     * text direction from the DOM.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Value of property `numberTextDirection`
     */
    getNumberTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getNumberUnit numberUnit}.
     *
     * Determines the units qualifier of the `ObjectHeader` number.
     *
     * **Note:** The value of the `numberUnit` is not displayed if the number property is set to `null`.
     *
     *
     * @returns Value of property `numberUnit`
     */
    getNumberUnit(): string;
    /**
     * Gets current value of property {@link #getResponsive responsive}.
     *
     * Determines whether the `ObjectHeader` is rendered with a different design that reacts responsively to
     * the screen sizes.
     *
     * When the `responsive` property is set to `true`, the following behavior specifics for the control exist:
     *
     * 	 - If an image (or an icon font) is set to the `icon` property, it is hidden in portrait mode on phone.
     *
     * 	 - The title is truncated to 80 characters if longer. For portrait mode on phone, the title is truncated
     *     to 50 characters.
     *
     * Default value is `false`.
     *
     * @since 1.21.1
     *
     * @returns Value of property `responsive`
     */
    getResponsive(): boolean;
    /**
     * Gets content of aggregation {@link #getSecondStatus secondStatus}.
     *
     * Second status shown on the right side of the attributes below the first status. If it is not set the
     * second attribute will expand to take the entire row.
     *
     * @deprecated As of version 1.16.0. replaced by `statuses` aggregation
     */
    getSecondStatus(): ObjectStatus;
    /**
     * Gets current value of property {@link #getShowMarkers showMarkers}.
     *
     * If set to `true`, the `ObjectHeader` can be marked with icons such as favorite and flag.
     *
     * Default value is `false`.
     *
     * @since 1.16.0
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation. This property is valid only if you
     * are using the already deprecated properties - `markFlagged` and `markFavorite`. If you are using `markers`,
     * the visibility of the markers depends on what is set in the aggregation itself.
     *
     * @returns Value of property `showMarkers`
     */
    getShowMarkers(): boolean;
    /**
     * Gets current value of property {@link #getShowTitleSelector showTitleSelector}.
     *
     * Determines whether the selector arrow icon/image is displayed and can be pressed.
     *
     * Default value is `false`.
     *
     * @since 1.16.0
     *
     * @returns Value of property `showTitleSelector`
     */
    getShowTitleSelector(): boolean;
    /**
     * Gets content of aggregation {@link #getStatuses statuses}.
     *
     * The list of Object sap.ui.core.Control. It will only allow sap.m.ObjectStatus and sap.m.ProgressIndicator
     * controls.
     *
     * @since 1.16.0
     */
    getStatuses(): Control[];
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Determines the title of the `ObjectHeader`.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getTitleActive titleActive}.
     *
     * Determines whether the title of the `ObjectHeader` is clickable and is set only if a title is provided.
     *
     *
     * @returns Value of property `titleActive`
     */
    getTitleActive(): boolean;
    /**
     * Gets current value of property {@link #getTitleHref titleHref}.
     *
     * Defines the title link target URI. Supports standard hyperlink behavior.
     *
     * **Note:** If an action should be triggered, this property should not be set, but instead an event handler
     * for the `titlePress` event should be registered.
     *
     * @since 1.28
     *
     * @returns Value of property `titleHref`
     */
    getTitleHref(): URI;
    /**
     * Gets current value of property {@link #getTitleLevel titleLevel}.
     *
     * Defines the semantic level of the title.
     *
     * This information is used by assistive technologies, such as screen readers to create a hierarchical site
     * map for faster navigation. Depending on this setting an HTML h1-h6 element is used.
     *
     * Default value is `H1`.
     *
     *
     * @returns Value of property `titleLevel`
     */
    getTitleLevel(): TitleLevel;
    /**
     * Gets current value of property {@link #getTitleSelectorTooltip titleSelectorTooltip}.
     *
     * Determines a custom text for the tooltip of the select title arrow. If not set, a default text of the
     * tooltip will be displayed.
     *
     * Default value is `"Options"`.
     *
     * @since 1.30.0
     *
     * @returns Value of property `titleSelectorTooltip`
     */
    getTitleSelectorTooltip(): string;
    /**
     * Gets current value of property {@link #getTitleTarget titleTarget}.
     *
     * Determines the `target` attribute for the title link. Options are `_self`, `_top`, `_blank`, `_parent`,
     * `_search`. Alternatively, a frame name can be entered.
     *
     * @since 1.28
     *
     * @returns Value of property `titleTarget`
     */
    getTitleTarget(): string;
    /**
     * Gets current value of property {@link #getTitleTextDirection titleTextDirection}.
     *
     * Specifies the title text directionality with enumerated options. By default, the control inherits text
     * direction from the DOM.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Value of property `titleTextDirection`
     */
    getTitleTextDirection(): TextDirection;
    /**
     * Checks for the provided `sap.m.ObjectNumber` in the aggregation {@link #getAdditionalNumbers additionalNumbers}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.38.0
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfAdditionalNumber(
      /**
       * The additionalNumber whose index is looked for
       */
      oAdditionalNumber: ObjectNumber
    ): int;
    /**
     * Checks for the provided `sap.m.ObjectAttribute` in the aggregation {@link #getAttributes attributes}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfAttribute(
      /**
       * The attribute whose index is looked for
       */
      oAttribute: ObjectAttribute
    ): int;
    /**
     * Checks for the provided `sap.m.ObjectMarker` in the aggregation {@link #getMarkers markers}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfMarker(
      /**
       * The marker whose index is looked for
       */
      oMarker: ObjectMarker
    ): int;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getStatuses statuses}. and returns
     * its index if found or -1 otherwise.
     *
     * @since 1.16.0
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfStatus(
      /**
       * The status whose index is looked for
       */
      oStatus: Control
    ): int;
    /**
     * Inserts a additionalNumber into the aggregation {@link #getAdditionalNumbers additionalNumbers}.
     *
     * @since 1.38.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertAdditionalNumber(
      /**
       * The additionalNumber to insert; if empty, nothing is inserted
       */
      oAdditionalNumber: ObjectNumber,
      /**
       * The `0`-based index the additionalNumber should be inserted at; for a negative value of `iIndex`, the
       * additionalNumber is inserted at position 0; for a value greater than the current size of the aggregation,
       * the additionalNumber is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a attribute into the aggregation {@link #getAttributes attributes}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertAttribute(
      /**
       * The attribute to insert; if empty, nothing is inserted
       */
      oAttribute: ObjectAttribute,
      /**
       * The `0`-based index the attribute should be inserted at; for a negative value of `iIndex`, the attribute
       * is inserted at position 0; for a value greater than the current size of the aggregation, the attribute
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a marker into the aggregation {@link #getMarkers markers}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertMarker(
      /**
       * The marker to insert; if empty, nothing is inserted
       */
      oMarker: ObjectMarker,
      /**
       * The `0`-based index the marker should be inserted at; for a negative value of `iIndex`, the marker is
       * inserted at position 0; for a value greater than the current size of the aggregation, the marker is inserted
       * at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a status into the aggregation {@link #getStatuses statuses}.
     *
     * @since 1.16.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertStatus(
      /**
       * The status to insert; if empty, nothing is inserted
       */
      oStatus: Control,
      /**
       * The `0`-based index the status should be inserted at; for a negative value of `iIndex`, the status is
       * inserted at position 0; for a value greater than the current size of the aggregation, the status is inserted
       * at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes a additionalNumber from the aggregation {@link #getAdditionalNumbers additionalNumbers}.
     *
     * @since 1.38.0
     *
     * @returns The removed additionalNumber or `null`
     */
    removeAdditionalNumber(
      /**
       * The additionalNumber to remove or its index or id
       */
      vAdditionalNumber: int | string | ObjectNumber
    ): ObjectNumber | null;
    /**
     * Removes all the controls from the aggregation {@link #getAdditionalNumbers additionalNumbers}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.38.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAdditionalNumbers(): ObjectNumber[];
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all the controls from the aggregation {@link #getAttributes attributes}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAttributes(): ObjectAttribute[];
    /**
     * Removes all the controls from the aggregation {@link #getMarkers markers}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllMarkers(): ObjectMarker[];
    /**
     * Removes all the controls from the aggregation {@link #getStatuses statuses}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.16.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllStatuses(): Control[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes a attribute from the aggregation {@link #getAttributes attributes}.
     *
     *
     * @returns The removed attribute or `null`
     */
    removeAttribute(
      /**
       * The attribute to remove or its index or id
       */
      vAttribute: int | string | ObjectAttribute
    ): ObjectAttribute | null;
    /**
     * Removes a marker from the aggregation {@link #getMarkers markers}.
     *
     *
     * @returns The removed marker or `null`
     */
    removeMarker(
      /**
       * The marker to remove or its index or id
       */
      vMarker: int | string | ObjectMarker
    ): ObjectMarker | null;
    /**
     * Removes a status from the aggregation {@link #getStatuses statuses}.
     *
     * @since 1.16.0
     *
     * @returns The removed status or `null`
     */
    removeStatus(
      /**
       * The status to remove or its index or id
       */
      vStatus: int | string | Control
    ): Control | null;
    /**
     * Sets a new value for property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Determines the background color of the `ObjectHeader`.
     *
     * **Note:** The different types of `ObjectHeader` come with different default background:
     * 	 - non responsive - Transparent
     * 	 - responsive - Translucent
     * 	 - condensed - Solid
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundDesign(
      /**
       * New value for property `backgroundDesign`
       */
      sBackgroundDesign: BackgroundDesign | keyof typeof BackgroundDesign
    ): this;
    /**
     * Set the condensed flag
     *
     *
     * @returns this pointer for chaining
     */
    setCondensed(
      /**
       * the new value
       */
      bCondensed: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getFirstStatus firstStatus}.
     *
     * @deprecated As of version 1.16.0. replaced by `statuses` aggregation
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFirstStatus(
      /**
       * The firstStatus to set
       */
      oFirstStatus: ObjectStatus
    ): this;
    /**
     * Sets a new value for property {@link #getFullScreenOptimized fullScreenOptimized}.
     *
     * Optimizes the display of the elements of the `ObjectHeader`.
     *
     * Set this property to `true` if your app uses a fullscreen layout (as opposed to a master-detail or other
     * split-screen layout).
     *
     * **Note**: Only applied if the `responsive` property is also set to `true`.
     *
     * If set to `true`, the following situations apply:
     * 	 - On desktop, 1-3 attributes/statuses - positioned as a third block on the right side of the Title/Number
     *     group
     * 	 - On desktop, 4+ attributes/statuses - 4 columns below the Title/Number
     * 	 - On tablet (portrait mode), always in 2 columns below the Title/Number
     * 	 - On tablet (landscape mode), 1-2 attributes/statuses - 2 columns below the Title/Number
     * 	 - On tablet (landscape mode), 3+ attributes/statuses - 3 columns below the Title/Number  On phone,
     *     the attributes and statuses are always positioned in 1 column below the Title/Number of the `ObjectHeader`.
     *
     * If set to `false`, the attributes and statuses are being positioned below the Title/Number of the `ObjectHeader`
     * in 2 or 3 columns depending on their number:
     * 	 - On desktop, 1-4 attributes/statuses - 2 columns
     * 	 - On desktop, 5+ attributes/statuses - 3 columns
     * 	 - On tablet, always in 2 columns
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.28
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFullScreenOptimized(
      /**
       * New value for property `fullScreenOptimized`
       */
      bFullScreenOptimized?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getHeaderContainer headerContainer}.
     *
     * @since 1.21.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeaderContainer(
      /**
       * The headerContainer to set
       */
      oHeaderContainer: ObjectHeaderContainer
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Defines the icon of the `ObjectHeader`.
     *
     * **Note:** Recursive resolution of binding expressions is not supported by the framework. It works only
     * in ObjectHeader, since it is a composite control and creates an Image control internally.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getIconActive iconActive}.
     *
     * Determines whether the `ObjectHeader` icon is clickable.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconActive(
      /**
       * New value for property `iconActive`
       */
      bIconActive?: boolean
    ): this;
    /**
     * Sets the alternative text of the `ObjectHeader` icon.
     *
     *
     * @returns this pointer for chaining
     */
    setIconAlt(
      /**
       * the alternative icon text
       */
      sIconAlt: string
    ): this;
    /**
     * Sets a new value for property {@link #getIconDensityAware iconDensityAware}.
     *
     * By default, this is set to `true` but then one or more requests are sent trying to get the density perfect
     * version of image if this version of image doesn't exist on the server.
     *
     * If bandwidth is the key for the application, set this value to `false`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconDensityAware(
      /**
       * New value for property `iconDensityAware`
       */
      bIconDensityAware?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIconTooltip iconTooltip}.
     *
     * Determines the tooltip text of the `ObjectHeader` icon.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconTooltip(
      /**
       * New value for property `iconTooltip`
       */
      sIconTooltip?: string
    ): this;
    /**
     * Sets a new value for property {@link #getImageShape imageShape}.
     *
     * Determines whether the picture should be displayed in a square or with a circle-shaped mask just like
     * in {@link sap.uxap.ObjectPageHeader}.
     *
     * **Note:** This property takes effect only on Images and it is ignored for Icons.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Square`.
     *
     * @since 1.61
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setImageShape(
      /**
       * New value for property `imageShape`
       */
      sImageShape?:
        | ObjectHeaderPictureShape
        | keyof typeof ObjectHeaderPictureShape
    ): this;
    /**
     * Sets a new value for property {@link #getIntro intro}.
     *
     * Determines the introductory text for the `ObjectHeader`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIntro(
      /**
       * New value for property `intro`
       */
      sIntro?: string
    ): this;
    /**
     * Sets a new value for property {@link #getIntroActive introActive}.
     *
     * Determines whether the introductory text of the `ObjectHeader` is clickable.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIntroActive(
      /**
       * New value for property `introActive`
       */
      bIntroActive?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIntroHref introHref}.
     *
     * Determines the intro link target URI. Supports standard hyperlink behavior. If an action should be triggered,
     * this should not be set, but instead an event handler for the `introPress` event should be registered.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.28
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIntroHref(
      /**
       * New value for property `introHref`
       */
      sIntroHref?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getIntroTarget introTarget}.
     *
     * Determines the `target` attribute for the intro link. Options are `_self`, `_top`, `_blank`, `_parent`,
     * `_search`. Alternatively, a frame name can be entered.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.28
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIntroTarget(
      /**
       * New value for property `introTarget`
       */
      sIntroTarget?: string
    ): this;
    /**
     * Sets a new value for property {@link #getIntroTextDirection introTextDirection}.
     *
     * Specifies the intro text directionality with enumerated options. By default, the control inherits text
     * direction from the DOM.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIntroTextDirection(
      /**
       * New value for property `introTextDirection`
       */
      sIntroTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets the visibility value of the Favorite marker.
     *
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation. Add {@link sap.m.ObjectMarker} with
     * type `sap.m.ObjectMarkerType.Favorite`.
     *
     * @returns this pointer for chaining
     */
    setMarkFavorite(
      /**
       * visibility of the marker
       */
      bMarked: boolean
    ): this;
    /**
     * Sets the visibility value of the Flagged marker.
     *
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation. Add {@link sap.m.ObjectMarker} with
     * type `sap.m.ObjectMarkerType.Flagged`.
     *
     * @returns this pointer for chaining
     */
    setMarkFlagged(
      /**
       * visibility of the marker
       */
      bMarked: boolean
    ): this;
    /**
     * Set the number value to the internal aggregation
     *
     *
     * @returns this pointer for chaining
     */
    setNumber(
      /**
       * the new value
       */
      sNumber: string
    ): this;
    /**
     * Set the number state to the internal aggregation
     *
     *
     * @returns this pointer for chaining
     */
    setNumberState(
      /**
       * the new value
       */
      sState: ValueState | keyof typeof ValueState
    ): this;
    /**
     * Sets a new value for property {@link #getNumberTextDirection numberTextDirection}.
     *
     * Specifies the number and unit text directionality with enumerated options. By default, the control inherits
     * text direction from the DOM.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNumberTextDirection(
      /**
       * New value for property `numberTextDirection`
       */
      sNumberTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Set the number unit to the internal aggregation
     *
     *
     * @returns this pointer for chaining
     */
    setNumberUnit(
      /**
       * the new value
       */
      sUnit: string
    ): this;
    /**
     * Sets a new value for property {@link #getResponsive responsive}.
     *
     * Determines whether the `ObjectHeader` is rendered with a different design that reacts responsively to
     * the screen sizes.
     *
     * When the `responsive` property is set to `true`, the following behavior specifics for the control exist:
     *
     * 	 - If an image (or an icon font) is set to the `icon` property, it is hidden in portrait mode on phone.
     *
     * 	 - The title is truncated to 80 characters if longer. For portrait mode on phone, the title is truncated
     *     to 50 characters.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.21.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setResponsive(
      /**
       * New value for property `responsive`
       */
      bResponsive?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getSecondStatus secondStatus}.
     *
     * @deprecated As of version 1.16.0. replaced by `statuses` aggregation
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSecondStatus(
      /**
       * The secondStatus to set
       */
      oSecondStatus: ObjectStatus
    ): this;
    /**
     * Sets the visibility value of the Flagged and Favorite markers.
     *
     * @deprecated As of version 1.42.0. replaced by `markers` aggregationv.
     *
     * @returns this pointer for chaining
     */
    setShowMarkers(
      /**
       * visibility of all markers
       */
      bMarked: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowTitleSelector showTitleSelector}.
     *
     * Determines whether the selector arrow icon/image is displayed and can be pressed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.16.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowTitleSelector(
      /**
       * New value for property `showTitleSelector`
       */
      bShowTitleSelector?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Determines the title of the `ObjectHeader`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitleActive titleActive}.
     *
     * Determines whether the title of the `ObjectHeader` is clickable and is set only if a title is provided.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleActive(
      /**
       * New value for property `titleActive`
       */
      bTitleActive?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getTitleHref titleHref}.
     *
     * Defines the title link target URI. Supports standard hyperlink behavior.
     *
     * **Note:** If an action should be triggered, this property should not be set, but instead an event handler
     * for the `titlePress` event should be registered.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.28
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleHref(
      /**
       * New value for property `titleHref`
       */
      sTitleHref?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getTitleLevel titleLevel}.
     *
     * Defines the semantic level of the title.
     *
     * This information is used by assistive technologies, such as screen readers to create a hierarchical site
     * map for faster navigation. Depending on this setting an HTML h1-h6 element is used.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `H1`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleLevel(
      /**
       * New value for property `titleLevel`
       */
      sTitleLevel?: TitleLevel | keyof typeof TitleLevel
    ): this;
    /**
     * Sets the new text for the tooltip of the select title arrow to the internal aggregation
     *
     *
     * @returns this pointer for chaining
     */
    setTitleSelectorTooltip(
      /**
       * the tooltip of the title selector
       */
      sTooltip: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitleTarget titleTarget}.
     *
     * Determines the `target` attribute for the title link. Options are `_self`, `_top`, `_blank`, `_parent`,
     * `_search`. Alternatively, a frame name can be entered.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.28
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleTarget(
      /**
       * New value for property `titleTarget`
       */
      sTitleTarget?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitleTextDirection titleTextDirection}.
     *
     * Specifies the title text directionality with enumerated options. By default, the control inherits text
     * direction from the DOM.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleTextDirection(
      /**
       * New value for property `titleTextDirection`
       */
      sTitleTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ObjectHeader constructor.
   */
  export interface $ObjectHeaderSettings extends $ControlSettings {
    /**
     * Determines the title of the `ObjectHeader`.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Determines the displayed number of the `ObjectHeader` number field.
     */
    number?: string | PropertyBindingInfo;

    /**
     * Determines the units qualifier of the `ObjectHeader` number.
     *
     * **Note:** The value of the `numberUnit` is not displayed if the number property is set to `null`.
     */
    numberUnit?: string | PropertyBindingInfo;

    /**
     * Determines the introductory text for the `ObjectHeader`.
     */
    intro?: string | PropertyBindingInfo;

    /**
     * Determines whether the introductory text of the `ObjectHeader` is clickable.
     */
    introActive?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the title of the `ObjectHeader` is clickable and is set only if a title is provided.
     */
    titleActive?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the icon of the `ObjectHeader`.
     *
     * **Note:** Recursive resolution of binding expressions is not supported by the framework. It works only
     * in ObjectHeader, since it is a composite control and creates an Image control internally.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the `ObjectHeader` icon is clickable.
     */
    iconActive?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the alternative text of the `ObjectHeader` icon. The text is displayed if the image for the
     * icon is not available, or cannot be displayed.
     *
     * **Note:** Provide an empty string value for the `iconAlt` property in case you want to use the icon for
     * decoration only.
     */
    iconAlt?: string | PropertyBindingInfo;

    /**
     * Determines the tooltip text of the `ObjectHeader` icon.
     */
    iconTooltip?: string | PropertyBindingInfo;

    /**
     * By default, this is set to `true` but then one or more requests are sent trying to get the density perfect
     * version of image if this version of image doesn't exist on the server.
     *
     * If bandwidth is the key for the application, set this value to `false`.
     */
    iconDensityAware?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the picture should be displayed in a square or with a circle-shaped mask just like
     * in {@link sap.uxap.ObjectPageHeader}.
     *
     * **Note:** This property takes effect only on Images and it is ignored for Icons.
     *
     * @since 1.61
     */
    imageShape?:
      | (ObjectHeaderPictureShape | keyof typeof ObjectHeaderPictureShape)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Sets the favorite state for the `ObjectHeader`. The `showMarkers` property must be set to `true` for
     * this property to take effect.
     *
     * @since 1.16.0
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation. Add {@link sap.m.ObjectMarker} with
     * type `sap.m.ObjectMarkerType.Favorite`. You should use either this property or the `markers` aggregation,
     * using both may lead to unpredicted behavior.
     */
    markFavorite?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the flagged state for the `ObjectHeader`. The `showMarkers` property must be set to `true` for this
     * property to take effect.
     *
     * @since 1.16.0
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation. Add {@link sap.m.ObjectMarker} with
     * type `sap.m.ObjectMarkerType.Flagged`. You should use either this property or the `markers` aggregation,
     * using both may lead to unpredicted behavior.
     */
    markFlagged?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * If set to `true`, the `ObjectHeader` can be marked with icons such as favorite and flag.
     *
     * @since 1.16.0
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation. This property is valid only if you
     * are using the already deprecated properties - `markFlagged` and `markFavorite`. If you are using `markers`,
     * the visibility of the markers depends on what is set in the aggregation itself.
     */
    showMarkers?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the selector arrow icon/image is displayed and can be pressed.
     *
     * @since 1.16.0
     */
    showTitleSelector?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the value state of the `number` and `numberUnit` properties.
     *
     * @since 1.16.0
     */
    numberState?:
      | (ValueState | keyof typeof ValueState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * `ObjectHeader` with title, one attribute, number, and number unit.
     *
     * **Note:** Only applied if the `responsive` property is set to `false`.
     */
    condensed?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the background color of the `ObjectHeader`.
     *
     * **Note:** The different types of `ObjectHeader` come with different default background:
     * 	 - non responsive - Transparent
     * 	 - responsive - Translucent
     * 	 - condensed - Solid
     */
    backgroundDesign?:
      | (BackgroundDesign | keyof typeof BackgroundDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines whether the `ObjectHeader` is rendered with a different design that reacts responsively to
     * the screen sizes.
     *
     * When the `responsive` property is set to `true`, the following behavior specifics for the control exist:
     *
     * 	 - If an image (or an icon font) is set to the `icon` property, it is hidden in portrait mode on phone.
     *
     * 	 - The title is truncated to 80 characters if longer. For portrait mode on phone, the title is truncated
     *     to 50 characters.
     *
     * @since 1.21.1
     */
    responsive?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Optimizes the display of the elements of the `ObjectHeader`.
     *
     * Set this property to `true` if your app uses a fullscreen layout (as opposed to a master-detail or other
     * split-screen layout).
     *
     * **Note**: Only applied if the `responsive` property is also set to `true`.
     *
     * If set to `true`, the following situations apply:
     * 	 - On desktop, 1-3 attributes/statuses - positioned as a third block on the right side of the Title/Number
     *     group
     * 	 - On desktop, 4+ attributes/statuses - 4 columns below the Title/Number
     * 	 - On tablet (portrait mode), always in 2 columns below the Title/Number
     * 	 - On tablet (landscape mode), 1-2 attributes/statuses - 2 columns below the Title/Number
     * 	 - On tablet (landscape mode), 3+ attributes/statuses - 3 columns below the Title/Number  On phone,
     *     the attributes and statuses are always positioned in 1 column below the Title/Number of the `ObjectHeader`.
     *
     * If set to `false`, the attributes and statuses are being positioned below the Title/Number of the `ObjectHeader`
     * in 2 or 3 columns depending on their number:
     * 	 - On desktop, 1-4 attributes/statuses - 2 columns
     * 	 - On desktop, 5+ attributes/statuses - 3 columns
     * 	 - On tablet, always in 2 columns
     *
     * @since 1.28
     */
    fullScreenOptimized?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the title link target URI. Supports standard hyperlink behavior.
     *
     * **Note:** If an action should be triggered, this property should not be set, but instead an event handler
     * for the `titlePress` event should be registered.
     *
     * @since 1.28
     */
    titleHref?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the `target` attribute for the title link. Options are `_self`, `_top`, `_blank`, `_parent`,
     * `_search`. Alternatively, a frame name can be entered.
     *
     * @since 1.28
     */
    titleTarget?: string | PropertyBindingInfo;

    /**
     * Determines the intro link target URI. Supports standard hyperlink behavior. If an action should be triggered,
     * this should not be set, but instead an event handler for the `introPress` event should be registered.
     *
     * @since 1.28
     */
    introHref?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the `target` attribute for the intro link. Options are `_self`, `_top`, `_blank`, `_parent`,
     * `_search`. Alternatively, a frame name can be entered.
     *
     * @since 1.28
     */
    introTarget?: string | PropertyBindingInfo;

    /**
     * Specifies the title text directionality with enumerated options. By default, the control inherits text
     * direction from the DOM.
     *
     * @since 1.28.0
     */
    titleTextDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies the intro text directionality with enumerated options. By default, the control inherits text
     * direction from the DOM.
     *
     * @since 1.28.0
     */
    introTextDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies the number and unit text directionality with enumerated options. By default, the control inherits
     * text direction from the DOM.
     *
     * @since 1.28.0
     */
    numberTextDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines a custom text for the tooltip of the select title arrow. If not set, a default text of the
     * tooltip will be displayed.
     *
     * @since 1.30.0
     */
    titleSelectorTooltip?: string | PropertyBindingInfo;

    /**
     * Defines the semantic level of the title.
     *
     * This information is used by assistive technologies, such as screen readers to create a hierarchical site
     * map for faster navigation. Depending on this setting an HTML h1-h6 element is used.
     */
    titleLevel?:
      | (TitleLevel | keyof typeof TitleLevel)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The list of Object Attributes
     */
    attributes?:
      | ObjectAttribute[]
      | ObjectAttribute
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * First status shown on the right side of the attributes above the second status. If it is not set the
     * first attribute will expand to take the entire row.
     *
     * @deprecated As of version 1.16.0. replaced by `statuses` aggregation
     */
    firstStatus?: ObjectStatus;

    /**
     * Second status shown on the right side of the attributes below the first status. If it is not set the
     * second attribute will expand to take the entire row.
     *
     * @deprecated As of version 1.16.0. replaced by `statuses` aggregation
     */
    secondStatus?: ObjectStatus;

    /**
     * The list of Object sap.ui.core.Control. It will only allow sap.m.ObjectStatus and sap.m.ProgressIndicator
     * controls.
     *
     * @since 1.16.0
     */
    statuses?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * NOTE: Only applied if you set "responsive=false". Additional object numbers and units are managed in
     * this aggregation. The numbers are hidden on tablet and phone size screens. When only one number is provided,
     * it is rendered with additional separator from the main ObjectHeader number.
     *
     * @since 1.38.0
     */
    additionalNumbers?:
      | ObjectNumber[]
      | ObjectNumber
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * This aggregation takes only effect when you set "responsive" to true. It can either be filled with an
     * sap.m.IconTabBar or an sap.suite.ui.commons.HeaderContainer control. Overflow handling must be taken
     * care of by the inner control. If used with an IconTabBar control, only the header will be displayed inside
     * the object header, the content will be displayed below the ObjectHeader.
     *
     * @since 1.21.1
     */
    headerContainer?: ObjectHeaderContainer;

    /**
     * List of markers (icon and/or text) that can be displayed for the `ObjectHeader`, such as favorite and
     * flagged.
     *
     *  **Note:** You should use either this aggregation or the already deprecated properties - `markFlagged`
     * and `markFavorite`. Using both can lead to unexpected results.
     */
    markers?:
      | ObjectMarker[]
      | ObjectMarker
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Association to controls / ids which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Event is fired when the title is active and the user taps/clicks on it
     */
    titlePress?: (oEvent: ObjectHeader$TitlePressEvent) => void;

    /**
     * Event is fired when the intro is active and the user taps/clicks on it
     */
    introPress?: (oEvent: ObjectHeader$IntroPressEvent) => void;

    /**
     * Event is fired when the title icon is active and the user taps/clicks on it
     */
    iconPress?: (oEvent: ObjectHeader$IconPressEvent) => void;

    /**
     * Event is fired when the object header title selector (down-arrow) is pressed
     *
     * @since 1.16.0
     */
    titleSelectorPress?: (oEvent: ObjectHeader$TitleSelectorPressEvent) => void;
  }

  /**
   * Parameters of the ObjectHeader#iconPress event.
   */
  export interface ObjectHeader$IconPressEventParameters {
    /**
     * Dom reference of the object header' icon to be used for positioning.
     */
    domRef?: object;
  }

  /**
   * Event object of the ObjectHeader#iconPress event.
   */
  export type ObjectHeader$IconPressEvent = Event<
    ObjectHeader$IconPressEventParameters,
    ObjectHeader
  >;

  /**
   * Parameters of the ObjectHeader#introPress event.
   */
  export interface ObjectHeader$IntroPressEventParameters {
    /**
     * Dom reference of the object header' intro to be used for positioning.
     */
    domRef?: object;
  }

  /**
   * Event object of the ObjectHeader#introPress event.
   */
  export type ObjectHeader$IntroPressEvent = Event<
    ObjectHeader$IntroPressEventParameters,
    ObjectHeader
  >;

  /**
   * Parameters of the ObjectHeader#titlePress event.
   */
  export interface ObjectHeader$TitlePressEventParameters {
    /**
     * Dom reference of the object header' title to be used for positioning.
     */
    domRef?: object;
  }

  /**
   * Event object of the ObjectHeader#titlePress event.
   */
  export type ObjectHeader$TitlePressEvent = Event<
    ObjectHeader$TitlePressEventParameters,
    ObjectHeader
  >;

  /**
   * Parameters of the ObjectHeader#titleSelectorPress event.
   */
  export interface ObjectHeader$TitleSelectorPressEventParameters {
    /**
     * Dom reference of the object header' titleArrow to be used for positioning.
     */
    domRef?: object;
  }

  /**
   * Event object of the ObjectHeader#titleSelectorPress event.
   */
  export type ObjectHeader$TitleSelectorPressEvent = Event<
    ObjectHeader$TitleSelectorPressEventParameters,
    ObjectHeader
  >;
}

declare module "sap/m/ObjectIdentifier" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { ID, AccessibilityInfo, TextDirection } from "sap/ui/core/library";

  import { EmptyIndicatorMode, ReactiveAreaMode } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * The ObjectIdentifier is a display control that enables the user to easily identify a specific object.
   * The ObjectIdentifier title is the key identifier of the object and additional text can be used to further
   * distinguish it from other objects.
   *
   * **Note:** This control should not be used with {@link sap.m.Label} or in Forms along with {@link sap.m.Label}.
   *
   * @since 1.12
   */
  export default class ObjectIdentifier extends Control {
    /**
     * Constructor for a new ObjectIdentifier.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/object-display-elements/#-object-status Object Identifier}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ObjectIdentifierSettings
    );
    /**
     * Constructor for a new ObjectIdentifier.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/object-display-elements/#-object-status Object Identifier}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ObjectIdentifierSettings
    );

    /**
     * Creates a new subclass of class sap.m.ObjectIdentifier with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ObjectIdentifier>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ObjectIdentifier.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:titlePress titlePress} event of this `sap.m.ObjectIdentifier`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ObjectIdentifier` itself.
     *
     * Fires when the title is active and the user taps/clicks on it.
     *
     * @since 1.26
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTitlePress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ObjectIdentifier$TitlePressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ObjectIdentifier` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:titlePress titlePress} event of this `sap.m.ObjectIdentifier`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ObjectIdentifier` itself.
     *
     * Fires when the title is active and the user taps/clicks on it.
     *
     * @since 1.26
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTitlePress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ObjectIdentifier$TitlePressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ObjectIdentifier` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:titlePress titlePress} event of this `sap.m.ObjectIdentifier`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.26
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachTitlePress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ObjectIdentifier$TitlePressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:titlePress titlePress} to attached listeners.
     *
     * @since 1.26
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireTitlePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ObjectIdentifier$TitlePressEventParameters
    ): this;
    /**
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Current accessibility state of the control
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getBadgeAttachments badgeAttachments}.
     *
     * Indicates whether or not the attachments icon is displayed.
     *
     * @deprecated As of version 1.24.0. There is no replacement for the moment.
     *
     * @returns Value of property `badgeAttachments`
     */
    getBadgeAttachments(): boolean;
    /**
     * Gets current value of property {@link #getBadgeNotes badgeNotes}.
     *
     * Indicates whether or not the notes icon is displayed.
     *
     * @deprecated As of version 1.24.0. There is no replacement for the moment.
     *
     * @returns Value of property `badgeNotes`
     */
    getBadgeNotes(): boolean;
    /**
     * Gets current value of property {@link #getBadgePeople badgePeople}.
     *
     * Indicates whether or not the address book icon is displayed.
     *
     * @deprecated As of version 1.24.0. There is no replacement for the moment.
     *
     * @returns Value of property `badgePeople`
     */
    getBadgePeople(): boolean;
    /**
     * Gets current value of property {@link #getEmptyIndicatorMode emptyIndicatorMode}.
     *
     * Specifies if an empty indicator should be displayed when there is no text.
     *
     * Default value is `Off`.
     *
     * @since 1.89
     *
     * @returns Value of property `emptyIndicatorMode`
     */
    getEmptyIndicatorMode(): EmptyIndicatorMode;
    /**
     * Gets current value of property {@link #getReactiveAreaMode reactiveAreaMode}.
     *
     * Defines the size of the reactive area of the link:
     * 	 - `ReactiveAreaMode.Inline` - The link is displayed as part of a sentence.
     * 	 - `ReactiveAreaMode.Overlay` - The link is displayed as an overlay on top of other interactive parts
     *     of the page.
     *
     * **Note:**It is designed to make links easier to activate and helps meet the WCAG 2.2 Target Size requirement.
     * It is applicable only for the SAP Horizon themes. **Note:**The Reactive area size is sufficiently large
     * to help users avoid accidentally selecting (clicking or tapping) on unintented UI elements. UI elements
     * positioned over other parts of the page may need an invisible active touch area. This will ensure that
     * no elements beneath are activated accidentally when the user tries to interact with the overlay element.
     *
     * Default value is `Inline`.
     *
     * @since 1.133.0
     *
     * @returns Value of property `reactiveAreaMode`
     */
    getReactiveAreaMode(): ReactiveAreaMode;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Defines the object text.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * Specifies the element's text directionality with enumerated options. By default, the control inherits
     * text direction from the DOM.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Defines the object title.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getTitleActive titleActive}.
     *
     * Indicates if the ObjectIdentifier's title is clickable.
     *
     * Default value is `false`.
     *
     * @since 1.26
     *
     * @returns Value of property `titleActive`
     */
    getTitleActive(): boolean;
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * Indicates if the ObjectIdentifier is visible. An invisible ObjectIdentifier is not being rendered.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getBadgeAttachments badgeAttachments}.
     *
     * Indicates whether or not the attachments icon is displayed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @deprecated As of version 1.24.0. There is no replacement for the moment.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBadgeAttachments(
      /**
       * New value for property `badgeAttachments`
       */
      bBadgeAttachments?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getBadgeNotes badgeNotes}.
     *
     * Indicates whether or not the notes icon is displayed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @deprecated As of version 1.24.0. There is no replacement for the moment.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBadgeNotes(
      /**
       * New value for property `badgeNotes`
       */
      bBadgeNotes?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getBadgePeople badgePeople}.
     *
     * Indicates whether or not the address book icon is displayed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @deprecated As of version 1.24.0. There is no replacement for the moment.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBadgePeople(
      /**
       * New value for property `badgePeople`
       */
      bBadgePeople?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEmptyIndicatorMode emptyIndicatorMode}.
     *
     * Specifies if an empty indicator should be displayed when there is no text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Off`.
     *
     * @since 1.89
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEmptyIndicatorMode(
      /**
       * New value for property `emptyIndicatorMode`
       */
      sEmptyIndicatorMode?: EmptyIndicatorMode | keyof typeof EmptyIndicatorMode
    ): this;
    /**
     * Sets a new value for property {@link #getReactiveAreaMode reactiveAreaMode}.
     *
     * Defines the size of the reactive area of the link:
     * 	 - `ReactiveAreaMode.Inline` - The link is displayed as part of a sentence.
     * 	 - `ReactiveAreaMode.Overlay` - The link is displayed as an overlay on top of other interactive parts
     *     of the page.
     *
     * **Note:**It is designed to make links easier to activate and helps meet the WCAG 2.2 Target Size requirement.
     * It is applicable only for the SAP Horizon themes. **Note:**The Reactive area size is sufficiently large
     * to help users avoid accidentally selecting (clicking or tapping) on unintented UI elements. UI elements
     * positioned over other parts of the page may need an invisible active touch area. This will ensure that
     * no elements beneath are activated accidentally when the user tries to interact with the overlay element.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inline`.
     *
     * @since 1.133.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setReactiveAreaMode(
      /**
       * New value for property `reactiveAreaMode`
       */
      sReactiveAreaMode?: ReactiveAreaMode | keyof typeof ReactiveAreaMode
    ): this;
    /**
     * Sets text. Default value is empty/undefined.
     *
     *
     * @returns this to allow method chaining
     */
    setText(
      /**
       * New value for property text
       */
      sText: string
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * Specifies the element's text directionality with enumerated options. By default, the control inherits
     * text direction from the DOM.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets the title. Default value is empty/undefined.
     *
     *
     * @returns this to allow method chaining
     */
    setTitle(
      /**
       * New value for property title
       */
      sTitle: string
    ): this;
    /**
     * Sets property titleActive. Default value is false.
     *
     *
     * @returns this to allow method chaining
     */
    setTitleActive(
      /**
       * new value for property titleActive
       */
      bValue: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * Indicates if the ObjectIdentifier is visible. An invisible ObjectIdentifier is not being rendered.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ObjectIdentifier constructor.
   */
  export interface $ObjectIdentifierSettings extends $ControlSettings {
    /**
     * Defines the object title.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Defines the object text.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Indicates whether or not the notes icon is displayed.
     *
     * @deprecated As of version 1.24.0. There is no replacement for the moment.
     */
    badgeNotes?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether or not the address book icon is displayed.
     *
     * @deprecated As of version 1.24.0. There is no replacement for the moment.
     */
    badgePeople?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether or not the attachments icon is displayed.
     *
     * @deprecated As of version 1.24.0. There is no replacement for the moment.
     */
    badgeAttachments?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates if the ObjectIdentifier is visible. An invisible ObjectIdentifier is not being rendered.
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates if the ObjectIdentifier's title is clickable.
     *
     * @since 1.26
     */
    titleActive?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the size of the reactive area of the link:
     * 	 - `ReactiveAreaMode.Inline` - The link is displayed as part of a sentence.
     * 	 - `ReactiveAreaMode.Overlay` - The link is displayed as an overlay on top of other interactive parts
     *     of the page.
     *
     * **Note:**It is designed to make links easier to activate and helps meet the WCAG 2.2 Target Size requirement.
     * It is applicable only for the SAP Horizon themes. **Note:**The Reactive area size is sufficiently large
     * to help users avoid accidentally selecting (clicking or tapping) on unintented UI elements. UI elements
     * positioned over other parts of the page may need an invisible active touch area. This will ensure that
     * no elements beneath are activated accidentally when the user tries to interact with the overlay element.
     *
     * @since 1.133.0
     */
    reactiveAreaMode?:
      | (ReactiveAreaMode | keyof typeof ReactiveAreaMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies the element's text directionality with enumerated options. By default, the control inherits
     * text direction from the DOM.
     *
     * @since 1.28.0
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies if an empty indicator should be displayed when there is no text.
     *
     * @since 1.89
     */
    emptyIndicatorMode?:
      | (EmptyIndicatorMode | keyof typeof EmptyIndicatorMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Association to controls / IDs, which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Fires when the title is active and the user taps/clicks on it.
     *
     * @since 1.26
     */
    titlePress?: (oEvent: ObjectIdentifier$TitlePressEvent) => void;
  }

  /**
   * Parameters of the ObjectIdentifier#titlePress event.
   */
  export interface ObjectIdentifier$TitlePressEventParameters {
    /**
     * DOM reference of the object identifier's title.
     */
    domRef?: object;
  }

  /**
   * Event object of the ObjectIdentifier#titlePress event.
   */
  export type ObjectIdentifier$TitlePressEvent = Event<
    ObjectIdentifier$TitlePressEventParameters,
    ObjectIdentifier
  >;
}

declare module "sap/m/ObjectListItem" {
  import {
    default as ListItemBase,
    $ListItemBaseSettings,
  } from "sap/m/ListItemBase";

  import ObjectAttribute from "sap/m/ObjectAttribute";

  import ObjectMarker from "sap/m/ObjectMarker";

  import { URI, TextDirection, ValueState } from "sap/ui/core/library";

  import ObjectStatus from "sap/m/ObjectStatus";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * ObjectListItem is a display control that provides summary information about an object as a list item.
   * The ObjectListItem title is the key identifier of the object. Additional text and icons can be used to
   * further distinguish it from other objects. Attributes and statuses can be used to provide additional
   * meaning about the object to the user.
   *
   * **Note:** The control must only be used in the context of a list.
   *
   * @since 1.12
   */
  export default class ObjectListItem extends ListItemBase {
    /**
     * Constructor for a new ObjectListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/object-list-item/ Object List Item}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ObjectListItemSettings
    );
    /**
     * Constructor for a new ObjectListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/object-list-item/ Object List Item}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ObjectListItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.ObjectListItem with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ListItemBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ObjectListItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ObjectListItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some attribute to the aggregation {@link #getAttributes attributes}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAttribute(
      /**
       * The attribute to add; if empty, nothing is inserted
       */
      oAttribute: ObjectAttribute
    ): this;
    /**
     * Adds some marker to the aggregation {@link #getMarkers markers}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addMarker(
      /**
       * The marker to add; if empty, nothing is inserted
       */
      oMarker: ObjectMarker
    ): this;
    /**
     * Destroys all the attributes in the aggregation {@link #getAttributes attributes}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyAttributes(): this;
    /**
     * Destroys the firstStatus in the aggregation {@link #getFirstStatus firstStatus}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyFirstStatus(): this;
    /**
     * Destroys all the markers in the aggregation {@link #getMarkers markers}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyMarkers(): this;
    /**
     * Destroys the secondStatus in the aggregation {@link #getSecondStatus secondStatus}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySecondStatus(): this;
    /**
     * Gets current value of property {@link #getActiveIcon activeIcon}.
     *
     * Icon displayed when the ObjectListItem is active.
     *
     *
     * @returns Value of property `activeIcon`
     */
    getActiveIcon(): URI;
    /**
     * Gets content of aggregation {@link #getAttributes attributes}.
     *
     * List of attributes displayed below the title to the left of the status fields.
     */
    getAttributes(): ObjectAttribute[];
    /**
     * Gets content of aggregation {@link #getFirstStatus firstStatus}.
     *
     * First status text field displayed on the right side of the attributes.
     */
    getFirstStatus(): ObjectStatus;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * ObjectListItem icon displayed to the left of the title.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getIconDensityAware iconDensityAware}.
     *
     * By default, this is set to true but then one or more requests are sent trying to get the density perfect
     * version of image (in case this version of image doesn't exist on the server).
     *
     * If bandwidth is key for the application, set this value to false.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `iconDensityAware`
     */
    getIconDensityAware(): boolean;
    /**
     * Gets current value of property {@link #getIntro intro}.
     *
     * Defines the introductory text for the ObjectListItem.
     *
     *
     * @returns Value of property `intro`
     */
    getIntro(): string;
    /**
     * Gets current value of property {@link #getIntroTextDirection introTextDirection}.
     *
     * Determines the text direction of the item intro. Available options for the intro direction are LTR (left-to-right)
     * and RTL (right-to-left). By default the item intro inherits the text direction from its parent.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Value of property `introTextDirection`
     */
    getIntroTextDirection(): TextDirection;
    /**
     * Gets content of aggregation {@link #getMarkers markers}.
     *
     * List of markers (icon and/or text) that can be displayed for the `ObjectListItems`, such as favorite
     * and flagged.
     *
     *  **Note:** You should use either this aggregation or the already deprecated properties - `markFlagged`,
     * `markFavorite`, and `markLocked`. Using both can lead to unexpected results.
     */
    getMarkers(): ObjectMarker[];
    /**
     * Gets current value of property {@link #getMarkFavorite markFavorite}.
     *
     * Sets the favorite state for the ObjectListItem.
     *
     *
     *
     * @since 1.16.0
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation. Add {@link sap.m.ObjectMarker} with
     * type `sap.m.ObjectMarkerType.Favorite`. You should use either this property or the `markers` aggregation,
     * using both may lead to unpredicted behavior.
     *
     * @returns Value of property `markFavorite`
     */
    getMarkFavorite(): boolean;
    /**
     * Gets current value of property {@link #getMarkFlagged markFlagged}.
     *
     * Sets the flagged state for the ObjectListItem.
     *
     *
     *
     * @since 1.16.0
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation. Add {@link sap.m.ObjectMarker} with
     * type `sap.m.ObjectMarkerType.Flagged`. You should use either this property or the `markers` aggregation,
     * using both may lead to unpredicted behavior.
     *
     * @returns Value of property `markFlagged`
     */
    getMarkFlagged(): boolean;
    /**
     * Gets current value of property {@link #getMarkLocked markLocked}.
     *
     * Sets the locked state of the ObjectListItem.
     *
     *
     *
     * Default value is `false`.
     *
     * @since 1.28
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation. Add {@link sap.m.ObjectMarker} with
     * type `sap.m.ObjectMarkerType.Locked`. You should use either this property or the `markers` aggregation,
     * using both may lead to unpredicted behavior.
     *
     *
     *
     * @returns Value of property `markLocked`
     */
    getMarkLocked(): boolean;
    /**
     * Gets current value of property {@link #getNumber number}.
     *
     * Defines the ObjectListItem number.
     *
     *
     * @returns Value of property `number`
     */
    getNumber(): string;
    /**
     * Gets current value of property {@link #getNumberState numberState}.
     *
     * Defines the ObjectListItem number and numberUnit value state.
     *
     * Default value is `None`.
     *
     * @since 1.16.0
     *
     * @returns Value of property `numberState`
     */
    getNumberState(): ValueState;
    /**
     * Gets current value of property {@link #getNumberTextDirection numberTextDirection}.
     *
     * Determines the text direction of the item number. Available options for the number direction are LTR
     * (left-to-right) and RTL (right-to-left). By default the item number inherits the text direction from
     * its parent.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Value of property `numberTextDirection`
     */
    getNumberTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getNumberUnit numberUnit}.
     *
     * Defines the number units qualifier of the ObjectListItem.
     *
     *
     * @returns Value of property `numberUnit`
     */
    getNumberUnit(): string;
    /**
     * Gets content of aggregation {@link #getSecondStatus secondStatus}.
     *
     * Second status text field displayed on the right side of the attributes.
     */
    getSecondStatus(): ObjectStatus;
    /**
     * Gets current value of property {@link #getShowMarkers showMarkers}.
     *
     * If set to true, the ObjectListItem can be marked with icons such as favorite and flag.
     *
     *
     *
     * @since 1.16.0
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation. This property is valid only if you
     * are using the already deprecated properties - `markFlagged`, `markFavorite`, and `markLocked`. If you
     * are using the `markers` aggregation, the visibility of the markers depends on what is set in the aggregation
     * itself.
     *
     * @returns Value of property `showMarkers`
     */
    getShowMarkers(): boolean;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Defines the ObjectListItem title.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getTitleTextDirection titleTextDirection}.
     *
     * Determines the text direction of the item title. Available options for the title direction are LTR (left-to-right)
     * and RTL (right-to-left). By default the item title inherits the text direction from its parent.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Value of property `titleTextDirection`
     */
    getTitleTextDirection(): TextDirection;
    /**
     * Checks for the provided `sap.m.ObjectAttribute` in the aggregation {@link #getAttributes attributes}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfAttribute(
      /**
       * The attribute whose index is looked for
       */
      oAttribute: ObjectAttribute
    ): int;
    /**
     * Checks for the provided `sap.m.ObjectMarker` in the aggregation {@link #getMarkers markers}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfMarker(
      /**
       * The marker whose index is looked for
       */
      oMarker: ObjectMarker
    ): int;
    /**
     * Inserts a attribute into the aggregation {@link #getAttributes attributes}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertAttribute(
      /**
       * The attribute to insert; if empty, nothing is inserted
       */
      oAttribute: ObjectAttribute,
      /**
       * The `0`-based index the attribute should be inserted at; for a negative value of `iIndex`, the attribute
       * is inserted at position 0; for a value greater than the current size of the aggregation, the attribute
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a marker into the aggregation {@link #getMarkers markers}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertMarker(
      /**
       * The marker to insert; if empty, nothing is inserted
       */
      oMarker: ObjectMarker,
      /**
       * The `0`-based index the marker should be inserted at; for a negative value of `iIndex`, the marker is
       * inserted at position 0; for a value greater than the current size of the aggregation, the marker is inserted
       * at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getAttributes attributes}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAttributes(): ObjectAttribute[];
    /**
     * Removes all the controls from the aggregation {@link #getMarkers markers}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllMarkers(): ObjectMarker[];
    /**
     * Removes a attribute from the aggregation {@link #getAttributes attributes}.
     *
     *
     * @returns The removed attribute or `null`
     */
    removeAttribute(
      /**
       * The attribute to remove or its index or id
       */
      vAttribute: int | string | ObjectAttribute
    ): ObjectAttribute | null;
    /**
     * Removes a marker from the aggregation {@link #getMarkers markers}.
     *
     *
     * @returns The removed marker or `null`
     */
    removeMarker(
      /**
       * The marker to remove or its index or id
       */
      vMarker: int | string | ObjectMarker
    ): ObjectMarker | null;
    /**
     * Sets a new value for property {@link #getActiveIcon activeIcon}.
     *
     * Icon displayed when the ObjectListItem is active.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setActiveIcon(
      /**
       * New value for property `activeIcon`
       */
      sActiveIcon?: URI
    ): this;
    /**
     * Sets the aggregated {@link #getFirstStatus firstStatus}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFirstStatus(
      /**
       * The firstStatus to set
       */
      oFirstStatus: ObjectStatus
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * ObjectListItem icon displayed to the left of the title.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getIconDensityAware iconDensityAware}.
     *
     * By default, this is set to true but then one or more requests are sent trying to get the density perfect
     * version of image (in case this version of image doesn't exist on the server).
     *
     * If bandwidth is key for the application, set this value to false.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconDensityAware(
      /**
       * New value for property `iconDensityAware`
       */
      bIconDensityAware?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIntro intro}.
     *
     * Defines the introductory text for the ObjectListItem.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIntro(
      /**
       * New value for property `intro`
       */
      sIntro?: string
    ): this;
    /**
     * Sets a new value for property {@link #getIntroTextDirection introTextDirection}.
     *
     * Determines the text direction of the item intro. Available options for the intro direction are LTR (left-to-right)
     * and RTL (right-to-left). By default the item intro inherits the text direction from its parent.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIntroTextDirection(
      /**
       * New value for property `introTextDirection`
       */
      sIntroTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets the visibility value of the Favorite marker.
     *
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation. Add {@link sap.m.ObjectMarker} with
     * type `sap.m.ObjectMarkerType.Favorite`.
     *
     * @returns this pointer for chaining
     */
    setMarkFavorite(
      /**
       * the new value
       */
      bMarked: boolean
    ): this;
    /**
     * Sets the visibility value of the Flagged marker.
     *
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation. Add {@link sap.m.ObjectMarker} with
     * type `sap.m.ObjectMarkerType.Flagged`.
     *
     * @returns this pointer for chaining
     */
    setMarkFlagged(
      /**
       * the new value
       */
      bMarked: boolean
    ): this;
    /**
     * Sets the visibility value of the Locked marker.
     *
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation. Add {@link sap.m.ObjectMarker} with
     * type `sap.m.ObjectMarkerType.Locked`.
     *
     * @returns this pointer for chaining
     */
    setMarkLocked(
      /**
       * the new value
       */
      bMarked: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getNumber number}.
     *
     * Defines the ObjectListItem number.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNumber(
      /**
       * New value for property `number`
       */
      sNumber?: string
    ): this;
    /**
     * Sets a new value for property {@link #getNumberState numberState}.
     *
     * Defines the ObjectListItem number and numberUnit value state.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     * @since 1.16.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNumberState(
      /**
       * New value for property `numberState`
       */
      sNumberState?: ValueState | keyof typeof ValueState
    ): this;
    /**
     * Sets a new value for property {@link #getNumberTextDirection numberTextDirection}.
     *
     * Determines the text direction of the item number. Available options for the number direction are LTR
     * (left-to-right) and RTL (right-to-left). By default the item number inherits the text direction from
     * its parent.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNumberTextDirection(
      /**
       * New value for property `numberTextDirection`
       */
      sNumberTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getNumberUnit numberUnit}.
     *
     * Defines the number units qualifier of the ObjectListItem.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNumberUnit(
      /**
       * New value for property `numberUnit`
       */
      sNumberUnit?: string
    ): this;
    /**
     * Sets the aggregated {@link #getSecondStatus secondStatus}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSecondStatus(
      /**
       * The secondStatus to set
       */
      oSecondStatus: ObjectStatus
    ): this;
    /**
     * Sets the visibility value of the Flagged and Favorite markers.
     *
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation.
     *
     * @returns this pointer for chaining
     */
    setShowMarkers(
      /**
       * the new value
       */
      bMarked: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Defines the ObjectListItem title.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitleTextDirection titleTextDirection}.
     *
     * Determines the text direction of the item title. Available options for the title direction are LTR (left-to-right)
     * and RTL (right-to-left). By default the item title inherits the text direction from its parent.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleTextDirection(
      /**
       * New value for property `titleTextDirection`
       */
      sTitleTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ObjectListItem constructor.
   */
  export interface $ObjectListItemSettings extends $ListItemBaseSettings {
    /**
     * Defines the ObjectListItem title.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Defines the ObjectListItem number.
     */
    number?: string | PropertyBindingInfo;

    /**
     * Defines the number units qualifier of the ObjectListItem.
     */
    numberUnit?: string | PropertyBindingInfo;

    /**
     * Defines the introductory text for the ObjectListItem.
     */
    intro?: string | PropertyBindingInfo;

    /**
     * ObjectListItem icon displayed to the left of the title.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Icon displayed when the ObjectListItem is active.
     */
    activeIcon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * By default, this is set to true but then one or more requests are sent trying to get the density perfect
     * version of image (in case this version of image doesn't exist on the server).
     *
     * If bandwidth is key for the application, set this value to false.
     */
    iconDensityAware?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the favorite state for the ObjectListItem.
     *
     *
     *
     * @since 1.16.0
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation. Add {@link sap.m.ObjectMarker} with
     * type `sap.m.ObjectMarkerType.Favorite`. You should use either this property or the `markers` aggregation,
     * using both may lead to unpredicted behavior.
     */
    markFavorite?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the flagged state for the ObjectListItem.
     *
     *
     *
     * @since 1.16.0
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation. Add {@link sap.m.ObjectMarker} with
     * type `sap.m.ObjectMarkerType.Flagged`. You should use either this property or the `markers` aggregation,
     * using both may lead to unpredicted behavior.
     */
    markFlagged?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * If set to true, the ObjectListItem can be marked with icons such as favorite and flag.
     *
     *
     *
     * @since 1.16.0
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation. This property is valid only if you
     * are using the already deprecated properties - `markFlagged`, `markFavorite`, and `markLocked`. If you
     * are using the `markers` aggregation, the visibility of the markers depends on what is set in the aggregation
     * itself.
     */
    showMarkers?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the ObjectListItem number and numberUnit value state.
     *
     * @since 1.16.0
     */
    numberState?:
      | (ValueState | keyof typeof ValueState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the text direction of the item title. Available options for the title direction are LTR (left-to-right)
     * and RTL (right-to-left). By default the item title inherits the text direction from its parent.
     */
    titleTextDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the text direction of the item intro. Available options for the intro direction are LTR (left-to-right)
     * and RTL (right-to-left). By default the item intro inherits the text direction from its parent.
     */
    introTextDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the text direction of the item number. Available options for the number direction are LTR
     * (left-to-right) and RTL (right-to-left). By default the item number inherits the text direction from
     * its parent.
     */
    numberTextDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Sets the locked state of the ObjectListItem.
     *
     *
     *
     * @since 1.28
     * @deprecated As of version 1.42.0. replaced by `markers` aggregation. Add {@link sap.m.ObjectMarker} with
     * type `sap.m.ObjectMarkerType.Locked`. You should use either this property or the `markers` aggregation,
     * using both may lead to unpredicted behavior.
     */
    markLocked?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * List of attributes displayed below the title to the left of the status fields.
     */
    attributes?:
      | ObjectAttribute[]
      | ObjectAttribute
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * First status text field displayed on the right side of the attributes.
     */
    firstStatus?: ObjectStatus;

    /**
     * Second status text field displayed on the right side of the attributes.
     */
    secondStatus?: ObjectStatus;

    /**
     * List of markers (icon and/or text) that can be displayed for the `ObjectListItems`, such as favorite
     * and flagged.
     *
     *  **Note:** You should use either this aggregation or the already deprecated properties - `markFlagged`,
     * `markFavorite`, and `markLocked`. Using both can lead to unexpected results.
     */
    markers?:
      | ObjectMarker[]
      | ObjectMarker
      | AggregationBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/ObjectMarker" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { ID } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    ReactiveAreaMode,
    ObjectMarkerType,
    ObjectMarkerVisibility,
  } from "sap/m/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * The `sap.m.ObjectMarker` control represents one of the following predefined types:
   * 	`Flagged` `Favorite` `Draft` `Locked` `LockedBy` `Unsaved` `UnsavedBy`
   * **Note**: Use the `LockedBy/UnsavedBy` type along with the `additionalInfo` property to display the name
   * of the user who locked/changed the object. If `additionalInfo` property is not set when using `LockedBy/UnsavedBy`
   * types, the string "Locked by another user"/"Unsaved changes by another user" will be displayed. If you
   * don't want to display name of the user, simply use the `Locked/Unsaved` types.
   *
   * @since 1.38
   */
  export default class ObjectMarker extends Control {
    /**
     * Constructor for a new ObjectMarker.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/object-display-elements/#-object-status Object Marker}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ObjectMarkerSettings
    );
    /**
     * Constructor for a new ObjectMarker.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/object-display-elements/#-object-status Object Marker}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ObjectMarkerSettings
    );

    /**
     * Creates a new subclass of class sap.m.ObjectMarker with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ObjectMarker>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ObjectMarker.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.ObjectMarker`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ObjectMarker` itself.
     *
     * Event is fired when the `ObjectMarker` is interactive and the user taps/clicks on it.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ObjectMarker$PressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ObjectMarker` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.ObjectMarker`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ObjectMarker` itself.
     *
     * Event is fired when the `ObjectMarker` is interactive and the user taps/clicks on it.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ObjectMarker$PressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ObjectMarker` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.ObjectMarker`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ObjectMarker$PressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ObjectMarker$PressEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getAdditionalInfo additionalInfo}.
     *
     * Sets additional information to the displayed `type`.
     *
     * **Note:** If no type is set, the additional information will not be displayed.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `additionalInfo`
     */
    getAdditionalInfo(): string;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getReactiveAreaMode reactiveAreaMode}.
     *
     * Defines the size of the reactive area of the link:
     * 	 - `ReactiveAreaMode.Inline` - The link is displayed as part of a sentence.
     * 	 - `ReactiveAreaMode.Overlay` - The link is displayed as an overlay on top of other interactive parts
     *     of the page.
     *
     * **Note:**It is designed to make links easier to activate and helps meet the WCAG 2.2 Target Size requirement.
     * It is applicable only for the SAP Horizon themes. **Note:**The Reactive area size is sufficiently large
     * to help users avoid accidentally selecting (clicking or tapping) on unintented UI elements. UI elements
     * positioned over other parts of the page may need an invisible active touch area. This will ensure that
     * no elements beneath are activated accidentally when the user tries to interact with the overlay element.
     *
     * Default value is `Inline`.
     *
     * @since 1.133.0
     *
     * @returns Value of property `reactiveAreaMode`
     */
    getReactiveAreaMode(): ReactiveAreaMode;
    /**
     * Gets current value of property {@link #getType type}.
     *
     * Sets one of the predefined types.
     *
     * **Note**: If the `visibility` property is not specified explicitly, every `type` comes with predefined
     * one as follows:
     * 	 - For `Flagged` and `Favorite` the icon is visible and the text is not displayed
     * 	 - For `Draft` the text is visible and the icon is not displayed
     * 	 - For `Locked`, `LockedBy`, `Unsaved` and `UnsavedBy` - on screens larger than 600px both icon and
     *     text are visible, otherwise only the icon
     *
     *
     *
     *
     * @returns Value of property `type`
     */
    getType(): ObjectMarkerType;
    /**
     * Gets current value of property {@link #getVisibility visibility}.
     *
     * Sets one of the visibility states. Visibility states are as follows:
     * 	 - `IconOnly` - displays only icon, regardless of the screen size
     * 	 - `TextOnly` - displays only text, regardless of the screen size
     * 	 - `IconAndText` - displays both icon and text, regardless of the screen size
     *
     *
     * @returns Value of property `visibility`
     */
    getVisibility(): ObjectMarkerVisibility;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getAdditionalInfo additionalInfo}.
     *
     * Sets additional information to the displayed `type`.
     *
     * **Note:** If no type is set, the additional information will not be displayed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAdditionalInfo(
      /**
       * New value for property `additionalInfo`
       */
      sAdditionalInfo?: string
    ): this;
    /**
     * Sets a new value for property {@link #getReactiveAreaMode reactiveAreaMode}.
     *
     * Defines the size of the reactive area of the link:
     * 	 - `ReactiveAreaMode.Inline` - The link is displayed as part of a sentence.
     * 	 - `ReactiveAreaMode.Overlay` - The link is displayed as an overlay on top of other interactive parts
     *     of the page.
     *
     * **Note:**It is designed to make links easier to activate and helps meet the WCAG 2.2 Target Size requirement.
     * It is applicable only for the SAP Horizon themes. **Note:**The Reactive area size is sufficiently large
     * to help users avoid accidentally selecting (clicking or tapping) on unintented UI elements. UI elements
     * positioned over other parts of the page may need an invisible active touch area. This will ensure that
     * no elements beneath are activated accidentally when the user tries to interact with the overlay element.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inline`.
     *
     * @since 1.133.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setReactiveAreaMode(
      /**
       * New value for property `reactiveAreaMode`
       */
      sReactiveAreaMode?: ReactiveAreaMode | keyof typeof ReactiveAreaMode
    ): this;
    /**
     * Sets a new value for property {@link #getType type}.
     *
     * Sets one of the predefined types.
     *
     * **Note**: If the `visibility` property is not specified explicitly, every `type` comes with predefined
     * one as follows:
     * 	 - For `Flagged` and `Favorite` the icon is visible and the text is not displayed
     * 	 - For `Draft` the text is visible and the icon is not displayed
     * 	 - For `Locked`, `LockedBy`, `Unsaved` and `UnsavedBy` - on screens larger than 600px both icon and
     *     text are visible, otherwise only the icon
     *
     *
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setType(
      /**
       * New value for property `type`
       */
      sType: ObjectMarkerType | keyof typeof ObjectMarkerType
    ): this;
    /**
     * Sets a new value for property {@link #getVisibility visibility}.
     *
     * Sets one of the visibility states. Visibility states are as follows:
     * 	 - `IconOnly` - displays only icon, regardless of the screen size
     * 	 - `TextOnly` - displays only text, regardless of the screen size
     * 	 - `IconAndText` - displays both icon and text, regardless of the screen size
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisibility(
      /**
       * New value for property `visibility`
       */
      sVisibility: ObjectMarkerVisibility | keyof typeof ObjectMarkerVisibility
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ObjectMarker constructor.
   */
  export interface $ObjectMarkerSettings extends $ControlSettings {
    /**
     * Sets one of the predefined types.
     *
     * **Note**: If the `visibility` property is not specified explicitly, every `type` comes with predefined
     * one as follows:
     * 	 - For `Flagged` and `Favorite` the icon is visible and the text is not displayed
     * 	 - For `Draft` the text is visible and the icon is not displayed
     * 	 - For `Locked`, `LockedBy`, `Unsaved` and `UnsavedBy` - on screens larger than 600px both icon and
     *     text are visible, otherwise only the icon
     */
    type?:
      | (ObjectMarkerType | keyof typeof ObjectMarkerType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the size of the reactive area of the link:
     * 	 - `ReactiveAreaMode.Inline` - The link is displayed as part of a sentence.
     * 	 - `ReactiveAreaMode.Overlay` - The link is displayed as an overlay on top of other interactive parts
     *     of the page.
     *
     * **Note:**It is designed to make links easier to activate and helps meet the WCAG 2.2 Target Size requirement.
     * It is applicable only for the SAP Horizon themes. **Note:**The Reactive area size is sufficiently large
     * to help users avoid accidentally selecting (clicking or tapping) on unintented UI elements. UI elements
     * positioned over other parts of the page may need an invisible active touch area. This will ensure that
     * no elements beneath are activated accidentally when the user tries to interact with the overlay element.
     *
     * @since 1.133.0
     */
    reactiveAreaMode?:
      | (ReactiveAreaMode | keyof typeof ReactiveAreaMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Sets one of the visibility states. Visibility states are as follows:
     * 	 - `IconOnly` - displays only icon, regardless of the screen size
     * 	 - `TextOnly` - displays only text, regardless of the screen size
     * 	 - `IconAndText` - displays both icon and text, regardless of the screen size
     */
    visibility?:
      | (ObjectMarkerVisibility | keyof typeof ObjectMarkerVisibility)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Sets additional information to the displayed `type`.
     *
     * **Note:** If no type is set, the additional information will not be displayed.
     */
    additionalInfo?: string | PropertyBindingInfo;

    /**
     * Association to controls / ids which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Event is fired when the `ObjectMarker` is interactive and the user taps/clicks on it.
     */
    press?: (oEvent: ObjectMarker$PressEvent) => void;
  }

  /**
   * Parameters of the ObjectMarker#press event.
   */
  export interface ObjectMarker$PressEventParameters {
    /**
     * Type of the `ObjectMarker`.
     */
    type?: ObjectMarkerType | keyof typeof ObjectMarkerType;
  }

  /**
   * Event object of the ObjectMarker#press event.
   */
  export type ObjectMarker$PressEvent = Event<
    ObjectMarker$PressEventParameters,
    ObjectMarker
  >;
}

declare module "sap/m/ObjectNumber" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IFormContent,
    ID,
    AccessibilityInfo,
    ValueState,
    TextAlign,
    TextDirection,
  } from "sap/ui/core/library";

  import Event from "sap/ui/base/Event";

  import { EmptyIndicatorMode, ReactiveAreaMode } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The ObjectNumber control displays number and number unit properties for an object. The number can be
   * displayed using semantic colors to provide additional meaning about the object to the user.
   *
   * With 1.63, large design of the control is supported by setting `sapMObjectNumberLarge` CSS class to the
   * `ObjectNumber`.
   *
   * With 1.110, inner text wrapping could be enabled by adding the `sapMObjectNumberLongText` CSS class to
   * the `ObjectNumber`. This class can be added by using оObjectStatus.addStyleClass("sapMObjectNumberLongText");
   *
   * **Note:** To fulfill the design guidelines when you are using `sapMObjectNumberLarge` CSS class set the
   * `emphasized` property to `false`.
   *
   * @since 1.12
   */
  export default class ObjectNumber extends Control implements IFormContent {
    __implements__sap_ui_core_IFormContent: boolean;
    /**
     * Constructor for a new ObjectNumber.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/object-display-elements/#-object-status Object Number}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ObjectNumberSettings
    );
    /**
     * Constructor for a new ObjectNumber.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/object-display-elements/#-object-status Object Number}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ObjectNumberSettings
    );

    /**
     * Creates a new subclass of class sap.m.ObjectNumber with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ObjectNumber>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ObjectNumber.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.ObjectNumber`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ObjectNumber` itself.
     *
     * Fires when the user clicks/taps on active `Object Number`.
     *
     * @since 1.86
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ObjectNumber` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.ObjectNumber`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ObjectNumber` itself.
     *
     * Fires when the user clicks/taps on active `Object Number`.
     *
     * @since 1.86
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ObjectNumber` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.ObjectNumber`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.86
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @since 1.86
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Current accessibility state of the control
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Gets current value of property {@link #getActive active}.
     *
     * Indicates if the `ObjectNumber` text and icon can be clicked/tapped by the user.
     *
     * **Note:** If you set this property to `true`, you have to set also the `number` or `unit` property.
     *
     * Default value is `false`.
     *
     * @since 1.86
     *
     * @returns Value of property `active`
     */
    getActive(): boolean;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getEmphasized emphasized}.
     *
     * Indicates if the object number should appear emphasized.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `emphasized`
     */
    getEmphasized(): boolean;
    /**
     * Gets current value of property {@link #getEmptyIndicatorMode emptyIndicatorMode}.
     *
     * Specifies if an empty indicator should be displayed when there is no number.
     *
     * Default value is `Off`.
     *
     * @since 1.89
     *
     * @returns Value of property `emptyIndicatorMode`
     */
    getEmptyIndicatorMode(): EmptyIndicatorMode;
    /**
     * Gets current value of property {@link #getInverted inverted}.
     *
     * Determines whether the background color reflects the set `state` instead of the control's text.
     *
     * Default value is `false`.
     *
     * @since 1.86
     *
     * @returns Value of property `inverted`
     */
    getInverted(): boolean;
    /**
     * Gets current value of property {@link #getNumber number}.
     *
     * Defines the number field.
     *
     *
     * @returns Value of property `number`
     */
    getNumber(): string;
    /**
     * Gets current value of property {@link #getNumberUnit numberUnit}.
     *
     * Defines the number units qualifier.
     *
     * @deprecated As of version 1.16.1. replaced by `unit` property
     *
     * @returns Value of property `numberUnit`
     */
    getNumberUnit(): string;
    /**
     * Gets current value of property {@link #getReactiveAreaMode reactiveAreaMode}.
     *
     * Defines the size of the reactive area of the link:
     * 	 - `ReactiveAreaMode.Inline` - The link is displayed as part of a sentence.
     * 	 - `ReactiveAreaMode.Overlay` - The link is displayed as an overlay on top of other interactive parts
     *     of the page.
     *
     * **Note:**It is designed to make links easier to activate and helps meet the WCAG 2.2 Target Size requirement.
     * It is applicable only for the SAP Horizon themes. **Note:**The Reactive area size is sufficiently large
     * to help users avoid accidentally selecting (clicking or tapping) on unintented UI elements. UI elements
     * positioned over other parts of the page may need an invisible active touch area. This will ensure that
     * no elements beneath are activated accidentally when the user tries to interact with the overlay element.
     *
     * Default value is `Inline`.
     *
     * @since 1.133.0
     *
     * @returns Value of property `reactiveAreaMode`
     */
    getReactiveAreaMode(): ReactiveAreaMode;
    /**
     * Gets current value of property {@link #getState state}.
     *
     * Determines the object number's value state. Setting this state will cause the number to be rendered in
     * state-specific colors.
     *
     * Default value is `None`.
     *
     *
     * @returns Value of property `state`
     */
    getState(): ValueState;
    /**
     * Gets current value of property {@link #getTextAlign textAlign}.
     *
     * Sets the horizontal alignment of the number and unit.
     *
     * Default value is `Begin`.
     *
     *
     * @returns Value of property `textAlign`
     */
    getTextAlign(): TextAlign;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * Available options for the number and unit text direction are LTR(left-to-right) and RTL(right-to-left).
     * By default, the control inherits the text direction from its parent control.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getUnit unit}.
     *
     * Defines the number units qualifier. If numberUnit and unit are both set, the unit value is used.
     *
     * @since 1.16.1
     *
     * @returns Value of property `unit`
     */
    getUnit(): string;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getActive active}.
     *
     * Indicates if the `ObjectNumber` text and icon can be clicked/tapped by the user.
     *
     * **Note:** If you set this property to `true`, you have to set also the `number` or `unit` property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.86
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setActive(
      /**
       * New value for property `active`
       */
      bActive?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEmphasized emphasized}.
     *
     * Indicates if the object number should appear emphasized.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEmphasized(
      /**
       * New value for property `emphasized`
       */
      bEmphasized?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEmptyIndicatorMode emptyIndicatorMode}.
     *
     * Specifies if an empty indicator should be displayed when there is no number.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Off`.
     *
     * @since 1.89
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEmptyIndicatorMode(
      /**
       * New value for property `emptyIndicatorMode`
       */
      sEmptyIndicatorMode?: EmptyIndicatorMode | keyof typeof EmptyIndicatorMode
    ): this;
    /**
     * Sets a new value for property {@link #getInverted inverted}.
     *
     * Determines whether the background color reflects the set `state` instead of the control's text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.86
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInverted(
      /**
       * New value for property `inverted`
       */
      bInverted?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getNumber number}.
     *
     * Defines the number field.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNumber(
      /**
       * New value for property `number`
       */
      sNumber?: string
    ): this;
    /**
     * Sets a new value for property {@link #getNumberUnit numberUnit}.
     *
     * Defines the number units qualifier.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @deprecated As of version 1.16.1. replaced by `unit` property
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNumberUnit(
      /**
       * New value for property `numberUnit`
       */
      sNumberUnit?: string
    ): this;
    /**
     * Sets a new value for property {@link #getReactiveAreaMode reactiveAreaMode}.
     *
     * Defines the size of the reactive area of the link:
     * 	 - `ReactiveAreaMode.Inline` - The link is displayed as part of a sentence.
     * 	 - `ReactiveAreaMode.Overlay` - The link is displayed as an overlay on top of other interactive parts
     *     of the page.
     *
     * **Note:**It is designed to make links easier to activate and helps meet the WCAG 2.2 Target Size requirement.
     * It is applicable only for the SAP Horizon themes. **Note:**The Reactive area size is sufficiently large
     * to help users avoid accidentally selecting (clicking or tapping) on unintented UI elements. UI elements
     * positioned over other parts of the page may need an invisible active touch area. This will ensure that
     * no elements beneath are activated accidentally when the user tries to interact with the overlay element.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inline`.
     *
     * @since 1.133.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setReactiveAreaMode(
      /**
       * New value for property `reactiveAreaMode`
       */
      sReactiveAreaMode?: ReactiveAreaMode | keyof typeof ReactiveAreaMode
    ): this;
    /**
     * Sets a new value for property {@link #getState state}.
     *
     * Determines the object number's value state. Setting this state will cause the number to be rendered in
     * state-specific colors.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setState(
      /**
       * New value for property `state`
       */
      sState?: ValueState | keyof typeof ValueState
    ): this;
    /**
     * Sets a new value for property {@link #getTextAlign textAlign}.
     *
     * Sets the horizontal alignment of the number and unit.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Begin`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextAlign(
      /**
       * New value for property `textAlign`
       */
      sTextAlign?: TextAlign | keyof typeof TextAlign
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * Available options for the number and unit text direction are LTR(left-to-right) and RTL(right-to-left).
     * By default, the control inherits the text direction from its parent control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getUnit unit}.
     *
     * Defines the number units qualifier. If numberUnit and unit are both set, the unit value is used.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.16.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUnit(
      /**
       * New value for property `unit`
       */
      sUnit?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ObjectNumber constructor.
   */
  export interface $ObjectNumberSettings extends $ControlSettings {
    /**
     * Defines the number field.
     */
    number?: string | PropertyBindingInfo;

    /**
     * Defines the number units qualifier.
     *
     * @deprecated As of version 1.16.1. replaced by `unit` property
     */
    numberUnit?: string | PropertyBindingInfo;

    /**
     * Indicates if the object number should appear emphasized.
     */
    emphasized?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the object number's value state. Setting this state will cause the number to be rendered in
     * state-specific colors.
     */
    state?:
      | (ValueState | keyof typeof ValueState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the number units qualifier. If numberUnit and unit are both set, the unit value is used.
     *
     * @since 1.16.1
     */
    unit?: string | PropertyBindingInfo;

    /**
     * Available options for the number and unit text direction are LTR(left-to-right) and RTL(right-to-left).
     * By default, the control inherits the text direction from its parent control.
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Sets the horizontal alignment of the number and unit.
     */
    textAlign?:
      | (TextAlign | keyof typeof TextAlign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Indicates if the `ObjectNumber` text and icon can be clicked/tapped by the user.
     *
     * **Note:** If you set this property to `true`, you have to set also the `number` or `unit` property.
     *
     * @since 1.86
     */
    active?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the size of the reactive area of the link:
     * 	 - `ReactiveAreaMode.Inline` - The link is displayed as part of a sentence.
     * 	 - `ReactiveAreaMode.Overlay` - The link is displayed as an overlay on top of other interactive parts
     *     of the page.
     *
     * **Note:**It is designed to make links easier to activate and helps meet the WCAG 2.2 Target Size requirement.
     * It is applicable only for the SAP Horizon themes. **Note:**The Reactive area size is sufficiently large
     * to help users avoid accidentally selecting (clicking or tapping) on unintented UI elements. UI elements
     * positioned over other parts of the page may need an invisible active touch area. This will ensure that
     * no elements beneath are activated accidentally when the user tries to interact with the overlay element.
     *
     * @since 1.133.0
     */
    reactiveAreaMode?:
      | (ReactiveAreaMode | keyof typeof ReactiveAreaMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines whether the background color reflects the set `state` instead of the control's text.
     *
     * @since 1.86
     */
    inverted?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies if an empty indicator should be displayed when there is no number.
     *
     * @since 1.89
     */
    emptyIndicatorMode?:
      | (EmptyIndicatorMode | keyof typeof EmptyIndicatorMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Association to controls / ids which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Fires when the user clicks/taps on active `Object Number`.
     *
     * @since 1.86
     */
    press?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the ObjectNumber#press event.
   */
  export interface ObjectNumber$PressEventParameters {}

  /**
   * Event object of the ObjectNumber#press event.
   */
  export type ObjectNumber$PressEvent = Event<
    ObjectNumber$PressEventParameters,
    ObjectNumber
  >;
}

declare module "sap/m/ObjectStatus" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IFormContent,
    ISemanticFormContent,
    ID,
    AccessibilityInfo,
    URI,
    TextDirection,
  } from "sap/ui/core/library";

  import Event from "sap/ui/base/Event";

  import { EmptyIndicatorMode, ReactiveAreaMode } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Status information that can be either text with a value state, or an icon.
   *
   * Wrapping and Truncation Behavior:
   *
   * The `ObjectStatus` usually is a short text. However, if the text is longer it wraps (word by word). Icon
   * and text can be separated. **Note:** It maybe handled differently depending on the individual control
   * use case. For example in `sap.ui.table.Table` the text of the control is truncated.
   *
   * With 1.63, large design of the control is supported by setting `sapMObjectStatusLarge` CSS class to the
   * `ObjectStatus`.
   *
   * With 1.110, Inner text wrapping could be enabled for longer texts without spaces (such as a serial number
   * that doesn't fit on one line) by adding `sapMObjectStatusLongText` CSS class to the `ObjectStatus`. This
   * class can be added by using оObjectStatus.addStyleClass("sapMObjectStatusLongText");
   *
   * With 1.130, bigger line height for texts that require it (like Thai) can be enabled by adding `sapUiHigherText`
   * CSS class to the `ObjectStatus`. This class can be added by using оObjectStatus.addStyleClass("sapUiHigherText");
   */
  export default class ObjectStatus
    extends Control
    implements IFormContent, ISemanticFormContent
  {
    __implements__sap_ui_core_IFormContent: boolean;
    __implements__sap_ui_core_ISemanticFormContent: boolean;
    /**
     * Constructor for a new ObjectStatus.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/object-display-elements/#-object-status Object Status}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ObjectStatusSettings
    );
    /**
     * Constructor for a new ObjectStatus.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/object-display-elements/#-object-status Object Status}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ObjectStatusSettings
    );

    /**
     * Creates a new subclass of class sap.m.ObjectStatus with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ObjectStatus>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ObjectStatus.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.ObjectStatus`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ObjectStatus` itself.
     *
     * Fires when the user clicks/taps on active text.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ObjectStatus` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.ObjectStatus`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ObjectStatus` itself.
     *
     * Fires when the user clicks/taps on active text.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ObjectStatus` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.ObjectStatus`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @since 1.54
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Current accessibility state of the control
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Gets current value of property {@link #getActive active}.
     *
     * Indicates if the `ObjectStatus` text and icon can be clicked/tapped by the user.
     *
     * **Note:** If you set this property to `true`, you have to also set the `text` or `icon` property.
     *
     * Default value is `false`.
     *
     * @since 1.54
     *
     * @returns Value of property `active`
     */
    getActive(): boolean;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getEmptyIndicatorMode emptyIndicatorMode}.
     *
     * Specifies if an empty indicator should be displayed when there is no text.
     *
     * Default value is `Off`.
     *
     * @since 1.89
     *
     * @returns Value of property `emptyIndicatorMode`
     */
    getEmptyIndicatorMode(): EmptyIndicatorMode;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Icon URI. This may be either an icon font or image path.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getIconDensityAware iconDensityAware}.
     *
     * By default, this is set to true but then one or more requests are sent trying to get the density perfect
     * version of image if this version of image doesn't exist on the server.
     *
     * If bandwidth is key for the application, set this value to false.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `iconDensityAware`
     */
    getIconDensityAware(): boolean;
    /**
     * Gets current value of property {@link #getInverted inverted}.
     *
     * Determines whether the background color reflects the set `state` instead of the control's text.
     *
     * Default value is `false`.
     *
     * @since 1.66
     *
     * @returns Value of property `inverted`
     */
    getInverted(): boolean;
    /**
     * Gets current value of property {@link #getReactiveAreaMode reactiveAreaMode}.
     *
     * Defines the size of the reactive area of the link:
     * 	 - `ReactiveAreaMode.Inline` - The link is displayed as part of a sentence.
     * 	 - `ReactiveAreaMode.Overlay` - The link is displayed as an overlay on top of other interactive parts
     *     of the page.
     *
     * **Note:**It is designed to make links easier to activate and helps meet the WCAG 2.2 Target Size requirement.
     * It is applicable only for the SAP Horizon themes. **Note:**The Reactive area size is sufficiently large
     * to help users avoid accidentally selecting (clicking or tapping) on unintented UI elements. UI elements
     * positioned over other parts of the page may need an invisible active touch area. This will ensure that
     * no elements beneath are activated accidentally when the user tries to interact with the overlay element.
     *
     * Default value is `Inline`.
     *
     * @since 1.133.0
     *
     * @returns Value of property `reactiveAreaMode`
     */
    getReactiveAreaMode(): ReactiveAreaMode;
    /**
     * Gets current value of property {@link #getState state}.
     *
     * Defines the text value state. The allowed values are from the enum type `sap.ui.core.ValueState`. Since
     * version 1.66 the `state` property also accepts values from enum type `sap.ui.core.IndicationColor`.
     *
     * Default value is `ValueState.None`.
     *
     *
     * @returns Value of property `state`
     */
    getState(): string;
    /**
     * Gets current value of property {@link #getStateAnnouncementText stateAnnouncementText}.
     *
     * Еnables overriding of the default state announcement.
     *
     * @since 1.110
     *
     * @returns Value of property `stateAnnouncementText`
     */
    getStateAnnouncementText(): string;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Defines the ObjectStatus text.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * Determines the direction of the text, not including the title. Available options for the text direction
     * are LTR (left-to-right) and RTL (right-to-left). By default the control inherits the text direction from
     * its parent control.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Defines the ObjectStatus title.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getActive active}.
     *
     * Indicates if the `ObjectStatus` text and icon can be clicked/tapped by the user.
     *
     * **Note:** If you set this property to `true`, you have to also set the `text` or `icon` property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setActive(
      /**
       * New value for property `active`
       */
      bActive?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEmptyIndicatorMode emptyIndicatorMode}.
     *
     * Specifies if an empty indicator should be displayed when there is no text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Off`.
     *
     * @since 1.89
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEmptyIndicatorMode(
      /**
       * New value for property `emptyIndicatorMode`
       */
      sEmptyIndicatorMode?: EmptyIndicatorMode | keyof typeof EmptyIndicatorMode
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Icon URI. This may be either an icon font or image path.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getIconDensityAware iconDensityAware}.
     *
     * By default, this is set to true but then one or more requests are sent trying to get the density perfect
     * version of image if this version of image doesn't exist on the server.
     *
     * If bandwidth is key for the application, set this value to false.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconDensityAware(
      /**
       * New value for property `iconDensityAware`
       */
      bIconDensityAware?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getInverted inverted}.
     *
     * Determines whether the background color reflects the set `state` instead of the control's text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.66
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInverted(
      /**
       * New value for property `inverted`
       */
      bInverted?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getReactiveAreaMode reactiveAreaMode}.
     *
     * Defines the size of the reactive area of the link:
     * 	 - `ReactiveAreaMode.Inline` - The link is displayed as part of a sentence.
     * 	 - `ReactiveAreaMode.Overlay` - The link is displayed as an overlay on top of other interactive parts
     *     of the page.
     *
     * **Note:**It is designed to make links easier to activate and helps meet the WCAG 2.2 Target Size requirement.
     * It is applicable only for the SAP Horizon themes. **Note:**The Reactive area size is sufficiently large
     * to help users avoid accidentally selecting (clicking or tapping) on unintented UI elements. UI elements
     * positioned over other parts of the page may need an invisible active touch area. This will ensure that
     * no elements beneath are activated accidentally when the user tries to interact with the overlay element.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inline`.
     *
     * @since 1.133.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setReactiveAreaMode(
      /**
       * New value for property `reactiveAreaMode`
       */
      sReactiveAreaMode?: ReactiveAreaMode | keyof typeof ReactiveAreaMode
    ): this;
    /**
     * Sets value for the `state` property. The default value is `ValueState.None`.
     *
     *
     * @returns this to allow method chaining
     */
    setState(
      /**
       * New value for property state. It should be valid value of enumeration `sap.ui.core.ValueState` or `sap.ui.core.IndicationColor`
       */
      sValue: string
    ): this;
    /**
     * Sets a new value for property {@link #getStateAnnouncementText stateAnnouncementText}.
     *
     * Еnables overriding of the default state announcement.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.110
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setStateAnnouncementText(
      /**
       * New value for property `stateAnnouncementText`
       */
      sStateAnnouncementText: string
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Defines the ObjectStatus text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * Determines the direction of the text, not including the title. Available options for the text direction
     * are LTR (left-to-right) and RTL (right-to-left). By default the control inherits the text direction from
     * its parent control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Defines the ObjectStatus title.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ObjectStatus constructor.
   */
  export interface $ObjectStatusSettings extends $ControlSettings {
    /**
     * Defines the ObjectStatus title.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Defines the ObjectStatus text.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Indicates if the `ObjectStatus` text and icon can be clicked/tapped by the user.
     *
     * **Note:** If you set this property to `true`, you have to also set the `text` or `icon` property.
     *
     * @since 1.54
     */
    active?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the size of the reactive area of the link:
     * 	 - `ReactiveAreaMode.Inline` - The link is displayed as part of a sentence.
     * 	 - `ReactiveAreaMode.Overlay` - The link is displayed as an overlay on top of other interactive parts
     *     of the page.
     *
     * **Note:**It is designed to make links easier to activate and helps meet the WCAG 2.2 Target Size requirement.
     * It is applicable only for the SAP Horizon themes. **Note:**The Reactive area size is sufficiently large
     * to help users avoid accidentally selecting (clicking or tapping) on unintented UI elements. UI elements
     * positioned over other parts of the page may need an invisible active touch area. This will ensure that
     * no elements beneath are activated accidentally when the user tries to interact with the overlay element.
     *
     * @since 1.133.0
     */
    reactiveAreaMode?:
      | (ReactiveAreaMode | keyof typeof ReactiveAreaMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the text value state. The allowed values are from the enum type `sap.ui.core.ValueState`. Since
     * version 1.66 the `state` property also accepts values from enum type `sap.ui.core.IndicationColor`.
     */
    state?: string | PropertyBindingInfo;

    /**
     * Determines whether the background color reflects the set `state` instead of the control's text.
     *
     * @since 1.66
     */
    inverted?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Icon URI. This may be either an icon font or image path.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * By default, this is set to true but then one or more requests are sent trying to get the density perfect
     * version of image if this version of image doesn't exist on the server.
     *
     * If bandwidth is key for the application, set this value to false.
     */
    iconDensityAware?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the direction of the text, not including the title. Available options for the text direction
     * are LTR (left-to-right) and RTL (right-to-left). By default the control inherits the text direction from
     * its parent control.
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies if an empty indicator should be displayed when there is no text.
     *
     * @since 1.89
     */
    emptyIndicatorMode?:
      | (EmptyIndicatorMode | keyof typeof EmptyIndicatorMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Еnables overriding of the default state announcement.
     *
     * @since 1.110
     */
    stateAnnouncementText?: string | PropertyBindingInfo;

    /**
     * Association to controls / IDs, which describe this control (see WAI-ARIA attribute aria-describedby).
     *
     * **Note:** The additional description will take effect only if `active` property is set to `true`.
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledby).
     *
     * **Note:** The additional labelling text will take effect only if `active` property is set to `true`.
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Fires when the user clicks/taps on active text.
     *
     * @since 1.54
     */
    press?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the ObjectStatus#press event.
   */
  export interface ObjectStatus$PressEventParameters {}

  /**
   * Event object of the ObjectStatus#press event.
   */
  export type ObjectStatus$PressEvent = Event<
    ObjectStatus$PressEventParameters,
    ObjectStatus
  >;
}

declare module "sap/m/OverflowToolbar" {
  import { default as Toolbar, $ToolbarSettings } from "sap/m/Toolbar";

  import { Toolbar as Toolbar1 } from "sap/ui/core/library";

  import { IBar } from "sap/m/library";

  import Control from "sap/ui/core/Control";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * A container control based on {@link sap.m.Toolbar}, that provides overflow when its content does not
   * fit in the visible area.
   *
   * Overview:
   *
   * The content of the `OverflowToolbar` moves into the overflow area from right to left when the available
   * space is not enough in the visible area of the container. It can be accessed by the user through the
   * overflow button that opens it in a popover.
   *
   * **Note:** It is recommended that you use `OverflowToolbar` over {@link sap.m.Toolbar}, unless you want
   * to avoid overflow in favor of shrinking.
   *
   * Usage:
   *
   * Different behavior and priorities can be set for each control inside the `OverflowToolbar`, such as certain
   * controls to appear only in the overflow area or to never move there. For more information, see {@link sap.m.OverflowToolbarLayoutData }
   * and {@link sap.m.OverflowToolbarPriority}.
   *
   * Overflow Behavior: By default, only the following controls can move to the overflow area:
   *
   *
   * 	 - {@link sap.m.Breadcrumbs}
   * 	 - {@link sap.m.Button}
   * 	 - {@link sap.m.CheckBox}
   * 	 - {@link sap.m.ComboBox}
   * 	 - {@link sap.m.DatePicker}
   * 	 - {@link sap.m.DateRangeSelection}
   * 	 - {@link sap.m.DateTimePicker}
   * 	 - {@link sap.m.GenericTag}
   * 	 - {@link sap.m.Input}
   * 	 - {@link sap.m.Label}
   * 	 - {@link sap.m.MenuButton}
   * 	 - {@link sap.m.OverflowToolbarButton}
   * 	 - {@link sap.m.OverflowToolbarToggleButton}
   * 	 - {@link sap.m.SearchField}
   * 	 - {@link sap.m.SegmentedButton}
   * 	 - {@link sap.m.Select}
   * 	 - {@link sap.m.TimePicker}
   * 	 - {@link sap.m.ToggleButton}
   * 	 - {@link sap.m.ToolbarSeparator}
   * 	 - {@link sap.ui.comp.smartfield.SmartField}
   * 	 - {@link sap.ui.comp.smartfield.SmartLabel}
   *
   * Additionally, any control that implements the {@link sap.m.IOverflowToolbarContent} interface may define
   * its behavior (most importantly overflow behavior) when placed inside `OverflowToolbar`.
   *
   * **Note:** The `OverflowToolbar` is an adaptive container that checks the available width and hides the
   * part of its content that doesn't fit. It is intended that simple controls, such as {@link sap.m.Button }
   * and {@link sap.m.Label} are used as content. Embedding other adaptive container controls (with the exception
   * of {@link sap.m.Breadcrumbs}), results in competition for the available space - both controls calculate
   * the available space based on the other one's size and both change their width at the same time, leading
   * to incorrectly distributed space.
   *
   * Responsive behavior:
   *
   * The height of the toolbar changes on desktop, tablet, and smartphones.
   *
   * @since 1.28
   */
  export default class OverflowToolbar
    extends Toolbar
    implements Toolbar1, IBar
  {
    __implements__sap_ui_core_Toolbar: boolean;
    __implements__sap_m_IBar: boolean;
    /**
     * Constructor for a new `OverflowToolbar`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/toolbar-overview/#overflow-generic Overflow Toolbar}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $OverflowToolbarSettings
    );
    /**
     * Constructor for a new `OverflowToolbar`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/toolbar-overview/#overflow-generic Overflow Toolbar}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $OverflowToolbarSettings
    );

    /**
     * Creates a new subclass of class sap.m.OverflowToolbar with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.Toolbar.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, OverflowToolbar>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.OverflowToolbar.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Moves each control in the suitable collection - Popover only, movable controls and toolbar only
     */
    _moveControlInSuitableCollection(
      oControl: undefined,

      sPriority: undefined
    ): void;
    /**
     * Removes Control from collections
     */
    _removeContentFromControlsCollections(oControl: undefined): void;
    /**
     * Closes the overflow area. Useful to manually close the overflow after having suppressed automatic closing
     * with "closeOverflowOnInteraction=false".
     *
     * @since 1.40
     */
    closeOverflow(): void;
    /**
     * This method is a hook for the RenderManager that gets called during the rendering of child Controls.
     * It allows to add, remove and update existing accessibility attributes (ARIA) of those controls.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    enhanceAccessibilityState(
      /**
       * The Control that gets rendered by the RenderManager
       */
      oElement: Control,
      /**
       * The mapping of "aria-" prefixed attributes
       */
      mAriaProps: object
    ): void;
    /**
     * Gets current value of property {@link #getAsyncMode asyncMode}.
     *
     * Defines whether the `OverflowToolbar` works in async mode.
     *
     * **Note:** When this property is set to `true`, the `OverflowToolbar` makes its layout recalculations
     * asynchronously. This way it is not blocking the thread immediately after re-rendering or resizing. However,
     * it may lead to flickering, when there is a change in the width of the content of the `OverflowToolbar`.
     *
     * Default value is `false`.
     *
     * @since 1.67
     *
     * @returns Value of property `asyncMode`
     */
    getAsyncMode(): boolean;
    /**
     * Sets the `asyncMode` property.
     *
     * @since 1.67
     *
     * @returns `this` pointer for chaining
     */
    setAsyncMode(bValue: boolean): this;
  }
  /**
   * Describes the settings that can be provided to the OverflowToolbar constructor.
   */
  export interface $OverflowToolbarSettings extends $ToolbarSettings {
    /**
     * Defines whether the `OverflowToolbar` works in async mode.
     *
     * **Note:** When this property is set to `true`, the `OverflowToolbar` makes its layout recalculations
     * asynchronously. This way it is not blocking the thread immediately after re-rendering or resizing. However,
     * it may lead to flickering, when there is a change in the width of the content of the `OverflowToolbar`.
     *
     * @since 1.67
     */
    asyncMode?: boolean | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/OverflowToolbarButton" {
  import { default as Button, $ButtonSettings } from "sap/m/Button";

  import { IShellBar } from "sap/f/library";

  import {
    IOverflowToolbarContent,
    IToolbarInteractiveControl,
  } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * Represents an {@link sap.m.Button} that shows its text only when in the overflow area of an {@link sap.m.OverflowToolbar}.
   *
   * **Note:** This control is intended to be used exclusively in the context of the `OverflowToolbar`, whenever
   * it is required to have buttons that show only an icon in the toolbar, but icon and text in the overflow
   * menu.
   *
   * @since 1.28
   */
  export default class OverflowToolbarButton
    extends Button
    implements IShellBar, IOverflowToolbarContent, IToolbarInteractiveControl
  {
    __implements__sap_f_IShellBar: boolean;
    __implements__sap_m_IOverflowToolbarContent: boolean;
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new `OverflowToolbarButton`.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $OverflowToolbarButtonSettings
    );
    /**
     * Constructor for a new `OverflowToolbarButton`.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $OverflowToolbarButtonSettings
    );

    /**
     * Creates a new subclass of class sap.m.OverflowToolbarButton with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.Button.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, OverflowToolbarButton>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.OverflowToolbarButton.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the OverflowToolbarButton constructor.
   */
  export interface $OverflowToolbarButtonSettings extends $ButtonSettings {}
}

declare module "sap/m/OverflowToolbarLayoutData" {
  import {
    default as ToolbarLayoutData,
    $ToolbarLayoutDataSettings,
  } from "sap/m/ToolbarLayoutData";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { OverflowToolbarPriority } from "sap/m/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Holds layout data for the {@link sap.m.OverflowToolbar} items.
   *
   * @since 1.28
   */
  export default class OverflowToolbarLayoutData extends ToolbarLayoutData {
    /**
     * Constructor for a new `OverflowToolbarLayoutData`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $OverflowToolbarLayoutDataSettings
    );
    /**
     * Constructor for a new `OverflowToolbarLayoutData`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new element, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $OverflowToolbarLayoutDataSettings
    );

    /**
     * Creates a new subclass of class sap.m.OverflowToolbarLayoutData with name `sClassName` and enriches it
     * with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ToolbarLayoutData.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, OverflowToolbarLayoutData>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.OverflowToolbarLayoutData.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getCloseOverflowOnInteraction closeOverflowOnInteraction}.
     *
     * Defines whether the overflow area is automatically closed when interacting with a control in it
     *
     * Default value is `true`.
     *
     * @since 1.40
     *
     * @returns Value of property `closeOverflowOnInteraction`
     */
    getCloseOverflowOnInteraction(): boolean;
    /**
     * Gets current value of property {@link #getGroup group}.
     *
     * Defines OverflowToolbar items group number. Default value is 0, which means that the control does not
     * belong to any group. Elements that belong to a group overflow together. The overall priority of the group
     * is defined by the element with highest priority. Elements that belong to a group are not allowed to have
     * AlwaysOverflow or NeverOverflow priority.
     *
     * Default value is `0`.
     *
     * @since 1.32
     *
     * @returns Value of property `group`
     */
    getGroup(): int;
    /**
     * Gets current value of property {@link #getMoveToOverflow moveToOverflow}.
     *
     * The OverflowToolbar item can or cannot move to the overflow area
     *
     * Default value is `true`.
     *
     * @deprecated As of version 1.32. Use {@link sap.m.OverflowToolbarPriority} instead.
     *
     * @returns Value of property `moveToOverflow`
     */
    getMoveToOverflow(): boolean;
    /**
     * Gets current value of property {@link #getPriority priority}.
     *
     * Defines OverflowToolbar items priority. Available priorities are NeverOverflow, High, Low, Disappear
     * and AlwaysOverflow.
     *
     * Default value is `High`.
     *
     * @since 1.32
     *
     * @returns Value of property `priority`
     */
    getPriority(): OverflowToolbarPriority;
    /**
     * Gets current value of property {@link #getStayInOverflow stayInOverflow}.
     *
     * The OverflowToolbar item can or cannot stay in the overflow area
     *
     * Default value is `false`.
     *
     * @deprecated As of version 1.32. Use {@link sap.m.OverflowToolbarPriority} instead.
     *
     * @returns Value of property `stayInOverflow`
     */
    getStayInOverflow(): boolean;
    /**
     * Sets a new value for property {@link #getCloseOverflowOnInteraction closeOverflowOnInteraction}.
     *
     * Defines whether the overflow area is automatically closed when interacting with a control in it
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.40
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCloseOverflowOnInteraction(
      /**
       * New value for property `closeOverflowOnInteraction`
       */
      bCloseOverflowOnInteraction?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getGroup group}.
     *
     * Defines OverflowToolbar items group number. Default value is 0, which means that the control does not
     * belong to any group. Elements that belong to a group overflow together. The overall priority of the group
     * is defined by the element with highest priority. Elements that belong to a group are not allowed to have
     * AlwaysOverflow or NeverOverflow priority.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     * @since 1.32
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGroup(
      /**
       * New value for property `group`
       */
      iGroup?: int
    ): this;
    /**
     * Sets a new value for property {@link #getMoveToOverflow moveToOverflow}.
     *
     * The OverflowToolbar item can or cannot move to the overflow area
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @deprecated As of version 1.32. Use {@link sap.m.OverflowToolbarPriority} instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMoveToOverflow(
      /**
       * New value for property `moveToOverflow`
       */
      bMoveToOverflow?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getPriority priority}.
     *
     * Defines OverflowToolbar items priority. Available priorities are NeverOverflow, High, Low, Disappear
     * and AlwaysOverflow.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `High`.
     *
     * @since 1.32
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPriority(
      /**
       * New value for property `priority`
       */
      sPriority?: OverflowToolbarPriority | keyof typeof OverflowToolbarPriority
    ): this;
    /**
     * Sets a new value for property {@link #getStayInOverflow stayInOverflow}.
     *
     * The OverflowToolbar item can or cannot stay in the overflow area
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @deprecated As of version 1.32. Use {@link sap.m.OverflowToolbarPriority} instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setStayInOverflow(
      /**
       * New value for property `stayInOverflow`
       */
      bStayInOverflow?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the OverflowToolbarLayoutData constructor.
   */
  export interface $OverflowToolbarLayoutDataSettings
    extends $ToolbarLayoutDataSettings {
    /**
     * The OverflowToolbar item can or cannot move to the overflow area
     *
     * @deprecated As of version 1.32. Use {@link sap.m.OverflowToolbarPriority} instead.
     */
    moveToOverflow?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The OverflowToolbar item can or cannot stay in the overflow area
     *
     * @deprecated As of version 1.32. Use {@link sap.m.OverflowToolbarPriority} instead.
     */
    stayInOverflow?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines OverflowToolbar items priority. Available priorities are NeverOverflow, High, Low, Disappear
     * and AlwaysOverflow.
     *
     * @since 1.32
     */
    priority?:
      | (OverflowToolbarPriority | keyof typeof OverflowToolbarPriority)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines OverflowToolbar items group number. Default value is 0, which means that the control does not
     * belong to any group. Elements that belong to a group overflow together. The overall priority of the group
     * is defined by the element with highest priority. Elements that belong to a group are not allowed to have
     * AlwaysOverflow or NeverOverflow priority.
     *
     * @since 1.32
     */
    group?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether the overflow area is automatically closed when interacting with a control in it
     *
     * @since 1.40
     */
    closeOverflowOnInteraction?: boolean | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/OverflowToolbarMenuButton" {
  import { default as MenuButton, $MenuButtonSettings } from "sap/m/MenuButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * Represents an {@link sap.m.MenuButton} that shows its text only when in the overflow area of an {@link sap.m.OverflowToolbar}.
   *
   * **Note:** This control is intended to be used exclusively in the context of the `OverflowToolbar`, whenever
   * it is required to have buttons that show only an icon in the toolbar, but icon and text in the overflow
   * menu.
   *
   * @since 1.109.0
   */
  export default class OverflowToolbarMenuButton extends MenuButton {
    /**
     * Constructor for a new `OverflowToolbarMenuButton`.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $OverflowToolbarMenuButtonSettings
    );
    /**
     * Constructor for a new `OverflowToolbarMenuButton`.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $OverflowToolbarMenuButtonSettings
    );

    /**
     * Creates a new subclass of class sap.m.OverflowToolbarMenuButton with name `sClassName` and enriches it
     * with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.MenuButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, OverflowToolbarMenuButton>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.OverflowToolbarMenuButton.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the OverflowToolbarMenuButton constructor.
   */
  export interface $OverflowToolbarMenuButtonSettings
    extends $MenuButtonSettings {}
}

declare module "sap/m/OverflowToolbarToggleButton" {
  import {
    default as ToggleButton,
    $ToggleButtonSettings,
  } from "sap/m/ToggleButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * Represents an {@link sap.m.ToggleButton} that shows its text only when in the overflow area of an {@link sap.m.OverflowToolbar}.
   *
   * **Note:** This control is intended to be used exclusively in the context of the `OverflowToolbar`, whenever
   * it is required to have buttons that show only an icon in the toolbar, but icon and text in the overflow
   * menu.
   *
   * @since 1.52
   */
  export default class OverflowToolbarToggleButton extends ToggleButton {
    /**
     * Constructor for a new `OverflowToolbarToggleButton`.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $OverflowToolbarToggleButtonSettings
    );
    /**
     * Constructor for a new `OverflowToolbarToggleButton`.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $OverflowToolbarToggleButtonSettings
    );

    /**
     * Creates a new subclass of class sap.m.OverflowToolbarToggleButton with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ToggleButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, OverflowToolbarToggleButton>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.OverflowToolbarToggleButton.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the OverflowToolbarToggleButton constructor.
   */
  export interface $OverflowToolbarToggleButtonSettings
    extends $ToggleButtonSettings {}
}

declare module "sap/m/p13n/BasePanel" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { p13n } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import MessageStrip from "sap/m/MessageStrip";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * This control serves as base class for personalization implementations. This faceless class serves as
   * a way to implement control-specific personalization panels.
   *
   * @since 1.96
   */
  export default abstract class BasePanel
    extends Control
    implements p13n.IContent
  {
    __implements__sap_m_p13n_IContent: boolean;
    /**
     * Constructor for a new `BasePanel`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $BasePanelSettings
    );
    /**
     * Constructor for a new `BasePanel`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $BasePanelSettings
    );

    /**
     * Creates a new subclass of class sap.m.p13n.BasePanel with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, BasePanel>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.p13n.BasePanel.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.p13n.BasePanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.p13n.BasePanel` itself.
     *
     * This event is fired if any change has been made within the `BasePanel` control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: BasePanel$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.p13n.BasePanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.p13n.BasePanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.p13n.BasePanel` itself.
     *
     * This event is fired if any change has been made within the `BasePanel` control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: BasePanel$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.p13n.BasePanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys the messageStrip in the aggregation {@link #getMessageStrip messageStrip}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyMessageStrip(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:change change} event of this `sap.m.p13n.BasePanel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: BasePanel$ChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:change change} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: BasePanel$ChangeEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getEnableReorder enableReorder}.
     *
     * Determines whether the reordering of personalization items is enabled.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enableReorder`
     */
    getEnableReorder(): boolean;
    /**
     * Gets the corresponding `sap.m.p13n.Item` for the provided key.
     *
     *
     * @returns The personalization model item
     */
    getItemByKey(
      /**
       * The unique identifier
       */
      sName: string
    ): Item | null;
    /**
     * Getter for the `messageStrip` aggregation.
     *
     *
     * @returns The BasePanel instance
     */
    getMessageStrip(): BasePanel;
    /**
     * Returns the personalization state that is currently displayed by the `BasePanel`.
     *
     *
     * @returns An array containing the personalization state that is currently displayed by the `BasePanel`
     */
    getP13nData(
      /**
       * Determines whether only the present items is included
       */
      bOnlyActive: boolean
    ): Item[];
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * A short text describing the panel. **Note:** This text will only be displayed if the panel is being used
     * in a `sap.m.p13n.Popup`.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * The `enableReorder` property determines whether additional move buttons are shown when hovering over
     * the inner list. In addition, drag and drop will be enabled for the inner list control.
     *
     *
     * @returns The BasePanel instance
     */
    setEnableReorder(
      /**
       * Determines whether reordering is enabled
       */
      bEnableReorder: boolean
    ): BasePanel;
    /**
     * Displays a `sap.m.MessageStrip` instance in the content area of the `BasePanel`.
     *
     *
     * @returns The `BasePanel` instance
     */
    setMessageStrip(
      /**
       * Instance of a sap.m.MessageStrip
       */
      oStrip: MessageStrip
    ): BasePanel;
    /**
     * Sets the personalization state of the panel instance.
     *
     *
     * @returns The BasePanel instance
     */
    setP13nData(
      /**
       * An array containing the personalization state that is represented by the `BasePanel`.
       */
      aP13nData: Item[]
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * A short text describing the panel. **Note:** This text will only be displayed if the panel is being used
     * in a `sap.m.p13n.Popup`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle: string
    ): this;
  }
  /**
   * P13n `Item` object type.
   */
  export type Item = {
    /**
     * The unique key of the item
     */
    name: string;
    /**
     * The label describing the personalization item
     */
    label: string;
    /**
     * Defines the selection state of the personalization item
     */
    visible: boolean;
  };

  /**
   * Describes the settings that can be provided to the BasePanel constructor.
   */
  export interface $BasePanelSettings extends $ControlSettings {
    /**
     * A short text describing the panel. **Note:** This text will only be displayed if the panel is being used
     * in a `sap.m.p13n.Popup`.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Determines whether the reordering of personalization items is enabled.
     */
    enableReorder?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines an optional message strip to be displayed in the content area.
     */
    messageStrip?: MessageStrip;

    /**
     * This event is fired if any change has been made within the `BasePanel` control.
     */
    change?: (oEvent: BasePanel$ChangeEvent) => void;
  }

  /**
   * Parameters of the BasePanel#change event.
   */
  export interface BasePanel$ChangeEventParameters {
    /**
     * The reason why the panel state has changed, for example, items have been added, removed, or moved.
     */
    reason?: string;

    /**
     * An object containing information about the specific item that has been changed.
     */
    item?: Item;
  }

  /**
   * Event object of the BasePanel#change event.
   */
  export type BasePanel$ChangeEvent = Event<
    BasePanel$ChangeEventParameters,
    BasePanel
  >;
}

declare module "sap/m/p13n/Engine" {
  import Control from "sap/ui/core/Control";

  import Event from "sap/ui/base/Event";

  import Metadata from "sap/ui/base/Metadata";

  import Popup from "sap/m/p13n/Popup";

  import MetadataHelper from "sap/m/p13n/MetadataHelper";

  import SelectionController from "sap/m/p13n/SelectionController";

  /**
   * The `Engine` entity offers personalization capabilities by registering a control instance for modification,
   * such as:
   *
   *
   * 	 - `sap.m.p13n.Popup` initialization
   * 	 - Storing personalization states by choosing the desired persistence layer
   * 	 - State appliance considering the persistence layer
   *
   * The Engine must be used whenever personalization should be enabled by taking a certain persistence layer
   * into account. Available controller implementations for the registration process are:
   *
   *
   * 	 - {@link sap.m.p13n.SelectionController SelectionController}: Used to define a list of selectable entries
   *
   * 	 - {@link sap.m.p13n.SortController SortController}: Used to define a list of sortable properties
   * 	 - {@link sap.m.p13n.GroupController GroupController}: Used to define a list of groupable properties
   *
   *
   * Can be used in combination with `sap.ui.fl.variants.VariantManagement` to persist a state in variants
   * using `sap.ui.fl` capabilities.
   *
   * @since 1.104
   */
  export default class Engine
    extends /* was: sap.m.p13n.modules.AdaptationProvider */ Object
  {
    /**
     * See:
     * 	{@link https://ui5.sap.com/#/topic/75c08fdebf784575947927e052712bab Personalization}
     */
    constructor();

    /**
     * Creates a new subclass of class sap.m.p13n.Engine with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.p13n.modules.AdaptationProvider.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Engine>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * This method is the central point of access to the Engine Singleton.
     *
     *
     * @returns The Engine instance
     */
    static getInstance(): Engine;
    /**
     * Returns a metadata object for class sap.m.p13n.Engine.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): Metadata;
    /**
     * Applies a state to a control by passing an object that contains the registered controller key and an
     * object matching the inner subcontroller logic.
     *
     *
     * @returns A Promise resolving after the state has been applied
     */
    applyState(
      /**
       * The registered control instance
       */
      oControl: Control,
      /**
       * The state object
       */
      oState: State
    ): Promise<State>;
    /**
     * Attaches an event handler to the `StateHandlerRegistry` class. The event handler is fired every time
     * a user triggers a personalization change for a control instance during runtime.
     *
     *
     * @returns Returns `this` to allow method chaining
     */
    attachStateChange(
      /**
       * The handler function to call when the event occurs
       */
      fnStateEventHandler: (p1: Event) => void
    ): this;
    /**
     * Unregisters a registered control. By unregistering a control the control is removed from the `Engine`
     * registry, and all instance-specific submodules, such as the registered controllers, are destroyed.
     */
    deregister(
      /**
       * The registered control instance
       */
      oControl: Control
    ): void;
    /**
     * Removes a previously attached state change event handler from the `StateHandlerRegistry` class. The passed
     * parameters must match those used for registration with {@link sap.m.p13n.Engine#attachStateChange} beforehand.
     *
     *
     * @returns Returns `this` to allow method chaining
     */
    detachStateChange(
      /**
       * The handler function to detach from the event
       */
      fnStateEventHandler: (p1: Event) => void
    ): this;

    register(
      /**
       * The control instance to be registered for adaptation
       */
      oControl: Control,
      /**
       * The Engine registration configuration
       */
      oConfig: EngineRegistrationConfig
    ): void;
    /**
     * This method can be used to trigger a reset to the provided control instance.
     *
     *
     * @returns A Promise resolving once the reset is completed
     */
    reset(
      /**
       * The related control instance
       */
      oControl: Control,
      /**
       * The key for the affected configuration
       */
      aKeys: string
    ): Promise<null>;
    /**
     * Retrieves the state for a given control instance after all necessary changes have been applied (e.g.
     * modification handler appliance). After the returned `Promise` has been resolved, the returned state is
     * in sync with the related state object of the control.
     *
     *
     * @returns A Promise resolving in the current control state
     */
    retrieveState(
      /**
       * The control instance implementing IxState to retrieve the externalized state
       */
      oControl: Control
    ): Promise<State>;
    /**
     * Opens the personalization dialog.
     *
     *
     * @returns Promise resolving in the `sap.m.p13n.Popup` instance
     */
    show(
      /**
       * The control instance that is personalized
       */
      oControl: Control,
      /**
       * The affected panels that are added to the `sap.m.p13n.Popup`
       */
      vPanelKeys: string | string[],
      /**
       * The settings object for the personalization
       */
      mSettings: {
        /**
         * The title for the `sap.m.p13n.Popup` control
         */
        title?: string;
        /**
         * The source control to be used by the `sap.m.p13n.Popup` control (only necessary if the mode is set to
         * `ResponsivePopover`)
         */
        source?: Control;
        /**
         * The mode is used by the `sap.m.p13n.Popup` control
         */
        mode?: object;
        /**
         * Height configuration for the related popup container
         */
        contentHeight?: object;
        /**
         * Width configuration for the related popup container
         */
        contentWidth?: object;
      }
    ): Promise<Popup>;
  }
  /**
   * The central registration for personalization functionality. The registration is a precondition for using
   * `Engine` functionality for a control instance. Once the control instance has been registered, it can
   * be passed to the related `Engine` methods that always expect a control instance as parameter. Only registered
   * control instances can be used for personalization through the `Engine`.
   */
  export type EngineRegistrationConfig = {
    /**
     * The `{@link sap.m.p13n.MetadataHelper MetadataHelper}` to provide metadata-specific information. It may
     * be used to define more granular information for the selection of items.
     */
    helper: MetadataHelper;
    /**
     * A map of arbitrary keys that contain a controller instance as value. The key must be unique and needs
     * to be provided for later access when using `Engine` functionality specific for one controller type.
     */
    controller: Record<string, SelectionController>;
  };

  export type State = {
    /**
     * A map of arbitrary keys that contain a controller instance as value. The key must be unique and needs
     * to be provided for later access when using `Engine` functionality specific for one controller type.
     */
    controller: Record<string, Object[]>;
  };
}

declare module "sap/m/p13n/FilterController" {
  import SelectionController from "sap/m/p13n/SelectionController";

  import Control from "sap/ui/core/Control";

  import Metadata from "sap/ui/base/Metadata";

  import FilterOperator from "sap/ui/model/FilterOperator";

  /**
   * The `FilterController` entity serves as a base class to create personalization implementations that are
   * specific to filtering.
   *
   * @since 1.121
   */
  export default class FilterController extends SelectionController {
    /**
     * Constructor for a new `FilterController`.
     */
    constructor(
      /**
       * Initial settings for the new controller
       */
      mSettings: {
        /**
         * The control instance that is personalized by this controller
         */
        control: Control;
        /**
         * A factory function that will be called whenever the user selects a new entry from the `ComboBox`. The
         * factory must return a single control instance of an input based control to provide custom filter capabilities.
         * This control is then going to be added in the layout provided by the `FilterPanel`. **Note:**: The Panel
         * will not handle the lifecylce of the provided factory control instance, in case the row is going to be
         * removed, the according consumer needs to decide about destroying or keeping the control instance. In
         * addition, the `getIdForLabel` method can be used to return a focusable children control to provide the
         * `labelFor` reference.
         */
        itemFactory?: Function;
      }
    );

    /**
     * Creates a new subclass of class sap.m.p13n.FilterController with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.p13n.SelectionController.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, FilterController>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.p13n.FilterController.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): Metadata;
  }
  /**
   * Personalization `FilterState` object type. This object describes the state processed by this controller
   * when accessing it through the {@link sap.m.p13n.Engine Engine}.
   */
  export type FilterState = Record<string, FilterStateItem[]>;

  /**
   * Personalization `FilterStateItem` object type. This object describes a single filter condition.
   */
  export type FilterStateItem = {
    /**
     * The operator of the condition
     */
    operator: FilterOperator | keyof typeof FilterOperator;
    /**
     * The values of the condition
     */
    values: string[];
    /**
     * Defines whether the item is filtered (if a filter state is provided, it's filtered automatically)
     */
    filtered?: boolean;
  };
}

declare module "sap/m/p13n/GroupController" {
  import SelectionController from "sap/m/p13n/SelectionController";

  import Control from "sap/ui/core/Control";

  /**
   * The `GroupController` entity serves as a base class to create group-specific personalization implementations.
   *
   * @since 1.104
   */
  export default class GroupController extends SelectionController {
    /**
     * Constructor for a new `GroupController`.
     */
    constructor(
      /**
       * Initial settings for the new controller
       */
      mSettings: {
        /**
         * The control instance that is personalized by this controller
         */
        control: Control;
      }
    );
  }
  /**
   * Personalization `GroupState` object type. This object describes the state processed by this controller
   * when accessing it through the {@link sap.m.p13n.Engine Engine}.
   */
  export type GroupState = {
    /**
     * The key for the group state
     */
    key: string;
    /**
     * Defines whether the item is grouped (if a group state is provided, it's grouped automatically)
     */
    grouped?: boolean;
    /**
     * Describes the index of the grouping
     */
    index?: int;
  };
}

declare module "sap/m/p13n/GroupPanel" {
  import {
    default as QueryPanel,
    $QueryPanelSettings,
  } from "sap/m/p13n/QueryPanel";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * P13n `GroupItem` object type.
   */
  export type GroupItem = {
    /**
     * The unique key of the item
     */
    name: string;
    /**
     * The label describing the personalization item
     */
    label: string;
    /**
     * Defines the grouping state of the personalization item
     */
    grouped: boolean;
  };

  /**
   * This control can be used to customize personalization content for grouping for an associated control
   * instance.
   */
  export default class GroupPanel extends QueryPanel {
    /**
     * Constructor for a new `GroupPanel`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $GroupPanelSettings
    );
    /**
     * Constructor for a new `GroupPanel`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $GroupPanelSettings
    );

    /**
     * Creates a new subclass of class sap.m.p13n.GroupPanel with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.p13n.QueryPanel.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, GroupPanel>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.p13n.GroupPanel.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Sets the personalization state of the panel instance.
     *
     *
     * @returns The GroupPanel instance
     */
    static setP13nData(
      /**
       * An array containing the personalization state
       */
      aP13nData: GroupItem[]
    ): GroupPanel;
    /**
     * Gets current value of property {@link #getEnableShowField enableShowField}.
     *
     * Toggles an additional checkbox in the group panel to define whether items are made visible.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `enableShowField`
     */
    getEnableShowField(): boolean;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * A short text describing the panel. **Note:** This text will only be displayed if the panel is being used
     * in a `sap.m.p13n.Popup`.
     *
     * Default value is `...see text or source`.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Sets a new value for property {@link #getEnableShowField enableShowField}.
     *
     * Toggles an additional checkbox in the group panel to define whether items are made visible.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableShowField(
      /**
       * New value for property `enableShowField`
       */
      bEnableShowField?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * A short text describing the panel. **Note:** This text will only be displayed if the panel is being used
     * in a `sap.m.p13n.Popup`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `...see text or source`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the GroupPanel constructor.
   */
  export interface $GroupPanelSettings extends $QueryPanelSettings {
    /**
     * A short text describing the panel. **Note:** This text will only be displayed if the panel is being used
     * in a `sap.m.p13n.Popup`.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Toggles an additional checkbox in the group panel to define whether items are made visible.
     */
    enableShowField?: boolean | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/p13n/MetadataHelper" {
  import BaseObject from "sap/ui/base/Object";

  import Metadata from "sap/ui/base/Metadata";

  /**
   * The `MetadataHelper` entity offers utility functionality for service metadata during the `Engine#register`
   * process.
   */
  export default class MetadataHelper extends BaseObject {
    /**
     * See:
     * 	{@link https://ui5.sap.com/#/topic/75c08fdebf784575947927e052712bab Personalization}
     */
    constructor(
      /**
       * Array of objects defining available items for personalization
       */
      aProperties: MetadataObject[]
    );

    /**
     * Creates a new subclass of class sap.m.p13n.MetadataHelper with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.base.Object.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, MetadataHelper>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.p13n.MetadataHelper.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): Metadata;
    /**
     * Gets a property path based on its key.
     *
     *
     * @returns The property path based on its key
     */
    getPath(
      /**
       * The property key identifying a property entry
       */
      sKey: string
    ): string;
    /**
     * Gets the array of properties.
     *
     *
     * @returns Array of properties
     */
    getProperties(): object[];
    /**
     * Gets a single property.
     *
     *
     * @returns A single property
     */
    getProperty(
      /**
       * The property key identifying a property entry
       */
      sKey: string
    ): MetadataObject | undefined;
    /**
     * Gets a list of properties that are redundant and should be filtered out in the {@link sap.ui.mdc.p13n.SelectionController }
     * for personalization.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns A list of properties
     */
    getRedundantProperties(): object[];
  }
  /**
   * Personalization `MetadataObject` type.
   */
  export type MetadataObject = {
    /**
     * The unique key for the p13n metadata object
     */
    key: string;
    /**
     * Defines the text that will be displayed in the personalization popup
     */
    label: string;
    /**
     * Defines the technical path to apply binding-related updates
     */
    path: string;
    /**
     * Defines whether the metadata object is sortable
     */
    sortable?: boolean;
    /**
     * Defines whether the metadata object is groupable
     */
    groupable?: boolean;
    /**
     * Defines whether the metadata object is visible for selection
     */
    visible?: boolean;
  };
}

declare module "sap/m/p13n/Popup" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import Button from "sap/m/Button";

  import { p13n, P13nPopupMode } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { CSSSize } from "sap/ui/core/library";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * This control can be used to show personalization-related content in different popup controls.
   *
   * @since 1.97
   */
  export default class Popup extends Control {
    /**
     * Constructor for a new `Popup`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $PopupSettings
    );
    /**
     * Constructor for a new `Popup`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $PopupSettings
    );

    /**
     * Creates a new subclass of class sap.m.p13n.Popup with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Popup>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.p13n.Popup.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some additionalButton to the aggregation {@link #getAdditionalButtons additionalButtons}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAdditionalButton(
      /**
       * The additionalButton to add; if empty, nothing is inserted
       */
      oAdditionalButton: Button
    ): this;
    /**
     * Adds a new panel to the `panels` aggregation.
     *
     *
     * @returns The popup instance
     */
    addPanel(
      /**
       * The panel instance
       */
      oPanel: p13n.IContent,
      /**
       * Optional key to be used for the panel registration instead of using the id
       */
      sKey?: string
    ): Popup;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:close close} event of this `sap.m.p13n.Popup`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.p13n.Popup` itself.
     *
     * This event is fired after the dialog has been closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Popup$CloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.p13n.Popup` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:close close} event of this `sap.m.p13n.Popup`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.p13n.Popup` itself.
     *
     * This event is fired after the dialog has been closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Popup$CloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.p13n.Popup` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the additionalButtons in the aggregation {@link #getAdditionalButtons additionalButtons}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyAdditionalButtons(): this;
    /**
     * Destroys all the panels in the aggregation {@link #getPanels panels}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyPanels(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:close close} event of this `sap.m.p13n.Popup`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Popup$CloseEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:close close} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Popup$CloseEventParameters
    ): this;
    /**
     * Gets content of aggregation {@link #getAdditionalButtons additionalButtons}.
     *
     * Additional set of `sap.m.Button` controls that are added to the existing Ok and Cancel buttons.
     */
    getAdditionalButtons(): Button[];
    /**
     * Gets current value of property {@link #getMode mode}.
     *
     * Describes the corresponding popup mode, see also {@link sap.m.P13nPopupMode}.
     *
     * Default value is `Dialog`.
     *
     *
     * @returns Value of property `mode`
     */
    getMode(): P13nPopupMode;
    /**
     * Returns the current panels in the `panels` aggregation.
     *
     *
     * @returns An array of panel instances
     */
    getPanels(): p13n.IContent[];
    /**
     * Gets current value of property {@link #getReset reset}.
     *
     * A callback that will be executed once a reset has been triggered. **Note:** The Reset button will only
     * be shown in case this callback is provided.
     *
     *
     * @returns Value of property `reset`
     */
    getReset(): Function;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Text describing the personalization popup.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getWarningText warningText}.
     *
     * Warning text which appears as a message prior to executing the rest callback. **Note:** The `warningText`
     * may only be used in case the `reset` callback has been provided.
     *
     *
     * @returns Value of property `warningText`
     */
    getWarningText(): string;
    /**
     * Checks for the provided `sap.m.Button` in the aggregation {@link #getAdditionalButtons additionalButtons}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfAdditionalButton(
      /**
       * The additionalButton whose index is looked for
       */
      oAdditionalButton: Button
    ): int;
    /**
     * Checks for the provided `sap.m.p13n.IContent` in the aggregation {@link #getPanels panels}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfPanel(
      /**
       * The panel whose index is looked for
       */
      oPanel: p13n.IContent
    ): int;
    /**
     * Inserts a additionalButton into the aggregation {@link #getAdditionalButtons additionalButtons}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertAdditionalButton(
      /**
       * The additionalButton to insert; if empty, nothing is inserted
       */
      oAdditionalButton: Button,
      /**
       * The `0`-based index the additionalButton should be inserted at; for a negative value of `iIndex`, the
       * additionalButton is inserted at position 0; for a value greater than the current size of the aggregation,
       * the additionalButton is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a panel into the aggregation {@link #getPanels panels}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertPanel(
      /**
       * The panel to insert; if empty, nothing is inserted
       */
      oPanel: p13n.IContent,
      /**
       * The `0`-based index the panel should be inserted at; for a negative value of `iIndex`, the panel is inserted
       * at position 0; for a value greater than the current size of the aggregation, the panel is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Checks whether there is an open `Popup` control.
     *
     *
     * @returns Flag that indicates if there is an open popup
     */
    isOpen(): boolean;
    /**
     * Opens the `Popup` control.
     */
    open(
      /**
       * The referenced control instance (used as anchor, for example, on popovers)
       */
      oSource: Control,
      /**
       * Configuration for the related popup container
       */
      mSettings?: {
        /**
         * Height configuration for the related popup container
         */
        contentHeight?: CSSSize;
        /**
         * Width configuration for the related popup container
         */
        contentWidth?: CSSSize;
        /**
         * Key of active panel that is opened initially
         */
        activePanel?: string;
      }
    ): void;
    /**
     * Removes a additionalButton from the aggregation {@link #getAdditionalButtons additionalButtons}.
     *
     *
     * @returns The removed additionalButton or `null`
     */
    removeAdditionalButton(
      /**
       * The additionalButton to remove or its index or id
       */
      vAdditionalButton: int | string | Button
    ): Button | null;
    /**
     * Removes all the controls from the aggregation {@link #getAdditionalButtons additionalButtons}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAdditionalButtons(): Button[];
    /**
     * Removes a panel instance.
     *
     *
     * @returns The popup instance
     */
    removePanel(
      /**
       * The panel instance
       */
      oPanel: p13n.IContent
    ): Popup;
    /**
     * Sets the desired popup mode, see also {@link sap.m.P13nPopupMode}.
     *
     *
     * @returns The popup instance
     */
    setMode(
      /**
       * The mode used for the popup creation
       */
      sMode: P13nPopupMode | keyof typeof P13nPopupMode
    ): Popup;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Text describing the personalization popup.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle: string
    ): this;
    /**
     * Sets a new value for property {@link #getWarningText warningText}.
     *
     * Warning text which appears as a message prior to executing the rest callback. **Note:** The `warningText`
     * may only be used in case the `reset` callback has been provided.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWarningText(
      /**
       * New value for property `warningText`
       */
      sWarningText: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Popup constructor.
   */
  export interface $PopupSettings extends $ControlSettings {
    /**
     * Text describing the personalization popup.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Describes the corresponding popup mode, see also {@link sap.m.P13nPopupMode}.
     */
    mode?:
      | (P13nPopupMode | keyof typeof P13nPopupMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Warning text which appears as a message prior to executing the rest callback. **Note:** The `warningText`
     * may only be used in case the `reset` callback has been provided.
     */
    warningText?: string | PropertyBindingInfo;

    /**
     * A callback that will be executed once a reset has been triggered. **Note:** The Reset button will only
     * be shown in case this callback is provided.
     */
    reset?: Function | PropertyBindingInfo | `{${string}}`;

    /**
     * The panels that are displayed by the `sap.m.p13n.Popup`.
     */
    panels?:
      | p13n.IContent[]
      | p13n.IContent
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Additional set of `sap.m.Button` controls that are added to the existing Ok and Cancel buttons.
     */
    additionalButtons?:
      | Button[]
      | Button
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * This event is fired after the dialog has been closed.
     */
    close?: (oEvent: Popup$CloseEvent) => void;
  }

  /**
   * Parameters of the Popup#close event.
   */
  export interface Popup$CloseEventParameters {
    /**
     * The corresponding reason for closing the dialog (Ok & Cancel).
     */
    reason?: string;
  }

  /**
   * Event object of the Popup#close event.
   */
  export type Popup$CloseEvent = Event<Popup$CloseEventParameters, Popup>;
}

declare module "sap/m/p13n/QueryPanel" {
  import {
    default as BasePanel,
    Item,
    $BasePanelSettings,
  } from "sap/m/p13n/BasePanel";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * This control serves as base class for a query builder like personalization implementation.
   *
   * @since 1.96
   */
  export default class QueryPanel extends BasePanel {
    /**
     * Constructor for a new `QueryPanel`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $QueryPanelSettings
    );
    /**
     * Constructor for a new `QueryPanel`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $QueryPanelSettings
    );

    /**
     * Creates a new subclass of class sap.m.p13n.QueryPanel with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.p13n.BasePanel.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, QueryPanel>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.p13n.QueryPanel.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getQueryLimit queryLimit}.
     *
     * The limit for the number of queries that can be created by the user. By default, no query limit is provided.
     *
     * Default value is `-1`.
     *
     *
     * @returns Value of property `queryLimit`
     */
    getQueryLimit(): int;
    /**
     * Sets the personalization state of the panel instance.
     *
     *
     * @returns The `QueryPanel` instance
     */
    setP13nData(
      /**
       * An array containing the personalization state that is represented by the `QueryPanel`
       */
      aP13nData: Item[]
    ): this;
    /**
     * Sets a new value for property {@link #getQueryLimit queryLimit}.
     *
     * The limit for the number of queries that can be created by the user. By default, no query limit is provided.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `-1`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setQueryLimit(
      /**
       * New value for property `queryLimit`
       */
      iQueryLimit?: int
    ): this;
  }
  /**
   * Describes the settings that can be provided to the QueryPanel constructor.
   */
  export interface $QueryPanelSettings extends $BasePanelSettings {
    /**
     * The limit for the number of queries that can be created by the user. By default, no query limit is provided.
     */
    queryLimit?: int | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/p13n/SelectionController" {
  import BaseObject from "sap/ui/base/Object";

  import Control from "sap/ui/core/Control";

  import UI5Element from "sap/ui/core/Element";

  import MetadataHelper from "sap/m/p13n/MetadataHelper";

  import Metadata from "sap/ui/base/Metadata";

  /**
   * The `SelectionController` entity serves as a base class to create control-specific personalization implementations.
   */
  export default class SelectionController extends BaseObject {
    /**
     * Constructor for a new `SelectionController`.
     */
    constructor(
      /**
       * Initial settings for the new controller
       */
      mSettings: {
        /**
         * The control instance that is personalized by this controller
         */
        control: Control;
        /**
         * By default the SelectionController tries to identify the existing item through the key by checking if
         * there is an existing item with this id. This behaviour can be overruled by implementing this method which
         * will provide the according item of the `targetAggregation` to return the according key associated to
         * this item.
         */
        getKeyForItem?: (p1: UI5Element) => string;
        /**
         * The name of the aggregation that is now managed by this controller
         */
        targetAggregation: string;
        /**
         * If multiple `SelectionController` controls exist for a personalization use case, the `persistenceIdentifier`
         * property must be added to uniquely identify a `SelectionController` control
         */
        persistenceIdentifier?: string;
        /**
         * The `{@link sap.m.p13n.MetadataHelper MetadataHelper}` to provide metadata-specific information. It may
         * be used to define more granular information for the selection of items.
         */
        helper?: MetadataHelper;
      }
    );

    /**
     * Creates a new subclass of class sap.m.p13n.SelectionController with name `sClassName` and enriches it
     * with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.base.Object.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SelectionController>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.p13n.SelectionController.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): Metadata;
  }
  /**
   * Personalization `SelectionState` object type. This object describes the state processed by this controller
   * when accessing it through the {@link sap.m.p13n.Engine Engine}.
   */
  export type SelectionState = {
    /**
     * The key for the group state
     */
    key: string;
    /**
     * Defines whether the item is selected (if a selection state is provided, it's selected automatically)
     */
    visible?: boolean;
    /**
     * Describes the index of the selection item
     */
    index?: int;
  };
}

declare module "sap/m/p13n/SelectionPanel" {
  import {
    default as BasePanel,
    Item,
    $BasePanelSettings,
  } from "sap/m/p13n/BasePanel";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { MultiSelectMode } from "sap/m/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * This control can be used to customize personalization content for adding/removing items for an associated
   * control instance.
   *
   * @since 1.96
   */
  export default class SelectionPanel extends BasePanel {
    /**
     * Constructor for a new `SelectionPanel`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SelectionPanelSettings
    );
    /**
     * Constructor for a new `SelectionPanel`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SelectionPanelSettings
    );

    /**
     * Creates a new subclass of class sap.m.p13n.SelectionPanel with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.p13n.BasePanel.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SelectionPanel>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.p13n.SelectionPanel.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getActiveColumn activeColumn}.
     *
     * The second column in the panel showing the move buttons for reordering.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `activeColumn`
     */
    getActiveColumn(): string;
    /**
     * Gets current value of property {@link #getEnableCount enableCount}.
     *
     * Enables a count for selected items compared to available items, for example, Currency (3/12), in addition
     * to the first column text.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `enableCount`
     */
    getEnableCount(): boolean;
    /**
     * Gets current value of property {@link #getFieldColumn fieldColumn}.
     *
     * The first column in the panel describing the selectable fields.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `fieldColumn`
     */
    getFieldColumn(): string;
    /**
     * Gets current value of property {@link #getItemFactory itemFactory}.
     *
     * An optional callback that may be used to display additional custom content in each selectable item. This
     * factory can be toggled by executing the {@link sap.m.p13n.SelectionPanel#showFactory} method.
     *
     * **Note:**: The `getIdForLabel` method can be imlplemented on the returned control instance to return
     * a focusable children control to provide the `labelFor` reference for the associated text.
     *
     *
     * @returns Value of property `itemFactory`
     */
    getItemFactory(): Function;
    /**
     * Gets current value of property {@link #getMultiSelectMode multiSelectMode}.
     *
     * Defines the multi-selection mode for the inner list control.
     *
     * Default value is `ClearAll`.
     *
     *
     * @returns Value of property `multiSelectMode`
     */
    getMultiSelectMode(): MultiSelectMode;
    /**
     * Gets current value of property {@link #getShowHeader showHeader}.
     *
     * /** Shows an additional header with a search field and the Show Selected button.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showHeader`
     */
    getShowHeader(): boolean;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * A short text describing the panel. **Note:** This text will only be displayed if the panel is being used
     * in a `sap.m.p13n.Popup`.
     *
     * Default value is `...see text or source`.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Sets a new value for property {@link #getActiveColumn activeColumn}.
     *
     * The second column in the panel showing the move buttons for reordering.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setActiveColumn(
      /**
       * New value for property `activeColumn`
       */
      sActiveColumn?: string
    ): this;
    /**
     * Sets a new value for property {@link #getEnableCount enableCount}.
     *
     * Enables a count for selected items compared to available items, for example, Currency (3/12), in addition
     * to the first column text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableCount(
      /**
       * New value for property `enableCount`
       */
      bEnableCount?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getFieldColumn fieldColumn}.
     *
     * The first column in the panel describing the selectable fields.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFieldColumn(
      /**
       * New value for property `fieldColumn`
       */
      sFieldColumn?: string
    ): this;
    /**
     * Sets a new value for property {@link #getItemFactory itemFactory}.
     *
     * An optional callback that may be used to display additional custom content in each selectable item. This
     * factory can be toggled by executing the {@link sap.m.p13n.SelectionPanel#showFactory} method.
     *
     * **Note:**: The `getIdForLabel` method can be imlplemented on the returned control instance to return
     * a focusable children control to provide the `labelFor` reference for the associated text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setItemFactory(
      /**
       * New value for property `itemFactory`
       */
      fnItemFactory: Function
    ): this;
    /**
     * Sets a new value for property {@link #getMultiSelectMode multiSelectMode}.
     *
     * Defines the multi-selection mode for the inner list control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `ClearAll`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMultiSelectMode(
      /**
       * New value for property `multiSelectMode`
       */
      sMultiSelectMode?: MultiSelectMode | keyof typeof MultiSelectMode
    ): this;
    /**
     * Sets the personalization state of the panel instance.
     *
     *
     * @returns The `SelectionPanel` instance
     */
    setP13nData(
      /**
       * An array containing the personalization state that is represented by the `SelectionPanel`.
       */
      aP13nData: Item[]
    ): this;
    /**
     * Sets a new value for property {@link #getShowHeader showHeader}.
     *
     * /** Shows an additional header with a search field and the Show Selected button.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowHeader(
      /**
       * New value for property `showHeader`
       */
      bShowHeader?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * A short text describing the panel. **Note:** This text will only be displayed if the panel is being used
     * in a `sap.m.p13n.Popup`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `...see text or source`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the SelectionPanel constructor.
   */
  export interface $SelectionPanelSettings extends $BasePanelSettings {
    /**
     * A short text describing the panel. **Note:** This text will only be displayed if the panel is being used
     * in a `sap.m.p13n.Popup`.
     */
    title?: string | PropertyBindingInfo;

    /**
     * /** Shows an additional header with a search field and the Show Selected button.
     */
    showHeader?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Enables a count for selected items compared to available items, for example, Currency (3/12), in addition
     * to the first column text.
     */
    enableCount?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The first column in the panel describing the selectable fields.
     */
    fieldColumn?: string | PropertyBindingInfo;

    /**
     * The second column in the panel showing the move buttons for reordering.
     */
    activeColumn?: string | PropertyBindingInfo;

    /**
     * An optional callback that may be used to display additional custom content in each selectable item. This
     * factory can be toggled by executing the {@link sap.m.p13n.SelectionPanel#showFactory} method.
     *
     * **Note:**: The `getIdForLabel` method can be imlplemented on the returned control instance to return
     * a focusable children control to provide the `labelFor` reference for the associated text.
     */
    itemFactory?: Function | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the multi-selection mode for the inner list control.
     */
    multiSelectMode?:
      | (MultiSelectMode | keyof typeof MultiSelectMode)
      | PropertyBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/p13n/SortController" {
  import SelectionController from "sap/m/p13n/SelectionController";

  import Control from "sap/ui/core/Control";

  import Metadata from "sap/ui/base/Metadata";

  /**
   * The `SortController` entity serves as a base class to create personalization implementations that are
   * specific to sorting.
   */
  export default class SortController extends SelectionController {
    /**
     * Constructor for a new `SortController`.
     */
    constructor(
      /**
       * Initial settings for the new controller
       */
      mSettings: {
        /**
         * The control instance that is personalized by this controller
         */
        control: Control;
      }
    );

    /**
     * Creates a new subclass of class sap.m.p13n.SortController with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.p13n.SelectionController.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SortController>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.p13n.SortController.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): Metadata;
  }
  /**
   * Personalization `SortState` object type. This object describes the state processed by this controller
   * when accessing it through the {@link sap.m.p13n.Engine Engine}.
   */
  export type SortState = {
    /**
     * The key for the sort state
     */
    key: string;
    /**
     * Defines whether the item is sorted (if a sort state is provided, it's sorted automatically)
     */
    sorted?: boolean;
    /**
     * Defines whether the sorting is processed in a descending order (`false` is the default)
     */
    descending?: boolean;
    /**
     * Describes the index of the sorter
     */
    index?: int;
  };
}

declare module "sap/m/p13n/SortPanel" {
  import {
    default as QueryPanel,
    $QueryPanelSettings,
  } from "sap/m/p13n/QueryPanel";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * P13n `SortItem` object type.
   */
  export type SortItem = {
    /**
     * The unique key of the item
     */
    name: string;
    /**
     * The label describing the personalization item
     */
    label: string;
    /**
     * Defines the sorting state of the personalization item
     */
    sorted: boolean;
    /**
     * Defines the descending state of the personalization item
     */
    descending: boolean;
  };

  /**
   * This control can be used to customize personalization content for sorting for an associated control instance.
   *
   * @since 1.96
   */
  export default class SortPanel extends QueryPanel {
    /**
     * Constructor for a new `SortPanel`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SortPanelSettings
    );
    /**
     * Constructor for a new `SortPanel`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SortPanelSettings
    );

    /**
     * Creates a new subclass of class sap.m.p13n.SortPanel with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.p13n.QueryPanel.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SortPanel>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.p13n.SortPanel.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Sets the personalization state of the panel instance.
     *
     *
     * @returns The SortPanel instance
     */
    static setP13nData(
      /**
       * An array containing the personalization state
       */
      aP13nData: SortItem[]
    ): SortPanel;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * A short text describing the panel. **Note:** This text will only be displayed if the panel is being used
     * in a `sap.m.p13n.Popup`.
     *
     * Default value is `...see text or source`.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * A short text describing the panel. **Note:** This text will only be displayed if the panel is being used
     * in a `sap.m.p13n.Popup`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `...see text or source`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the SortPanel constructor.
   */
  export interface $SortPanelSettings extends $QueryPanelSettings {
    /**
     * A short text describing the panel. **Note:** This text will only be displayed if the panel is being used
     * in a `sap.m.p13n.Popup`.
     */
    title?: string | PropertyBindingInfo;
  }
}

declare module "sap/m/P13nColumnsItem" {
  import { default as Item, $ItemSettings } from "sap/ui/core/Item";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Type for `columnsItems` aggregation in `P13nColumnsPanel` control.
   *
   * @since 1.26.0
   * @deprecated As of version 1.120. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export default class P13nColumnsItem extends Item {
    /**
     * Constructor for a new P13nColumnsItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nColumnsItemSettings
    );
    /**
     * Constructor for a new P13nColumnsItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nColumnsItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.P13nColumnsItem with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Item.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, P13nColumnsItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.P13nColumnsItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getColumnKey columnKey}.
     *
     * This property contains the unique table column key
     *
     * @since 1.26.0
     *
     * @returns Value of property `columnKey`
     */
    getColumnKey(): string;
    /**
     * Gets current value of property {@link #getIndex index}.
     *
     * This property contains the index of a table column
     *
     * @since 1.26.0
     *
     * @returns Value of property `index`
     */
    getIndex(): int;
    /**
     * Gets current value of property {@link #getTotal total}.
     *
     * This property contains the total flag of a table column.
     *
     * @since 1.26.0
     *
     * @returns Value of property `total`
     */
    getTotal(): boolean;
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * This property decides whether a `P13nColumnsItem` is visible
     *
     * @since 1.26.0
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * This property contains the with of a table column.
     *
     * @since 1.26.0
     *
     * @returns Value of property `width`
     */
    getWidth(): string;
    /**
     * Sets a new value for property {@link #getColumnKey columnKey}.
     *
     * This property contains the unique table column key
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.26.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setColumnKey(
      /**
       * New value for property `columnKey`
       */
      sColumnKey: string
    ): this;
    /**
     * Sets a new value for property {@link #getIndex index}.
     *
     * This property contains the index of a table column
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.26.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIndex(
      /**
       * New value for property `index`
       */
      iIndex: int
    ): this;
    /**
     * Sets a new value for property {@link #getTotal total}.
     *
     * This property contains the total flag of a table column.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.26.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTotal(
      /**
       * New value for property `total`
       */
      bTotal: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * This property decides whether a `P13nColumnsItem` is visible
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.26.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * This property contains the with of a table column.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.26.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the P13nColumnsItem constructor.
   *
   * @deprecated As of version 1.120. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export interface $P13nColumnsItemSettings extends $ItemSettings {
    /**
     * This property contains the unique table column key
     *
     * @since 1.26.0
     */
    columnKey?: string | PropertyBindingInfo;

    /**
     * This property contains the index of a table column
     *
     * @since 1.26.0
     */
    index?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * This property decides whether a `P13nColumnsItem` is visible
     *
     * @since 1.26.0
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This property contains the with of a table column.
     *
     * @since 1.26.0
     */
    width?: string | PropertyBindingInfo;

    /**
     * This property contains the total flag of a table column.
     *
     * @since 1.26.0
     */
    total?: boolean | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/P13nColumnsPanel" {
  import { default as P13nPanel, $P13nPanelSettings } from "sap/m/P13nPanel";

  import P13nColumnsItem from "sap/m/P13nColumnsItem";

  import Event from "sap/ui/base/Event";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * The `P13nColumnsPanel` control is used to define column-specific settings for table personalization.
   *
   * @since 1.26.0
   * @deprecated As of version 1.98. Use the {@link sap.m.p13n.SelectionPanel} instead.
   */
  export default class P13nColumnsPanel extends P13nPanel {
    /**
     * Constructor for a new P13nColumnsPanel.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nColumnsPanelSettings
    );
    /**
     * Constructor for a new P13nColumnsPanel.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nColumnsPanelSettings
    );

    /**
     * Creates a new subclass of class sap.m.P13nColumnsPanel with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.P13nPanel.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, P13nColumnsPanel>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.P13nColumnsPanel.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some columnsItem to the aggregation {@link #getColumnsItems columnsItems}.
     *
     * @since 1.26.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addColumnsItem(
      /**
       * The columnsItem to add; if empty, nothing is inserted
       */
      oColumnsItem: P13nColumnsItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:addColumnsItem addColumnsItem} event of this
     * `sap.m.P13nColumnsPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nColumnsPanel` itself.
     *
     * Event raised when a `columnsItem` is added.
     *
     * @since 1.26.0
     * @deprecated As of version 1.50. replaced by extended event {@link sap.m.P13nColumnsPanel#event:changeColumnsItems}
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAddColumnsItem(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: P13nColumnsPanel$AddColumnsItemEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nColumnsPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:addColumnsItem addColumnsItem} event of this
     * `sap.m.P13nColumnsPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nColumnsPanel` itself.
     *
     * Event raised when a `columnsItem` is added.
     *
     * @since 1.26.0
     * @deprecated As of version 1.50. replaced by extended event {@link sap.m.P13nColumnsPanel#event:changeColumnsItems}
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAddColumnsItem(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: P13nColumnsPanel$AddColumnsItemEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nColumnsPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:changeColumnsItems changeColumnsItems} event
     * of this `sap.m.P13nColumnsPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nColumnsPanel` itself.
     *
     * Event raised if `columnsItems` is changed or new one needs to be created in the model.
     *
     * @since 1.26.7
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChangeColumnsItems(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: P13nColumnsPanel$ChangeColumnsItemsEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nColumnsPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:changeColumnsItems changeColumnsItems} event
     * of this `sap.m.P13nColumnsPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nColumnsPanel` itself.
     *
     * Event raised if `columnsItems` is changed or new one needs to be created in the model.
     *
     * @since 1.26.7
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChangeColumnsItems(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: P13nColumnsPanel$ChangeColumnsItemsEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nColumnsPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:setData setData} event of this `sap.m.P13nColumnsPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nColumnsPanel` itself.
     *
     * Event raised if `setData` is called in model. The event serves the purpose of minimizing such calls since
     * they can take up a lot of performance.
     *
     * @since 1.26.7
     * @deprecated As of version 1.50. the event `setData` is obsolete.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSetData(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nColumnsPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:setData setData} event of this `sap.m.P13nColumnsPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nColumnsPanel` itself.
     *
     * Event raised if `setData` is called in model. The event serves the purpose of minimizing such calls since
     * they can take up a lot of performance.
     *
     * @since 1.26.7
     * @deprecated As of version 1.50. the event `setData` is obsolete.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSetData(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nColumnsPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getColumnsItems columnsItems} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     * @since 1.26.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindColumnsItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the columnsItems in the aggregation {@link #getColumnsItems columnsItems}.
     *
     * @since 1.26.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyColumnsItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:addColumnsItem addColumnsItem} event of this
     * `sap.m.P13nColumnsPanel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.26.0
     * @deprecated As of version 1.50. replaced by extended event {@link sap.m.P13nColumnsPanel#event:changeColumnsItems}
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAddColumnsItem(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: P13nColumnsPanel$AddColumnsItemEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:changeColumnsItems changeColumnsItems} event
     * of this `sap.m.P13nColumnsPanel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.26.7
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChangeColumnsItems(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: P13nColumnsPanel$ChangeColumnsItemsEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:setData setData} event of this `sap.m.P13nColumnsPanel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.26.7
     * @deprecated As of version 1.50. the event `setData` is obsolete.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSetData(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:addColumnsItem addColumnsItem} to attached listeners.
     *
     * @since 1.26.0
     * @deprecated As of version 1.50. replaced by extended event {@link sap.m.P13nColumnsPanel#event:changeColumnsItems}
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAddColumnsItem(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: P13nColumnsPanel$AddColumnsItemEventParameters
    ): this;
    /**
     * Fires event {@link #event:changeColumnsItems changeColumnsItems} to attached listeners.
     *
     * @since 1.26.7
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChangeColumnsItems(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: P13nColumnsPanel$ChangeColumnsItemsEventParameters
    ): this;
    /**
     * Fires event {@link #event:setData setData} to attached listeners.
     *
     * @since 1.26.7
     * @deprecated As of version 1.50. the event `setData` is obsolete.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSetData(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets content of aggregation {@link #getColumnsItems columnsItems}.
     *
     * List of columns that has been changed.
     *
     * @since 1.26.0
     */
    getColumnsItems(): P13nColumnsItem[];
    /**
     * Delivers a payload for columnsPanel that can be used at consumer side
     *
     * @since 1.26.7
     *
     * @returns oPayload, which contains useful information
     */
    getOkPayload(): object;
    /**
     * Delivers a payload for columnsPanel that can be used at consumer side
     *
     * @since 1.28
     *
     * @returns oPayload, which contains useful information
     */
    getResetPayload(): object;
    /**
     * Gets current value of property {@link #getVisibleItemsThreshold visibleItemsThreshold}.
     *
     * Specifies a threshold of visible items. If the end user makes a lot of columns visible, this might cause
     * performance to slow down. When this happens, the user can receive a corresponding warning triggered by
     * the `visibleItemsThreshold` property. The property needs to be activated and set to the required value
     * by the consuming application to ensure that the warning message is shown when the threshold has been
     * exceeded. In the following example the message will be shown if more than 100 visible columns are selected:
     *
     *
     * ```javascript
     *
     * customData>
     * core:CustomData key="p13nDialogSettings"
     * value='\{"columns":\{"visible": true, "payload": \{"visibleItemsThreshold": 3\}\}\}' />
     * /customData>
     * ```
     *
     *
     * Default value is `-1`.
     *
     * @since 1.26.7
     *
     * @returns Value of property `visibleItemsThreshold`
     */
    getVisibleItemsThreshold(): int;
    /**
     * Checks for the provided `sap.m.P13nColumnsItem` in the aggregation {@link #getColumnsItems columnsItems}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.26.0
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfColumnsItem(
      /**
       * The columnsItem whose index is looked for
       */
      oColumnsItem: P13nColumnsItem
    ): int;
    /**
     * Inserts a columnsItem into the aggregation {@link #getColumnsItems columnsItems}.
     *
     * @since 1.26.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertColumnsItem(
      /**
       * The columnsItem to insert; if empty, nothing is inserted
       */
      oColumnsItem: P13nColumnsItem,
      /**
       * The `0`-based index the columnsItem should be inserted at; for a negative value of `iIndex`, the columnsItem
       * is inserted at position 0; for a value greater than the current size of the aggregation, the columnsItem
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * This method does a re-initialization of the panel
     *
     * @since 1.28
     */
    reInitialize(): void;
    /**
     * Removes all the controls from the aggregation {@link #getColumnsItems columnsItems}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.26.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllColumnsItems(): P13nColumnsItem[];
    /**
     * Removes a columnsItem from the aggregation {@link #getColumnsItems columnsItems}.
     *
     * @since 1.26.0
     *
     * @returns The removed columnsItem or `null`
     */
    removeColumnsItem(
      /**
       * The columnsItem to remove or its index or id
       */
      vColumnsItem: int | string | P13nColumnsItem
    ): P13nColumnsItem | null;
    /**
     * Sets a new value for property {@link #getVisibleItemsThreshold visibleItemsThreshold}.
     *
     * Specifies a threshold of visible items. If the end user makes a lot of columns visible, this might cause
     * performance to slow down. When this happens, the user can receive a corresponding warning triggered by
     * the `visibleItemsThreshold` property. The property needs to be activated and set to the required value
     * by the consuming application to ensure that the warning message is shown when the threshold has been
     * exceeded. In the following example the message will be shown if more than 100 visible columns are selected:
     *
     *
     * ```javascript
     *
     * customData>
     * core:CustomData key="p13nDialogSettings"
     * value='\{"columns":\{"visible": true, "payload": \{"visibleItemsThreshold": 3\}\}\}' />
     * /customData>
     * ```
     *
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `-1`.
     *
     * @since 1.26.7
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisibleItemsThreshold(
      /**
       * New value for property `visibleItemsThreshold`
       */
      iVisibleItemsThreshold?: int
    ): this;
    /**
     * Unbinds aggregation {@link #getColumnsItems columnsItems} from model data.
     *
     * @since 1.26.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindColumnsItems(): this;
  }
  /**
   * Describes the settings that can be provided to the P13nColumnsPanel constructor.
   *
   * @deprecated As of version 1.98. Use the {@link sap.m.p13n.SelectionPanel} instead.
   */
  export interface $P13nColumnsPanelSettings extends $P13nPanelSettings {
    /**
     * Specifies a threshold of visible items. If the end user makes a lot of columns visible, this might cause
     * performance to slow down. When this happens, the user can receive a corresponding warning triggered by
     * the `visibleItemsThreshold` property. The property needs to be activated and set to the required value
     * by the consuming application to ensure that the warning message is shown when the threshold has been
     * exceeded. In the following example the message will be shown if more than 100 visible columns are selected:
     *
     *
     * ```javascript
     *
     * customData>
     * core:CustomData key="p13nDialogSettings"
     * value='\{"columns":\{"visible": true, "payload": \{"visibleItemsThreshold": 3\}\}\}' />
     * /customData>
     * ```
     *
     *
     * @since 1.26.7
     */
    visibleItemsThreshold?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * List of columns that has been changed.
     *
     * @since 1.26.0
     */
    columnsItems?:
      | P13nColumnsItem[]
      | P13nColumnsItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Event raised when a `columnsItem` is added.
     *
     * @since 1.26.0
     * @deprecated As of version 1.50. replaced by extended event {@link sap.m.P13nColumnsPanel#event:changeColumnsItems}
     */
    addColumnsItem?: (oEvent: P13nColumnsPanel$AddColumnsItemEvent) => void;

    /**
     * Event raised if `columnsItems` is changed or new one needs to be created in the model.
     *
     * @since 1.26.7
     */
    changeColumnsItems?: (
      oEvent: P13nColumnsPanel$ChangeColumnsItemsEvent
    ) => void;

    /**
     * Event raised if `setData` is called in model. The event serves the purpose of minimizing such calls since
     * they can take up a lot of performance.
     *
     * @since 1.26.7
     * @deprecated As of version 1.50. the event `setData` is obsolete.
     */
    setData?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the P13nColumnsPanel#addColumnsItem event.
   *
   * @deprecated As of version 1.50. replaced by extended event {@link sap.m.P13nColumnsPanel#event:changeColumnsItems}
   */
  export interface P13nColumnsPanel$AddColumnsItemEventParameters {
    /**
     * `columnsItem` that needs to be added in the model.
     */
    newItem?: P13nColumnsItem;
  }

  /**
   * Event object of the P13nColumnsPanel#addColumnsItem event.
   *
   * @deprecated As of version 1.50. replaced by extended event {@link sap.m.P13nColumnsPanel#event:changeColumnsItems}
   */
  export type P13nColumnsPanel$AddColumnsItemEvent = Event<
    P13nColumnsPanel$AddColumnsItemEventParameters,
    P13nColumnsPanel
  >;

  /**
   * Parameters of the P13nColumnsPanel#changeColumnsItems event.
   */
  export interface P13nColumnsPanel$ChangeColumnsItemsEventParameters {
    /**
     * Contains `columnsItems` that needs to be created in the model. Deprecated as of version 1.50, replaced
     * by new parameter `items`.
     */
    newItems?: P13nColumnsItem[];

    /**
     * Contains `columnsItems` that needs to be changed in the model. Deprecated as of version 1.50, replaced
     * by new parameter `items`.
     */
    existingItems?: P13nColumnsItem[];

    /**
     * Array contains an object for each item in `items` aggregation enriched with index and visibility information.
     * The item order reflects the current order of columns in the panel.
     */
    items?: object[];
  }

  /**
   * Event object of the P13nColumnsPanel#changeColumnsItems event.
   */
  export type P13nColumnsPanel$ChangeColumnsItemsEvent = Event<
    P13nColumnsPanel$ChangeColumnsItemsEventParameters,
    P13nColumnsPanel
  >;

  /**
   * Parameters of the P13nColumnsPanel#setData event.
   *
   * @deprecated As of version 1.50. the event `setData` is obsolete.
   */
  export interface P13nColumnsPanel$SetDataEventParameters {}

  /**
   * Event object of the P13nColumnsPanel#setData event.
   *
   * @deprecated As of version 1.50. the event `setData` is obsolete.
   */
  export type P13nColumnsPanel$SetDataEvent = Event<
    P13nColumnsPanel$SetDataEventParameters,
    P13nColumnsPanel
  >;
}

declare module "sap/m/P13nConditionPanel" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { P13nConditionOperation } from "sap/m/library";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The ConditionPanel Control will be used to implement the Sorting, Filtering and Grouping panel of the
   * new Personalization dialog.
   *
   * @since 1.26.0
   * @deprecated As of version 1.124. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export default class P13nConditionPanel extends Control {
    /**
     * Constructor for a new P13nConditionPanel.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nConditionPanelSettings
    );
    /**
     * Constructor for a new P13nConditionPanel.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nConditionPanelSettings
    );

    /**
     * Creates a new subclass of class sap.m.P13nConditionPanel with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, P13nConditionPanel>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * creates and returns a formatted text for the specified condition
     *
     *
     * @returns the range token text. An empty string when no operation matches or the values for the operation
     * are wrong
     */
    static getFormatedConditionText(
      /**
       * the operation type sap.m.P13nConditionOperation
       */
      sOperation: string,
      /**
       * value of the first range field
       */
      sValue1: string,
      /**
       * value of the second range field
       */
      sValue2: string,
      /**
       * indicates if the range is an Exclude range
       */
      bExclude: boolean
    ): string;
    /**
     * Returns a metadata object for class sap.m.P13nConditionPanel.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * add a single condition.
     */
    addCondition(
      /**
       * the new condition of type `{ "key": "007", "operation": sap.m.P13nConditionOperation.Ascending, "keyField":
       * "keyFieldKey", "value1": "", "value2": ""};`
       */
      oCondition: object
    ): void;
    /**
     * add a single KeyField
     */
    addKeyField(
      /**
       * {key: "CompanyCode", text: "ID"}
       */
      oKeyField: object
    ): void;
    /**
     * add a single operation
     */
    addOperation(
      oOperation: P13nConditionOperation | keyof typeof P13nConditionOperation,
      /**
       * defines the type for which this operations will be used.
       */
      sType: string
    ): void;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:dataChange dataChange} event of this `sap.m.P13nConditionPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nConditionPanel` itself.
     *
     * Workaround for updating the binding
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDataChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nConditionPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:dataChange dataChange} event of this `sap.m.P13nConditionPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nConditionPanel` itself.
     *
     * Workaround for updating the binding
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDataChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nConditionPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:dataChange dataChange} event of this `sap.m.P13nConditionPanel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachDataChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:dataChange dataChange} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireDataChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getAlwaysShowAddIcon alwaysShowAddIcon}.
     *
     * makes the Add icon visible on each condition row. If is set to false the Add is only visible at the end
     * and you can only append a new condition.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `alwaysShowAddIcon`
     */
    getAlwaysShowAddIcon(): boolean;
    /**
     * Gets current value of property {@link #getAutoAddNewRow autoAddNewRow}.
     *
     * adds initial a new empty condition row
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `autoAddNewRow`
     */
    getAutoAddNewRow(): boolean;
    /**
     * Gets current value of property {@link #getAutoReduceKeyFieldItems autoReduceKeyFieldItems}.
     *
     * KeyField value can only be selected once. When you set the property to `true` the ConditionPanel will
     * automatically offers on the KeyField drop down only the keyFields which are not used. The default behavior
     * is that in each keyField dropdown all keyfields are listed.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `autoReduceKeyFieldItems`
     */
    getAutoReduceKeyFieldItems(): boolean;
    /**
     * returns array of all defined conditions.
     *
     *
     * @returns array of Conditions
     */
    getConditions(): object[];
    /**
     * Gets current value of property {@link #getContainerQuery containerQuery}.
     *
     * defines if the mediaQuery or a ContainerResize will be used for layout update. When the `P13nConditionPanel`
     * is used on a dialog the property should be set to `true`!
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `containerQuery`
     */
    getContainerQuery(): boolean;
    /**
     * Gets current value of property {@link #getDisableFirstRemoveIcon disableFirstRemoveIcon}.
     *
     * makes the remove icon on the first condition row disabled when only one condition exist.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `disableFirstRemoveIcon`
     */
    getDisableFirstRemoveIcon(): boolean;
    /**
     * Gets current value of property {@link #getDisplayFormat displayFormat}.
     *
     * This represents the displayFormat of the condition Values. With the value "UpperCase" the entered value
     * of the condition will be converted to upperCase.
     *
     *
     * @returns Value of property `displayFormat`
     */
    getDisplayFormat(): string;
    /**
     * Gets current value of property {@link #getExclude exclude}.
     *
     * exclude options for filter
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `exclude`
     */
    getExclude(): boolean;
    /**
     * getter for KeyFields array
     *
     *
     * @returns array of KeyFields `[{key: "CompanyCode", text: "ID"}, {key:"CompanyName", text : "Name"}]`
     */
    getKeyFields(): object[];
    /**
     * Gets current value of property {@link #getLayoutMode layoutMode}.
     *
     * can be used to control the layout behavior. Default is "" which will automatically change the layout.
     * With "Desktop", "Table" or "Phone" you can set a fixed layout.
     *
     *
     * @returns Value of property `layoutMode`
     */
    getLayoutMode(): string;
    /**
     * Gets current value of property {@link #getMaxConditions maxConditions}.
     *
     * defines the max number of conditions on the ConditionPanel
     *
     * Default value is `'-1'`.
     *
     *
     * @returns Value of property `maxConditions`
     */
    getMaxConditions(): string;
    /**
     * returns the default array of operations
     *
     *
     * @returns array of operations
     */
    getOperations(
      /**
       * defines the type for which the operations should be returned.
       */
      sType?: string
    ): P13nConditionOperation[];
    /**
     * Gets current value of property {@link #getShowLabel showLabel}.
     *
     * show additional labels in the condition
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showLabel`
     */
    getShowLabel(): boolean;
    /**
     * Gets current value of property {@link #getUsePrevConditionSetting usePrevConditionSetting}.
     *
     * new added condition use the settings from the previous condition as default.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `usePrevConditionSetting`
     */
    getUsePrevConditionSetting(): boolean;
    /**
     * Gets current value of property {@link #getValidationExecutor validationExecutor}.
     *
     * Calls the validation listener tbd...
     *
     *
     * @returns Value of property `validationExecutor`
     */
    getValidationExecutor(): object;
    /**
     * insert a single condition.
     */
    insertCondition(
      /**
       * the new condition of type `{ "key": "007", "operation": sap.m.P13nConditionOperation.Ascending, "keyField":
       * "keyFieldKey", "value1": "", "value2": ""};`
       */
      oCondition: object,
      /**
       * of the new condition
       */
      index: int
    ): void;
    /**
     * remove all conditions.
     */
    removeAllConditions(): void;
    /**
     * removes all KeyFields
     */
    removeAllKeyFields(): void;
    /**
     * remove all operations
     */
    removeAllOperations(
      /**
       * defines the type for which all operations should be removed
       */
      sType: string
    ): void;
    /**
     * remove a single condition.
     */
    removeCondition(
      /**
       * is the condition which should be removed. can be either a string with the key of the condition of the
       * condition object itself.
       */
      vCondition: object
    ): void;
    /**
     * removes all invalid conditions.
     *
     * @since 1.28.0
     */
    removeInvalidConditions(): void;
    /**
     * removes all errors/warning states from the value1/2 fields of all conditions.
     *
     * @since 1.28.0
     */
    removeValidationErrors(): void;
    /**
     * Sets a new value for property {@link #getAutoAddNewRow autoAddNewRow}.
     *
     * adds initial a new empty condition row
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAutoAddNewRow(
      /**
       * New value for property `autoAddNewRow`
       */
      bAutoAddNewRow?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getAutoReduceKeyFieldItems autoReduceKeyFieldItems}.
     *
     * KeyField value can only be selected once. When you set the property to `true` the ConditionPanel will
     * automatically offers on the KeyField drop down only the keyFields which are not used. The default behavior
     * is that in each keyField dropdown all keyfields are listed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAutoReduceKeyFieldItems(
      /**
       * New value for property `autoReduceKeyFieldItems`
       */
      bAutoReduceKeyFieldItems?: boolean
    ): this;
    /**
     * This method must be used to assign a list of conditions.
     */
    setConditions(
      /**
       * array of Conditions.
       */
      aConditions: object[]
    ): void;
    /**
     * Sets a new value for property {@link #getDisableFirstRemoveIcon disableFirstRemoveIcon}.
     *
     * makes the remove icon on the first condition row disabled when only one condition exist.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisableFirstRemoveIcon(
      /**
       * New value for property `disableFirstRemoveIcon`
       */
      bDisableFirstRemoveIcon?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getDisplayFormat displayFormat}.
     *
     * This represents the displayFormat of the condition Values. With the value "UpperCase" the entered value
     * of the condition will be converted to upperCase.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisplayFormat(
      /**
       * New value for property `displayFormat`
       */
      sDisplayFormat?: string
    ): this;
    /**
     * Sets a new value for property {@link #getExclude exclude}.
     *
     * exclude options for filter
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setExclude(
      /**
       * New value for property `exclude`
       */
      bExclude?: boolean
    ): this;
    /**
     * This method allows you to specify the KeyFields for the conditions. You can set an array of object with
     * Key and Text properties to define the keyfields.
     */
    setKeyFields(
      /**
       * array of KeyFields `[{key: "CompanyCode", text: "ID"}, {key:"CompanyName", text : "Name"}]`
       */
      aKeyFields: any[]
    ): void;
    /**
     * Sets a new value for property {@link #getMaxConditions maxConditions}.
     *
     * defines the max number of conditions on the ConditionPanel
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `'-1'`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxConditions(
      /**
       * New value for property `maxConditions`
       */
      sMaxConditions?: string
    ): this;
    /**
     * setter for the supported operations which we show per condition row. This array of "default" operations
     * will only be used when we do not have on the keyfield itself some specific operations and a keyfield
     * is of not of type date or numeric.
     */
    setOperations(
      /**
       * array of operations `[sap.m.P13nConditionOperation.BT, sap.m.P13nConditionOperation.EQ]`
       */
      aOperations: Array<
        P13nConditionOperation | keyof typeof P13nConditionOperation
      >,
      /**
       * defines the type for which this operations will be used. is `sType` is not defined the operations will
       * be used as default operations.
       */
      sType: string
    ): void;
    /**
     * Sets a new value for property {@link #getShowLabel showLabel}.
     *
     * show additional labels in the condition
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowLabel(
      /**
       * New value for property `showLabel`
       */
      bShowLabel?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getUsePrevConditionSetting usePrevConditionSetting}.
     *
     * new added condition use the settings from the previous condition as default.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUsePrevConditionSetting(
      /**
       * New value for property `usePrevConditionSetting`
       */
      bUsePrevConditionSetting?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getValidationExecutor validationExecutor}.
     *
     * Calls the validation listener tbd...
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValidationExecutor(
      /**
       * New value for property `validationExecutor`
       */
      oValidationExecutor?: object
    ): this;
  }
  /**
   * Describes the settings that can be provided to the P13nConditionPanel constructor.
   *
   * @deprecated As of version 1.124. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export interface $P13nConditionPanelSettings extends $ControlSettings {
    /**
     * defines the max number of conditions on the ConditionPanel
     */
    maxConditions?: string | PropertyBindingInfo;

    /**
     * exclude options for filter
     */
    exclude?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * defines if the mediaQuery or a ContainerResize will be used for layout update. When the `P13nConditionPanel`
     * is used on a dialog the property should be set to `true`!
     */
    containerQuery?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * adds initial a new empty condition row
     */
    autoAddNewRow?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * makes the remove icon on the first condition row disabled when only one condition exist.
     */
    disableFirstRemoveIcon?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * makes the Add icon visible on each condition row. If is set to false the Add is only visible at the end
     * and you can only append a new condition.
     */
    alwaysShowAddIcon?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * new added condition use the settings from the previous condition as default.
     */
    usePrevConditionSetting?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * KeyField value can only be selected once. When you set the property to `true` the ConditionPanel will
     * automatically offers on the KeyField drop down only the keyFields which are not used. The default behavior
     * is that in each keyField dropdown all keyfields are listed.
     */
    autoReduceKeyFieldItems?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * can be used to control the layout behavior. Default is "" which will automatically change the layout.
     * With "Desktop", "Table" or "Phone" you can set a fixed layout.
     */
    layoutMode?: string | PropertyBindingInfo;

    /**
     * show additional labels in the condition
     */
    showLabel?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This represents the displayFormat of the condition Values. With the value "UpperCase" the entered value
     * of the condition will be converted to upperCase.
     */
    displayFormat?: string | PropertyBindingInfo;

    /**
     * Calls the validation listener tbd...
     */
    validationExecutor?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Workaround for updating the binding
     */
    dataChange?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the P13nConditionPanel#dataChange event.
   */
  export interface P13nConditionPanel$DataChangeEventParameters {}

  /**
   * Event object of the P13nConditionPanel#dataChange event.
   */
  export type P13nConditionPanel$DataChangeEvent = Event<
    P13nConditionPanel$DataChangeEventParameters,
    P13nConditionPanel
  >;
}

declare module "sap/m/P13nDialog" {
  import { default as Dialog, $DialogSettings } from "sap/m/Dialog";

  import P13nPanel from "sap/m/P13nPanel";

  import Event from "sap/ui/base/Event";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * The P13nDialog control provides a dialog that contains one or more panels. On each of the panels, one
   * or more changes with regards to a table can be processed. For example, a panel to set a column to invisible,
   * change the order of the columns or a panel to sort or filter tables.
   *
   * @since 1.26.0
   * @deprecated As of version 1.98. Use the {@link sap.m.p13n.Popup} instead.
   */
  export default class P13nDialog extends Dialog {
    /**
     * Constructor for a new P13nDialog.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/a3c3c5eb54bc4cc38e6cfbd8e90c6a01 Personalization Dialog}
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nDialogSettings
    );
    /**
     * Constructor for a new P13nDialog.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/a3c3c5eb54bc4cc38e6cfbd8e90c6a01 Personalization Dialog}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nDialogSettings
    );

    /**
     * Creates a new subclass of class sap.m.P13nDialog with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.Dialog.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, P13nDialog>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.P13nDialog.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some panel to the aggregation {@link #getPanels panels}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addPanel(
      /**
       * The panel to add; if empty, nothing is inserted
       */
      oPanel: P13nPanel
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cancel cancel} event of this `sap.m.P13nDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nDialog` itself.
     *
     * Event fired if the 'cancel' button in `P13nDialog` is clicked.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCancel(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cancel cancel} event of this `sap.m.P13nDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nDialog` itself.
     *
     * Event fired if the 'cancel' button in `P13nDialog` is clicked.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCancel(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:ok ok} event of this `sap.m.P13nDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nDialog` itself.
     *
     * Event fired if the 'ok' button in `P13nDialog` is clicked.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachOk(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:ok ok} event of this `sap.m.P13nDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nDialog` itself.
     *
     * Event fired if the 'ok' button in `P13nDialog` is clicked.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachOk(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:reset reset} event of this `sap.m.P13nDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nDialog` itself.
     *
     * Event fired if the 'reset' button in `P13nDialog` is clicked.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachReset(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:reset reset} event of this `sap.m.P13nDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nDialog` itself.
     *
     * Event fired if the 'reset' button in `P13nDialog` is clicked.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachReset(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getPanels panels} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindPanels(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the panels in the aggregation {@link #getPanels panels}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyPanels(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:cancel cancel} event of this `sap.m.P13nDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachCancel(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:ok ok} event of this `sap.m.P13nDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachOk(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:reset reset} event of this `sap.m.P13nDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachReset(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:cancel cancel} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireCancel(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:ok ok} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireOk(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:reset reset} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireReset(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getInitialVisiblePanelType initialVisiblePanelType}.
     *
     * This property determines which panel is initially shown when dialog is opened. If not defined then the
     * first visible panel of `panels` aggregation is taken. Setting value after the dialog is opened has no
     * effect anymore. Due to extensibility reason the type should be `string`. So it is feasible to add a custom
     * panel without expanding the type.
     *
     *
     * @returns Value of property `initialVisiblePanelType`
     */
    getInitialVisiblePanelType(): string;
    /**
     * Gets content of aggregation {@link #getPanels panels}.
     *
     * The dialog panels displayed in the dialog.
     */
    getPanels(): P13nPanel[];
    /**
     * Gets current value of property {@link #getShowReset showReset}.
     *
     * This property determines whether the 'Restore' button is shown inside the dialog. If this property is
     * set to true, clicking the 'Reset' button will trigger the `reset` event sending a notification that model
     * data must be reset.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showReset`
     */
    getShowReset(): boolean;
    /**
     * Gets current value of property {@link #getShowResetEnabled showResetEnabled}.
     *
     * This property determines whether the 'Restore' button is enabled and is taken into account only if `showReset`
     * is set to `true`.
     *
     * Default value is `false`.
     *
     * @since 1.36.0
     *
     * @returns Value of property `showResetEnabled`
     */
    getShowResetEnabled(): boolean;
    /**
     * Gets current value of property {@link #getValidationExecutor validationExecutor}.
     *
     * Calls the validation listener once all panel-relevant validation checks have been done. This callback
     * function is called in order to perform cross-model validation checks.
     *
     *
     * @returns Value of property `validationExecutor`
     */
    getValidationExecutor(): object;
    /**
     * Returns visible panel.
     *
     *
     * @returns panel
     */
    getVisiblePanel(): P13nPanel | null;
    /**
     * Checks for the provided `sap.m.P13nPanel` in the aggregation {@link #getPanels panels}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfPanel(
      /**
       * The panel whose index is looked for
       */
      oPanel: P13nPanel
    ): int;
    /**
     * Inserts a panel into the aggregation {@link #getPanels panels}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertPanel(
      /**
       * The panel to insert; if empty, nothing is inserted
       */
      oPanel: P13nPanel,
      /**
       * The `0`-based index the panel should be inserted at; for a negative value of `iIndex`, the panel is inserted
       * at position 0; for a value greater than the current size of the aggregation, the panel is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getPanels panels}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllPanels(): P13nPanel[];
    /**
     * Removes a panel from the aggregation {@link #getPanels panels}.
     *
     *
     * @returns The removed panel or `null`
     */
    removePanel(
      /**
       * The panel to remove or its index or id
       */
      vPanel: int | string | P13nPanel
    ): P13nPanel | null;
    /**
     * Sets a new value for property {@link #getInitialVisiblePanelType initialVisiblePanelType}.
     *
     * This property determines which panel is initially shown when dialog is opened. If not defined then the
     * first visible panel of `panels` aggregation is taken. Setting value after the dialog is opened has no
     * effect anymore. Due to extensibility reason the type should be `string`. So it is feasible to add a custom
     * panel without expanding the type.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInitialVisiblePanelType(
      /**
       * New value for property `initialVisiblePanelType`
       */
      sInitialVisiblePanelType?: string
    ): this;
    /**
     * Sets a new value for property {@link #getShowReset showReset}.
     *
     * This property determines whether the 'Restore' button is shown inside the dialog. If this property is
     * set to true, clicking the 'Reset' button will trigger the `reset` event sending a notification that model
     * data must be reset.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowReset(
      /**
       * New value for property `showReset`
       */
      bShowReset?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowResetEnabled showResetEnabled}.
     *
     * This property determines whether the 'Restore' button is enabled and is taken into account only if `showReset`
     * is set to `true`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.36.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowResetEnabled(
      /**
       * New value for property `showResetEnabled`
       */
      bShowResetEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getValidationExecutor validationExecutor}.
     *
     * Calls the validation listener once all panel-relevant validation checks have been done. This callback
     * function is called in order to perform cross-model validation checks.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValidationExecutor(
      /**
       * New value for property `validationExecutor`
       */
      oValidationExecutor?: object
    ): this;
    /**
     * Unbinds aggregation {@link #getPanels panels} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindPanels(): this;
  }
  /**
   * Describes the settings that can be provided to the P13nDialog constructor.
   *
   * @deprecated As of version 1.98. Use the {@link sap.m.p13n.Popup} instead.
   */
  export interface $P13nDialogSettings extends $DialogSettings {
    /**
     * This property determines which panel is initially shown when dialog is opened. If not defined then the
     * first visible panel of `panels` aggregation is taken. Setting value after the dialog is opened has no
     * effect anymore. Due to extensibility reason the type should be `string`. So it is feasible to add a custom
     * panel without expanding the type.
     */
    initialVisiblePanelType?: string | PropertyBindingInfo;

    /**
     * This property determines whether the 'Restore' button is shown inside the dialog. If this property is
     * set to true, clicking the 'Reset' button will trigger the `reset` event sending a notification that model
     * data must be reset.
     */
    showReset?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This property determines whether the 'Restore' button is enabled and is taken into account only if `showReset`
     * is set to `true`.
     *
     * @since 1.36.0
     */
    showResetEnabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Calls the validation listener once all panel-relevant validation checks have been done. This callback
     * function is called in order to perform cross-model validation checks.
     */
    validationExecutor?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * The dialog panels displayed in the dialog.
     */
    panels?: P13nPanel[] | P13nPanel | AggregationBindingInfo | `{${string}}`;

    /**
     * Event fired if the 'ok' button in `P13nDialog` is clicked.
     */
    ok?: (oEvent: Event) => void;

    /**
     * Event fired if the 'cancel' button in `P13nDialog` is clicked.
     */
    cancel?: (oEvent: Event) => void;

    /**
     * Event fired if the 'reset' button in `P13nDialog` is clicked.
     */
    reset?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the P13nDialog#cancel event.
   */
  export interface P13nDialog$CancelEventParameters {}

  /**
   * Event object of the P13nDialog#cancel event.
   */
  export type P13nDialog$CancelEvent = Event<
    P13nDialog$CancelEventParameters,
    P13nDialog
  >;

  /**
   * Parameters of the P13nDialog#ok event.
   */
  export interface P13nDialog$OkEventParameters {}

  /**
   * Event object of the P13nDialog#ok event.
   */
  export type P13nDialog$OkEvent = Event<
    P13nDialog$OkEventParameters,
    P13nDialog
  >;

  /**
   * Parameters of the P13nDialog#reset event.
   */
  export interface P13nDialog$ResetEventParameters {}

  /**
   * Event object of the P13nDialog#reset event.
   */
  export type P13nDialog$ResetEvent = Event<
    P13nDialog$ResetEventParameters,
    P13nDialog
  >;
}

declare module "sap/m/P13nDimMeasureItem" {
  import { default as Item, $ItemSettings } from "sap/ui/core/Item";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Type for `columnsItems` aggregation in `P13nDimMeasurePanel` control.
   *
   * @since 1.34.0
   * @deprecated As of version 1.120. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export default class P13nDimMeasureItem extends Item {
    /**
     * Constructor for a new P13nDimMeasureItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nDimMeasureItemSettings
    );
    /**
     * Constructor for a new P13nDimMeasureItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nDimMeasureItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.P13nDimMeasureItem with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Item.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, P13nDimMeasureItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.P13nDimMeasureItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getColumnKey columnKey}.
     *
     * Specifies the unique chart column key. In this context a column refers to dimensions or measures of a
     * chart.
     *
     *
     * @returns Value of property `columnKey`
     */
    getColumnKey(): string;
    /**
     * Gets current value of property {@link #getIndex index}.
     *
     * Specifies the order of visible dimensions or measures of a chart.
     *
     * Default value is `-1`.
     *
     *
     * @returns Value of property `index`
     */
    getIndex(): int;
    /**
     * Gets current value of property {@link #getRole role}.
     *
     * Specifies the role of dimensions or measures. The role determines how dimensions and measures influence
     * the chart.
     *
     *
     * @returns Value of property `role`
     */
    getRole(): string;
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * Specifies the visibility of dimensions or measures.
     *
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Sets a new value for property {@link #getColumnKey columnKey}.
     *
     * Specifies the unique chart column key. In this context a column refers to dimensions or measures of a
     * chart.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setColumnKey(
      /**
       * New value for property `columnKey`
       */
      sColumnKey: string
    ): this;
    /**
     * Sets a new value for property {@link #getIndex index}.
     *
     * Specifies the order of visible dimensions or measures of a chart.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `-1`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIndex(
      /**
       * New value for property `index`
       */
      iIndex?: int
    ): this;
    /**
     * Sets a new value for property {@link #getRole role}.
     *
     * Specifies the role of dimensions or measures. The role determines how dimensions and measures influence
     * the chart.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRole(
      /**
       * New value for property `role`
       */
      sRole: string
    ): this;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * Specifies the visibility of dimensions or measures.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the P13nDimMeasureItem constructor.
   *
   * @deprecated As of version 1.120. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export interface $P13nDimMeasureItemSettings extends $ItemSettings {
    /**
     * Specifies the unique chart column key. In this context a column refers to dimensions or measures of a
     * chart.
     */
    columnKey?: string | PropertyBindingInfo;

    /**
     * Specifies the order of visible dimensions or measures of a chart.
     */
    index?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the visibility of dimensions or measures.
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the role of dimensions or measures. The role determines how dimensions and measures influence
     * the chart.
     */
    role?: string | PropertyBindingInfo;
  }
}

declare module "sap/m/P13nDimMeasurePanel" {
  import { default as P13nPanel, $P13nPanelSettings } from "sap/m/P13nPanel";

  import Item from "sap/ui/core/Item";

  import P13nDimMeasureItem from "sap/m/P13nDimMeasureItem";

  import Event from "sap/ui/base/Event";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * The P13nDimMeasurePanel control is used to define chart-specific settings like chart type, the visibility,
   * the order and roles of dimensions and measures for table personalization.
   *
   * @since 1.34.0
   * @deprecated As of version 1.120. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export default class P13nDimMeasurePanel extends P13nPanel {
    /**
     * Constructor for a new P13nDimMeasurePanel.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nDimMeasurePanelSettings
    );
    /**
     * Constructor for a new P13nDimMeasurePanel.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nDimMeasurePanelSettings
    );

    /**
     * Creates a new subclass of class sap.m.P13nDimMeasurePanel with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.P13nPanel.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, P13nDimMeasurePanel>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.P13nDimMeasurePanel.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some availableChartType to the aggregation {@link #getAvailableChartTypes availableChartTypes}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAvailableChartType(
      /**
       * The availableChartType to add; if empty, nothing is inserted
       */
      oAvailableChartType: Item
    ): this;
    /**
     * Adds some dimMeasureItem to the aggregation {@link #getDimMeasureItems dimMeasureItems}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addDimMeasureItem(
      /**
       * The dimMeasureItem to add; if empty, nothing is inserted
       */
      oDimMeasureItem: P13nDimMeasureItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:changeChartType changeChartType} event of this
     * `sap.m.P13nDimMeasurePanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nDimMeasurePanel` itself.
     *
     * Event raised when a `ChartType` has been updated.
     *
     * @since 1.50.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChangeChartType(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nDimMeasurePanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:changeChartType changeChartType} event of this
     * `sap.m.P13nDimMeasurePanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nDimMeasurePanel` itself.
     *
     * Event raised when a `ChartType` has been updated.
     *
     * @since 1.50.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChangeChartType(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nDimMeasurePanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:changeDimMeasureItems changeDimMeasureItems }
     * event of this `sap.m.P13nDimMeasurePanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nDimMeasurePanel` itself.
     *
     * Event raised when one or more `DimMeasureItems` has been updated. Aggregation `DimMeasureItems` should
     * be updated outside...
     *
     * @since 1.50.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChangeDimMeasureItems(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nDimMeasurePanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:changeDimMeasureItems changeDimMeasureItems }
     * event of this `sap.m.P13nDimMeasurePanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nDimMeasurePanel` itself.
     *
     * Event raised when one or more `DimMeasureItems` has been updated. Aggregation `DimMeasureItems` should
     * be updated outside...
     *
     * @since 1.50.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChangeDimMeasureItems(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nDimMeasurePanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getDimMeasureItems dimMeasureItems} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindDimMeasureItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the availableChartTypes in the aggregation {@link #getAvailableChartTypes availableChartTypes}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyAvailableChartTypes(): this;
    /**
     * Destroys all the dimMeasureItems in the aggregation {@link #getDimMeasureItems dimMeasureItems}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyDimMeasureItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:changeChartType changeChartType} event of
     * this `sap.m.P13nDimMeasurePanel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.50.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChangeChartType(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:changeDimMeasureItems changeDimMeasureItems }
     * event of this `sap.m.P13nDimMeasurePanel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.50.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChangeDimMeasureItems(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:changeChartType changeChartType} to attached listeners.
     *
     * @since 1.50.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChangeChartType(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:changeDimMeasureItems changeDimMeasureItems} to attached listeners.
     *
     * @since 1.50.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChangeDimMeasureItems(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets content of aggregation {@link #getAvailableChartTypes availableChartTypes}.
     *
     * Specifies available chart types.
     */
    getAvailableChartTypes(): Item[];
    /**
     * Gets current value of property {@link #getChartTypeKey chartTypeKey}.
     *
     * Specifies a chart type key.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `chartTypeKey`
     */
    getChartTypeKey(): string;
    /**
     * Gets content of aggregation {@link #getDimMeasureItems dimMeasureItems}.
     *
     * List of columns that has been changed.
     */
    getDimMeasureItems(): P13nDimMeasureItem[];
    /**
     * Checks for the provided `sap.ui.core.Item` in the aggregation {@link #getAvailableChartTypes availableChartTypes}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfAvailableChartType(
      /**
       * The availableChartType whose index is looked for
       */
      oAvailableChartType: Item
    ): int;
    /**
     * Checks for the provided `sap.m.P13nDimMeasureItem` in the aggregation {@link #getDimMeasureItems dimMeasureItems}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfDimMeasureItem(
      /**
       * The dimMeasureItem whose index is looked for
       */
      oDimMeasureItem: P13nDimMeasureItem
    ): int;
    /**
     * Inserts a availableChartType into the aggregation {@link #getAvailableChartTypes availableChartTypes}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertAvailableChartType(
      /**
       * The availableChartType to insert; if empty, nothing is inserted
       */
      oAvailableChartType: Item,
      /**
       * The `0`-based index the availableChartType should be inserted at; for a negative value of `iIndex`, the
       * availableChartType is inserted at position 0; for a value greater than the current size of the aggregation,
       * the availableChartType is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a dimMeasureItem into the aggregation {@link #getDimMeasureItems dimMeasureItems}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertDimMeasureItem(
      /**
       * The dimMeasureItem to insert; if empty, nothing is inserted
       */
      oDimMeasureItem: P13nDimMeasureItem,
      /**
       * The `0`-based index the dimMeasureItem should be inserted at; for a negative value of `iIndex`, the dimMeasureItem
       * is inserted at position 0; for a value greater than the current size of the aggregation, the dimMeasureItem
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getAvailableChartTypes availableChartTypes}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAvailableChartTypes(): Item[];
    /**
     * Removes all the controls from the aggregation {@link #getDimMeasureItems dimMeasureItems}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllDimMeasureItems(): P13nDimMeasureItem[];
    /**
     * Removes a availableChartType from the aggregation {@link #getAvailableChartTypes availableChartTypes}.
     *
     *
     * @returns The removed availableChartType or `null`
     */
    removeAvailableChartType(
      /**
       * The availableChartType to remove or its index or id
       */
      vAvailableChartType: int | string | Item
    ): Item | null;
    /**
     * Removes a dimMeasureItem from the aggregation {@link #getDimMeasureItems dimMeasureItems}.
     *
     *
     * @returns The removed dimMeasureItem or `null`
     */
    removeDimMeasureItem(
      /**
       * The dimMeasureItem to remove or its index or id
       */
      vDimMeasureItem: int | string | P13nDimMeasureItem
    ): P13nDimMeasureItem | null;
    /**
     * Sets a new value for property {@link #getChartTypeKey chartTypeKey}.
     *
     * Specifies a chart type key.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setChartTypeKey(
      /**
       * New value for property `chartTypeKey`
       */
      sChartTypeKey?: string
    ): this;
    /**
     * Unbinds aggregation {@link #getDimMeasureItems dimMeasureItems} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindDimMeasureItems(): this;
  }
  /**
   * Describes the settings that can be provided to the P13nDimMeasurePanel constructor.
   *
   * @deprecated As of version 1.120. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export interface $P13nDimMeasurePanelSettings extends $P13nPanelSettings {
    /**
     * Specifies a chart type key.
     */
    chartTypeKey?: string | PropertyBindingInfo;

    /**
     * List of columns that has been changed.
     */
    dimMeasureItems?:
      | P13nDimMeasureItem[]
      | P13nDimMeasureItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Specifies available chart types.
     */
    availableChartTypes?:
      | Item[]
      | Item
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Event raised when one or more `DimMeasureItems` has been updated. Aggregation `DimMeasureItems` should
     * be updated outside...
     *
     * @since 1.50.0
     */
    changeDimMeasureItems?: (oEvent: Event) => void;

    /**
     * Event raised when a `ChartType` has been updated.
     *
     * @since 1.50.0
     */
    changeChartType?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the P13nDimMeasurePanel#changeChartType event.
   */
  export interface P13nDimMeasurePanel$ChangeChartTypeEventParameters {}

  /**
   * Event object of the P13nDimMeasurePanel#changeChartType event.
   */
  export type P13nDimMeasurePanel$ChangeChartTypeEvent = Event<
    P13nDimMeasurePanel$ChangeChartTypeEventParameters,
    P13nDimMeasurePanel
  >;

  /**
   * Parameters of the P13nDimMeasurePanel#changeDimMeasureItems event.
   */
  export interface P13nDimMeasurePanel$ChangeDimMeasureItemsEventParameters {}

  /**
   * Event object of the P13nDimMeasurePanel#changeDimMeasureItems event.
   */
  export type P13nDimMeasurePanel$ChangeDimMeasureItemsEvent = Event<
    P13nDimMeasurePanel$ChangeDimMeasureItemsEventParameters,
    P13nDimMeasurePanel
  >;
}

declare module "sap/m/P13nFilterItem" {
  import { default as Item, $ItemSettings } from "sap/ui/core/Item";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Type for `filterItems` aggregation in P13nFilterPanel control.
   *
   * @since 1.26.0
   * @deprecated As of version 1.124. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export default class P13nFilterItem extends Item {
    /**
     * Constructor for a new P13nFilterItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nFilterItemSettings
    );
    /**
     * Constructor for a new P13nFilterItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nFilterItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.P13nFilterItem with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Item.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, P13nFilterItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.P13nFilterItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getColumnKey columnKey}.
     *
     * key of the column
     *
     *
     * @returns Value of property `columnKey`
     */
    getColumnKey(): string;
    /**
     * Gets current value of property {@link #getExclude exclude}.
     *
     * defines if the filter is an include or exclude filter item
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `exclude`
     */
    getExclude(): boolean;
    /**
     * Gets current value of property {@link #getOperation operation}.
     *
     * sap.m.P13nConditionOperation
     *
     *
     * @returns Value of property `operation`
     */
    getOperation(): string;
    /**
     * Gets current value of property {@link #getValue1 value1}.
     *
     * value of the filter
     *
     *
     * @returns Value of property `value1`
     */
    getValue1(): string;
    /**
     * Gets current value of property {@link #getValue2 value2}.
     *
     * to value of the between filter
     *
     *
     * @returns Value of property `value2`
     */
    getValue2(): string;
    /**
     * Sets a new value for property {@link #getColumnKey columnKey}.
     *
     * key of the column
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setColumnKey(
      /**
       * New value for property `columnKey`
       */
      sColumnKey?: string
    ): this;
    /**
     * Sets a new value for property {@link #getExclude exclude}.
     *
     * defines if the filter is an include or exclude filter item
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setExclude(
      /**
       * New value for property `exclude`
       */
      bExclude?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getOperation operation}.
     *
     * sap.m.P13nConditionOperation
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setOperation(
      /**
       * New value for property `operation`
       */
      sOperation?: string
    ): this;
    /**
     * Sets a new value for property {@link #getValue1 value1}.
     *
     * value of the filter
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValue1(
      /**
       * New value for property `value1`
       */
      sValue1?: string
    ): this;
    /**
     * Sets a new value for property {@link #getValue2 value2}.
     *
     * to value of the between filter
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValue2(
      /**
       * New value for property `value2`
       */
      sValue2?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the P13nFilterItem constructor.
   *
   * @deprecated As of version 1.124. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export interface $P13nFilterItemSettings extends $ItemSettings {
    /**
     * sap.m.P13nConditionOperation
     */
    operation?: string | PropertyBindingInfo;

    /**
     * value of the filter
     */
    value1?: string | PropertyBindingInfo;

    /**
     * to value of the between filter
     */
    value2?: string | PropertyBindingInfo;

    /**
     * key of the column
     */
    columnKey?: string | PropertyBindingInfo;

    /**
     * defines if the filter is an include or exclude filter item
     */
    exclude?: boolean | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/P13nFilterPanel" {
  import { default as P13nPanel, $P13nPanelSettings } from "sap/m/P13nPanel";

  import P13nFilterItem from "sap/m/P13nFilterItem";

  import Event from "sap/ui/base/Event";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import { P13nConditionOperation } from "sap/m/library";

  import MessageStrip from "sap/m/MessageStrip";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * The P13nFilterPanel control is used to define filter-specific settings for table personalization.
   *
   * @since 1.26.0
   * @deprecated As of version 1.124. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export default class P13nFilterPanel extends P13nPanel {
    /**
     * Constructor for a new P13nFilterPanel.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nFilterPanelSettings
    );
    /**
     * Constructor for a new P13nFilterPanel.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nFilterPanelSettings
    );

    /**
     * Creates a new subclass of class sap.m.P13nFilterPanel with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.P13nPanel.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, P13nFilterPanel>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.P13nFilterPanel.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some filterItem to the aggregation {@link #getFilterItems filterItems}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addFilterItem(
      /**
       * The filterItem to add; if empty, nothing is inserted
       */
      oFilterItem: P13nFilterItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:addFilterItem addFilterItem} event of this `sap.m.P13nFilterPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nFilterPanel` itself.
     *
     * Event raised if a filter item has been added.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAddFilterItem(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nFilterPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:addFilterItem addFilterItem} event of this `sap.m.P13nFilterPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nFilterPanel` itself.
     *
     * Event raised if a filter item has been added.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAddFilterItem(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nFilterPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:filterItemChanged filterItemChanged} event of
     * this `sap.m.P13nFilterPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nFilterPanel` itself.
     *
     * Event raised if a filter item has been changed. reason can be added, updated or removed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFilterItemChanged(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: P13nFilterPanel$FilterItemChangedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nFilterPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:filterItemChanged filterItemChanged} event of
     * this `sap.m.P13nFilterPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nFilterPanel` itself.
     *
     * Event raised if a filter item has been changed. reason can be added, updated or removed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFilterItemChanged(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: P13nFilterPanel$FilterItemChangedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nFilterPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:removeFilterItem removeFilterItem} event of
     * this `sap.m.P13nFilterPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nFilterPanel` itself.
     *
     * Event raised if a filter item has been removed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachRemoveFilterItem(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nFilterPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:removeFilterItem removeFilterItem} event of
     * this `sap.m.P13nFilterPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nFilterPanel` itself.
     *
     * Event raised if a filter item has been removed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachRemoveFilterItem(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nFilterPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:updateFilterItem updateFilterItem} event of
     * this `sap.m.P13nFilterPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nFilterPanel` itself.
     *
     * Event raised if a filter item has been updated.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUpdateFilterItem(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nFilterPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:updateFilterItem updateFilterItem} event of
     * this `sap.m.P13nFilterPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nFilterPanel` itself.
     *
     * Event raised if a filter item has been updated.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUpdateFilterItem(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nFilterPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getFilterItems filterItems} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindFilterItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the filterItems in the aggregation {@link #getFilterItems filterItems}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyFilterItems(): this;
    /**
     * Destroys the messageStrip in the aggregation {@link #getMessageStrip messageStrip}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyMessageStrip(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:addFilterItem addFilterItem} event of this
     * `sap.m.P13nFilterPanel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAddFilterItem(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:filterItemChanged filterItemChanged} event
     * of this `sap.m.P13nFilterPanel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachFilterItemChanged(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: P13nFilterPanel$FilterItemChangedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:removeFilterItem removeFilterItem} event of
     * this `sap.m.P13nFilterPanel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachRemoveFilterItem(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:updateFilterItem updateFilterItem} event of
     * this `sap.m.P13nFilterPanel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUpdateFilterItem(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:addFilterItem addFilterItem} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAddFilterItem(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:filterItemChanged filterItemChanged} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireFilterItemChanged(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: P13nFilterPanel$FilterItemChangedEventParameters
    ): this;
    /**
     * Fires event {@link #event:removeFilterItem removeFilterItem} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireRemoveFilterItem(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:updateFilterItem updateFilterItem} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUpdateFilterItem(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Returns the array of conditions.
     *
     *
     * @returns array with filter conditions
     */
    getConditions(): FilterConditionOperations[];
    /**
     * Gets current value of property {@link #getContainerQuery containerQuery}.
     *
     * Defines if the `mediaQuery` or a `ContainerResize` is used for layout update. If the `ConditionPanel`
     * is used in a dialog, the property must be set to `true`.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `containerQuery`
     */
    getContainerQuery(): boolean;
    /**
     * Gets current value of property {@link #getEnableEmptyOperations enableEmptyOperations}.
     *
     * Should empty operation be enabled for certain data types. This is also based on their nullable setting.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `enableEmptyOperations`
     */
    getEnableEmptyOperations(): boolean;
    /**
     * Getter for the exclude operations.
     *
     *
     * @returns array of operations [`sap.m.P13nConditionOperation.BT`, `sap.m.P13nConditionOperation.EQ`]
     */
    getExcludeOperations(
      /**
       * the type for which the operations are defined
       */
      sType: string
    ): P13nConditionOperation[];
    /**
     * Gets content of aggregation {@link #getFilterItems filterItems}.
     *
     * Defines filter items.
     */
    getFilterItems(): P13nFilterItem[];
    /**
     * Getter for the include operations.
     *
     *
     * @returns array of operations [`sap.m.P13nConditionOperation.BT`, `sap.m.P13nConditionOperation.EQ`]
     */
    getIncludeOperations(
      /**
       * for which the operations are defined
       */
      sType: string
    ): P13nConditionOperation;
    /**
     * Gets current value of property {@link #getLayoutMode layoutMode}.
     *
     * Can be used to control the layout behavior. Default is "" which will automatically change the layout.
     * With "Desktop", "Table" or"Phone" you can set a fixed layout.
     *
     *
     * @returns Value of property `layoutMode`
     */
    getLayoutMode(): string;
    /**
     * Gets current value of property {@link #getMaxExcludes maxExcludes}.
     *
     * Defines the maximum number of exclude filters.
     *
     * Default value is `'-1'`.
     *
     *
     * @returns Value of property `maxExcludes`
     */
    getMaxExcludes(): string;
    /**
     * Gets current value of property {@link #getMaxIncludes maxIncludes}.
     *
     * Defines the maximum number of include filters.
     *
     * Default value is `'-1'`.
     *
     *
     * @returns Value of property `maxIncludes`
     */
    getMaxIncludes(): string;
    /**
     * Gets content of aggregation {@link #getMessageStrip messageStrip}.
     *
     * Defines an optional message strip to be displayed in the content area
     */
    getMessageStrip(): MessageStrip;
    /**
     * Checks for the provided `sap.m.P13nFilterItem` in the aggregation {@link #getFilterItems filterItems}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfFilterItem(
      /**
       * The filterItem whose index is looked for
       */
      oFilterItem: P13nFilterItem
    ): int;
    /**
     * Inserts a filterItem into the aggregation {@link #getFilterItems filterItems}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertFilterItem(
      /**
       * The filterItem to insert; if empty, nothing is inserted
       */
      oFilterItem: P13nFilterItem,
      /**
       * The `0`-based index the filterItem should be inserted at; for a negative value of `iIndex`, the filterItem
       * is inserted at position 0; for a value greater than the current size of the aggregation, the filterItem
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getFilterItems filterItems}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllFilterItems(): P13nFilterItem[];
    /**
     * Removes a filterItem from the aggregation {@link #getFilterItems filterItems}.
     *
     *
     * @returns The removed filterItem or `null`
     */
    removeFilterItem(
      /**
       * The filterItem to remove or its index or id
       */
      vFilterItem: int | string | P13nFilterItem
    ): P13nFilterItem | null;
    /**
     * Removes all invalid conditions.
     *
     * @since 1.28
     */
    removeInvalidConditions(): void;
    /**
     * Removes all errors and warnings states from of all filter conditions.
     *
     * @since 1.28
     */
    removeValidationErrors(): void;
    /**
     * Sets the array of conditions.
     *
     *
     * @returns this for chaining
     */
    setConditions(
      /**
       * the complete list of conditions
       */
      aConditions: FilterConditionOperations[]
    ): this;
    /**
     * Sets a new value for property {@link #getContainerQuery containerQuery}.
     *
     * Defines if the `mediaQuery` or a `ContainerResize` is used for layout update. If the `ConditionPanel`
     * is used in a dialog, the property must be set to `true`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContainerQuery(
      /**
       * New value for property `containerQuery`
       */
      bContainerQuery?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnableEmptyOperations enableEmptyOperations}.
     *
     * Should empty operation be enabled for certain data types. This is also based on their nullable setting.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableEmptyOperations(
      /**
       * New value for property `enableEmptyOperations`
       */
      bEnableEmptyOperations?: boolean
    ): this;
    /**
     * Setter for the supported exclude operations array.
     */
    setExcludeOperations(
      /**
       * array of operations [`sap.m.P13nConditionOperation.BT`, `sap.m.P13nConditionOperation.EQ`]
       */
      aOperation: Array<
        P13nConditionOperation | keyof typeof P13nConditionOperation
      >,
      /**
       * the type for which the operations are defined
       */
      sType: string
    ): void;
    /**
     * Setter for the supported Include operations array.
     */
    setIncludeOperations(
      /**
       * array of operations [`sap.m.P13nConditionOperation.BT`, `sap.m.P13nConditionOperation.EQ`]
       */
      aOperation: Array<
        P13nConditionOperation | keyof typeof P13nConditionOperation
      >,
      /**
       * the type for which the operations are defined
       */
      sType: string
    ): void;
    /**
     * Sets a new value for property {@link #getLayoutMode layoutMode}.
     *
     * Can be used to control the layout behavior. Default is "" which will automatically change the layout.
     * With "Desktop", "Table" or"Phone" you can set a fixed layout.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLayoutMode(
      /**
       * New value for property `layoutMode`
       */
      sLayoutMode?: string
    ): this;
    /**
     * Sets a new value for property {@link #getMaxExcludes maxExcludes}.
     *
     * Defines the maximum number of exclude filters.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `'-1'`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxExcludes(
      /**
       * New value for property `maxExcludes`
       */
      sMaxExcludes?: string
    ): this;
    /**
     * Sets a new value for property {@link #getMaxIncludes maxIncludes}.
     *
     * Defines the maximum number of include filters.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `'-1'`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxIncludes(
      /**
       * New value for property `maxIncludes`
       */
      sMaxIncludes?: string
    ): this;
    /**
     * Sets the aggregated {@link #getMessageStrip messageStrip}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMessageStrip(
      /**
       * The messageStrip to set
       */
      oMessageStrip: MessageStrip
    ): this;
    /**
     * Unbinds aggregation {@link #getFilterItems filterItems} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindFilterItems(): this;
    /**
     * Checks if the entered and modified conditions are correct, marks invalid fields in yellow (warning).
     *
     *
     * @returns `True` if all conditions are valid, `false` otherwise.
     */
    validateConditions(): boolean;
  }
  /**
   * @deprecated As of version 1.124. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export type FilterConditionOperations = {
    exclude: undefined | boolean;

    key: string;

    keyField: string;

    operation: P13nConditionOperation | keyof typeof P13nConditionOperation;

    showIfGrouped: boolean;

    text: string;

    value1: string;

    value2: string;
  };

  /**
   * Describes the settings that can be provided to the P13nFilterPanel constructor.
   *
   * @deprecated As of version 1.124. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export interface $P13nFilterPanelSettings extends $P13nPanelSettings {
    /**
     * Defines the maximum number of include filters.
     */
    maxIncludes?: string | PropertyBindingInfo;

    /**
     * Defines the maximum number of exclude filters.
     */
    maxExcludes?: string | PropertyBindingInfo;

    /**
     * Defines if the `mediaQuery` or a `ContainerResize` is used for layout update. If the `ConditionPanel`
     * is used in a dialog, the property must be set to `true`.
     */
    containerQuery?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Can be used to control the layout behavior. Default is "" which will automatically change the layout.
     * With "Desktop", "Table" or"Phone" you can set a fixed layout.
     */
    layoutMode?: string | PropertyBindingInfo;

    /**
     * Should empty operation be enabled for certain data types. This is also based on their nullable setting.
     */
    enableEmptyOperations?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines filter items.
     */
    filterItems?:
      | P13nFilterItem[]
      | P13nFilterItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Defines an optional message strip to be displayed in the content area
     */
    messageStrip?: MessageStrip;

    /**
     * Event raised if a filter item has been added.
     */
    addFilterItem?: (oEvent: Event) => void;

    /**
     * Event raised if a filter item has been removed.
     */
    removeFilterItem?: (oEvent: Event) => void;

    /**
     * Event raised if a filter item has been updated.
     */
    updateFilterItem?: (oEvent: Event) => void;

    /**
     * Event raised if a filter item has been changed. reason can be added, updated or removed.
     */
    filterItemChanged?: (
      oEvent: P13nFilterPanel$FilterItemChangedEvent
    ) => void;
  }

  /**
   * Parameters of the P13nFilterPanel#addFilterItem event.
   */
  export interface P13nFilterPanel$AddFilterItemEventParameters {}

  /**
   * Event object of the P13nFilterPanel#addFilterItem event.
   */
  export type P13nFilterPanel$AddFilterItemEvent = Event<
    P13nFilterPanel$AddFilterItemEventParameters,
    P13nFilterPanel
  >;

  /**
   * Parameters of the P13nFilterPanel#filterItemChanged event.
   */
  export interface P13nFilterPanel$FilterItemChangedEventParameters {
    /**
     * reason for the changeFilterItem event. Value can be added, updated or removed.
     */
    reason?: string;

    /**
     * key of the changed filterItem
     */
    key?: string;

    /**
     * index of the changed filterItem
     */
    index?: int;

    /**
     * JSON object of the changed filterItem instance (in case of reason=="removed" the itemData parameter does
     * not exist)
     */
    itemData?: object;
  }

  /**
   * Event object of the P13nFilterPanel#filterItemChanged event.
   */
  export type P13nFilterPanel$FilterItemChangedEvent = Event<
    P13nFilterPanel$FilterItemChangedEventParameters,
    P13nFilterPanel
  >;

  /**
   * Parameters of the P13nFilterPanel#removeFilterItem event.
   */
  export interface P13nFilterPanel$RemoveFilterItemEventParameters {}

  /**
   * Event object of the P13nFilterPanel#removeFilterItem event.
   */
  export type P13nFilterPanel$RemoveFilterItemEvent = Event<
    P13nFilterPanel$RemoveFilterItemEventParameters,
    P13nFilterPanel
  >;

  /**
   * Parameters of the P13nFilterPanel#updateFilterItem event.
   */
  export interface P13nFilterPanel$UpdateFilterItemEventParameters {}

  /**
   * Event object of the P13nFilterPanel#updateFilterItem event.
   */
  export type P13nFilterPanel$UpdateFilterItemEvent = Event<
    P13nFilterPanel$UpdateFilterItemEventParameters,
    P13nFilterPanel
  >;
}

declare module "sap/m/P13nGroupItem" {
  import { default as Item, $ItemSettings } from "sap/ui/core/Item";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Type for `groupItems` aggregation in P13nGroupPanel control.
   *
   * @since 1.28.0
   * @deprecated As of version 1.120. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export default class P13nGroupItem extends Item {
    /**
     * Constructor for a new P13nGroupItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nGroupItemSettings
    );
    /**
     * Constructor for a new P13nGroupItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nGroupItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.P13nGroupItem with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Item.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, P13nGroupItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.P13nGroupItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getColumnKey columnKey}.
     *
     * key of the column
     *
     *
     * @returns Value of property `columnKey`
     */
    getColumnKey(): string;
    /**
     * Gets current value of property {@link #getOperation operation}.
     *
     * sap.m.P13nConditionOperation
     *
     *
     * @returns Value of property `operation`
     */
    getOperation(): string;
    /**
     * Gets current value of property {@link #getShowIfGrouped showIfGrouped}.
     *
     * make the grouped column as normalcolumn visible
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showIfGrouped`
     */
    getShowIfGrouped(): boolean;
    /**
     * Sets a new value for property {@link #getColumnKey columnKey}.
     *
     * key of the column
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setColumnKey(
      /**
       * New value for property `columnKey`
       */
      sColumnKey?: string
    ): this;
    /**
     * Sets a new value for property {@link #getOperation operation}.
     *
     * sap.m.P13nConditionOperation
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setOperation(
      /**
       * New value for property `operation`
       */
      sOperation?: string
    ): this;
    /**
     * Sets a new value for property {@link #getShowIfGrouped showIfGrouped}.
     *
     * make the grouped column as normalcolumn visible
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowIfGrouped(
      /**
       * New value for property `showIfGrouped`
       */
      bShowIfGrouped?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the P13nGroupItem constructor.
   *
   * @deprecated As of version 1.120. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export interface $P13nGroupItemSettings extends $ItemSettings {
    /**
     * sap.m.P13nConditionOperation
     */
    operation?: string | PropertyBindingInfo;

    /**
     * key of the column
     */
    columnKey?: string | PropertyBindingInfo;

    /**
     * make the grouped column as normalcolumn visible
     */
    showIfGrouped?: boolean | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/P13nGroupPanel" {
  import { default as P13nPanel, $P13nPanelSettings } from "sap/m/P13nPanel";

  import P13nGroupItem from "sap/m/P13nGroupItem";

  import Event from "sap/ui/base/Event";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * The P13nGroupPanel control is used to define group-specific settings for table personalization.
   *
   * @since 1.26.0
   * @deprecated As of version 1.98. Use the {@link sap.m.p13n.GroupPanel} instead.
   */
  export default class P13nGroupPanel extends P13nPanel {
    /**
     * Constructor for a new P13nGroupPanel.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nGroupPanelSettings
    );
    /**
     * Constructor for a new P13nGroupPanel.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nGroupPanelSettings
    );

    /**
     * Creates a new subclass of class sap.m.P13nGroupPanel with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.P13nPanel.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, P13nGroupPanel>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.P13nGroupPanel.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some groupItem to the aggregation {@link #getGroupItems groupItems}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addGroupItem(
      /**
       * The groupItem to add; if empty, nothing is inserted
       */
      oGroupItem: P13nGroupItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:addGroupItem addGroupItem} event of this `sap.m.P13nGroupPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nGroupPanel` itself.
     *
     * Event raised if a `GroupItem` has been added.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAddGroupItem(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nGroupPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:addGroupItem addGroupItem} event of this `sap.m.P13nGroupPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nGroupPanel` itself.
     *
     * Event raised if a `GroupItem` has been added.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAddGroupItem(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nGroupPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:removeGroupItem removeGroupItem} event of this
     * `sap.m.P13nGroupPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nGroupPanel` itself.
     *
     * Event raised if a `GroupItem` has been removed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachRemoveGroupItem(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nGroupPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:removeGroupItem removeGroupItem} event of this
     * `sap.m.P13nGroupPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nGroupPanel` itself.
     *
     * Event raised if a `GroupItem` has been removed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachRemoveGroupItem(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nGroupPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:updateGroupItem updateGroupItem} event of this
     * `sap.m.P13nGroupPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nGroupPanel` itself.
     *
     * Event raised if a `GroupItem` has been updated.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUpdateGroupItem(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nGroupPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:updateGroupItem updateGroupItem} event of this
     * `sap.m.P13nGroupPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nGroupPanel` itself.
     *
     * Event raised if a `GroupItem` has been updated.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUpdateGroupItem(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nGroupPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getGroupItems groupItems} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindGroupItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the groupItems in the aggregation {@link #getGroupItems groupItems}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyGroupItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:addGroupItem addGroupItem} event of this `sap.m.P13nGroupPanel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAddGroupItem(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:removeGroupItem removeGroupItem} event of
     * this `sap.m.P13nGroupPanel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachRemoveGroupItem(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:updateGroupItem updateGroupItem} event of
     * this `sap.m.P13nGroupPanel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUpdateGroupItem(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:addGroupItem addGroupItem} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAddGroupItem(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:removeGroupItem removeGroupItem} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireRemoveGroupItem(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:updateGroupItem updateGroupItem} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUpdateGroupItem(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getContainerQuery containerQuery}.
     *
     * Defines if `mediaQuery` or `ContainerResize` is used for a layout update. If `ConditionPanel` is used
     * in a dialog, the property must be set to true.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `containerQuery`
     */
    getContainerQuery(): boolean;
    /**
     * Gets content of aggregation {@link #getGroupItems groupItems}.
     *
     * Defined group items.
     */
    getGroupItems(): P13nGroupItem[];
    /**
     * Gets current value of property {@link #getLayoutMode layoutMode}.
     *
     * Can be used to control the layout behavior. Default is "" which will automatically change the layout.
     * With "Desktop", "Table" or "Phone" you can set a fixed layout.
     *
     *
     * @returns Value of property `layoutMode`
     */
    getLayoutMode(): string;
    /**
     * Gets current value of property {@link #getMaxGroups maxGroups}.
     *
     * Defines the maximum number of groups.
     *
     * Default value is `'-1'`.
     *
     *
     * @returns Value of property `maxGroups`
     */
    getMaxGroups(): string;
    /**
     * Checks for the provided `sap.m.P13nGroupItem` in the aggregation {@link #getGroupItems groupItems}. and
     * returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfGroupItem(
      /**
       * The groupItem whose index is looked for
       */
      oGroupItem: P13nGroupItem
    ): int;
    /**
     * Inserts a groupItem into the aggregation {@link #getGroupItems groupItems}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertGroupItem(
      /**
       * The groupItem to insert; if empty, nothing is inserted
       */
      oGroupItem: P13nGroupItem,
      /**
       * The `0`-based index the groupItem should be inserted at; for a negative value of `iIndex`, the groupItem
       * is inserted at position 0; for a value greater than the current size of the aggregation, the groupItem
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getGroupItems groupItems}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllGroupItems(): P13nGroupItem[];
    /**
     * Removes a groupItem from the aggregation {@link #getGroupItems groupItems}.
     *
     *
     * @returns The removed groupItem or `null`
     */
    removeGroupItem(
      /**
       * The groupItem to remove or its index or id
       */
      vGroupItem: int | string | P13nGroupItem
    ): P13nGroupItem | null;
    /**
     * Removes all invalid group conditions.
     *
     * @since 1.28
     */
    removeInvalidConditions(): void;
    /**
     * Removes all errors/warning states from of all group conditions.
     *
     * @since 1.28
     */
    removeValidationErrors(): void;
    /**
     * Sets a new value for property {@link #getContainerQuery containerQuery}.
     *
     * Defines if `mediaQuery` or `ContainerResize` is used for a layout update. If `ConditionPanel` is used
     * in a dialog, the property must be set to true.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContainerQuery(
      /**
       * New value for property `containerQuery`
       */
      bContainerQuery?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getLayoutMode layoutMode}.
     *
     * Can be used to control the layout behavior. Default is "" which will automatically change the layout.
     * With "Desktop", "Table" or "Phone" you can set a fixed layout.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLayoutMode(
      /**
       * New value for property `layoutMode`
       */
      sLayoutMode?: string
    ): this;
    /**
     * Sets a new value for property {@link #getMaxGroups maxGroups}.
     *
     * Defines the maximum number of groups.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `'-1'`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxGroups(
      /**
       * New value for property `maxGroups`
       */
      sMaxGroups?: string
    ): this;
    /**
     * Setter for the supported operations array.
     */
    setOperations(
      /**
       * array of operations `[sap.m.P13nConditionOperation.BT, sap.m.P13nConditionOperation.EQ]`
       */
      aOperations: any[]
    ): void;
    /**
     * Unbinds aggregation {@link #getGroupItems groupItems} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindGroupItems(): this;
    /**
     * Checks if the entered or modified conditions are correct, marks invalid fields yellow (Warning) and opens
     * a popup message dialog to let the user know that some values are not correct or missing.
     *
     *
     * @returns `True` if all conditions are valid, `false` otherwise.
     */
    validateConditions(): boolean;
  }
  /**
   * Describes the settings that can be provided to the P13nGroupPanel constructor.
   *
   * @deprecated As of version 1.98. Use the {@link sap.m.p13n.GroupPanel} instead.
   */
  export interface $P13nGroupPanelSettings extends $P13nPanelSettings {
    /**
     * Defines the maximum number of groups.
     */
    maxGroups?: string | PropertyBindingInfo;

    /**
     * Defines if `mediaQuery` or `ContainerResize` is used for a layout update. If `ConditionPanel` is used
     * in a dialog, the property must be set to true.
     */
    containerQuery?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Can be used to control the layout behavior. Default is "" which will automatically change the layout.
     * With "Desktop", "Table" or "Phone" you can set a fixed layout.
     */
    layoutMode?: string | PropertyBindingInfo;

    /**
     * Defined group items.
     */
    groupItems?:
      | P13nGroupItem[]
      | P13nGroupItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Event raised if a `GroupItem` has been added.
     */
    addGroupItem?: (oEvent: Event) => void;

    /**
     * Event raised if a `GroupItem` has been removed.
     */
    removeGroupItem?: (oEvent: Event) => void;

    /**
     * Event raised if a `GroupItem` has been updated.
     */
    updateGroupItem?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the P13nGroupPanel#addGroupItem event.
   */
  export interface P13nGroupPanel$AddGroupItemEventParameters {}

  /**
   * Event object of the P13nGroupPanel#addGroupItem event.
   */
  export type P13nGroupPanel$AddGroupItemEvent = Event<
    P13nGroupPanel$AddGroupItemEventParameters,
    P13nGroupPanel
  >;

  /**
   * Parameters of the P13nGroupPanel#removeGroupItem event.
   */
  export interface P13nGroupPanel$RemoveGroupItemEventParameters {}

  /**
   * Event object of the P13nGroupPanel#removeGroupItem event.
   */
  export type P13nGroupPanel$RemoveGroupItemEvent = Event<
    P13nGroupPanel$RemoveGroupItemEventParameters,
    P13nGroupPanel
  >;

  /**
   * Parameters of the P13nGroupPanel#updateGroupItem event.
   */
  export interface P13nGroupPanel$UpdateGroupItemEventParameters {}

  /**
   * Event object of the P13nGroupPanel#updateGroupItem event.
   */
  export type P13nGroupPanel$UpdateGroupItemEvent = Event<
    P13nGroupPanel$UpdateGroupItemEventParameters,
    P13nGroupPanel
  >;
}

declare module "sap/m/P13nItem" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Base type for `items` aggregation in `P13nPanel` control.
   *
   * @since 1.26.0
   * @deprecated As of version 1.124. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export default class P13nItem extends UI5Element {
    /**
     * Constructor for a new P13nItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nItemSettings
    );
    /**
     * Constructor for a new P13nItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.P13nItem with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, P13nItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.P13nItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getAggregationRole aggregationRole}.
     *
     * Defines aggregation role
     *
     * @since 1.34.0
     *
     * @returns Value of property `aggregationRole`
     */
    getAggregationRole(): string;
    /**
     * Gets current value of property {@link #getColumnKey columnKey}.
     *
     * Can be used as input for subsequent actions.
     *
     *
     * @returns Value of property `columnKey`
     */
    getColumnKey(): string;
    /**
     * Gets current value of property {@link #getDescription description}.
     *
     * Defines additional information of the link.
     *
     * @since 1.56.0
     *
     * @returns Value of property `description`
     */
    getDescription(): string;
    /**
     * Gets current value of property {@link #getFormatSettings formatSettings}.
     *
     * A JSON object containing the formatSettings which will be used to pass additional type/format settings
     * for the entered value. if type==time or date or datetime the object will be used for the DateFormatter,
     * TimeFormatter or DateTimeFormatter
     *
     * Below you can find a brief example
     *
     *
     * ```javascript
     *
     * {
     * 		UTC: false,
     * 		style: "medium" //"short" or "long"
     * }
     * ```
     *
     *
     * @since 1.52
     *
     * @returns Value of property `formatSettings`
     */
    getFormatSettings(): object;
    /**
     * Gets current value of property {@link #getHref href}.
     *
     * Defines href of a link.
     *
     * @since 1.46.0
     *
     * @returns Value of property `href`
     */
    getHref(): string;
    /**
     * Gets current value of property {@link #getIsDefault isDefault}.
     *
     * the column with isDefault==true will be used as the selected column item on the conditionPanel
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `isDefault`
     */
    getIsDefault(): boolean;
    /**
     * Gets current value of property {@link #getMaxLength maxLength}.
     *
     * specifies the number of characters which can be entered in the value fields of the condition panel
     *
     *
     * @returns Value of property `maxLength`
     */
    getMaxLength(): string;
    /**
     * Gets current value of property {@link #getNullable nullable}.
     *
     * Defines if the item is nullable
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `nullable`
     */
    getNullable(): boolean;
    /**
     * Gets current value of property {@link #getPrecision precision}.
     *
     * if type==numeric the precision will be used to format the entered value (maxIntegerDigits of the used
     * Formatter)
     *
     *
     * @returns Value of property `precision`
     */
    getPrecision(): string;
    /**
     * Gets current value of property {@link #getPress press}.
     *
     * Defines press handler of a link.
     *
     * @since 1.46.0
     *
     * @returns Value of property `press`
     */
    getPress(): object;
    /**
     * Gets current value of property {@link #getRole role}.
     *
     * Defines role. The role is reflected in the manner how the dimension will influence the chart layout.
     *
     * @since 1.34.0
     *
     * @returns Value of property `role`
     */
    getRole(): string;
    /**
     * Gets current value of property {@link #getScale scale}.
     *
     * if type==numeric the scale will be used to format the entered value (maxFractionDigits of the used Formatter)
     *
     *
     * @returns Value of property `scale`
     */
    getScale(): string;
    /**
     * Gets current value of property {@link #getTarget target}.
     *
     * Defines target of a link.
     *
     *
     * @returns Value of property `target`
     */
    getTarget(): string;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * The text to be displayed for the item.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getType type}.
     *
     * data type of the column (text, numeric or date is supported)
     *
     * Default value is `"text"`.
     *
     *
     * @returns Value of property `type`
     */
    getType(): string;
    /**
     * Gets current value of property {@link #getTypeInstance typeInstance}.
     *
     * data type instance of the column. Can be used instead of the type, precision, scale and formatSettings
     * properties
     *
     * @since 1.56
     *
     * @returns Value of property `typeInstance`
     */
    getTypeInstance(): object;
    /**
     * Gets current value of property {@link #getValues values}.
     *
     * the array of values for type bool. e.g. ["", "Off", "On"]. The first entry can be empty (used to blank
     * the value field). Next value represent the false value, last entry the true value.
     *
     * @since 1.34.0
     *
     * @returns Value of property `values`
     */
    getValues(): string[];
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * Defines visibility of column
     *
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Defines column width
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): string;
    /**
     * Sets a new value for property {@link #getAggregationRole aggregationRole}.
     *
     * Defines aggregation role
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.34.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAggregationRole(
      /**
       * New value for property `aggregationRole`
       */
      sAggregationRole?: string
    ): this;
    /**
     * Sets a new value for property {@link #getColumnKey columnKey}.
     *
     * Can be used as input for subsequent actions.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setColumnKey(
      /**
       * New value for property `columnKey`
       */
      sColumnKey?: string
    ): this;
    /**
     * Sets a new value for property {@link #getDescription description}.
     *
     * Defines additional information of the link.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.56.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDescription(
      /**
       * New value for property `description`
       */
      sDescription?: string
    ): this;
    /**
     * Sets a new value for property {@link #getFormatSettings formatSettings}.
     *
     * A JSON object containing the formatSettings which will be used to pass additional type/format settings
     * for the entered value. if type==time or date or datetime the object will be used for the DateFormatter,
     * TimeFormatter or DateTimeFormatter
     *
     * Below you can find a brief example
     *
     *
     * ```javascript
     *
     * {
     * 		UTC: false,
     * 		style: "medium" //"short" or "long"
     * }
     * ```
     *
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.52
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFormatSettings(
      /**
       * New value for property `formatSettings`
       */
      oFormatSettings?: object
    ): this;
    /**
     * Sets a new value for property {@link #getHref href}.
     *
     * Defines href of a link.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.46.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHref(
      /**
       * New value for property `href`
       */
      sHref?: string
    ): this;
    /**
     * Sets a new value for property {@link #getIsDefault isDefault}.
     *
     * the column with isDefault==true will be used as the selected column item on the conditionPanel
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIsDefault(
      /**
       * New value for property `isDefault`
       */
      bIsDefault?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getMaxLength maxLength}.
     *
     * specifies the number of characters which can be entered in the value fields of the condition panel
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxLength(
      /**
       * New value for property `maxLength`
       */
      sMaxLength?: string
    ): this;
    /**
     * Sets a new value for property {@link #getNullable nullable}.
     *
     * Defines if the item is nullable
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNullable(
      /**
       * New value for property `nullable`
       */
      bNullable?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getPrecision precision}.
     *
     * if type==numeric the precision will be used to format the entered value (maxIntegerDigits of the used
     * Formatter)
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPrecision(
      /**
       * New value for property `precision`
       */
      sPrecision?: string
    ): this;
    /**
     * Sets a new value for property {@link #getPress press}.
     *
     * Defines press handler of a link.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.46.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPress(
      /**
       * New value for property `press`
       */
      oPress?: object
    ): this;
    /**
     * Sets a new value for property {@link #getRole role}.
     *
     * Defines role. The role is reflected in the manner how the dimension will influence the chart layout.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.34.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRole(
      /**
       * New value for property `role`
       */
      sRole?: string
    ): this;
    /**
     * Sets a new value for property {@link #getScale scale}.
     *
     * if type==numeric the scale will be used to format the entered value (maxFractionDigits of the used Formatter)
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setScale(
      /**
       * New value for property `scale`
       */
      sScale?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTarget target}.
     *
     * Defines target of a link.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTarget(
      /**
       * New value for property `target`
       */
      sTarget?: string
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * The text to be displayed for the item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getType type}.
     *
     * data type of the column (text, numeric or date is supported)
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"text"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setType(
      /**
       * New value for property `type`
       */
      sType?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTypeInstance typeInstance}.
     *
     * data type instance of the column. Can be used instead of the type, precision, scale and formatSettings
     * properties
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTypeInstance(
      /**
       * New value for property `typeInstance`
       */
      oTypeInstance?: object
    ): this;
    /**
     * Sets a new value for property {@link #getValues values}.
     *
     * the array of values for type bool. e.g. ["", "Off", "On"]. The first entry can be empty (used to blank
     * the value field). Next value represent the false value, last entry the true value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.34.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValues(
      /**
       * New value for property `values`
       */
      sValues?: string[]
    ): this;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * Defines visibility of column
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Defines column width
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the P13nItem constructor.
   *
   * @deprecated As of version 1.124. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export interface $P13nItemSettings extends $ElementSettings {
    /**
     * Can be used as input for subsequent actions.
     */
    columnKey?: string | PropertyBindingInfo;

    /**
     * The text to be displayed for the item.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Defines visibility of column
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * data type of the column (text, numeric or date is supported)
     */
    type?: string | PropertyBindingInfo;

    /**
     * data type instance of the column. Can be used instead of the type, precision, scale and formatSettings
     * properties
     *
     * @since 1.56
     */
    typeInstance?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * if type==numeric the precision will be used to format the entered value (maxIntegerDigits of the used
     * Formatter)
     */
    precision?: string | PropertyBindingInfo;

    /**
     * A JSON object containing the formatSettings which will be used to pass additional type/format settings
     * for the entered value. if type==time or date or datetime the object will be used for the DateFormatter,
     * TimeFormatter or DateTimeFormatter
     *
     * Below you can find a brief example
     *
     *
     * ```javascript
     *
     * {
     * 		UTC: false,
     * 		style: "medium" //"short" or "long"
     * }
     * ```
     *
     *
     * @since 1.52
     */
    formatSettings?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * if type==numeric the scale will be used to format the entered value (maxFractionDigits of the used Formatter)
     */
    scale?: string | PropertyBindingInfo;

    /**
     * specifies the number of characters which can be entered in the value fields of the condition panel
     */
    maxLength?: string | PropertyBindingInfo;

    /**
     * Defines column width
     */
    width?: string | PropertyBindingInfo;

    /**
     * the column with isDefault==true will be used as the selected column item on the conditionPanel
     */
    isDefault?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * the array of values for type bool. e.g. ["", "Off", "On"]. The first entry can be empty (used to blank
     * the value field). Next value represent the false value, last entry the true value.
     *
     * @since 1.34.0
     */
    values?: string[] | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines role. The role is reflected in the manner how the dimension will influence the chart layout.
     *
     * @since 1.34.0
     */
    role?: string | PropertyBindingInfo;

    /**
     * Defines aggregation role
     *
     * @since 1.34.0
     */
    aggregationRole?: string | PropertyBindingInfo;

    /**
     * Defines href of a link.
     *
     * @since 1.46.0
     */
    href?: string | PropertyBindingInfo;

    /**
     * Defines target of a link.
     */
    target?: string | PropertyBindingInfo;

    /**
     * Defines press handler of a link.
     *
     * @since 1.46.0
     */
    press?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines additional information of the link.
     *
     * @since 1.56.0
     */
    description?: string | PropertyBindingInfo;

    /**
     * Defines if the item is nullable
     */
    nullable?: boolean | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/P13nPanel" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { p13n } from "sap/m/library";

  import P13nItem from "sap/m/P13nItem";

  import Event from "sap/ui/base/Event";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * An abstract base type for `panels` aggregation in `P13nDialog` control.
   *
   * @since 1.26.0
   * @deprecated As of version 1.124. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export default abstract class P13nPanel
    extends Control
    implements p13n.IContent
  {
    __implements__sap_m_p13n_IContent: boolean;
    /**
     * Constructor for a new P13nPanel.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nPanelSettings
    );
    /**
     * Constructor for a new P13nPanel.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nPanelSettings
    );

    /**
     * Creates a new subclass of class sap.m.P13nPanel with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, P13nPanel>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.P13nPanel.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: P13nItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeNavigationTo beforeNavigationTo} event
     * of this `sap.m.P13nPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nPanel` itself.
     *
     * Due to performance the data of the panel can be requested in lazy mode e.g. when the panel is displayed
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeNavigationTo(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeNavigationTo beforeNavigationTo} event
     * of this `sap.m.P13nPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nPanel` itself.
     *
     * Due to performance the data of the panel can be requested in lazy mode e.g. when the panel is displayed
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeNavigationTo(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * This method defines the point in time before the panel becomes active.
     *
     * @since 1.28.0
     */
    beforeNavigationTo(): void;
    /**
     * Binds aggregation {@link #getItems items} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeNavigationTo beforeNavigationTo} event
     * of this `sap.m.P13nPanel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeNavigationTo(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:beforeNavigationTo beforeNavigationTo} to attached listeners.
     *
     * @since 1.28.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforeNavigationTo(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getChangeNotifier changeNotifier}.
     *
     * Callback which notifies a change on this panel.
     *
     *
     * @returns Value of property `changeNotifier`
     */
    getChangeNotifier(): object;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * Defines personalization items (e.g. columns in the `P13nColumnsPanel`).
     */
    getItems(): P13nItem[];
    /**
     * This method can be overwritten by subclass in order to return a payload for Ok action
     *
     * @since 1.26.7
     * @deprecated As of version 1.50. replaced by the event of the respective inherited control, for example
     * {@link sap.m.P13nColumnsPanel#event:changeColumnsItems} of `P13nColumnsPanel` control.
     *
     * @returns Object which describes the state after Ok has been pressed
     */
    getOkPayload(): object;
    /**
     * This method can be overwritten by subclass in order to return a payload for Reset action
     *
     * @since 1.28.0
     */
    getResetPayload(): void;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Title text appears in the panel.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getTitleLarge titleLarge}.
     *
     * Large title text appears e.g. in dialog header in case that only one panel is shown.
     *
     * @since 1.30.0
     *
     * @returns Value of property `titleLarge`
     */
    getTitleLarge(): string;
    /**
     * Gets current value of property {@link #getType type}.
     *
     * Panel type for generic use. Due to extensibility reason the type of `type` property should be `string`.
     * So it is feasible to add a custom panel without expanding the type.
     *
     *
     * @returns Value of property `type`
     */
    getType(): string;
    /**
     * Gets current value of property {@link #getValidationExecutor validationExecutor}.
     *
     * Callback method which is called in order to validate end user entry.
     *
     *
     * @returns Value of property `validationExecutor`
     */
    getValidationExecutor(): object;
    /**
     * Gets current value of property {@link #getValidationListener validationListener}.
     *
     * Callback method which is called in order to register for validation result.
     *
     *
     * @returns Value of property `validationListener`
     */
    getValidationListener(): object;
    /**
     * Gets current value of property {@link #getVerticalScrolling verticalScrolling}.
     *
     * Enables the vertical Scrolling on the `P13nDialog` when the panel is shown.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `verticalScrolling`
     */
    getVerticalScrolling(): boolean;
    /**
     * Checks for the provided `sap.m.P13nItem` in the aggregation {@link #getItems items}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: P13nItem
    ): int;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: P13nItem,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * This method can be overwritten by subclass in order to cleanup after navigation, e.g. to remove invalid
     * content on the panel.
     *
     * @since 1.28.0
     */
    onAfterNavigationFrom(): void;
    /**
     * This method can be overwritten by subclass in order to prevent navigation to another panel. This could
     * be the case if some content on the panel is considered 'invalid'.
     *
     * @since 1.28.0
     *
     * @returns true if it is allowed to navigate away from this panel, false if it is not allowed
     */
    onBeforeNavigationFrom(): boolean;
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): P13nItem[];
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | P13nItem
    ): P13nItem | null;
    /**
     * Sets a new value for property {@link #getChangeNotifier changeNotifier}.
     *
     * Callback which notifies a change on this panel.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setChangeNotifier(
      /**
       * New value for property `changeNotifier`
       */
      oChangeNotifier?: object
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Title text appears in the panel.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitleLarge titleLarge}.
     *
     * Large title text appears e.g. in dialog header in case that only one panel is shown.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleLarge(
      /**
       * New value for property `titleLarge`
       */
      sTitleLarge?: string
    ): this;
    /**
     * Sets a new value for property {@link #getType type}.
     *
     * Panel type for generic use. Due to extensibility reason the type of `type` property should be `string`.
     * So it is feasible to add a custom panel without expanding the type.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setType(
      /**
       * New value for property `type`
       */
      sType?: string
    ): this;
    /**
     * Sets a new value for property {@link #getValidationExecutor validationExecutor}.
     *
     * Callback method which is called in order to validate end user entry.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValidationExecutor(
      /**
       * New value for property `validationExecutor`
       */
      oValidationExecutor?: object
    ): this;
    /**
     * Sets a new value for property {@link #getValidationListener validationListener}.
     *
     * Callback method which is called in order to register for validation result.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValidationListener(
      /**
       * New value for property `validationListener`
       */
      oValidationListener?: object
    ): this;
    /**
     * Sets a new value for property {@link #getVerticalScrolling verticalScrolling}.
     *
     * Enables the vertical Scrolling on the `P13nDialog` when the panel is shown.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVerticalScrolling(
      /**
       * New value for property `verticalScrolling`
       */
      bVerticalScrolling?: boolean
    ): this;
    /**
     * Unbinds aggregation {@link #getItems items} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindItems(): this;
  }
  /**
   * Describes the settings that can be provided to the P13nPanel constructor.
   *
   * @deprecated As of version 1.124. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export interface $P13nPanelSettings extends $ControlSettings {
    /**
     * Title text appears in the panel.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Large title text appears e.g. in dialog header in case that only one panel is shown.
     *
     * @since 1.30.0
     */
    titleLarge?: string | PropertyBindingInfo;

    /**
     * Panel type for generic use. Due to extensibility reason the type of `type` property should be `string`.
     * So it is feasible to add a custom panel without expanding the type.
     */
    type?: string | PropertyBindingInfo;

    /**
     * Enables the vertical Scrolling on the `P13nDialog` when the panel is shown.
     */
    verticalScrolling?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Callback method which is called in order to validate end user entry.
     */
    validationExecutor?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Callback method which is called in order to register for validation result.
     */
    validationListener?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Callback which notifies a change on this panel.
     */
    changeNotifier?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines personalization items (e.g. columns in the `P13nColumnsPanel`).
     */
    items?: P13nItem[] | P13nItem | AggregationBindingInfo | `{${string}}`;

    /**
     * Due to performance the data of the panel can be requested in lazy mode e.g. when the panel is displayed
     *
     * @since 1.28.0
     */
    beforeNavigationTo?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the P13nPanel#beforeNavigationTo event.
   */
  export interface P13nPanel$BeforeNavigationToEventParameters {}

  /**
   * Event object of the P13nPanel#beforeNavigationTo event.
   */
  export type P13nPanel$BeforeNavigationToEvent = Event<
    P13nPanel$BeforeNavigationToEventParameters,
    P13nPanel
  >;
}

declare module "sap/m/P13nSortItem" {
  import { default as Item, $ItemSettings } from "sap/ui/core/Item";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Type for `sortItems` aggregation in P13nSortPanel control.
   *
   * @since 1.26.0
   * @deprecated As of version 1.120. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export default class P13nSortItem extends Item {
    /**
     * Constructor for a new P13nSortItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nSortItemSettings
    );
    /**
     * Constructor for a new P13nSortItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nSortItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.P13nSortItem with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Item.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, P13nSortItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.P13nSortItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getColumnKey columnKey}.
     *
     * key of the column
     *
     *
     * @returns Value of property `columnKey`
     */
    getColumnKey(): string;
    /**
     * Gets current value of property {@link #getOperation operation}.
     *
     * sap.m.P13nConditionOperation
     *
     *
     * @returns Value of property `operation`
     */
    getOperation(): string;
    /**
     * Sets a new value for property {@link #getColumnKey columnKey}.
     *
     * key of the column
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setColumnKey(
      /**
       * New value for property `columnKey`
       */
      sColumnKey?: string
    ): this;
    /**
     * Sets a new value for property {@link #getOperation operation}.
     *
     * sap.m.P13nConditionOperation
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setOperation(
      /**
       * New value for property `operation`
       */
      sOperation?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the P13nSortItem constructor.
   *
   * @deprecated As of version 1.120. replaced by the artifacts in {@link sap.m.p13n}.
   */
  export interface $P13nSortItemSettings extends $ItemSettings {
    /**
     * sap.m.P13nConditionOperation
     */
    operation?: string | PropertyBindingInfo;

    /**
     * key of the column
     */
    columnKey?: string | PropertyBindingInfo;
  }
}

declare module "sap/m/P13nSortPanel" {
  import { default as P13nPanel, $P13nPanelSettings } from "sap/m/P13nPanel";

  import P13nSortItem from "sap/m/P13nSortItem";

  import Event from "sap/ui/base/Event";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * The P13nSortPanel control is used to define settings for sorting in table personalization.
   *
   * @since 1.26.0
   * @deprecated As of version 1.98. Use the {@link sap.m.p13n.SortPanel} instead.
   */
  export default class P13nSortPanel extends P13nPanel {
    /**
     * Constructor for a new P13nSortPanel.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nSortPanelSettings
    );
    /**
     * Constructor for a new P13nSortPanel.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $P13nSortPanelSettings
    );

    /**
     * Creates a new subclass of class sap.m.P13nSortPanel with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.P13nPanel.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, P13nSortPanel>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.P13nSortPanel.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some sortItem to the aggregation {@link #getSortItems sortItems}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addSortItem(
      /**
       * The sortItem to add; if empty, nothing is inserted
       */
      oSortItem: P13nSortItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:addSortItem addSortItem} event of this `sap.m.P13nSortPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nSortPanel` itself.
     *
     * event raised when a SortItem was added
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAddSortItem(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nSortPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:addSortItem addSortItem} event of this `sap.m.P13nSortPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nSortPanel` itself.
     *
     * event raised when a SortItem was added
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAddSortItem(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nSortPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:removeSortItem removeSortItem} event of this
     * `sap.m.P13nSortPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nSortPanel` itself.
     *
     * event raised when a SortItem was removed
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachRemoveSortItem(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nSortPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:removeSortItem removeSortItem} event of this
     * `sap.m.P13nSortPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nSortPanel` itself.
     *
     * event raised when a SortItem was removed
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachRemoveSortItem(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nSortPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:updateSortItem updateSortItem} event of this
     * `sap.m.P13nSortPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nSortPanel` itself.
     *
     * event raised when a SortItem was updated
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUpdateSortItem(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nSortPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:updateSortItem updateSortItem} event of this
     * `sap.m.P13nSortPanel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.P13nSortPanel` itself.
     *
     * event raised when a SortItem was updated
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUpdateSortItem(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.P13nSortPanel` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getSortItems sortItems} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindSortItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the sortItems in the aggregation {@link #getSortItems sortItems}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySortItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:addSortItem addSortItem} event of this `sap.m.P13nSortPanel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAddSortItem(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:removeSortItem removeSortItem} event of this
     * `sap.m.P13nSortPanel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachRemoveSortItem(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:updateSortItem updateSortItem} event of this
     * `sap.m.P13nSortPanel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUpdateSortItem(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:addSortItem addSortItem} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAddSortItem(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:removeSortItem removeSortItem} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireRemoveSortItem(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:updateSortItem updateSortItem} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUpdateSortItem(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getContainerQuery containerQuery}.
     *
     * defines if the mediaQuery or a ContainerResize will be used for layout update. When the ConditionPanel
     * is used on a dialog the property should be set to true!
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `containerQuery`
     */
    getContainerQuery(): boolean;
    /**
     * Gets current value of property {@link #getLayoutMode layoutMode}.
     *
     * can be used to control the layout behavior. Default is "" which will automatically change the layout.
     * With "Desktop", "Table" or "Phone" you can set a fixed layout.
     *
     *
     * @returns Value of property `layoutMode`
     */
    getLayoutMode(): string;
    /**
     * Gets content of aggregation {@link #getSortItems sortItems}.
     *
     * defined Sort Items
     */
    getSortItems(): P13nSortItem[];
    /**
     * Checks for the provided `sap.m.P13nSortItem` in the aggregation {@link #getSortItems sortItems}. and
     * returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfSortItem(
      /**
       * The sortItem whose index is looked for
       */
      oSortItem: P13nSortItem
    ): int;
    /**
     * Inserts a sortItem into the aggregation {@link #getSortItems sortItems}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertSortItem(
      /**
       * The sortItem to insert; if empty, nothing is inserted
       */
      oSortItem: P13nSortItem,
      /**
       * The `0`-based index the sortItem should be inserted at; for a negative value of `iIndex`, the sortItem
       * is inserted at position 0; for a value greater than the current size of the aggregation, the sortItem
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getSortItems sortItems}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllSortItems(): P13nSortItem[];
    /**
     * removes all invalid sort conditions.
     *
     * @since 1.28
     */
    removeInvalidConditions(): void;
    /**
     * Removes a sortItem from the aggregation {@link #getSortItems sortItems}.
     *
     *
     * @returns The removed sortItem or `null`
     */
    removeSortItem(
      /**
       * The sortItem to remove or its index or id
       */
      vSortItem: int | string | P13nSortItem
    ): P13nSortItem | null;
    /**
     * removes all errors/warning states from of all sort conditions.
     *
     * @since 1.28
     */
    removeValidationErrors(): void;
    /**
     * Sets a new value for property {@link #getContainerQuery containerQuery}.
     *
     * defines if the mediaQuery or a ContainerResize will be used for layout update. When the ConditionPanel
     * is used on a dialog the property should be set to true!
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContainerQuery(
      /**
       * New value for property `containerQuery`
       */
      bContainerQuery?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getLayoutMode layoutMode}.
     *
     * can be used to control the layout behavior. Default is "" which will automatically change the layout.
     * With "Desktop", "Table" or "Phone" you can set a fixed layout.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLayoutMode(
      /**
       * New value for property `layoutMode`
       */
      sLayoutMode?: string
    ): this;
    /**
     * setter for the supported operations array
     *
     *
     * @returns this for chaining
     */
    setOperations(
      /**
       * array of operations `[sap.m.P13nConditionOperation.BT, sap.m.P13nConditionOperation.EQ]`
       */
      aOperations: any[]
    ): this;
    /**
     * Unbinds aggregation {@link #getSortItems sortItems} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindSortItems(): this;
    /**
     * check if the entered/modified conditions are correct, marks invalid fields yellow (Warning state) and
     * opens a popup message dialog to give the user the feedback that some values are wrong or missing.
     *
     *
     * @returns `True` if all conditions are valid, `false` otherwise.
     */
    validateConditions(): boolean;
  }
  /**
   * Describes the settings that can be provided to the P13nSortPanel constructor.
   *
   * @deprecated As of version 1.98. Use the {@link sap.m.p13n.SortPanel} instead.
   */
  export interface $P13nSortPanelSettings extends $P13nPanelSettings {
    /**
     * defines if the mediaQuery or a ContainerResize will be used for layout update. When the ConditionPanel
     * is used on a dialog the property should be set to true!
     */
    containerQuery?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * can be used to control the layout behavior. Default is "" which will automatically change the layout.
     * With "Desktop", "Table" or "Phone" you can set a fixed layout.
     */
    layoutMode?: string | PropertyBindingInfo;

    /**
     * defined Sort Items
     */
    sortItems?:
      | P13nSortItem[]
      | P13nSortItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * event raised when a SortItem was added
     */
    addSortItem?: (oEvent: Event) => void;

    /**
     * event raised when a SortItem was removed
     */
    removeSortItem?: (oEvent: Event) => void;

    /**
     * event raised when a SortItem was updated
     */
    updateSortItem?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the P13nSortPanel#addSortItem event.
   */
  export interface P13nSortPanel$AddSortItemEventParameters {}

  /**
   * Event object of the P13nSortPanel#addSortItem event.
   */
  export type P13nSortPanel$AddSortItemEvent = Event<
    P13nSortPanel$AddSortItemEventParameters,
    P13nSortPanel
  >;

  /**
   * Parameters of the P13nSortPanel#removeSortItem event.
   */
  export interface P13nSortPanel$RemoveSortItemEventParameters {}

  /**
   * Event object of the P13nSortPanel#removeSortItem event.
   */
  export type P13nSortPanel$RemoveSortItemEvent = Event<
    P13nSortPanel$RemoveSortItemEventParameters,
    P13nSortPanel
  >;

  /**
   * Parameters of the P13nSortPanel#updateSortItem event.
   */
  export interface P13nSortPanel$UpdateSortItemEventParameters {}

  /**
   * Event object of the P13nSortPanel#updateSortItem event.
   */
  export type P13nSortPanel$UpdateSortItemEvent = Event<
    P13nSortPanel$UpdateSortItemEventParameters,
    P13nSortPanel
  >;
}

declare module "sap/m/Page" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import Event from "sap/ui/base/Event";

  import {
    PageBackgroundDesign,
    IBar,
    ButtonType,
    TitleAlignment,
  } from "sap/m/library";

  import { URI, TitleLevel } from "sap/ui/core/library";

  import PageAccessibleLandmarkInfo from "sap/m/PageAccessibleLandmarkInfo";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import UI5Element from "sap/ui/core/Element";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * A container control that holds one whole screen of an application.
   *
   * Overview: The sap.m.Page is a container control that holds one whole screen of an application. The page
   * has three distinct areas that can hold content - a header, content area and a footer. Structure: Header:
   * The top most area of the page is occupied by the header. The standard header includes a navigation button
   * and a title. Alternatively, you can create your own custom header, which is defined in the `customHeader`
   * aggregation. Content: The content occupies the main part of the page. Only the content area is scrollable
   * by default. This can be prevented by setting `enableScrolling` to `false`. Footer: The footer is optional
   * and occupies the fixed bottom part of the page. Alternatively, the footer can be floating above the bottom
   * part of the content. This is enabled with the `floatingFooter` property.
   *
   * **Note:** All accessibility information for the different areas and their corresponding ARIA roles is
   * set in the aggregation `landmarkInfo` of type {@link sap.m.PageAccessibleLandmarkInfo} Responsive Behavior:
   * When using the sap.m.Page in SAP Quartz theme, the breakpoints and layout paddings could be determined
   * by the container's width. To enable this concept and add responsive paddings to an element of the Page
   * control, you may add the following classes depending on your use case: `sapUiResponsivePadding--header`,
   * `sapUiResponsivePadding--subHeader`, `sapUiResponsivePadding--content`, `sapUiResponsivePadding--footer`,
   * `sapUiResponsivePadding--floatingFooter`.
   */
  export default class Page extends Control {
    /**
     * Constructor for a new Page.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $PageSettings
    );
    /**
     * Constructor for a new Page.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $PageSettings
    );

    /**
     * Creates a new subclass of class sap.m.Page with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Page>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Page.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some content to the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContent(
      /**
       * The content to add; if empty, nothing is inserted
       */
      oContent: Control
    ): this;
    /**
     * Adds some headerContent to the aggregation {@link #getHeaderContent headerContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addHeaderContent(
      /**
       * The headerContent to add; if empty, nothing is inserted
       */
      oHeaderContent: Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navButtonPress navButtonPress} event of this
     * `sap.m.Page`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Page` itself.
     *
     * this event is fired when Nav Button is pressed
     *
     * @since 1.12.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavButtonPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Page` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navButtonPress navButtonPress} event of this
     * `sap.m.Page`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Page` itself.
     *
     * this event is fired when Nav Button is pressed
     *
     * @since 1.12.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavButtonPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Page` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navButtonTap navButtonTap} event of this `sap.m.Page`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Page` itself.
     *
     * this event is fired when Nav Button is tapped
     *
     * @deprecated As of version 1.12.2. the navButtonPress event is replacing this event
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavButtonTap(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Page` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navButtonTap navButtonTap} event of this `sap.m.Page`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Page` itself.
     *
     * this event is fired when Nav Button is tapped
     *
     * @deprecated As of version 1.12.2. the navButtonPress event is replacing this event
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavButtonTap(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Page` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Destroys the customHeader in the aggregation {@link #getCustomHeader customHeader}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCustomHeader(): this;
    /**
     * Destroys the footer in the aggregation {@link #getFooter footer}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyFooter(): this;
    /**
     * Destroys all the headerContent in the aggregation {@link #getHeaderContent headerContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyHeaderContent(): this;
    /**
     * Destroys the landmarkInfo in the aggregation {@link #getLandmarkInfo landmarkInfo}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyLandmarkInfo(): this;
    /**
     * Destroys the subHeader in the aggregation {@link #getSubHeader subHeader}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySubHeader(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:navButtonPress navButtonPress} event of this
     * `sap.m.Page`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.12.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachNavButtonPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:navButtonTap navButtonTap} event of this `sap.m.Page`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @deprecated As of version 1.12.2. the navButtonPress event is replacing this event
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachNavButtonTap(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:navButtonPress navButtonPress} to attached listeners.
     *
     * @since 1.12.2
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireNavButtonPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:navButtonTap navButtonTap} to attached listeners.
     *
     * @deprecated As of version 1.12.2. the navButtonPress event is replacing this event
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireNavButtonTap(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getBackgroundDesign backgroundDesign}.
     *
     * This property is used to set the background color of a page. When a list is placed inside a page, the
     * value "List" should be used to display a gray background. "Standard", with the default background color,
     * is used if not specified.
     *
     * Default value is `Standard`.
     *
     *
     * @returns Value of property `backgroundDesign`
     */
    getBackgroundDesign(): PageBackgroundDesign;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * The content of this page
     */
    getContent(): Control[];
    /**
     * Gets current value of property {@link #getContentOnlyBusy contentOnlyBusy}.
     *
     * Decides which area is covered by the local BusyIndicator when `page.setBusy()` is called. By default
     * the entire page is covered, including headers and footer. When this property is set to "true", only the
     * content area is covered (not header/sub header and footer), which is useful e.g. when there is a SearchField
     * in the sub header and live search continuously updates the content area while the user is still able
     * to type.
     *
     * Default value is `false`.
     *
     * @since 1.29.0
     *
     * @returns Value of property `contentOnlyBusy`
     */
    getContentOnlyBusy(): boolean;
    /**
     * Gets content of aggregation {@link #getCustomHeader customHeader}.
     *
     * The (optional) custom header of this page. Use this aggregation only when a custom header is constructed
     * where the default header consisting of title text + nav button is not sufficient. If this aggregation
     * is set, the simple properties "title", "showNavButton", "NavButtonText" and "icon" are not used.
     */
    getCustomHeader(): IBar;
    /**
     * Gets current value of property {@link #getEnableScrolling enableScrolling}.
     *
     * Enable vertical scrolling of page contents. Page headers and footers are fixed and do not scroll. If
     * set to false, there will be no vertical scrolling at all.
     *
     * The Page only allows vertical scrolling because horizontal scrolling is discouraged in general for full-page
     * content. If it still needs to be achieved, disable the Page scrolling and use a ScrollContainer as full-page
     * content of the Page. This allows you to freely configure scrolling. It can also be used to create horizontally-scrolling
     * sub-areas of (vertically-scrolling) Pages.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enableScrolling`
     */
    getEnableScrolling(): boolean;
    /**
     * Gets current value of property {@link #getFloatingFooter floatingFooter}.
     *
     * Decides whether the footer can float. When set to true, the footer is not fixed below the content area
     * anymore, but rather floats over it with a slight offset from the bottom.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `floatingFooter`
     */
    getFloatingFooter(): boolean;
    /**
     * Gets content of aggregation {@link #getFooter footer}.
     *
     * The (optional) footer of this page. It is always located at the bottom of the page
     */
    getFooter(): IBar;
    /**
     * Gets content of aggregation {@link #getHeaderContent headerContent}.
     *
     * Controls to be added to the right side of the page header. Usually an application would use Button controls
     * and limit the number to one when the application needs to run on smartphones. There is no automatic overflow
     * handling when the space is insufficient. When a customHeader is used, this aggregation will be ignored.
     */
    getHeaderContent(): Control[];
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * the icon that is rendered in the page header bar in non-iOS phone/tablet platforms. This property is
     * theme-dependent and only has an effect in the MVI theme.
     *
     * @deprecated As of version 1.20. Deprecated since the MVI theme is removed now. This property only affected
     * the NavButton in that theme.
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets content of aggregation {@link #getLandmarkInfo landmarkInfo}.
     *
     * Accessible landmark settings to be applied on the containers of the `sap.m.Page` control.
     *
     * If not set, no landmarks will be written.
     */
    getLandmarkInfo(): PageAccessibleLandmarkInfo;
    /**
     * Gets current value of property {@link #getNavButtonText navButtonText}.
     *
     * The text of the nav button when running in iOS (if shown) in case it deviates from the default, which
     * is "Back". This property is mvi-theme-dependent and will not have any effect in other themes.
     *
     * @deprecated As of version 1.20. Deprecated since the MVI theme is removed now. This property only affected
     * the NavButton in that theme.
     *
     * @returns Value of property `navButtonText`
     */
    getNavButtonText(): string;
    /**
     * Gets current value of property {@link #getNavButtonTooltip navButtonTooltip}.
     *
     * The tooltip of the nav button
     *
     * Since version 1.34
     *
     *
     * @returns Value of property `navButtonTooltip`
     */
    getNavButtonTooltip(): string;
    /**
     * Gets current value of property {@link #getNavButtonType navButtonType}.
     *
     * This property is used to set the appearance of the NavButton. By default when showNavButton is set to
     * true, a back button will be shown in iOS and an up button in other platforms. In case you want to show
     * a normal button in the left header area, you can set the value to "Default".
     *
     * Default value is `Back`.
     *
     * @since 1.12
     * @deprecated As of version 1.20. Deprecated since the MVI theme is removed now. This property is only
     * usable with a Button text in that theme.
     *
     * @returns Value of property `navButtonType`
     */
    getNavButtonType(): ButtonType;
    /**
     * Gets current value of property {@link #getShowFooter showFooter}.
     *
     * Whether this page shall have a footer
     *
     * Default value is `true`.
     *
     * @since 1.13.1
     *
     * @returns Value of property `showFooter`
     */
    getShowFooter(): boolean;
    /**
     * Gets current value of property {@link #getShowHeader showHeader}.
     *
     * Whether this page shall have a header. If set to true, either the control under the "customHeader" aggregation
     * is used, or if there is no such control, a Header control is constructed from the properties "title",
     * "showNavButton", "navButtonText" and "icon" depending on the platform.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showHeader`
     */
    getShowHeader(): boolean;
    /**
     * Gets current value of property {@link #getShowNavButton showNavButton}.
     *
     * A nav button will be rendered on the left area of header bar if this property is set to true.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showNavButton`
     */
    getShowNavButton(): boolean;
    /**
     * Gets current value of property {@link #getShowSubHeader showSubHeader}.
     *
     * Whether this page shall show the subheader.
     *
     * Default value is `true`.
     *
     * @since 1.28
     *
     * @returns Value of property `showSubHeader`
     */
    getShowSubHeader(): boolean;
    /**
     * Gets content of aggregation {@link #getSubHeader subHeader}.
     *
     * a subHeader will be rendered directly under the header
     */
    getSubHeader(): IBar;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * The title text appearing in the page header bar.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getTitleAlignment titleAlignment}.
     *
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * Default value is `Auto`.
     *
     * @since 1.72
     *
     * @returns Value of property `titleAlignment`
     */
    getTitleAlignment(): TitleAlignment;
    /**
     * Gets current value of property {@link #getTitleLevel titleLevel}.
     *
     * Defines the semantic level of the title. Using "Auto" no explicit level information is written. Used
     * for accessibility purposes only.
     *
     * Default value is `Auto`.
     *
     *
     * @returns Value of property `titleLevel`
     */
    getTitleLevel(): TitleLevel;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContent content}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContent(
      /**
       * The content whose index is looked for
       */
      oContent: Control
    ): int;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getHeaderContent headerContent}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfHeaderContent(
      /**
       * The headerContent whose index is looked for
       */
      oHeaderContent: Control
    ): int;
    /**
     * Inserts a content into the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContent(
      /**
       * The content to insert; if empty, nothing is inserted
       */
      oContent: Control,
      /**
       * The `0`-based index the content should be inserted at; for a negative value of `iIndex`, the content
       * is inserted at position 0; for a value greater than the current size of the aggregation, the content
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a headerContent into the aggregation {@link #getHeaderContent headerContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertHeaderContent(
      /**
       * The headerContent to insert; if empty, nothing is inserted
       */
      oHeaderContent: Control,
      /**
       * The `0`-based index the headerContent should be inserted at; for a negative value of `iIndex`, the headerContent
       * is inserted at position 0; for a value greater than the current size of the aggregation, the headerContent
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getContent content}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContent(): Control[];
    /**
     * Removes all the controls from the aggregation {@link #getHeaderContent headerContent}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllHeaderContent(): Control[];
    /**
     * Removes a content from the aggregation {@link #getContent content}.
     *
     *
     * @returns The removed content or `null`
     */
    removeContent(
      /**
       * The content to remove or its index or id
       */
      vContent: int | string | Control
    ): Control | null;
    /**
     * Removes a headerContent from the aggregation {@link #getHeaderContent headerContent}.
     *
     *
     * @returns The removed headerContent or `null`
     */
    removeHeaderContent(
      /**
       * The headerContent to remove or its index or id
       */
      vHeaderContent: int | string | Control
    ): Control | null;
    /**
     * Scrolls to the given position. Only available if enableScrolling is set to "true".
     *
     *
     * @returns `this` to facilitate method chaining.
     */
    scrollTo(
      /**
       * The vertical pixel position to scroll to. Scrolling down happens with positive values.
       */
      y: int,
      /**
       * The duration of animated scrolling in milliseconds. The value `0` results in immediate scrolling without
       * animation.
       */
      time?: int
    ): this;
    /**
     * Scrolls to an element (DOM or sap.ui.core.Element) within the page if the element is rendered.
     *
     * @since 1.30
     *
     * @returns `this` to facilitate method chaining.
     */
    scrollToElement(
      /**
       * The element to which should be scrolled.
       */
      oElement: HTMLElement | UI5Element,
      /**
       * The duration of animated scrolling in milliseconds. To scroll immediately without animation, give 0 as
       * value.
       */
      iTime?: int,
      /**
       * Specifies an additional left and top offset of the target scroll position, relative to the upper left
       * corner of the DOM element
       */
      aOffset?: int[]
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundDesign backgroundDesign}.
     *
     * This property is used to set the background color of a page. When a list is placed inside a page, the
     * value "List" should be used to display a gray background. "Standard", with the default background color,
     * is used if not specified.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Standard`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundDesign(
      /**
       * New value for property `backgroundDesign`
       */
      sBackgroundDesign?:
        | PageBackgroundDesign
        | keyof typeof PageBackgroundDesign
    ): this;
    /**
     * Sets a new value for property {@link #getContentOnlyBusy contentOnlyBusy}.
     *
     * Decides which area is covered by the local BusyIndicator when `page.setBusy()` is called. By default
     * the entire page is covered, including headers and footer. When this property is set to "true", only the
     * content area is covered (not header/sub header and footer), which is useful e.g. when there is a SearchField
     * in the sub header and live search continuously updates the content area while the user is still able
     * to type.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.29.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContentOnlyBusy(
      /**
       * New value for property `contentOnlyBusy`
       */
      bContentOnlyBusy?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getCustomHeader customHeader}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomHeader(
      /**
       * The customHeader to set
       */
      oCustomHeader: IBar
    ): this;
    /**
     * Sets a new value for property {@link #getEnableScrolling enableScrolling}.
     *
     * Enable vertical scrolling of page contents. Page headers and footers are fixed and do not scroll. If
     * set to false, there will be no vertical scrolling at all.
     *
     * The Page only allows vertical scrolling because horizontal scrolling is discouraged in general for full-page
     * content. If it still needs to be achieved, disable the Page scrolling and use a ScrollContainer as full-page
     * content of the Page. This allows you to freely configure scrolling. It can also be used to create horizontally-scrolling
     * sub-areas of (vertically-scrolling) Pages.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableScrolling(
      /**
       * New value for property `enableScrolling`
       */
      bEnableScrolling?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getFloatingFooter floatingFooter}.
     *
     * Decides whether the footer can float. When set to true, the footer is not fixed below the content area
     * anymore, but rather floats over it with a slight offset from the bottom.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFloatingFooter(
      /**
       * New value for property `floatingFooter`
       */
      bFloatingFooter?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getFooter footer}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFooter(
      /**
       * The footer to set
       */
      oFooter: IBar
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * the icon that is rendered in the page header bar in non-iOS phone/tablet platforms. This property is
     * theme-dependent and only has an effect in the MVI theme.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @deprecated As of version 1.20. Deprecated since the MVI theme is removed now. This property only affected
     * the NavButton in that theme.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets the aggregated {@link #getLandmarkInfo landmarkInfo}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLandmarkInfo(
      /**
       * The landmarkInfo to set
       */
      oLandmarkInfo: PageAccessibleLandmarkInfo
    ): this;
    /**
     * Sets a new value for property {@link #getNavButtonText navButtonText}.
     *
     * The text of the nav button when running in iOS (if shown) in case it deviates from the default, which
     * is "Back". This property is mvi-theme-dependent and will not have any effect in other themes.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @deprecated As of version 1.20. Deprecated since the MVI theme is removed now. This property only affected
     * the NavButton in that theme.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNavButtonText(
      /**
       * New value for property `navButtonText`
       */
      sNavButtonText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getNavButtonTooltip navButtonTooltip}.
     *
     * The tooltip of the nav button
     *
     * Since version 1.34
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNavButtonTooltip(
      /**
       * New value for property `navButtonTooltip`
       */
      sNavButtonTooltip?: string
    ): this;
    /**
     * Sets a new value for property {@link #getNavButtonType navButtonType}.
     *
     * This property is used to set the appearance of the NavButton. By default when showNavButton is set to
     * true, a back button will be shown in iOS and an up button in other platforms. In case you want to show
     * a normal button in the left header area, you can set the value to "Default".
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Back`.
     *
     * @since 1.12
     * @deprecated As of version 1.20. Deprecated since the MVI theme is removed now. This property is only
     * usable with a Button text in that theme.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNavButtonType(
      /**
       * New value for property `navButtonType`
       */
      sNavButtonType?: ButtonType | keyof typeof ButtonType
    ): this;
    /**
     * Sets a new value for property {@link #getShowFooter showFooter}.
     *
     * Whether this page shall have a footer
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.13.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowFooter(
      /**
       * New value for property `showFooter`
       */
      bShowFooter?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowHeader showHeader}.
     *
     * Whether this page shall have a header. If set to true, either the control under the "customHeader" aggregation
     * is used, or if there is no such control, a Header control is constructed from the properties "title",
     * "showNavButton", "navButtonText" and "icon" depending on the platform.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowHeader(
      /**
       * New value for property `showHeader`
       */
      bShowHeader?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowNavButton showNavButton}.
     *
     * A nav button will be rendered on the left area of header bar if this property is set to true.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowNavButton(
      /**
       * New value for property `showNavButton`
       */
      bShowNavButton?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowSubHeader showSubHeader}.
     *
     * Whether this page shall show the subheader.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.28
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowSubHeader(
      /**
       * New value for property `showSubHeader`
       */
      bShowSubHeader?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getSubHeader subHeader}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSubHeader(
      /**
       * The subHeader to set
       */
      oSubHeader: IBar
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * The title text appearing in the page header bar.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitleAlignment titleAlignment}.
     *
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     * @since 1.72
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleAlignment(
      /**
       * New value for property `titleAlignment`
       */
      sTitleAlignment?: TitleAlignment | keyof typeof TitleAlignment
    ): this;
    /**
     * Sets a new value for property {@link #getTitleLevel titleLevel}.
     *
     * Defines the semantic level of the title. Using "Auto" no explicit level information is written. Used
     * for accessibility purposes only.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleLevel(
      /**
       * New value for property `titleLevel`
       */
      sTitleLevel?: TitleLevel | keyof typeof TitleLevel
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Page constructor.
   */
  export interface $PageSettings extends $ControlSettings {
    /**
     * The title text appearing in the page header bar.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Defines the semantic level of the title. Using "Auto" no explicit level information is written. Used
     * for accessibility purposes only.
     */
    titleLevel?:
      | (TitleLevel | keyof typeof TitleLevel)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * A nav button will be rendered on the left area of header bar if this property is set to true.
     */
    showNavButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Whether this page shall have a header. If set to true, either the control under the "customHeader" aggregation
     * is used, or if there is no such control, a Header control is constructed from the properties "title",
     * "showNavButton", "navButtonText" and "icon" depending on the platform.
     */
    showHeader?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Whether this page shall show the subheader.
     *
     * @since 1.28
     */
    showSubHeader?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The text of the nav button when running in iOS (if shown) in case it deviates from the default, which
     * is "Back". This property is mvi-theme-dependent and will not have any effect in other themes.
     *
     * @deprecated As of version 1.20. Deprecated since the MVI theme is removed now. This property only affected
     * the NavButton in that theme.
     */
    navButtonText?: string | PropertyBindingInfo;

    /**
     * The tooltip of the nav button
     *
     * Since version 1.34
     */
    navButtonTooltip?: string | PropertyBindingInfo;

    /**
     * Enable vertical scrolling of page contents. Page headers and footers are fixed and do not scroll. If
     * set to false, there will be no vertical scrolling at all.
     *
     * The Page only allows vertical scrolling because horizontal scrolling is discouraged in general for full-page
     * content. If it still needs to be achieved, disable the Page scrolling and use a ScrollContainer as full-page
     * content of the Page. This allows you to freely configure scrolling. It can also be used to create horizontally-scrolling
     * sub-areas of (vertically-scrolling) Pages.
     */
    enableScrolling?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * the icon that is rendered in the page header bar in non-iOS phone/tablet platforms. This property is
     * theme-dependent and only has an effect in the MVI theme.
     *
     * @deprecated As of version 1.20. Deprecated since the MVI theme is removed now. This property only affected
     * the NavButton in that theme.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * This property is used to set the background color of a page. When a list is placed inside a page, the
     * value "List" should be used to display a gray background. "Standard", with the default background color,
     * is used if not specified.
     */
    backgroundDesign?:
      | (PageBackgroundDesign | keyof typeof PageBackgroundDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * This property is used to set the appearance of the NavButton. By default when showNavButton is set to
     * true, a back button will be shown in iOS and an up button in other platforms. In case you want to show
     * a normal button in the left header area, you can set the value to "Default".
     *
     * @since 1.12
     * @deprecated As of version 1.20. Deprecated since the MVI theme is removed now. This property is only
     * usable with a Button text in that theme.
     */
    navButtonType?:
      | (ButtonType | keyof typeof ButtonType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Whether this page shall have a footer
     *
     * @since 1.13.1
     */
    showFooter?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Decides which area is covered by the local BusyIndicator when `page.setBusy()` is called. By default
     * the entire page is covered, including headers and footer. When this property is set to "true", only the
     * content area is covered (not header/sub header and footer), which is useful e.g. when there is a SearchField
     * in the sub header and live search continuously updates the content area while the user is still able
     * to type.
     *
     * @since 1.29.0
     */
    contentOnlyBusy?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Decides whether the footer can float. When set to true, the footer is not fixed below the content area
     * anymore, but rather floats over it with a slight offset from the bottom.
     */
    floatingFooter?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * @since 1.72
     */
    titleAlignment?:
      | (TitleAlignment | keyof typeof TitleAlignment)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The content of this page
     */
    content?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * The (optional) custom header of this page. Use this aggregation only when a custom header is constructed
     * where the default header consisting of title text + nav button is not sufficient. If this aggregation
     * is set, the simple properties "title", "showNavButton", "NavButtonText" and "icon" are not used.
     */
    customHeader?: IBar;

    /**
     * The (optional) footer of this page. It is always located at the bottom of the page
     */
    footer?: IBar;

    /**
     * a subHeader will be rendered directly under the header
     */
    subHeader?: IBar;

    /**
     * Controls to be added to the right side of the page header. Usually an application would use Button controls
     * and limit the number to one when the application needs to run on smartphones. There is no automatic overflow
     * handling when the space is insufficient. When a customHeader is used, this aggregation will be ignored.
     */
    headerContent?:
      | Control[]
      | Control
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Accessible landmark settings to be applied on the containers of the `sap.m.Page` control.
     *
     * If not set, no landmarks will be written.
     */
    landmarkInfo?: PageAccessibleLandmarkInfo;

    /**
     * this event is fired when Nav Button is tapped
     *
     * @deprecated As of version 1.12.2. the navButtonPress event is replacing this event
     */
    navButtonTap?: (oEvent: Event) => void;

    /**
     * this event is fired when Nav Button is pressed
     *
     * @since 1.12.2
     */
    navButtonPress?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the Page#navButtonPress event.
   */
  export interface Page$NavButtonPressEventParameters {}

  /**
   * Event object of the Page#navButtonPress event.
   */
  export type Page$NavButtonPressEvent = Event<
    Page$NavButtonPressEventParameters,
    Page
  >;

  /**
   * Parameters of the Page#navButtonTap event.
   *
   * @deprecated As of version 1.12.2. the navButtonPress event is replacing this event
   */
  export interface Page$NavButtonTapEventParameters {}

  /**
   * Event object of the Page#navButtonTap event.
   *
   * @deprecated As of version 1.12.2. the navButtonPress event is replacing this event
   */
  export type Page$NavButtonTapEvent = Event<
    Page$NavButtonTapEventParameters,
    Page
  >;
}

declare module "sap/m/PageAccessibleLandmarkInfo" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import { AccessibleLandmarkRole } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Settings for accessible landmarks which can be applied to the container elements of a `sap.m.Page` control.
   * These landmarks are e.g. used by assistive technologies (like screenreaders) to provide a meaningful
   * page overview.
   */
  export default class PageAccessibleLandmarkInfo extends UI5Element {
    /**
     * Constructor for a new `sap.m.PageAccessibleLandmarkInfo` element.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new element
       */
      mSettings?: $PageAccessibleLandmarkInfoSettings
    );
    /**
     * Constructor for a new `sap.m.PageAccessibleLandmarkInfo` element.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new element, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new element
       */
      mSettings?: $PageAccessibleLandmarkInfoSettings
    );

    /**
     * Creates a new subclass of class sap.m.PageAccessibleLandmarkInfo with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, PageAccessibleLandmarkInfo>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.PageAccessibleLandmarkInfo.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getContentLabel contentLabel}.
     *
     * Texts that describe the landmark of the content container of the corresponding `sap.m.Page` control.
     *
     * If not set (and a landmark different than `sap.ui.core.AccessibleLandmarkRole.None` is defined), a predefined
     * text is used.
     *
     *
     * @returns Value of property `contentLabel`
     */
    getContentLabel(): string;
    /**
     * Gets current value of property {@link #getContentRole contentRole}.
     *
     * Landmark role of the content container of the corresponding `sap.m.Page` control.
     *
     * If set to `sap.ui.core.AccessibleLandmarkRole.None`, no landmark will be added to the container.
     *
     * Default value is `"Main"`.
     *
     *
     * @returns Value of property `contentRole`
     */
    getContentRole(): AccessibleLandmarkRole;
    /**
     * Gets current value of property {@link #getFooterLabel footerLabel}.
     *
     * Texts that describe the landmark of the footer container of the corresponding `sap.m.Page` control.
     *
     * If not set (and a landmark different than `sap.ui.core.AccessibleLandmarkRole.None` is defined), a predefined
     * text is used.
     *
     *
     * @returns Value of property `footerLabel`
     */
    getFooterLabel(): string;
    /**
     * Gets current value of property {@link #getFooterRole footerRole}.
     *
     * Landmark role of the footer container of the corresponding `sap.m.Page` control.
     *
     * If set to `sap.ui.core.AccessibleLandmarkRole.None`, no landmark will be added to the container.
     *
     * Default value is `"Region"`.
     *
     *
     * @returns Value of property `footerRole`
     */
    getFooterRole(): AccessibleLandmarkRole;
    /**
     * Gets current value of property {@link #getHeaderLabel headerLabel}.
     *
     * Texts that describe the landmark of the header container of the corresponding `sap.m.Page` control.
     *
     * If not set (and a landmark different than `sap.ui.core.AccessibleLandmarkRole.None` is defined), a predefined
     * text is used.
     *
     *
     * @returns Value of property `headerLabel`
     */
    getHeaderLabel(): string;
    /**
     * Gets current value of property {@link #getHeaderRole headerRole}.
     *
     * Landmark role of the header container of the corresponding `sap.m.Page` control.
     *
     * If set to `sap.ui.core.AccessibleLandmarkRole.None`, no landmark will be added to the container.
     *
     * Default value is `"Region"`.
     *
     *
     * @returns Value of property `headerRole`
     */
    getHeaderRole(): AccessibleLandmarkRole;
    /**
     * Gets current value of property {@link #getRootLabel rootLabel}.
     *
     * Texts that describe the landmark of the root container of the corresponding `sap.m.Page` control.
     *
     * If not set (and a landmark different than `sap.ui.core.AccessibleLandmarkRole.None` is defined), a predefined
     * text is used.
     *
     *
     * @returns Value of property `rootLabel`
     */
    getRootLabel(): string;
    /**
     * Gets current value of property {@link #getRootRole rootRole}.
     *
     * Landmark role of the root container of the corresponding `sap.m.Page` control.
     *
     * If set to `sap.ui.core.AccessibleLandmarkRole.None`, no landmark will be added to the container.
     *
     * Default value is `"Region"`.
     *
     *
     * @returns Value of property `rootRole`
     */
    getRootRole(): AccessibleLandmarkRole;
    /**
     * Gets current value of property {@link #getSubHeaderLabel subHeaderLabel}.
     *
     * Texts that describe the landmark of the subheader container of the corresponding `sap.m.Page` control.
     *
     * If not set (and a landmark different than `sap.ui.core.AccessibleLandmarkRole.None` is defined), a predefined
     * text is used.
     *
     *
     * @returns Value of property `subHeaderLabel`
     */
    getSubHeaderLabel(): string;
    /**
     * Gets current value of property {@link #getSubHeaderRole subHeaderRole}.
     *
     * Landmark role of the subheader container of the corresponding `sap.m.Page` control.
     *
     * If set to `sap.ui.core.AccessibleLandmarkRole.None`, no landmark will be added to the container.
     *
     * Default value is `"None"`.
     *
     *
     * @returns Value of property `subHeaderRole`
     */
    getSubHeaderRole(): AccessibleLandmarkRole;
    /**
     * Sets a new value for property {@link #getContentLabel contentLabel}.
     *
     * Texts that describe the landmark of the content container of the corresponding `sap.m.Page` control.
     *
     * If not set (and a landmark different than `sap.ui.core.AccessibleLandmarkRole.None` is defined), a predefined
     * text is used.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContentLabel(
      /**
       * New value for property `contentLabel`
       */
      sContentLabel?: string
    ): this;
    /**
     * Sets a new value for property {@link #getContentRole contentRole}.
     *
     * Landmark role of the content container of the corresponding `sap.m.Page` control.
     *
     * If set to `sap.ui.core.AccessibleLandmarkRole.None`, no landmark will be added to the container.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Main"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContentRole(
      /**
       * New value for property `contentRole`
       */
      sContentRole?:
        | AccessibleLandmarkRole
        | keyof typeof AccessibleLandmarkRole
    ): this;
    /**
     * Sets a new value for property {@link #getFooterLabel footerLabel}.
     *
     * Texts that describe the landmark of the footer container of the corresponding `sap.m.Page` control.
     *
     * If not set (and a landmark different than `sap.ui.core.AccessibleLandmarkRole.None` is defined), a predefined
     * text is used.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFooterLabel(
      /**
       * New value for property `footerLabel`
       */
      sFooterLabel?: string
    ): this;
    /**
     * Sets a new value for property {@link #getFooterRole footerRole}.
     *
     * Landmark role of the footer container of the corresponding `sap.m.Page` control.
     *
     * If set to `sap.ui.core.AccessibleLandmarkRole.None`, no landmark will be added to the container.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Region"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFooterRole(
      /**
       * New value for property `footerRole`
       */
      sFooterRole?: AccessibleLandmarkRole | keyof typeof AccessibleLandmarkRole
    ): this;
    /**
     * Sets a new value for property {@link #getHeaderLabel headerLabel}.
     *
     * Texts that describe the landmark of the header container of the corresponding `sap.m.Page` control.
     *
     * If not set (and a landmark different than `sap.ui.core.AccessibleLandmarkRole.None` is defined), a predefined
     * text is used.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeaderLabel(
      /**
       * New value for property `headerLabel`
       */
      sHeaderLabel?: string
    ): this;
    /**
     * Sets a new value for property {@link #getHeaderRole headerRole}.
     *
     * Landmark role of the header container of the corresponding `sap.m.Page` control.
     *
     * If set to `sap.ui.core.AccessibleLandmarkRole.None`, no landmark will be added to the container.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Region"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeaderRole(
      /**
       * New value for property `headerRole`
       */
      sHeaderRole?: AccessibleLandmarkRole | keyof typeof AccessibleLandmarkRole
    ): this;
    /**
     * Sets a new value for property {@link #getRootLabel rootLabel}.
     *
     * Texts that describe the landmark of the root container of the corresponding `sap.m.Page` control.
     *
     * If not set (and a landmark different than `sap.ui.core.AccessibleLandmarkRole.None` is defined), a predefined
     * text is used.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRootLabel(
      /**
       * New value for property `rootLabel`
       */
      sRootLabel?: string
    ): this;
    /**
     * Sets a new value for property {@link #getRootRole rootRole}.
     *
     * Landmark role of the root container of the corresponding `sap.m.Page` control.
     *
     * If set to `sap.ui.core.AccessibleLandmarkRole.None`, no landmark will be added to the container.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Region"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRootRole(
      /**
       * New value for property `rootRole`
       */
      sRootRole?: AccessibleLandmarkRole | keyof typeof AccessibleLandmarkRole
    ): this;
    /**
     * Sets a new value for property {@link #getSubHeaderLabel subHeaderLabel}.
     *
     * Texts that describe the landmark of the subheader container of the corresponding `sap.m.Page` control.
     *
     * If not set (and a landmark different than `sap.ui.core.AccessibleLandmarkRole.None` is defined), a predefined
     * text is used.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSubHeaderLabel(
      /**
       * New value for property `subHeaderLabel`
       */
      sSubHeaderLabel?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSubHeaderRole subHeaderRole}.
     *
     * Landmark role of the subheader container of the corresponding `sap.m.Page` control.
     *
     * If set to `sap.ui.core.AccessibleLandmarkRole.None`, no landmark will be added to the container.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"None"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSubHeaderRole(
      /**
       * New value for property `subHeaderRole`
       */
      sSubHeaderRole?:
        | AccessibleLandmarkRole
        | keyof typeof AccessibleLandmarkRole
    ): this;
  }
  /**
   * Describes the settings that can be provided to the PageAccessibleLandmarkInfo constructor.
   */
  export interface $PageAccessibleLandmarkInfoSettings
    extends $ElementSettings {
    /**
     * Landmark role of the root container of the corresponding `sap.m.Page` control.
     *
     * If set to `sap.ui.core.AccessibleLandmarkRole.None`, no landmark will be added to the container.
     */
    rootRole?:
      | (AccessibleLandmarkRole | keyof typeof AccessibleLandmarkRole)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Texts that describe the landmark of the root container of the corresponding `sap.m.Page` control.
     *
     * If not set (and a landmark different than `sap.ui.core.AccessibleLandmarkRole.None` is defined), a predefined
     * text is used.
     */
    rootLabel?: string | PropertyBindingInfo;

    /**
     * Landmark role of the content container of the corresponding `sap.m.Page` control.
     *
     * If set to `sap.ui.core.AccessibleLandmarkRole.None`, no landmark will be added to the container.
     */
    contentRole?:
      | (AccessibleLandmarkRole | keyof typeof AccessibleLandmarkRole)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Texts that describe the landmark of the content container of the corresponding `sap.m.Page` control.
     *
     * If not set (and a landmark different than `sap.ui.core.AccessibleLandmarkRole.None` is defined), a predefined
     * text is used.
     */
    contentLabel?: string | PropertyBindingInfo;

    /**
     * Landmark role of the header container of the corresponding `sap.m.Page` control.
     *
     * If set to `sap.ui.core.AccessibleLandmarkRole.None`, no landmark will be added to the container.
     */
    headerRole?:
      | (AccessibleLandmarkRole | keyof typeof AccessibleLandmarkRole)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Texts that describe the landmark of the header container of the corresponding `sap.m.Page` control.
     *
     * If not set (and a landmark different than `sap.ui.core.AccessibleLandmarkRole.None` is defined), a predefined
     * text is used.
     */
    headerLabel?: string | PropertyBindingInfo;

    /**
     * Landmark role of the subheader container of the corresponding `sap.m.Page` control.
     *
     * If set to `sap.ui.core.AccessibleLandmarkRole.None`, no landmark will be added to the container.
     */
    subHeaderRole?:
      | (AccessibleLandmarkRole | keyof typeof AccessibleLandmarkRole)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Texts that describe the landmark of the subheader container of the corresponding `sap.m.Page` control.
     *
     * If not set (and a landmark different than `sap.ui.core.AccessibleLandmarkRole.None` is defined), a predefined
     * text is used.
     */
    subHeaderLabel?: string | PropertyBindingInfo;

    /**
     * Landmark role of the footer container of the corresponding `sap.m.Page` control.
     *
     * If set to `sap.ui.core.AccessibleLandmarkRole.None`, no landmark will be added to the container.
     */
    footerRole?:
      | (AccessibleLandmarkRole | keyof typeof AccessibleLandmarkRole)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Texts that describe the landmark of the footer container of the corresponding `sap.m.Page` control.
     *
     * If not set (and a landmark different than `sap.ui.core.AccessibleLandmarkRole.None` is defined), a predefined
     * text is used.
     */
    footerLabel?: string | PropertyBindingInfo;
  }
}

declare module "sap/m/PagingButton" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * Enables users to navigate between items/entities.
   *
   * @since 1.30
   */
  export default class PagingButton extends Control {
    /**
     * Constructor for a new PagingButton.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $PagingButtonSettings
    );
    /**
     * Constructor for a new PagingButton.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $PagingButtonSettings
    );

    /**
     * Creates a new subclass of class sap.m.PagingButton with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, PagingButton>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.PagingButton.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:positionChange positionChange} event of this
     * `sap.m.PagingButton`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PagingButton` itself.
     *
     * Fired when the current position is changed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPositionChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PagingButton$PositionChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PagingButton` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:positionChange positionChange} event of this
     * `sap.m.PagingButton`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PagingButton` itself.
     *
     * Fired when the current position is changed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPositionChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PagingButton$PositionChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PagingButton` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:positionChange positionChange} event of this
     * `sap.m.PagingButton`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPositionChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: PagingButton$PositionChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:positionChange positionChange} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePositionChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: PagingButton$PositionChangeEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getCount count}.
     *
     * Determines the total count of items/entities that the control navigates through. The minimum number of
     * items/entities is 1.
     *
     * Default value is `1`.
     *
     *
     * @returns Value of property `count`
     */
    getCount(): int;
    /**
     * Gets current value of property {@link #getNextButtonTooltip nextButtonTooltip}.
     *
     * Determines the tooltip of the next button.
     *
     * Default value is `empty string`.
     *
     * @since 1.36
     *
     * @returns Value of property `nextButtonTooltip`
     */
    getNextButtonTooltip(): string;
    /**
     * Gets current value of property {@link #getPosition position}.
     *
     * Determines the current position in the items/entities that the control navigates through. Starting (minimum)
     * number is 1.
     *
     * Default value is `1`.
     *
     *
     * @returns Value of property `position`
     */
    getPosition(): int;
    /**
     * Gets current value of property {@link #getPreviousButtonTooltip previousButtonTooltip}.
     *
     * Determines the tooltip of the previous button.
     *
     * Default value is `empty string`.
     *
     * @since 1.36
     *
     * @returns Value of property `previousButtonTooltip`
     */
    getPreviousButtonTooltip(): string;
    /**
     * Sets a new value for property {@link #getCount count}.
     *
     * Determines the total count of items/entities that the control navigates through. The minimum number of
     * items/entities is 1.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `1`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCount(
      /**
       * New value for property `count`
       */
      iCount?: int
    ): this;
    /**
     * Sets a new value for property {@link #getNextButtonTooltip nextButtonTooltip}.
     *
     * Determines the tooltip of the next button.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.36
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNextButtonTooltip(
      /**
       * New value for property `nextButtonTooltip`
       */
      sNextButtonTooltip?: string
    ): this;
    /**
     * Sets a new value for property {@link #getPosition position}.
     *
     * Determines the current position in the items/entities that the control navigates through. Starting (minimum)
     * number is 1.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `1`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPosition(
      /**
       * New value for property `position`
       */
      iPosition?: int
    ): this;
    /**
     * Sets a new value for property {@link #getPreviousButtonTooltip previousButtonTooltip}.
     *
     * Determines the tooltip of the previous button.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.36
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPreviousButtonTooltip(
      /**
       * New value for property `previousButtonTooltip`
       */
      sPreviousButtonTooltip?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the PagingButton constructor.
   */
  export interface $PagingButtonSettings extends $ControlSettings {
    /**
     * Determines the total count of items/entities that the control navigates through. The minimum number of
     * items/entities is 1.
     */
    count?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the current position in the items/entities that the control navigates through. Starting (minimum)
     * number is 1.
     */
    position?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the tooltip of the next button.
     *
     * @since 1.36
     */
    nextButtonTooltip?: string | PropertyBindingInfo;

    /**
     * Determines the tooltip of the previous button.
     *
     * @since 1.36
     */
    previousButtonTooltip?: string | PropertyBindingInfo;

    /**
     * Fired when the current position is changed.
     */
    positionChange?: (oEvent: PagingButton$PositionChangeEvent) => void;
  }

  /**
   * Parameters of the PagingButton#positionChange event.
   */
  export interface PagingButton$PositionChangeEventParameters {
    /**
     * The number of the new position.
     */
    newPosition?: int;

    /**
     * The number of the old position.
     */
    oldPosition?: int;
  }

  /**
   * Event object of the PagingButton#positionChange event.
   */
  export type PagingButton$PositionChangeEvent = Event<
    PagingButton$PositionChangeEventParameters,
    PagingButton
  >;
}

declare module "sap/m/Panel" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { PanelAccessibleRole, BackgroundDesign } from "sap/m/library";

  import Toolbar from "sap/m/Toolbar";

  import { CSSSize } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * A container control which has a header and content. Overview: The panel is a container for grouping and
   * displaying information. It can be collapsed to save space on the screen. Guidelines::
   * 	 - Nesting two or more panels is not recommended.
   * 	 - Do not stack too many panels on one page.  Structure: A panel consists of a title bar with a
   *     header text or header toolbar, an info toolbar (optional), and a content area. Using the `headerToolbar`
   *     aggregation, you can add a toolbar with any toolbar content (i.e. custom buttons, spacers, titles) inside
   *     the title bar.
   *
   * There are two types of panels: fixed and expandable. Expendable panels are enabled by the `expandable`
   * property. Furthermore you can define an expand animation with the property `expandAnimation`. Usage:
   * When to use::
   * 	 - You need to group or display information and want to give users the option of hiding this information.
   *
   * 	 - You want to show additional information on demand (for example, a panel could show optional input
   *     fields for an advanced search).
   * 	 - You want to create a panel with controls that do not require user interaction and are not part of
   *     a form. Depending on the usage, change the `accessibleRole` property from the default `{@link sap.m.PanelAccessibleRole Form}`
   *     to `{@link sap.m.PanelAccessibleRole Region}` or `{@link sap.m.PanelAccessibleRole Complementary}`.
   *     Responsive Behavior:
   * 	 - If the width of the panel is set to 100% (default), the panel and its children are resized responsively,
   *     depending on its parent container.
   * 	 - If the panel has a fixed defined height, it will take up the space, even if the panel is collapsed.
   *
   * 	 - When the panel is expandable, an arrow icon (pointing to the right) appears in front of the header.
   *
   * 	 - When the animation is activated, expand/collapse uses a smooth animation to open or close the content
   *     area.
   * 	 - When the panel expands/collapses, the arrow icon rotates 90 degrees clockwise/counter-clockwise.
   *
   * 	 - When the height uses the default property `auto`, the height of the content area is automatically
   *     adjusted to match the height of its content.
   * 	 - When the height of the panel is set to a fixed size, the content area can be scrolled through.
   *
   * @since 1.16
   */
  export default class Panel extends Control {
    /**
     * Constructor for a new Panel.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/panel/ Panel}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $PanelSettings
    );
    /**
     * Constructor for a new Panel.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/panel/ Panel}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $PanelSettings
    );

    /**
     * Creates a new subclass of class sap.m.Panel with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Panel>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Panel.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some content to the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContent(
      /**
       * The content to add; if empty, nothing is inserted
       */
      oContent: Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:expand expand} event of this `sap.m.Panel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Panel` itself.
     *
     * Indicates that the panel will expand or collapse.
     *
     * @since 1.22
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachExpand(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Panel$ExpandEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Panel` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:expand expand} event of this `sap.m.Panel`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Panel` itself.
     *
     * Indicates that the panel will expand or collapse.
     *
     * @since 1.22
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachExpand(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Panel$ExpandEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Panel` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Destroys the headerToolbar in the aggregation {@link #getHeaderToolbar headerToolbar}.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyHeaderToolbar(): this;
    /**
     * Destroys the infoToolbar in the aggregation {@link #getInfoToolbar infoToolbar}.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyInfoToolbar(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:expand expand} event of this `sap.m.Panel`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.22
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachExpand(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Panel$ExpandEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:expand expand} to attached listeners.
     *
     * @since 1.22
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireExpand(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Panel$ExpandEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getAccessibleRole accessibleRole}.
     *
     * This property is used to set the accessible aria role of the Panel. Depending on the usage you can change
     * the role from the default `Form` to `Region` or `Complementary`.
     *
     * Default value is `Form`.
     *
     * @since 1.46
     *
     * @returns Value of property `accessibleRole`
     */
    getAccessibleRole(): PanelAccessibleRole;
    /**
     * Gets current value of property {@link #getBackgroundDesign backgroundDesign}.
     *
     * This property is used to set the background color of the Panel. Depending on the theme you can change
     * the state of the background from "Solid" over "Translucent" to "Transparent".
     *
     * Default value is `Translucent`.
     *
     * @since 1.30
     *
     * @returns Value of property `backgroundDesign`
     */
    getBackgroundDesign(): BackgroundDesign;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * Determines the content of the Panel. The content will be visible only when the Panel is expanded.
     */
    getContent(): Control[];
    /**
     * Gets current value of property {@link #getExpandable expandable}.
     *
     * Specifies whether the control is expandable. This allows for collapsing or expanding the infoToolbar
     * (if available) and content of the Panel. Note: If expandable is set to false, the Panel will always be
     * rendered expanded.
     *
     * Default value is `false`.
     *
     * @since 1.22
     *
     * @returns Value of property `expandable`
     */
    getExpandable(): boolean;
    /**
     * Gets current value of property {@link #getExpandAnimation expandAnimation}.
     *
     * Indicates whether the transition between the expanded and the collapsed state of the control is animated.
     * By default the animation is enabled.
     *
     * Default value is `true`.
     *
     * @since 1.26
     *
     * @returns Value of property `expandAnimation`
     */
    getExpandAnimation(): boolean;
    /**
     * Gets current value of property {@link #getExpanded expanded}.
     *
     * Indicates whether the Panel is expanded or not. If expanded is set to true, then both the infoToolbar
     * (if available) and the content are rendered. If expanded is set to false, then only the headerText or
     * headerToolbar is rendered.
     *
     * Default value is `false`.
     *
     * @since 1.22
     *
     * @returns Value of property `expanded`
     */
    getExpanded(): boolean;
    /**
     * Gets current value of property {@link #getHeaderText headerText}.
     *
     * This property is used to set the header text of the Panel. The "headerText" is visible in both expanded
     * and collapsed state. Note: This property is overwritten by the "headerToolbar" aggregation.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `headerText`
     */
    getHeaderText(): string;
    /**
     * Gets content of aggregation {@link #getHeaderToolbar headerToolbar}.
     *
     * This aggregation allows the use of a custom Toolbar as header for the Panel. The "headerToolbar" is visible
     * in both expanded and collapsed state. Use it when you want to add extra controls for user interactions
     * in the header. Note: This aggregation overwrites "headerText" property.
     *
     * @since 1.16
     */
    getHeaderToolbar(): Toolbar;
    /**
     * Gets current value of property {@link #getHeight height}.
     *
     * Determines the Panel height.
     *
     * Default value is `"auto"`.
     *
     *
     * @returns Value of property `height`
     */
    getHeight(): CSSSize;
    /**
     * Gets content of aggregation {@link #getInfoToolbar infoToolbar}.
     *
     * This aggregation allows the use of a custom Toolbar as information bar for the Panel. The "infoToolbar"
     * is placed below the header and is visible only in expanded state. Use it when you want to show extra
     * information to the user.
     *
     * @since 1.16
     */
    getInfoToolbar(): Toolbar;
    /**
     * Gets current value of property {@link #getStickyHeader stickyHeader}.
     *
     * Indicates whether the Panel header is sticky or not. If stickyHeader is set to true, then whenever you
     * scroll the content or the application, the header of the panel will be always visible and a solid color
     * will be used for its design.
     *
     * Default value is `false`.
     *
     * @since 1.117
     *
     * @returns Value of property `stickyHeader`
     */
    getStickyHeader(): boolean;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Determines the Panel width.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContent content}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContent(
      /**
       * The content whose index is looked for
       */
      oContent: Control
    ): int;
    /**
     * Inserts a content into the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContent(
      /**
       * The content to insert; if empty, nothing is inserted
       */
      oContent: Control,
      /**
       * The `0`-based index the content should be inserted at; for a negative value of `iIndex`, the content
       * is inserted at position 0; for a value greater than the current size of the aggregation, the content
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getContent content}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContent(): Control[];
    /**
     * Removes a content from the aggregation {@link #getContent content}.
     *
     *
     * @returns The removed content or `null`
     */
    removeContent(
      /**
       * The content to remove or its index or id
       */
      vContent: int | string | Control
    ): Control | null;
    /**
     * Sets a new value for property {@link #getAccessibleRole accessibleRole}.
     *
     * This property is used to set the accessible aria role of the Panel. Depending on the usage you can change
     * the role from the default `Form` to `Region` or `Complementary`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Form`.
     *
     * @since 1.46
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAccessibleRole(
      /**
       * New value for property `accessibleRole`
       */
      sAccessibleRole?: PanelAccessibleRole | keyof typeof PanelAccessibleRole
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundDesign backgroundDesign}.
     *
     * This property is used to set the background color of the Panel. Depending on the theme you can change
     * the state of the background from "Solid" over "Translucent" to "Transparent".
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Translucent`.
     *
     * @since 1.30
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundDesign(
      /**
       * New value for property `backgroundDesign`
       */
      sBackgroundDesign?: BackgroundDesign | keyof typeof BackgroundDesign
    ): this;
    /**
     * Sets a new value for property {@link #getExpandable expandable}.
     *
     * Specifies whether the control is expandable. This allows for collapsing or expanding the infoToolbar
     * (if available) and content of the Panel. Note: If expandable is set to false, the Panel will always be
     * rendered expanded.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.22
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setExpandable(
      /**
       * New value for property `expandable`
       */
      bExpandable?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getExpandAnimation expandAnimation}.
     *
     * Indicates whether the transition between the expanded and the collapsed state of the control is animated.
     * By default the animation is enabled.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.26
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setExpandAnimation(
      /**
       * New value for property `expandAnimation`
       */
      bExpandAnimation?: boolean
    ): this;
    /**
     * Sets the expanded property of the control.
     *
     *
     * @returns Pointer to the control instance to allow method chaining.
     */
    setExpanded(
      /**
       * Defines whether control is expanded or not.
       */
      bExpanded: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getHeaderText headerText}.
     *
     * This property is used to set the header text of the Panel. The "headerText" is visible in both expanded
     * and collapsed state. Note: This property is overwritten by the "headerToolbar" aggregation.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeaderText(
      /**
       * New value for property `headerText`
       */
      sHeaderText?: string
    ): this;
    /**
     * Sets the aggregated {@link #getHeaderToolbar headerToolbar}.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeaderToolbar(
      /**
       * The headerToolbar to set
       */
      oHeaderToolbar: Toolbar
    ): this;
    /**
     * Sets a new value for property {@link #getHeight height}.
     *
     * Determines the Panel height.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"auto"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeight(
      /**
       * New value for property `height`
       */
      sHeight?: CSSSize
    ): this;
    /**
     * Sets the aggregated {@link #getInfoToolbar infoToolbar}.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInfoToolbar(
      /**
       * The infoToolbar to set
       */
      oInfoToolbar: Toolbar
    ): this;
    /**
     * Sets a new value for property {@link #getStickyHeader stickyHeader}.
     *
     * Indicates whether the Panel header is sticky or not. If stickyHeader is set to true, then whenever you
     * scroll the content or the application, the header of the panel will be always visible and a solid color
     * will be used for its design.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.117
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setStickyHeader(
      /**
       * New value for property `stickyHeader`
       */
      bStickyHeader?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Determines the Panel width.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Panel constructor.
   */
  export interface $PanelSettings extends $ControlSettings {
    /**
     * This property is used to set the header text of the Panel. The "headerText" is visible in both expanded
     * and collapsed state. Note: This property is overwritten by the "headerToolbar" aggregation.
     */
    headerText?: string | PropertyBindingInfo;

    /**
     * Determines the Panel width.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the Panel height.
     */
    height?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies whether the control is expandable. This allows for collapsing or expanding the infoToolbar
     * (if available) and content of the Panel. Note: If expandable is set to false, the Panel will always be
     * rendered expanded.
     *
     * @since 1.22
     */
    expandable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether the Panel is expanded or not. If expanded is set to true, then both the infoToolbar
     * (if available) and the content are rendered. If expanded is set to false, then only the headerText or
     * headerToolbar is rendered.
     *
     * @since 1.22
     */
    expanded?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether the transition between the expanded and the collapsed state of the control is animated.
     * By default the animation is enabled.
     *
     * @since 1.26
     */
    expandAnimation?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This property is used to set the background color of the Panel. Depending on the theme you can change
     * the state of the background from "Solid" over "Translucent" to "Transparent".
     *
     * @since 1.30
     */
    backgroundDesign?:
      | (BackgroundDesign | keyof typeof BackgroundDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * This property is used to set the accessible aria role of the Panel. Depending on the usage you can change
     * the role from the default `Form` to `Region` or `Complementary`.
     *
     * @since 1.46
     */
    accessibleRole?:
      | (PanelAccessibleRole | keyof typeof PanelAccessibleRole)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Indicates whether the Panel header is sticky or not. If stickyHeader is set to true, then whenever you
     * scroll the content or the application, the header of the panel will be always visible and a solid color
     * will be used for its design.
     *
     * @since 1.117
     */
    stickyHeader?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the content of the Panel. The content will be visible only when the Panel is expanded.
     */
    content?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * This aggregation allows the use of a custom Toolbar as header for the Panel. The "headerToolbar" is visible
     * in both expanded and collapsed state. Use it when you want to add extra controls for user interactions
     * in the header. Note: This aggregation overwrites "headerText" property.
     *
     * @since 1.16
     */
    headerToolbar?: Toolbar;

    /**
     * This aggregation allows the use of a custom Toolbar as information bar for the Panel. The "infoToolbar"
     * is placed below the header and is visible only in expanded state. Use it when you want to show extra
     * information to the user.
     *
     * @since 1.16
     */
    infoToolbar?: Toolbar;

    /**
     * Indicates that the panel will expand or collapse.
     *
     * @since 1.22
     */
    expand?: (oEvent: Panel$ExpandEvent) => void;
  }

  /**
   * Parameters of the Panel#expand event.
   */
  export interface Panel$ExpandEventParameters {
    /**
     * If the panel will expand, this is true. If the panel will collapse, this is false.
     */
    expand?: boolean;

    /**
     * Identifies whether the event is triggered by an user interaction or by calling setExpanded.
     */
    triggeredByInteraction?: boolean;
  }

  /**
   * Event object of the Panel#expand event.
   */
  export type Panel$ExpandEvent = Event<Panel$ExpandEventParameters, Panel>;
}

declare module "sap/m/PDFViewer" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import Button from "sap/m/Button";

  import Event from "sap/ui/base/Event";

  import { PDFViewerDisplayType } from "sap/m/library";

  import { CSSSize, URI } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    default as ManagedObject,
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * This control enables you to display PDF documents within your app. It can be embedded in your user
   * interface layout, or you can set it to open in a popup dialog. Please note that the PDF Viewer
   * control can be fully displayed on desktop devices only. On mobile devices, only the toolbar with a download
   * button is visible.
   *
   * @since 1.48
   */
  export default class PDFViewer extends Control {
    /**
     * Definition of PDFViewer control
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/cd80a8bca4ac450b86547d78f0653330 PDF Viewer}
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $PDFViewerSettings
    );
    /**
     * Definition of PDFViewer control
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/cd80a8bca4ac450b86547d78f0653330 PDF Viewer}
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $PDFViewerSettings
    );

    /**
     * Creates a new subclass of class sap.m.PDFViewer with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, PDFViewer>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.PDFViewer.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some popupButton to the aggregation {@link #getPopupButtons popupButtons}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addPopupButton(
      /**
       * The popupButton to add; if empty, nothing is inserted
       */
      oPopupButton: Button
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:error error} event of this `sap.m.PDFViewer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PDFViewer` itself.
     *
     * This event is fired when there is an error loading the PDF file.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachError(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PDFViewer$ErrorEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PDFViewer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:error error} event of this `sap.m.PDFViewer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PDFViewer` itself.
     *
     * This event is fired when there is an error loading the PDF file.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachError(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PDFViewer$ErrorEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PDFViewer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:loaded loaded} event of this `sap.m.PDFViewer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PDFViewer` itself.
     *
     * This event is fired when a PDF file is loaded. If the PDF is loaded in smaller chunks, this event is
     * fired as often as defined by the browser's plugin. This may happen after a couple chunks are processed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLoaded(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PDFViewer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:loaded loaded} event of this `sap.m.PDFViewer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PDFViewer` itself.
     *
     * This event is fired when a PDF file is loaded. If the PDF is loaded in smaller chunks, this event is
     * fired as often as defined by the browser's plugin. This may happen after a couple chunks are processed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLoaded(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PDFViewer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:sourceValidationFailed sourceValidationFailed }
     * event of this `sap.m.PDFViewer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PDFViewer` itself.
     *
     * This event is fired when the PDF viewer control cannot check the loaded content. For example, the default
     * configuration of the Mozilla Firefox browser may not allow checking the loaded content. This may also
     * happen when the source PDF file is stored in a different domain. If you want no error message to be displayed
     * when this event is fired, call the preventDefault() method inside the event handler.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSourceValidationFailed(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PDFViewer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:sourceValidationFailed sourceValidationFailed }
     * event of this `sap.m.PDFViewer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PDFViewer` itself.
     *
     * This event is fired when the PDF viewer control cannot check the loaded content. For example, the default
     * configuration of the Mozilla Firefox browser may not allow checking the loaded content. This may also
     * happen when the source PDF file is stored in a different domain. If you want no error message to be displayed
     * when this event is fired, call the preventDefault() method inside the event handler.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSourceValidationFailed(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PDFViewer` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys the errorPlaceholder in the aggregation {@link #getErrorPlaceholder errorPlaceholder}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyErrorPlaceholder(): this;
    /**
     * Destroys all the popupButtons in the aggregation {@link #getPopupButtons popupButtons}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyPopupButtons(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:error error} event of this `sap.m.PDFViewer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachError(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: PDFViewer$ErrorEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:loaded loaded} event of this `sap.m.PDFViewer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLoaded(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:sourceValidationFailed sourceValidationFailed }
     * event of this `sap.m.PDFViewer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSourceValidationFailed(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Downloads the PDF file.
     */
    downloadPDF(): void;
    /**
     * Fires event {@link #event:error error} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireError(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: PDFViewer$ErrorEventParameters
    ): this;
    /**
     * Fires event {@link #event:loaded loaded} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLoaded(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:sourceValidationFailed sourceValidationFailed} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSourceValidationFailed(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getDisplayType displayType}.
     *
     * Defines how the PDF viewer should be displayed.
     * 	 - If set to `Link`, the PDF viewer appears as a toolbar with a download button that can be used to
     *     download the PDF file.
     *  When the {@link #open} method is called, the user can either open the PDF file in a new tab or download
     * it.
     * 	 - If set to `Embedded`, the PDF viewer appears embedded in the parent container and displays either
     *     the PDF document or the message defined by the `errorPlaceholderMessage` property.
     * 	 - If set to `Auto`, the appearance of the PDF viewer depends on the device being used:
     * 	On mobile devices (phones, tablets), the PDF viewer appears as a toolbar with a download button.
     * 	 - On desktop devices, the PDF viewer is embedded in its parent container.
     *
     * Default value is `Auto`.
     *
     *
     * @returns Value of property `displayType`
     */
    getDisplayType(): PDFViewerDisplayType;
    /**
     * Gets current value of property {@link #getErrorMessage errorMessage}.
     *
     * A custom error message that is displayed when the PDF file cannot be loaded.
     *
     * @deprecated As of version 1.50.0. replaced by {@link sap.m.PDFViewer#getErrorPlaceholderMessage}.
     *
     * @returns Value of property `errorMessage`
     */
    getErrorMessage(): string;
    /**
     * Gets content of aggregation {@link #getErrorPlaceholder errorPlaceholder}.
     *
     * A custom control that can be used instead of the error message specified by the errorPlaceholderMessage
     * property.
     */
    getErrorPlaceholder(): Control;
    /**
     * Gets current value of property {@link #getErrorPlaceholderMessage errorPlaceholderMessage}.
     *
     * A custom text that is displayed instead of the PDF file content when the PDF file cannot be loaded.
     *
     *
     * @returns Value of property `errorPlaceholderMessage`
     */
    getErrorPlaceholderMessage(): string;
    /**
     * Gets current value of property {@link #getHeight height}.
     *
     * Defines the height of the PDF viewer control, respective to the height of the parent container. Can be
     * set to a percent, pixel, or em value.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Value of property `height`
     */
    getHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getIsTrustedSource isTrustedSource}.
     *
     * Parameter to determine if the given PDF is from a trusted source. If the source is valid this property
     * can be set to true. If isTrustedSource is set to true, the PDFViewer opens with the displayType set to
     * "Embedded" on desktop devices. This means that the PDF content is directly shown within the PDFViewer.
     * Set this property to true only when the PDF is generated by the application or the PDF is scanned for
     * viruses. If isTrustedSource is set to false, the PDFViewer opens with the displayType set to "Link" on
     * desktop devices. This means that any configuration that has been provided by the application for the
     * property displayType is overridden. In this case, the user would need to download the PDF to view its
     * content.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `isTrustedSource`
     */
    getIsTrustedSource(): boolean;
    /**
     * Gets content of aggregation {@link #getPopupButtons popupButtons}.
     *
     * A multiple aggregation for buttons that can be added to the footer of the popup dialog. Works only if
     * the PDF viewer is set to open in a popup dialog.
     */
    getPopupButtons(): Button[];
    /**
     * Gets current value of property {@link #getPopupHeaderTitle popupHeaderTitle}.
     *
     * A custom title for the PDF viewer popup dialog. Works only if the PDF viewer is set to open in a popup
     * dialog.
     *
     * @deprecated As of version 1.50.0. replaced by {@link sap.m.PDFViewer#getTitle}.
     *
     * @returns Value of property `popupHeaderTitle`
     */
    getPopupHeaderTitle(): string;
    /**
     * Gets current value of property {@link #getShowDownloadButton showDownloadButton}.
     *
     * Shows or hides the download button.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showDownloadButton`
     */
    getShowDownloadButton(): boolean;
    /**
     * Gets current value of property {@link #getSource source}.
     *
     * Specifies the path to the PDF file to display. Can be set to a relative or an absolute path.
     *  Optionally, this property can also be set to a data URI path or a blob URL in all major web browsers
     * except Internet Explorer and Microsoft Edge, provided that this data URI or blob URL is allowed in advance.
     * For more information about URL filtering, see {@link https://ui5.sap.com/#/topic/91f3768f6f4d1014b6dd926db0e91070 URLList Validator Filtering}.
     *
     *
     * @returns Value of property `source`
     */
    getSource(): URI;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * A custom title for the PDF viewer.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Defines the width of the PDF viewer control, respective to the width of the parent container. Can be
     * set to a percent, pixel, or em value.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Checks for the provided `sap.m.Button` in the aggregation {@link #getPopupButtons popupButtons}. and
     * returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfPopupButton(
      /**
       * The popupButton whose index is looked for
       */
      oPopupButton: Button
    ): int;
    /**
     * Inserts a popupButton into the aggregation {@link #getPopupButtons popupButtons}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertPopupButton(
      /**
       * The popupButton to insert; if empty, nothing is inserted
       */
      oPopupButton: Button,
      /**
       * The `0`-based index the popupButton should be inserted at; for a negative value of `iIndex`, the popupButton
       * is inserted at position 0; for a value greater than the current size of the aggregation, the popupButton
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Triggers rerendering of this element and its children.
     */
    invalidate(
      /**
       * Child control for which the method was called
       */
      oOrigin?: ManagedObject
    ): void;
    /**
     * Opens the PDF viewer in a popup dialog.
     */
    open(): void;
    /**
     * Removes all the controls from the aggregation {@link #getPopupButtons popupButtons}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllPopupButtons(): Button[];
    /**
     * Removes a popupButton from the aggregation {@link #getPopupButtons popupButtons}.
     *
     *
     * @returns The removed popupButton or `null`
     */
    removePopupButton(
      /**
       * The popupButton to remove or its index or id
       */
      vPopupButton: int | string | Button
    ): Button | null;
    /**
     * Sets a new value for property {@link #getDisplayType displayType}.
     *
     * Defines how the PDF viewer should be displayed.
     * 	 - If set to `Link`, the PDF viewer appears as a toolbar with a download button that can be used to
     *     download the PDF file.
     *  When the {@link #open} method is called, the user can either open the PDF file in a new tab or download
     * it.
     * 	 - If set to `Embedded`, the PDF viewer appears embedded in the parent container and displays either
     *     the PDF document or the message defined by the `errorPlaceholderMessage` property.
     * 	 - If set to `Auto`, the appearance of the PDF viewer depends on the device being used:
     * 	On mobile devices (phones, tablets), the PDF viewer appears as a toolbar with a download button.
     * 	 - On desktop devices, the PDF viewer is embedded in its parent container.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisplayType(
      /**
       * New value for property `displayType`
       */
      sDisplayType?: PDFViewerDisplayType | keyof typeof PDFViewerDisplayType
    ): this;
    /**
     * Sets a new value for property {@link #getErrorMessage errorMessage}.
     *
     * A custom error message that is displayed when the PDF file cannot be loaded.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @deprecated As of version 1.50.0. replaced by {@link sap.m.PDFViewer#getErrorPlaceholderMessage}.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setErrorMessage(
      /**
       * New value for property `errorMessage`
       */
      sErrorMessage?: string
    ): this;
    /**
     * Sets the aggregated {@link #getErrorPlaceholder errorPlaceholder}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setErrorPlaceholder(
      /**
       * The errorPlaceholder to set
       */
      oErrorPlaceholder: Control
    ): this;
    /**
     * Sets a new value for property {@link #getErrorPlaceholderMessage errorPlaceholderMessage}.
     *
     * A custom text that is displayed instead of the PDF file content when the PDF file cannot be loaded.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setErrorPlaceholderMessage(
      /**
       * New value for property `errorPlaceholderMessage`
       */
      sErrorPlaceholderMessage?: string
    ): this;
    /**
     * Sets a new value for property {@link #getHeight height}.
     *
     * Defines the height of the PDF viewer control, respective to the height of the parent container. Can be
     * set to a percent, pixel, or em value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeight(
      /**
       * New value for property `height`
       */
      sHeight?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getIsTrustedSource isTrustedSource}.
     *
     * Parameter to determine if the given PDF is from a trusted source. If the source is valid this property
     * can be set to true. If isTrustedSource is set to true, the PDFViewer opens with the displayType set to
     * "Embedded" on desktop devices. This means that the PDF content is directly shown within the PDFViewer.
     * Set this property to true only when the PDF is generated by the application or the PDF is scanned for
     * viruses. If isTrustedSource is set to false, the PDFViewer opens with the displayType set to "Link" on
     * desktop devices. This means that any configuration that has been provided by the application for the
     * property displayType is overridden. In this case, the user would need to download the PDF to view its
     * content.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIsTrustedSource(
      /**
       * New value for property `isTrustedSource`
       */
      bIsTrustedSource?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getPopupHeaderTitle popupHeaderTitle}.
     *
     * A custom title for the PDF viewer popup dialog. Works only if the PDF viewer is set to open in a popup
     * dialog.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @deprecated As of version 1.50.0. replaced by {@link sap.m.PDFViewer#getTitle}.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPopupHeaderTitle(
      /**
       * New value for property `popupHeaderTitle`
       */
      sPopupHeaderTitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getShowDownloadButton showDownloadButton}.
     *
     * Shows or hides the download button.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowDownloadButton(
      /**
       * New value for property `showDownloadButton`
       */
      bShowDownloadButton?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getSource source}.
     *
     * Specifies the path to the PDF file to display. Can be set to a relative or an absolute path.
     *  Optionally, this property can also be set to a data URI path or a blob URL in all major web browsers
     * except Internet Explorer and Microsoft Edge, provided that this data URI or blob URL is allowed in advance.
     * For more information about URL filtering, see {@link https://ui5.sap.com/#/topic/91f3768f6f4d1014b6dd926db0e91070 URLList Validator Filtering}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSource(
      /**
       * New value for property `source`
       */
      sSource?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * A custom title for the PDF viewer.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Defines the width of the PDF viewer control, respective to the width of the parent container. Can be
     * set to a percent, pixel, or em value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
  }
  /**
   * Describes the settings that can be provided to the PDFViewer constructor.
   */
  export interface $PDFViewerSettings extends $ControlSettings {
    /**
     * Defines the height of the PDF viewer control, respective to the height of the parent container. Can be
     * set to a percent, pixel, or em value.
     */
    height?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the width of the PDF viewer control, respective to the width of the parent container. Can be
     * set to a percent, pixel, or em value.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the path to the PDF file to display. Can be set to a relative or an absolute path.
     *  Optionally, this property can also be set to a data URI path or a blob URL in all major web browsers
     * except Internet Explorer and Microsoft Edge, provided that this data URI or blob URL is allowed in advance.
     * For more information about URL filtering, see {@link https://ui5.sap.com/#/topic/91f3768f6f4d1014b6dd926db0e91070 URLList Validator Filtering}.
     */
    source?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * A custom error message that is displayed when the PDF file cannot be loaded.
     *
     * @deprecated As of version 1.50.0. replaced by {@link sap.m.PDFViewer#getErrorPlaceholderMessage}.
     */
    errorMessage?: string | PropertyBindingInfo;

    /**
     * A custom text that is displayed instead of the PDF file content when the PDF file cannot be loaded.
     */
    errorPlaceholderMessage?: string | PropertyBindingInfo;

    /**
     * A custom title for the PDF viewer popup dialog. Works only if the PDF viewer is set to open in a popup
     * dialog.
     *
     * @deprecated As of version 1.50.0. replaced by {@link sap.m.PDFViewer#getTitle}.
     */
    popupHeaderTitle?: string | PropertyBindingInfo;

    /**
     * A custom title for the PDF viewer.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Shows or hides the download button.
     */
    showDownloadButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines how the PDF viewer should be displayed.
     * 	 - If set to `Link`, the PDF viewer appears as a toolbar with a download button that can be used to
     *     download the PDF file.
     *  When the {@link #open} method is called, the user can either open the PDF file in a new tab or download
     * it.
     * 	 - If set to `Embedded`, the PDF viewer appears embedded in the parent container and displays either
     *     the PDF document or the message defined by the `errorPlaceholderMessage` property.
     * 	 - If set to `Auto`, the appearance of the PDF viewer depends on the device being used:
     * 	On mobile devices (phones, tablets), the PDF viewer appears as a toolbar with a download button.
     * 	 - On desktop devices, the PDF viewer is embedded in its parent container.
     */
    displayType?:
      | (PDFViewerDisplayType | keyof typeof PDFViewerDisplayType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Parameter to determine if the given PDF is from a trusted source. If the source is valid this property
     * can be set to true. If isTrustedSource is set to true, the PDFViewer opens with the displayType set to
     * "Embedded" on desktop devices. This means that the PDF content is directly shown within the PDFViewer.
     * Set this property to true only when the PDF is generated by the application or the PDF is scanned for
     * viruses. If isTrustedSource is set to false, the PDFViewer opens with the displayType set to "Link" on
     * desktop devices. This means that any configuration that has been provided by the application for the
     * property displayType is overridden. In this case, the user would need to download the PDF to view its
     * content.
     */
    isTrustedSource?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * A custom control that can be used instead of the error message specified by the errorPlaceholderMessage
     * property.
     */
    errorPlaceholder?: Control;

    /**
     * A multiple aggregation for buttons that can be added to the footer of the popup dialog. Works only if
     * the PDF viewer is set to open in a popup dialog.
     */
    popupButtons?: Button[] | Button | AggregationBindingInfo | `{${string}}`;

    /**
     * This event is fired when a PDF file is loaded. If the PDF is loaded in smaller chunks, this event is
     * fired as often as defined by the browser's plugin. This may happen after a couple chunks are processed.
     */
    loaded?: (oEvent: Event) => void;

    /**
     * This event is fired when there is an error loading the PDF file.
     */
    error?: (oEvent: PDFViewer$ErrorEvent) => void;

    /**
     * This event is fired when the PDF viewer control cannot check the loaded content. For example, the default
     * configuration of the Mozilla Firefox browser may not allow checking the loaded content. This may also
     * happen when the source PDF file is stored in a different domain. If you want no error message to be displayed
     * when this event is fired, call the preventDefault() method inside the event handler.
     */
    sourceValidationFailed?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the PDFViewer#error event.
   */
  export interface PDFViewer$ErrorEventParameters {
    /**
     * The iframe element.
     */
    target?: any;
  }

  /**
   * Event object of the PDFViewer#error event.
   */
  export type PDFViewer$ErrorEvent = Event<
    PDFViewer$ErrorEventParameters,
    PDFViewer
  >;

  /**
   * Parameters of the PDFViewer#loaded event.
   */
  export interface PDFViewer$LoadedEventParameters {}

  /**
   * Event object of the PDFViewer#loaded event.
   */
  export type PDFViewer$LoadedEvent = Event<
    PDFViewer$LoadedEventParameters,
    PDFViewer
  >;

  /**
   * Parameters of the PDFViewer#sourceValidationFailed event.
   */
  export interface PDFViewer$SourceValidationFailedEventParameters {}

  /**
   * Event object of the PDFViewer#sourceValidationFailed event.
   */
  export type PDFViewer$SourceValidationFailedEvent = Event<
    PDFViewer$SourceValidationFailedEventParameters,
    PDFViewer
  >;
}

declare module "sap/m/PlanningCalendar" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { ID, CSSSize } from "sap/ui/core/library";

  import PlanningCalendarRow from "sap/m/PlanningCalendarRow";

  import DateTypeRange from "sap/ui/unified/DateTypeRange";

  import PlanningCalendarView from "sap/m/PlanningCalendarView";

  import Event from "sap/ui/base/Event";

  import {
    CalendarAppointmentHeight,
    CalendarAppointmentRoundWidth,
    CalendarAppointmentVisualization,
    GroupAppointmentsMode,
  } from "sap/ui/unified/library";

  import CalendarWeekNumbering from "sap/base/i18n/date/CalendarWeekNumbering";

  import UI5Date from "sap/ui/core/date/UI5Date";

  import AvatarShape from "sap/m/AvatarShape";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import CalendarType from "sap/base/i18n/date/CalendarType";

  import CalendarLegend from "sap/ui/unified/CalendarLegend";

  import CalendarAppointment from "sap/ui/unified/CalendarAppointment";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * Displays rows with appointments for different entities (such as persons or teams) for the selected time
   * interval.
   *
   * Overview:
   *
   * You can use the `PlanningCalendar` to represent a calendar containing multiple rows with appointments,
   * where each row represents a different person.
   *
   * You can configure different time-interval views that the user can switch between, such as hours or days,
   * and even a whole week/month. The available navigation allows the user to select a specific interval using
   * a picker, or move to the previous/next interval using arrows.
   *
   * **Note:** The application developer should add dependency to `sap.ui.unified` library on application
   * level to ensure that the library is loaded before the module dependencies will be required. The `PlanningCalendar`
   * uses parts of the `sap.ui.unified` library. This library will be loaded after the `PlanningCalendar`,
   * if it wasn't loaded first. This could lead to CSP compliance issues and adds an additional waiting time
   * when a `PlanningCalendar` is used for the first time. To prevent this, apps that use the `PlanningCalendar`
   * should also load the `sap.ui.unified` library in advance.
   *
   * Usage:
   *
   * The `PlanningCalendar` has the following structure from top to bottom:
   *
   *
   * 	 - A toolbar where you can add your own buttons or other controls using the `toolbarContent` aggregation.
   *
   * 	 - A header containing a drop-down menu for selecting the {@link sap.m.PlanningCalendarView PlanningCalendarViews},
   *     and navigation for moving through the intervals using arrows or selecting a specific interval with a
   *     picker. Custom views can be configured using the `views` aggregation. If not configured, the following
   *     set of default built-in views is available - Hours, Days, 1 Week, 1 Month, and Months. Setting a custom
   *     view(s) replaces the built-in ones.
   * 	 - The rows of the `PlanningCalendar` that contain the assigned appointments. They can be configured
   *     with the `rows` aggregation, which is of type {@link sap.m.PlanningCalendarRow PlanningCalendarRow}.
   *
   *
   * Since 1.48 the empty space in the cell that is below an appointment can be removed by adding the `sapUiCalendarAppFitVertically`
   * CSS class to the `PlanningCalendar`. Please note that it should be used only for a `PlanningCalendar`
   * with one appointment per day for a row that doesn't have interval headers set.
   *
   * Since 1.44 alternating row colors can be suppressed by adding the `sapMPlanCalSuppressAlternatingRowColors`
   * CSS class to the `PlanningCalendar`.
   *
   * Responsive behavior:
   *
   * You can define the number of displayed intervals based on the size of the `PlanningCalendar` using the
   * {@link sap.m.PlanningCalendarView PlanningCalendarView}'s properties.
   *
   * @since 1.34
   */
  export default class PlanningCalendar extends Control {
    /**
     * Constructor for a new `PlanningCalendar`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/planning-calendar/ Planning Calendar}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $PlanningCalendarSettings
    );
    /**
     * Constructor for a new `PlanningCalendar`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/planning-calendar/ Planning Calendar}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sID?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $PlanningCalendarSettings
    );

    /**
     * Creates a new subclass of class sap.m.PlanningCalendar with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, PlanningCalendar>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.PlanningCalendar.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.40.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds some row to the aggregation {@link #getRows rows}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addRow(
      /**
       * The row to add; if empty, nothing is inserted
       */
      oRow: PlanningCalendarRow
    ): this;
    /**
     * Adds some specialDate to the aggregation {@link #getSpecialDates specialDates}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addSpecialDate(
      /**
       * The specialDate to add; if empty, nothing is inserted
       */
      oSpecialDate: DateTypeRange
    ): this;
    /**
     * Adds some toolbarContent to the aggregation {@link #getToolbarContent toolbarContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addToolbarContent(
      /**
       * The toolbarContent to add; if empty, nothing is inserted
       */
      oToolbarContent: Control
    ): this;
    /**
     * Adds some view to the aggregation {@link #getViews views}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addView(
      /**
       * The view to add; if empty, nothing is inserted
       */
      oView: PlanningCalendarView
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:appointmentSelect appointmentSelect} event of
     * this `sap.m.PlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendar` itself.
     *
     * Fired if an appointment is selected.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAppointmentSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PlanningCalendar$AppointmentSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:appointmentSelect appointmentSelect} event of
     * this `sap.m.PlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendar` itself.
     *
     * Fired if an appointment is selected.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAppointmentSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PlanningCalendar$AppointmentSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:intervalSelect intervalSelect} event of this
     * `sap.m.PlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendar` itself.
     *
     * Fired if an interval was selected in the calendar header or in the row.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachIntervalSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PlanningCalendar$IntervalSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:intervalSelect intervalSelect} event of this
     * `sap.m.PlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendar` itself.
     *
     * Fired if an interval was selected in the calendar header or in the row.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachIntervalSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PlanningCalendar$IntervalSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:rowHeaderClick rowHeaderClick} event of this
     * `sap.m.PlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendar` itself.
     *
     * Fires when a row header is clicked.
     *
     * @since 1.46.0
     * @deprecated As of version 1.119. replaced by `rowHeaderPress` event
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachRowHeaderClick(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PlanningCalendar$RowHeaderClickEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:rowHeaderClick rowHeaderClick} event of this
     * `sap.m.PlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendar` itself.
     *
     * Fires when a row header is clicked.
     *
     * @since 1.46.0
     * @deprecated As of version 1.119. replaced by `rowHeaderPress` event
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachRowHeaderClick(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PlanningCalendar$RowHeaderClickEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:rowHeaderPress rowHeaderPress} event of this
     * `sap.m.PlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendar` itself.
     *
     * Fires when a row header press is triggered with mouse click, SPACE or ENTER press.
     *
     * @since 1.119.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachRowHeaderPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PlanningCalendar$RowHeaderPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:rowHeaderPress rowHeaderPress} event of this
     * `sap.m.PlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendar` itself.
     *
     * Fires when a row header press is triggered with mouse click, SPACE or ENTER press.
     *
     * @since 1.119.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachRowHeaderPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PlanningCalendar$RowHeaderPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:rowSelectionChange rowSelectionChange} event
     * of this `sap.m.PlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendar` itself.
     *
     * Fires when row selection is changed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachRowSelectionChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PlanningCalendar$RowSelectionChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:rowSelectionChange rowSelectionChange} event
     * of this `sap.m.PlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendar` itself.
     *
     * Fires when row selection is changed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachRowSelectionChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PlanningCalendar$RowSelectionChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:startDateChange startDateChange} event of this
     * `sap.m.PlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendar` itself.
     *
     * Fired when the `startDate` property was changed while navigating in the `PlanningCalendar`. The new value
     * can be obtained using the `sap.m.PlanningCalendar#getStartDate()` method. **Note:** This event is fired
     * in case when the `viewKey` property is changed, and as a result of which the view requires a change in
     * the `startDate` property.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachStartDateChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:startDateChange startDateChange} event of this
     * `sap.m.PlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendar` itself.
     *
     * Fired when the `startDate` property was changed while navigating in the `PlanningCalendar`. The new value
     * can be obtained using the `sap.m.PlanningCalendar#getStartDate()` method. **Note:** This event is fired
     * in case when the `viewKey` property is changed, and as a result of which the view requires a change in
     * the `startDate` property.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachStartDateChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:viewChange viewChange} event of this `sap.m.PlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendar` itself.
     *
     * Fired when the `viewKey` property was changed by user interaction.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachViewChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:viewChange viewChange} event of this `sap.m.PlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendar` itself.
     *
     * Fired when the `viewKey` property was changed by user interaction.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachViewChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys the noData in the aggregation {@link #getNoData noData}.
     *
     * @since 1.125.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyNoData(): this;
    /**
     * Destroys all the rows in the aggregation {@link #getRows rows}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyRows(): this;
    /**
     * Destroys all the specialDates in the aggregation {@link #getSpecialDates specialDates}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySpecialDates(): this;
    /**
     * Destroys all the toolbarContent in the aggregation {@link #getToolbarContent toolbarContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyToolbarContent(): this;
    /**
     * Destroys all the views in the aggregation {@link #getViews views}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyViews(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:appointmentSelect appointmentSelect} event
     * of this `sap.m.PlanningCalendar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAppointmentSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: PlanningCalendar$AppointmentSelectEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:intervalSelect intervalSelect} event of this
     * `sap.m.PlanningCalendar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachIntervalSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: PlanningCalendar$IntervalSelectEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:rowHeaderClick rowHeaderClick} event of this
     * `sap.m.PlanningCalendar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.46.0
     * @deprecated As of version 1.119. replaced by `rowHeaderPress` event
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachRowHeaderClick(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: PlanningCalendar$RowHeaderClickEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:rowHeaderPress rowHeaderPress} event of this
     * `sap.m.PlanningCalendar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.119.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachRowHeaderPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: PlanningCalendar$RowHeaderPressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:rowSelectionChange rowSelectionChange} event
     * of this `sap.m.PlanningCalendar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachRowSelectionChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: PlanningCalendar$RowSelectionChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:startDateChange startDateChange} event of
     * this `sap.m.PlanningCalendar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachStartDateChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:viewChange viewChange} event of this `sap.m.PlanningCalendar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachViewChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:appointmentSelect appointmentSelect} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAppointmentSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: PlanningCalendar$AppointmentSelectEventParameters
    ): this;
    /**
     * Fires event {@link #event:intervalSelect intervalSelect} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireIntervalSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: PlanningCalendar$IntervalSelectEventParameters
    ): this;
    /**
     * Fires event {@link #event:rowHeaderClick rowHeaderClick} to attached listeners.
     *
     * @since 1.46.0
     * @deprecated As of version 1.119. replaced by `rowHeaderPress` event
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireRowHeaderClick(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: PlanningCalendar$RowHeaderClickEventParameters
    ): this;
    /**
     * Fires event {@link #event:rowHeaderPress rowHeaderPress} to attached listeners.
     *
     * @since 1.119.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireRowHeaderPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: PlanningCalendar$RowHeaderPressEventParameters
    ): this;
    /**
     * Fires event {@link #event:rowSelectionChange rowSelectionChange} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireRowSelectionChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: PlanningCalendar$RowSelectionChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:startDateChange startDateChange} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireStartDateChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:viewChange viewChange} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireViewChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getAppointmentHeight appointmentHeight}.
     *
     * Determines the different possible sizes for appointments.
     *
     * Default value is `Regular`.
     *
     * @since 1.81.0
     *
     * @returns Value of property `appointmentHeight`
     */
    getAppointmentHeight(): CalendarAppointmentHeight;
    /**
     * Gets current value of property {@link #getAppointmentRoundWidth appointmentRoundWidth}.
     *
     * Defines rounding of the width `CalendarAppoinment` **Note:** This property is applied, when the calendar
     * interval type is Day and the view shows more than 20 days
     *
     * Default value is `None`.
     *
     * @since 1.81.0
     *
     * @returns Value of property `appointmentRoundWidth`
     */
    getAppointmentRoundWidth(): CalendarAppointmentRoundWidth;
    /**
     * Gets current value of property {@link #getAppointmentsReducedHeight appointmentsReducedHeight}.
     *
     * Determines whether the appointments that have only title without text are rendered with smaller height.
     *
     * **Note:** On phone devices this property is ignored, appointments are always rendered in full height
     * to facilitate touching.
     *
     * Default value is `false`.
     *
     * @since 1.38.0
     * @deprecated As of version 1.119. Please use the `appointmentHeight` with value "Automatic" property instead.
     *
     * @returns Value of property `appointmentsReducedHeight`
     */
    getAppointmentsReducedHeight(): boolean;
    /**
     * Gets current value of property {@link #getAppointmentsVisualization appointmentsVisualization}.
     *
     * Determines how the appointments are visualized depending on the used theme.
     *
     * Default value is `Standard`.
     *
     * @since 1.40.0
     *
     * @returns Value of property `appointmentsVisualization`
     */
    getAppointmentsVisualization(): CalendarAppointmentVisualization;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.40.0
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getBuiltInViews builtInViews}.
     *
     * Defines the list of predefined views as an array. The views should be specified by their keys.
     *
     * The default predefined views and their keys are available at {@link sap.m.PlanningCalendarBuiltInView}.
     *
     * **Note:** If set, all specified views will be displayed along with any custom views (if available). If
     * not set and no custom views are available, all default views will be displayed. If not set and there
     * are any custom views available, only the custom views will be displayed.
     *
     * Default value is `[]`.
     *
     * @since 1.50
     *
     * @returns Value of property `builtInViews`
     */
    getBuiltInViews(): string[];
    /**
     * Gets current value of property {@link #getCalendarWeekNumbering calendarWeekNumbering}.
     *
     * If set, the calendar week numbering is used for display. If not set, the calendar week numbering of the
     * global configuration is used.
     *
     * @since 1.110.0
     *
     * @returns Value of property `calendarWeekNumbering`
     */
    getCalendarWeekNumbering(): CalendarWeekNumbering;
    /**
     * Getter for custom appointments sorter (if any).
     *
     * @since 1.54
     */
    getCustomAppointmentsSorterCallback(): appointmentsSorterCallback;
    /**
     * Getter for the end point in time of the shown interval
     *
     * @since 1.87
     *
     * @returns date instance with the end date
     */
    getEndDate(): Date | UI5Date;
    /**
     * Gets current value of property {@link #getFirstDayOfWeek firstDayOfWeek}.
     *
     * If set, the first day of the displayed week is this day. Valid values are 0 to 6 starting on Sunday.
     * If there is no valid value set, the default of the used locale is used.
     *
     * Note: this property will only have effect in the weekly – based views of the PlanningCalendar – Week
     * view, and OneMonth view (on small devices).
     *
     * Default value is `-1`.
     *
     * @since 1.94
     *
     * @returns Value of property `firstDayOfWeek`
     */
    getFirstDayOfWeek(): int;
    /**
     * Gets current value of property {@link #getGroupAppointmentsMode groupAppointmentsMode}.
     *
     * Defines the mode in which the overlapping appointments are displayed.
     *
     * **Note:** This property takes effect, only if the `intervalType` of the current calendar view is set
     * to `sap.ui.unified.CalendarIntervalType.Month`. On phone devices this property is ignored, and the default
     * value is applied.
     *
     * Default value is `Collapsed`.
     *
     * @since 1.48.0
     *
     * @returns Value of property `groupAppointmentsMode`
     */
    getGroupAppointmentsMode(): GroupAppointmentsMode;
    /**
     * Gets current value of property {@link #getHeight height}.
     *
     * Specifies the height of the `PlanningCalendar`. **Note:** If the set height is less than the displayed
     * content, it will not be applied
     *
     *
     * @returns Value of property `height`
     */
    getHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getIconShape iconShape}.
     *
     * Defines the shape of the `Avatar`.
     *
     * Default value is `Circle`.
     *
     *
     * @returns Value of property `iconShape`
     */
    getIconShape(): AvatarShape;
    /**
     * ID of the element which is the current target of the association {@link #getLegend legend}, or `null`.
     *
     * @since 1.40.0
     */
    getLegend(): ID | null;
    /**
     * Gets current value of property `maxDate`.
     *
     *
     * @returns The maxDate as a UI5Date or JavaScript Date object
     */
    getMaxDate(): Date | UI5Date;
    /**
     * Gets current value of property `minDate`.
     *
     *
     * @returns The minDate as a UI5Date or JavaScript Date object
     */
    getMinDate(): Date | UI5Date;
    /**
     * Gets current value of property {@link #getMultipleAppointmentsSelection multipleAppointmentsSelection}.
     *
     * Determines whether the selection of multiple appointments is enabled.
     *
     * Note: selection of multiple appointments is possible using CTRL key regardless of the value of this property.
     *
     * Default value is `false`.
     *
     * @since 1.97
     *
     * @returns Value of property `multipleAppointmentsSelection`
     */
    getMultipleAppointmentsSelection(): boolean;
    /**
     * Gets content of aggregation {@link #getNoData noData}.
     *
     * Defines the custom visualization if there is no data available. **Note:** If both `noDataText` property
     * and `noData` aggregation are provided, the `noData` aggregation takes priority. If the `noData` aggregation
     * is undefined or set to null, the `noDataText` property is used instead.
     *
     * @since 1.125.0
     */
    getNoData(): Control | string;
    /**
     * Gets current value of property {@link #getNoDataText noDataText}.
     *
     * Defines the text that is displayed when no {@link sap.m.PlanningCalendarRow PlanningCalendarRows} are
     * assigned. **Note:** If both `noDataText` property and `noData` aggregation are provided, the `noData`
     * aggregation takes priority. If the `noData` aggregation is undefined or set to null, the `noDataText`
     * property is used instead.
     *
     *
     * @returns Value of property `noDataText`
     */
    getNoDataText(): string;
    /**
     * Gets current value of property {@link #getPrimaryCalendarType primaryCalendarType}.
     *
     * If set, the calendar type is used for display. If not set, the calendar type of the global configuration
     * is used.
     *
     * @since 1.108.0
     *
     * @returns Value of property `primaryCalendarType`
     */
    getPrimaryCalendarType(): CalendarType;
    /**
     * Gets content of aggregation {@link #getRows rows}.
     *
     * Rows of the `PlanningCalendar`.
     */
    getRows(): PlanningCalendarRow[];
    /**
     * Gets current value of property {@link #getSecondaryCalendarType secondaryCalendarType}.
     *
     * If set, the days are also represented in this calendar type. If not set, the dates are only represented
     * in the primary calendar type. Note: The second calendar type won't be represented in the DOM when this
     * property is not set explicitly.
     *
     * @since 1.109.0
     *
     * @returns Value of property `secondaryCalendarType`
     */
    getSecondaryCalendarType(): CalendarType;
    /**
     * Returns the IDs of the selected appointments. If no appointments are selected, an empty array is returned.
     *
     * @since 1.54
     *
     * @returns Array with the IDs of the selected appointments
     */
    getSelectedAppointments(): string[];
    /**
     * Returns an array containing the selected rows. If no row is selected, an empty array is returned.
     *
     *
     * @returns selected rows
     */
    getSelectedRows(): PlanningCalendarRow[];
    /**
     * Gets current value of property {@link #getShowDayNamesLine showDayNamesLine}.
     *
     * Determines whether the day names are displayed in a separate line or inside the single days.
     *
     * Default value is `false`.
     *
     * @since 1.50
     *
     * @returns Value of property `showDayNamesLine`
     */
    getShowDayNamesLine(): boolean;
    /**
     * Gets current value of property {@link #getShowEmptyIntervalHeaders showEmptyIntervalHeaders}.
     *
     * Determines whether the space (at the top of the intervals), where the assigned interval headers appear,
     * should remain visible even when no interval headers are present in the visible time frame. If set to
     * `false`, this space would collapse/disappear when no interval headers are assigned.
     *
     * **Note:** This property takes effect, only if `showIntervalHeaders` is also set to `true`.
     *
     * Default value is `true`.
     *
     * @since 1.38.0
     *
     * @returns Value of property `showEmptyIntervalHeaders`
     */
    getShowEmptyIntervalHeaders(): boolean;
    /**
     * Gets current value of property {@link #getShowIntervalHeaders showIntervalHeaders}.
     *
     * Determines whether the assigned interval headers are displayed. You can assign them using the `intervalHeaders`
     * aggregation of the {@link sap.m.PlanningCalendarRow PlanningCalendarRow}.
     *
     * **Note:** If you set both `showIntervalHeaders` and `showEmptyIntervalHeaders` properties to `true`,
     * the space (at the top of the intervals) where the assigned interval headers appear, will remain visible
     * even if no interval headers are assigned.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showIntervalHeaders`
     */
    getShowIntervalHeaders(): boolean;
    /**
     * Gets current value of property {@link #getShowRowHeaders showRowHeaders}.
     *
     * Determines whether the column containing the headers of the {@link sap.m.PlanningCalendarRow PlanningCalendarRows }
     * is displayed.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showRowHeaders`
     */
    getShowRowHeaders(): boolean;
    /**
     * Gets current value of property {@link #getShowWeekNumbers showWeekNumbers}.
     *
     * Determines if the week numbers are displayed.
     *
     * Default value is `false`.
     *
     * @since 1.52
     *
     * @returns Value of property `showWeekNumbers`
     */
    getShowWeekNumbers(): boolean;
    /**
     * Gets current value of property {@link #getSingleSelection singleSelection}.
     *
     * Determines whether only a single row can be selected.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `singleSelection`
     */
    getSingleSelection(): boolean;
    /**
     * Gets content of aggregation {@link #getSpecialDates specialDates}.
     *
     * Special days in the header calendar visualized as date range with a type.
     *
     * **Note:** In case there are multiple `sap.ui.unified.DateTypeRange` instances given for a single date,
     * only the first `sap.ui.unified.DateTypeRange` instance will be used. For example, using the following
     * sample, the 1st of November will be displayed as a working day of type "Type10":
     *
     *
     * ```javascript
     *
     * 	new DateTypeRange({
     * 		startDate: UI5Date.getInstance(2023, 10, 1),
     * 		type: CalendarDayType.Type10,
     * 	}),
     * 	new DateTypeRange({
     * 		startDate: UI5Date.getInstance(2023, 10, 1),
     * 		type: CalendarDayType.NonWorking
     * 	})
     * 	```
     *
     *
     * If you want the first of November to be displayed as a non-working day and also as "Type10," the following
     * should be done:
     * ```javascript
     *
     * 	new DateTypeRange({
     * 		startDate: UI5Date.getInstance(2023, 10, 1),
     * 		type: CalendarDayType.Type10,
     * 		secondaryType: CalendarDayType.NonWorking
     * 	})
     * 	```
     *
     *
     * You can use only one of the following types for a given date: `sap.ui.unified.CalendarDayType.NonWorking`,
     * `sap.ui.unified.CalendarDayType.Working` or `sap.ui.unified.CalendarDayType.None`. Assigning more than
     * one of these values in combination for the same date will lead to unpredictable results.
     */
    getSpecialDates(): DateTypeRange[];
    /**
     * Gets current value of property `startDate`.
     *
     *
     * @returns The startDate as a UI5Date or JavaScript Date object
     */
    getStartDate(): Date | UI5Date;
    /**
     * Gets current value of property {@link #getStickyHeader stickyHeader}.
     *
     * Determines whether the header area will remain visible (fixed on top) when the rest of the content is
     * scrolled out of view.
     *
     * The sticky header behavior is automatically disabled on phones in landscape mode for better visibility
     * of the content.
     *
     * **Note:** There is limited browser support, hence the API is in experimental state. Browsers that currently
     * support this feature are Chrome (desktop and mobile), Safari (desktop and mobile) and Edge 41.
     *
     * There are also some known issues with respect to the scrolling behavior and focus handling. A few are
     * given below:
     *
     * When the PlanningCalendar is placed in certain layout containers, for example the `GridLayout` control,
     * the column headers do not fix at the top of the viewport. Similar behavior is also observed with the
     * `ObjectPage` control.
     *
     * This API should not be used in production environment.
     *
     * **Note:** The `stickyHeader` of the `PlanningCalendar` uses the `sticky` property of `sap.m.Table`. Therefore,
     * all features and restrictions of the property in `sap.m.Table` apply to the `PlanningCalendar` as well.
     *
     * Default value is `false`.
     *
     * @since 1.54
     *
     * @returns Value of property `stickyHeader`
     */
    getStickyHeader(): boolean;
    /**
     * Gets content of aggregation {@link #getToolbarContent toolbarContent}.
     *
     * The content of the toolbar.
     */
    getToolbarContent(): Control[];
    /**
     * Gets current value of property {@link #getViewKey viewKey}.
     *
     * Defines the key of the `PlanningCalendarView` used for the output.
     *
     * **Note:** The default value is set `Hour`. If you are using your own views, the keys of these views should
     * be used instead.
     *
     * Default value is `CalendarIntervalType.Hour`.
     *
     *
     * @returns Value of property `viewKey`
     */
    getViewKey(): string;
    /**
     * Gets content of aggregation {@link #getViews views}.
     *
     * Views of the `PlanningCalendar`.
     *
     * **Note:** If not set, all the default views are available. Their keys are defined in {@link sap.ui.unified.CalendarIntervalType}.
     */
    getViews(): PlanningCalendarView[];
    /**
     * Getter for how many intervals are currently displayed
     *
     *
     * @returns The number of displayed intervals
     */
    getVisibleIntervalsCount(): number;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Specifies the width of the `PlanningCalendar`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Checks for the provided `sap.m.PlanningCalendarRow` in the aggregation {@link #getRows rows}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfRow(
      /**
       * The row whose index is looked for
       */
      oRow: PlanningCalendarRow
    ): int;
    /**
     * Checks for the provided `sap.ui.unified.DateTypeRange` in the aggregation {@link #getSpecialDates specialDates}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfSpecialDate(
      /**
       * The specialDate whose index is looked for
       */
      oSpecialDate: DateTypeRange
    ): int;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getToolbarContent toolbarContent}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfToolbarContent(
      /**
       * The toolbarContent whose index is looked for
       */
      oToolbarContent: Control
    ): int;
    /**
     * Checks for the provided `sap.m.PlanningCalendarView` in the aggregation {@link #getViews views}. and
     * returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfView(
      /**
       * The view whose index is looked for
       */
      oView: PlanningCalendarView
    ): int;
    /**
     * Inserts a row into the aggregation {@link #getRows rows}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertRow(
      /**
       * The row to insert; if empty, nothing is inserted
       */
      oRow: PlanningCalendarRow,
      /**
       * The `0`-based index the row should be inserted at; for a negative value of `iIndex`, the row is inserted
       * at position 0; for a value greater than the current size of the aggregation, the row is inserted at the
       * last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a specialDate into the aggregation {@link #getSpecialDates specialDates}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertSpecialDate(
      /**
       * The specialDate to insert; if empty, nothing is inserted
       */
      oSpecialDate: DateTypeRange,
      /**
       * The `0`-based index the specialDate should be inserted at; for a negative value of `iIndex`, the specialDate
       * is inserted at position 0; for a value greater than the current size of the aggregation, the specialDate
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a toolbarContent into the aggregation {@link #getToolbarContent toolbarContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertToolbarContent(
      /**
       * The toolbarContent to insert; if empty, nothing is inserted
       */
      oToolbarContent: Control,
      /**
       * The `0`-based index the toolbarContent should be inserted at; for a negative value of `iIndex`, the toolbarContent
       * is inserted at position 0; for a value greater than the current size of the aggregation, the toolbarContent
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a view into the aggregation {@link #getViews views}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertView(
      /**
       * The view to insert; if empty, nothing is inserted
       */
      oView: PlanningCalendarView,
      /**
       * The `0`-based index the view should be inserted at; for a negative value of `iIndex`, the view is inserted
       * at position 0; for a value greater than the current size of the aggregation, the view is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.40.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all the controls from the aggregation {@link #getRows rows}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllRows(): PlanningCalendarRow[];
    /**
     * Removes all the controls from the aggregation {@link #getSpecialDates specialDates}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllSpecialDates(): DateTypeRange[];
    /**
     * Removes all the controls from the aggregation {@link #getToolbarContent toolbarContent}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllToolbarContent(): Control[];
    /**
     * Removes all the controls from the aggregation {@link #getViews views}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllViews(): PlanningCalendarView[];
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.40.0
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes a row from the aggregation {@link #getRows rows}.
     *
     *
     * @returns The removed row or `null`
     */
    removeRow(
      /**
       * The row to remove or its index or id
       */
      vRow: int | string | PlanningCalendarRow
    ): PlanningCalendarRow | null;
    /**
     * Removes a specialDate from the aggregation {@link #getSpecialDates specialDates}.
     *
     *
     * @returns The removed specialDate or `null`
     */
    removeSpecialDate(
      /**
       * The specialDate to remove or its index or id
       */
      vSpecialDate: int | string | DateTypeRange
    ): DateTypeRange | null;
    /**
     * Removes a toolbarContent from the aggregation {@link #getToolbarContent toolbarContent}.
     *
     *
     * @returns The removed toolbarContent or `null`
     */
    removeToolbarContent(
      /**
       * The toolbarContent to remove or its index or id
       */
      vToolbarContent: int | string | Control
    ): Control | null;
    /**
     * Removes a view from the aggregation {@link #getViews views}.
     *
     *
     * @returns The removed view or `null`
     */
    removeView(
      /**
       * The view to remove or its index or id
       */
      vView: int | string | PlanningCalendarView
    ): PlanningCalendarView | null;
    /**
     * Selects or deselects all `PlanningCalendarRows`.
     *
     * **Note:** Selection only works if `singleSelection` is set to `false`.
     *
     *
     * @returns `this` to allow method chaining
     */
    selectAllRows(
      /**
       * Indicator showing whether `PlanningCalendarRows` should be selected or deselected
       */
      bSelect: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getAppointmentHeight appointmentHeight}.
     *
     * Determines the different possible sizes for appointments.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Regular`.
     *
     * @since 1.81.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAppointmentHeight(
      /**
       * New value for property `appointmentHeight`
       */
      sAppointmentHeight?:
        | CalendarAppointmentHeight
        | keyof typeof CalendarAppointmentHeight
    ): this;
    /**
     * Sets a new value for property {@link #getAppointmentRoundWidth appointmentRoundWidth}.
     *
     * Defines rounding of the width `CalendarAppoinment` **Note:** This property is applied, when the calendar
     * interval type is Day and the view shows more than 20 days
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     * @since 1.81.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAppointmentRoundWidth(
      /**
       * New value for property `appointmentRoundWidth`
       */
      sAppointmentRoundWidth?:
        | CalendarAppointmentRoundWidth
        | keyof typeof CalendarAppointmentRoundWidth
    ): this;
    /**
     * Set the appointment reduced height property to the appointments in the calendar
     *
     * @deprecated As of version 1.119. Please use the `appointmentHeight` with value "Automatic" property instead.
     *
     * @returns Reference to `this` for method chaining
     */
    setAppointmentsReducedHeight(
      /**
       * if set to true, the appointments will have a reduced height
       */
      bAppointmentsReducedHeight: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getAppointmentsVisualization appointmentsVisualization}.
     *
     * Determines how the appointments are visualized depending on the used theme.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Standard`.
     *
     * @since 1.40.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAppointmentsVisualization(
      /**
       * New value for property `appointmentsVisualization`
       */
      sAppointmentsVisualization?:
        | CalendarAppointmentVisualization
        | keyof typeof CalendarAppointmentVisualization
    ): this;
    /**
     * Sets a new value for property {@link #getBuiltInViews builtInViews}.
     *
     * Defines the list of predefined views as an array. The views should be specified by their keys.
     *
     * The default predefined views and their keys are available at {@link sap.m.PlanningCalendarBuiltInView}.
     *
     * **Note:** If set, all specified views will be displayed along with any custom views (if available). If
     * not set and no custom views are available, all default views will be displayed. If not set and there
     * are any custom views available, only the custom views will be displayed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `[]`.
     *
     * @since 1.50
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBuiltInViews(
      /**
       * New value for property `builtInViews`
       */
      sBuiltInViews?: string[]
    ): this;
    /**
     * Sets a new value for property {@link #getCalendarWeekNumbering calendarWeekNumbering}.
     *
     * If set, the calendar week numbering is used for display. If not set, the calendar week numbering of the
     * global configuration is used.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.110.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCalendarWeekNumbering(
      /**
       * New value for property `calendarWeekNumbering`
       */
      sCalendarWeekNumbering?:
        | CalendarWeekNumbering
        | keyof typeof CalendarWeekNumbering
    ): this;
    /**
     * Setter for custom sorting of appointments. If not used, the appointments will be sorted according to
     * their duration vertically. For example, the start time and order to the X axis won't change.
     *
     * @since 1.54
     *
     * @returns `this` for chaining
     */
    setCustomAppointmentsSorterCallback(
      fnSorter: appointmentsSorterCallback
    ): this;
    /**
     * Sets a new value for property {@link #getFirstDayOfWeek firstDayOfWeek}.
     *
     * If set, the first day of the displayed week is this day. Valid values are 0 to 6 starting on Sunday.
     * If there is no valid value set, the default of the used locale is used.
     *
     * Note: this property will only have effect in the weekly – based views of the PlanningCalendar – Week
     * view, and OneMonth view (on small devices).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `-1`.
     *
     * @since 1.94
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFirstDayOfWeek(
      /**
       * New value for property `firstDayOfWeek`
       */
      iFirstDayOfWeek?: int
    ): this;
    /**
     * Sets a new value for property {@link #getGroupAppointmentsMode groupAppointmentsMode}.
     *
     * Defines the mode in which the overlapping appointments are displayed.
     *
     * **Note:** This property takes effect, only if the `intervalType` of the current calendar view is set
     * to `sap.ui.unified.CalendarIntervalType.Month`. On phone devices this property is ignored, and the default
     * value is applied.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Collapsed`.
     *
     * @since 1.48.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGroupAppointmentsMode(
      /**
       * New value for property `groupAppointmentsMode`
       */
      sGroupAppointmentsMode?:
        | GroupAppointmentsMode
        | keyof typeof GroupAppointmentsMode
    ): this;
    /**
     * Sets a new value for property {@link #getHeight height}.
     *
     * Specifies the height of the `PlanningCalendar`. **Note:** If the set height is less than the displayed
     * content, it will not be applied
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeight(
      /**
       * New value for property `height`
       */
      sHeight?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getIconShape iconShape}.
     *
     * Defines the shape of the `Avatar`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Circle`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconShape(
      /**
       * New value for property `iconShape`
       */
      sIconShape?: AvatarShape | keyof typeof AvatarShape
    ): this;
    /**
     * Sets the associated {@link #getLegend legend}.
     *
     * @since 1.40.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLegend(
      /**
       * ID of an element which becomes the new target of this legend association; alternatively, an element instance
       * may be given
       */
      oLegend: ID | CalendarLegend
    ): this;
    /**
     * Set maximum date that can be shown and selected in the `PlanningCalendar`. This must be a UI5Date or
     * JavaScript Date object.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setMaxDate(
      /**
       * A date instance
       */
      oDate: Date | UI5Date
    ): this;
    /**
     * Set minimum date that can be shown and selected in the `PlanningCalendar`. This must be a UI5Date or
     * JavaScript Date object.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setMinDate(
      /**
       * A date instance
       */
      oDate: Date | UI5Date
    ): this;
    /**
     * Sets a new value for property {@link #getMultipleAppointmentsSelection multipleAppointmentsSelection}.
     *
     * Determines whether the selection of multiple appointments is enabled.
     *
     * Note: selection of multiple appointments is possible using CTRL key regardless of the value of this property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.97
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMultipleAppointmentsSelection(
      /**
       * New value for property `multipleAppointmentsSelection`
       */
      bMultipleAppointmentsSelection?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getNoData noData}.
     *
     * @since 1.125.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNoData(
      /**
       * The noData to set
       */
      vNoData: Control | string
    ): this;
    /**
     * Sets a new value for property {@link #getNoDataText noDataText}.
     *
     * Defines the text that is displayed when no {@link sap.m.PlanningCalendarRow PlanningCalendarRows} are
     * assigned. **Note:** If both `noDataText` property and `noData` aggregation are provided, the `noData`
     * aggregation takes priority. If the `noData` aggregation is undefined or set to null, the `noDataText`
     * property is used instead.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNoDataText(
      /**
       * New value for property `noDataText`
       */
      sNoDataText?: string
    ): this;
    /**
     * Sets the primaryCalendarType. If not set, the calendar type of the global configuration is used.
     *
     *
     * @returns `this` to allow method chaining
     */
    setPrimaryCalendarType(
      /**
       * the `CalendarType` to set as `sap.m.PlanningCalendar` `primaryCalendarType`.
       */
      sPrimaryCalendarType: CalendarType | keyof typeof CalendarType
    ): this;
    /**
     * Sets the secondaryCalendarType.
     *
     *
     * @returns `this` to allow method chaining
     */
    setSecondaryCalendarType(
      /**
       * the `CalendarType` to set as `sap.m.PlanningCalendar` `secondaryCalendarType`.
       */
      sSecondaryCalendarType: CalendarType | keyof typeof CalendarType
    ): this;
    /**
     * Sets a new value for property {@link #getShowDayNamesLine showDayNamesLine}.
     *
     * Determines whether the day names are displayed in a separate line or inside the single days.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.50
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowDayNamesLine(
      /**
       * New value for property `showDayNamesLine`
       */
      bShowDayNamesLine?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowEmptyIntervalHeaders showEmptyIntervalHeaders}.
     *
     * Determines whether the space (at the top of the intervals), where the assigned interval headers appear,
     * should remain visible even when no interval headers are present in the visible time frame. If set to
     * `false`, this space would collapse/disappear when no interval headers are assigned.
     *
     * **Note:** This property takes effect, only if `showIntervalHeaders` is also set to `true`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.38.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowEmptyIntervalHeaders(
      /**
       * New value for property `showEmptyIntervalHeaders`
       */
      bShowEmptyIntervalHeaders?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowIntervalHeaders showIntervalHeaders}.
     *
     * Determines whether the assigned interval headers are displayed. You can assign them using the `intervalHeaders`
     * aggregation of the {@link sap.m.PlanningCalendarRow PlanningCalendarRow}.
     *
     * **Note:** If you set both `showIntervalHeaders` and `showEmptyIntervalHeaders` properties to `true`,
     * the space (at the top of the intervals) where the assigned interval headers appear, will remain visible
     * even if no interval headers are assigned.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowIntervalHeaders(
      /**
       * New value for property `showIntervalHeaders`
       */
      bShowIntervalHeaders?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowRowHeaders showRowHeaders}.
     *
     * Determines whether the column containing the headers of the {@link sap.m.PlanningCalendarRow PlanningCalendarRows }
     * is displayed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowRowHeaders(
      /**
       * New value for property `showRowHeaders`
       */
      bShowRowHeaders?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowWeekNumbers showWeekNumbers}.
     *
     * Determines if the week numbers are displayed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.52
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowWeekNumbers(
      /**
       * New value for property `showWeekNumbers`
       */
      bShowWeekNumbers?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getSingleSelection singleSelection}.
     *
     * Determines whether only a single row can be selected.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSingleSelection(
      /**
       * New value for property `singleSelection`
       */
      bSingleSelection?: boolean
    ): this;
    /**
     * Sets the given date as start date. The current date is used as default. Depending on the current view
     * the start date may be adjusted (for example, the week view shows always the first weekday of the same
     * week as the given date).
     *
     *
     * @returns `this` to allow method chaining
     */
    setStartDate(
      /**
       * the date to set as `sap.m.PlanningCalendar` `startDate`. May be changed(adjusted) if property `startDate`
       * is adjusted. See remark about week view above.
       */
      oDate: Date
    ): this;
    /**
     * Sets the stickyHeader property.
     *
     *
     * @returns this pointer for chaining
     */
    setStickyHeader(
      /**
       * Whether the header area will remain visible (fixed on top)
       */
      bStick: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getViewKey viewKey}.
     *
     * Defines the key of the `PlanningCalendarView` used for the output.
     *
     * **Note:** The default value is set `Hour`. If you are using your own views, the keys of these views should
     * be used instead.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `CalendarIntervalType.Hour`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setViewKey(
      /**
       * New value for property `viewKey`
       */
      sViewKey?: string
    ): this;
    /**
     * Sets the width property and ensures that the start date is in sync with each row timeline.
     *
     *
     * @returns this for method chaining
     */
    setWidth(
      /**
       * the width to be set to the PlanningCalendar
       */
      sWidth: CSSSize
    ): this;
  }
  /**
   * A comparison function for appointments.
   *
   * Used by the {@link sap.m.PlanningCalendar PlanningCalendar} to sort appointments in a timeline.
   */
  export type appointmentsSorterCallback = (
    appointment1: CalendarAppointment,
    appointment2: CalendarAppointment
  ) => int;

  /**
   * Describes the settings that can be provided to the PlanningCalendar constructor.
   */
  export interface $PlanningCalendarSettings extends $ControlSettings {
    /**
     * Determines the start date of the row, as a UI5Date or JavaScript Date object. The current date is used
     * as default.
     */
    startDate?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the key of the `PlanningCalendarView` used for the output.
     *
     * **Note:** The default value is set `Hour`. If you are using your own views, the keys of these views should
     * be used instead.
     */
    viewKey?: string | PropertyBindingInfo;

    /**
     * Determines whether only a single row can be selected.
     */
    singleSelection?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the width of the `PlanningCalendar`.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the height of the `PlanningCalendar`. **Note:** If the set height is less than the displayed
     * content, it will not be applied
     */
    height?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the assigned interval headers are displayed. You can assign them using the `intervalHeaders`
     * aggregation of the {@link sap.m.PlanningCalendarRow PlanningCalendarRow}.
     *
     * **Note:** If you set both `showIntervalHeaders` and `showEmptyIntervalHeaders` properties to `true`,
     * the space (at the top of the intervals) where the assigned interval headers appear, will remain visible
     * even if no interval headers are assigned.
     */
    showIntervalHeaders?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the space (at the top of the intervals), where the assigned interval headers appear,
     * should remain visible even when no interval headers are present in the visible time frame. If set to
     * `false`, this space would collapse/disappear when no interval headers are assigned.
     *
     * **Note:** This property takes effect, only if `showIntervalHeaders` is also set to `true`.
     *
     * @since 1.38.0
     */
    showEmptyIntervalHeaders?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the column containing the headers of the {@link sap.m.PlanningCalendarRow PlanningCalendarRows }
     * is displayed.
     */
    showRowHeaders?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the text that is displayed when no {@link sap.m.PlanningCalendarRow PlanningCalendarRows} are
     * assigned. **Note:** If both `noDataText` property and `noData` aggregation are provided, the `noData`
     * aggregation takes priority. If the `noData` aggregation is undefined or set to null, the `noDataText`
     * property is used instead.
     */
    noDataText?: string | PropertyBindingInfo;

    /**
     * Defines the mode in which the overlapping appointments are displayed.
     *
     * **Note:** This property takes effect, only if the `intervalType` of the current calendar view is set
     * to `sap.ui.unified.CalendarIntervalType.Month`. On phone devices this property is ignored, and the default
     * value is applied.
     *
     * @since 1.48.0
     */
    groupAppointmentsMode?:
      | (GroupAppointmentsMode | keyof typeof GroupAppointmentsMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines whether the appointments that have only title without text are rendered with smaller height.
     *
     * **Note:** On phone devices this property is ignored, appointments are always rendered in full height
     * to facilitate touching.
     *
     * @since 1.38.0
     * @deprecated As of version 1.119. Please use the `appointmentHeight` with value "Automatic" property instead.
     */
    appointmentsReducedHeight?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the different possible sizes for appointments.
     *
     * @since 1.81.0
     */
    appointmentHeight?:
      | (CalendarAppointmentHeight | keyof typeof CalendarAppointmentHeight)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines rounding of the width `CalendarAppoinment` **Note:** This property is applied, when the calendar
     * interval type is Day and the view shows more than 20 days
     *
     * @since 1.81.0
     */
    appointmentRoundWidth?:
      | (
          | CalendarAppointmentRoundWidth
          | keyof typeof CalendarAppointmentRoundWidth
        )
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines how the appointments are visualized depending on the used theme.
     *
     * @since 1.40.0
     */
    appointmentsVisualization?:
      | (
          | CalendarAppointmentVisualization
          | keyof typeof CalendarAppointmentVisualization
        )
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the minimum date that can be displayed and selected in the `PlanningCalendar`. This must be a
     * UI5Date or JavaScript Date object.
     *
     * **Note:** If the `minDate` is set to be after the current `maxDate`, the `maxDate` is set to the last
     * date of the month in which the `minDate` belongs.
     *
     * @since 1.38.0
     */
    minDate?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the maximum date that can be displayed and selected in the `PlanningCalendar`. This must be a
     * UI5Date or JavaScript Date object.
     *
     * **Note:** If the `maxDate` is set to be before the current `minDate`, the `minDate` is set to the first
     * date of the month in which the `maxDate` belongs.
     *
     * @since 1.38.0
     */
    maxDate?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the day names are displayed in a separate line or inside the single days.
     *
     * @since 1.50
     */
    showDayNamesLine?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines if the week numbers are displayed.
     *
     * @since 1.52
     */
    showWeekNumbers?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the list of predefined views as an array. The views should be specified by their keys.
     *
     * The default predefined views and their keys are available at {@link sap.m.PlanningCalendarBuiltInView}.
     *
     * **Note:** If set, all specified views will be displayed along with any custom views (if available). If
     * not set and no custom views are available, all default views will be displayed. If not set and there
     * are any custom views available, only the custom views will be displayed.
     *
     * @since 1.50
     */
    builtInViews?: string[] | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the header area will remain visible (fixed on top) when the rest of the content is
     * scrolled out of view.
     *
     * The sticky header behavior is automatically disabled on phones in landscape mode for better visibility
     * of the content.
     *
     * **Note:** There is limited browser support, hence the API is in experimental state. Browsers that currently
     * support this feature are Chrome (desktop and mobile), Safari (desktop and mobile) and Edge 41.
     *
     * There are also some known issues with respect to the scrolling behavior and focus handling. A few are
     * given below:
     *
     * When the PlanningCalendar is placed in certain layout containers, for example the `GridLayout` control,
     * the column headers do not fix at the top of the viewport. Similar behavior is also observed with the
     * `ObjectPage` control.
     *
     * This API should not be used in production environment.
     *
     * **Note:** The `stickyHeader` of the `PlanningCalendar` uses the `sticky` property of `sap.m.Table`. Therefore,
     * all features and restrictions of the property in `sap.m.Table` apply to the `PlanningCalendar` as well.
     *
     * @since 1.54
     */
    stickyHeader?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * If set, the first day of the displayed week is this day. Valid values are 0 to 6 starting on Sunday.
     * If there is no valid value set, the default of the used locale is used.
     *
     * Note: this property will only have effect in the weekly – based views of the PlanningCalendar – Week
     * view, and OneMonth view (on small devices).
     *
     * @since 1.94
     */
    firstDayOfWeek?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * If set, the calendar week numbering is used for display. If not set, the calendar week numbering of the
     * global configuration is used.
     *
     * @since 1.110.0
     */
    calendarWeekNumbering?:
      | (CalendarWeekNumbering | keyof typeof CalendarWeekNumbering)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * If set, the calendar type is used for display. If not set, the calendar type of the global configuration
     * is used.
     *
     * @since 1.108.0
     */
    primaryCalendarType?:
      | (CalendarType | keyof typeof CalendarType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * If set, the days are also represented in this calendar type. If not set, the dates are only represented
     * in the primary calendar type. Note: The second calendar type won't be represented in the DOM when this
     * property is not set explicitly.
     *
     * @since 1.109.0
     */
    secondaryCalendarType?:
      | (CalendarType | keyof typeof CalendarType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines whether the selection of multiple appointments is enabled.
     *
     * Note: selection of multiple appointments is possible using CTRL key regardless of the value of this property.
     *
     * @since 1.97
     */
    multipleAppointmentsSelection?:
      | boolean
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the shape of the `Avatar`.
     */
    iconShape?:
      | (AvatarShape | keyof typeof AvatarShape)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Rows of the `PlanningCalendar`.
     */
    rows?:
      | PlanningCalendarRow[]
      | PlanningCalendarRow
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Views of the `PlanningCalendar`.
     *
     * **Note:** If not set, all the default views are available. Their keys are defined in {@link sap.ui.unified.CalendarIntervalType}.
     */
    views?:
      | PlanningCalendarView[]
      | PlanningCalendarView
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Special days in the header calendar visualized as date range with a type.
     *
     * **Note:** In case there are multiple `sap.ui.unified.DateTypeRange` instances given for a single date,
     * only the first `sap.ui.unified.DateTypeRange` instance will be used. For example, using the following
     * sample, the 1st of November will be displayed as a working day of type "Type10":
     *
     *
     * ```javascript
     *
     * 	new DateTypeRange({
     * 		startDate: UI5Date.getInstance(2023, 10, 1),
     * 		type: CalendarDayType.Type10,
     * 	}),
     * 	new DateTypeRange({
     * 		startDate: UI5Date.getInstance(2023, 10, 1),
     * 		type: CalendarDayType.NonWorking
     * 	})
     * 	```
     *
     *
     * If you want the first of November to be displayed as a non-working day and also as "Type10," the following
     * should be done:
     * ```javascript
     *
     * 	new DateTypeRange({
     * 		startDate: UI5Date.getInstance(2023, 10, 1),
     * 		type: CalendarDayType.Type10,
     * 		secondaryType: CalendarDayType.NonWorking
     * 	})
     * 	```
     *
     *
     * You can use only one of the following types for a given date: `sap.ui.unified.CalendarDayType.NonWorking`,
     * `sap.ui.unified.CalendarDayType.Working` or `sap.ui.unified.CalendarDayType.None`. Assigning more than
     * one of these values in combination for the same date will lead to unpredictable results.
     */
    specialDates?:
      | DateTypeRange[]
      | DateTypeRange
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * The content of the toolbar.
     */
    toolbarContent?:
      | Control[]
      | Control
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Defines the custom visualization if there is no data available. **Note:** If both `noDataText` property
     * and `noData` aggregation are provided, the `noData` aggregation takes priority. If the `noData` aggregation
     * is undefined or set to null, the `noDataText` property is used instead.
     *
     * @since 1.125.0
     */
    noData?: string | Control | PropertyBindingInfo;

    /**
     * Association to controls / IDs which label this control (see WAI-ARIA attribute aria-labelledby).
     *
     * @since 1.40.0
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Association to the `CalendarLegend` explaining the colors of the `Appointments`.
     *
     * **Note:** The legend does not have to be rendered but must exist, and all required types must be assigned.
     *
     * @since 1.40.0
     */
    legend?: CalendarLegend | string;

    /**
     * Fired if an appointment is selected.
     */
    appointmentSelect?: (
      oEvent: PlanningCalendar$AppointmentSelectEvent
    ) => void;

    /**
     * Fired if an interval was selected in the calendar header or in the row.
     */
    intervalSelect?: (oEvent: PlanningCalendar$IntervalSelectEvent) => void;

    /**
     * Fires when row selection is changed.
     */
    rowSelectionChange?: (
      oEvent: PlanningCalendar$RowSelectionChangeEvent
    ) => void;

    /**
     * Fired when the `startDate` property was changed while navigating in the `PlanningCalendar`. The new value
     * can be obtained using the `sap.m.PlanningCalendar#getStartDate()` method. **Note:** This event is fired
     * in case when the `viewKey` property is changed, and as a result of which the view requires a change in
     * the `startDate` property.
     */
    startDateChange?: (oEvent: Event) => void;

    /**
     * Fired when the `viewKey` property was changed by user interaction.
     */
    viewChange?: (oEvent: Event) => void;

    /**
     * Fires when a row header is clicked.
     *
     * @since 1.46.0
     * @deprecated As of version 1.119. replaced by `rowHeaderPress` event
     */
    rowHeaderClick?: (oEvent: PlanningCalendar$RowHeaderClickEvent) => void;

    /**
     * Fires when a row header press is triggered with mouse click, SPACE or ENTER press.
     *
     * @since 1.119.0
     */
    rowHeaderPress?: (oEvent: PlanningCalendar$RowHeaderPressEvent) => void;
  }

  /**
   * Parameters of the PlanningCalendar#appointmentSelect event.
   */
  export interface PlanningCalendar$AppointmentSelectEventParameters {
    /**
     * The selected appointment.
     */
    appointment?: CalendarAppointment;

    /**
     * The selected appointments in case a group appointment is selected.
     */
    appointments?: CalendarAppointment[];

    /**
     * If set, the appointment was selected using multiple selection (e.g. Shift + single mouse click), meaning
     * more than the current appointment could be selected.
     */
    multiSelect?: boolean;

    /**
     * Gives the ID of the DOM element of the clicked appointment
     */
    domRefId?: string;
  }

  /**
   * Event object of the PlanningCalendar#appointmentSelect event.
   */
  export type PlanningCalendar$AppointmentSelectEvent = Event<
    PlanningCalendar$AppointmentSelectEventParameters,
    PlanningCalendar
  >;

  /**
   * Parameters of the PlanningCalendar#intervalSelect event.
   */
  export interface PlanningCalendar$IntervalSelectEventParameters {
    /**
     * Start date of the selected interval, as a UI5Date or JavaScript Date object.
     */
    startDate?: object;

    /**
     * Interval end date as a UI5Date or JavaScript Date object.
     */
    endDate?: object;

    /**
     * If set, the selected interval is a subinterval.
     */
    subInterval?: boolean;

    /**
     * Row of the selected interval.
     */
    row?: PlanningCalendarRow;
  }

  /**
   * Event object of the PlanningCalendar#intervalSelect event.
   */
  export type PlanningCalendar$IntervalSelectEvent = Event<
    PlanningCalendar$IntervalSelectEventParameters,
    PlanningCalendar
  >;

  /**
   * Parameters of the PlanningCalendar#rowHeaderClick event.
   *
   * @deprecated As of version 1.119. replaced by `rowHeaderPress` event
   */
  export interface PlanningCalendar$RowHeaderClickEventParameters {
    /**
     * The ID of the `PlanningCalendarRowHeader` of the selected appointment.
     *
     * **Note:** Intended to be used as an easy way to get an ID of a `PlanningCalendarRowHeader`. Do NOT use
     * for modification.
     */
    headerId?: string;

    /**
     * The row user clicked on.
     */
    row?: PlanningCalendarRow;
  }

  /**
   * Event object of the PlanningCalendar#rowHeaderClick event.
   *
   * @deprecated As of version 1.119. replaced by `rowHeaderPress` event
   */
  export type PlanningCalendar$RowHeaderClickEvent = Event<
    PlanningCalendar$RowHeaderClickEventParameters,
    PlanningCalendar
  >;

  /**
   * Parameters of the PlanningCalendar#rowHeaderPress event.
   */
  export interface PlanningCalendar$RowHeaderPressEventParameters {
    /**
     * The ID of the `PlanningCalendarRowHeader` of the selected appointment.
     *
     * **Note:** Intended to be used as an easy way to get an ID of a `PlanningCalendarRowHeader`. Do NOT use
     * for modification.
     */
    headerId?: string;

    /**
     * The row user pressed.
     */
    row?: PlanningCalendarRow;
  }

  /**
   * Event object of the PlanningCalendar#rowHeaderPress event.
   */
  export type PlanningCalendar$RowHeaderPressEvent = Event<
    PlanningCalendar$RowHeaderPressEventParameters,
    PlanningCalendar
  >;

  /**
   * Parameters of the PlanningCalendar#rowSelectionChange event.
   */
  export interface PlanningCalendar$RowSelectionChangeEventParameters {
    /**
     * Array of rows whose selection has changed.
     */
    rows?: PlanningCalendarRow[];
  }

  /**
   * Event object of the PlanningCalendar#rowSelectionChange event.
   */
  export type PlanningCalendar$RowSelectionChangeEvent = Event<
    PlanningCalendar$RowSelectionChangeEventParameters,
    PlanningCalendar
  >;

  /**
   * Parameters of the PlanningCalendar#startDateChange event.
   */
  export interface PlanningCalendar$StartDateChangeEventParameters {}

  /**
   * Event object of the PlanningCalendar#startDateChange event.
   */
  export type PlanningCalendar$StartDateChangeEvent = Event<
    PlanningCalendar$StartDateChangeEventParameters,
    PlanningCalendar
  >;

  /**
   * Parameters of the PlanningCalendar#viewChange event.
   */
  export interface PlanningCalendar$ViewChangeEventParameters {}

  /**
   * Event object of the PlanningCalendar#viewChange event.
   */
  export type PlanningCalendar$ViewChangeEvent = Event<
    PlanningCalendar$ViewChangeEventParameters,
    PlanningCalendar
  >;
}

declare module "sap/m/PlanningCalendarLegend" {
  import {
    default as CalendarLegend,
    $CalendarLegendSettings,
  } from "sap/ui/unified/CalendarLegend";

  import CalendarLegendItem from "sap/ui/unified/CalendarLegendItem";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * A legend for the {@link sap.m.PlanningCalendar} that displays the special dates and appointments in colors
   * with their corresponding description. The `PlanningCalendarLegend` extends {@link sap.ui.unified.CalendarLegend }
   * and overwrites the default value for property `columnWidth` to `auto`
   *
   * @since 1.50
   */
  export default class PlanningCalendarLegend extends CalendarLegend {
    /**
     * Constructor for a new `PlanningCalendarLegend`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $PlanningCalendarLegendSettings
    );
    /**
     * Constructor for a new `PlanningCalendarLegend`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $PlanningCalendarLegendSettings
    );

    /**
     * Creates a new subclass of class sap.m.PlanningCalendarLegend with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.unified.CalendarLegend.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, PlanningCalendarLegend>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.PlanningCalendarLegend.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some appointmentItem to the aggregation {@link #getAppointmentItems appointmentItems}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAppointmentItem(
      /**
       * The appointmentItem to add; if empty, nothing is inserted
       */
      oAppointmentItem: CalendarLegendItem
    ): this;
    /**
     * Destroys all the appointmentItems in the aggregation {@link #getAppointmentItems appointmentItems}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyAppointmentItems(): this;
    /**
     * Gets content of aggregation {@link #getAppointmentItems appointmentItems}.
     *
     * The legend items which show color and type information about the calendar appointments.
     */
    getAppointmentItems(): CalendarLegendItem[];
    /**
     * Gets current value of property {@link #getAppointmentItemsHeader appointmentItemsHeader}.
     *
     * Defines the text displayed in the header of the appointment items list. It is commonly related to the
     * calendar appointments.
     *
     *
     * @returns Value of property `appointmentItemsHeader`
     */
    getAppointmentItemsHeader(): string;
    /**
     * Gets current value of property {@link #getItemsHeader itemsHeader}.
     *
     * Defines the text displayed in the header of the items list. It is commonly related to the calendar days.
     *
     *
     * @returns Value of property `itemsHeader`
     */
    getItemsHeader(): string;
    /**
     * Checks for the provided `sap.ui.unified.CalendarLegendItem` in the aggregation {@link #getAppointmentItems appointmentItems}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfAppointmentItem(
      /**
       * The appointmentItem whose index is looked for
       */
      oAppointmentItem: CalendarLegendItem
    ): int;
    /**
     * Inserts a appointmentItem into the aggregation {@link #getAppointmentItems appointmentItems}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertAppointmentItem(
      /**
       * The appointmentItem to insert; if empty, nothing is inserted
       */
      oAppointmentItem: CalendarLegendItem,
      /**
       * The `0`-based index the appointmentItem should be inserted at; for a negative value of `iIndex`, the
       * appointmentItem is inserted at position 0; for a value greater than the current size of the aggregation,
       * the appointmentItem is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getAppointmentItems appointmentItems}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAppointmentItems(): CalendarLegendItem[];
    /**
     * Removes a appointmentItem from the aggregation {@link #getAppointmentItems appointmentItems}.
     *
     *
     * @returns The removed appointmentItem or `null`
     */
    removeAppointmentItem(
      /**
       * The appointmentItem to remove or its index or id
       */
      vAppointmentItem: int | string | CalendarLegendItem
    ): CalendarLegendItem | null;
    /**
     * Sets a new value for property {@link #getAppointmentItemsHeader appointmentItemsHeader}.
     *
     * Defines the text displayed in the header of the appointment items list. It is commonly related to the
     * calendar appointments.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAppointmentItemsHeader(
      /**
       * New value for property `appointmentItemsHeader`
       */
      sAppointmentItemsHeader: string
    ): this;
    /**
     * Sets a new value for property {@link #getItemsHeader itemsHeader}.
     *
     * Defines the text displayed in the header of the items list. It is commonly related to the calendar days.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setItemsHeader(
      /**
       * New value for property `itemsHeader`
       */
      sItemsHeader: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the PlanningCalendarLegend constructor.
   */
  export interface $PlanningCalendarLegendSettings
    extends $CalendarLegendSettings {
    /**
     * Defines the text displayed in the header of the items list. It is commonly related to the calendar days.
     */
    itemsHeader?: string | PropertyBindingInfo;

    /**
     * Defines the text displayed in the header of the appointment items list. It is commonly related to the
     * calendar appointments.
     */
    appointmentItemsHeader?: string | PropertyBindingInfo;

    /**
     * The legend items which show color and type information about the calendar appointments.
     */
    appointmentItems?:
      | CalendarLegendItem[]
      | CalendarLegendItem
      | AggregationBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/PlanningCalendarRow" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import CalendarAppointment from "sap/ui/unified/CalendarAppointment";

  import Control from "sap/ui/core/Control";

  import NonWorkingPeriod from "sap/ui/unified/NonWorkingPeriod";

  import DateTypeRange from "sap/ui/unified/DateTypeRange";

  import { URI } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * Represents a row in the {@link sap.m.PlanningCalendar}.
   *
   * This element holds the data of one row in the {@link sap.m.PlanningCalendar}. Once the header information
   * (for example, person information) is assigned, the appointments are assigned. The `sap.m.PlanningCalendarRow`
   * allows you to modify appointments at row level.
   *
   * @since 1.34
   */
  export default class PlanningCalendarRow extends UI5Element {
    /**
     * Constructor for a new `PlanningCalendarRow`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $PlanningCalendarRowSettings
    );
    /**
     * Constructor for a new `PlanningCalendarRow`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $PlanningCalendarRowSettings
    );

    /**
     * Creates a new subclass of class sap.m.PlanningCalendarRow with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, PlanningCalendarRow>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.PlanningCalendarRow.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some appointment to the aggregation {@link #getAppointments appointments}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAppointment(
      /**
       * The appointment to add; if empty, nothing is inserted
       */
      oAppointment: CalendarAppointment
    ): this;
    /**
     * Adds some headerContent to the aggregation {@link #getHeaderContent headerContent}.
     *
     * @since 1.67
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addHeaderContent(
      /**
       * The headerContent to add; if empty, nothing is inserted
       */
      oHeaderContent: Control
    ): this;
    /**
     * Adds some intervalHeader to the aggregation {@link #getIntervalHeaders intervalHeaders}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addIntervalHeader(
      /**
       * The intervalHeader to add; if empty, nothing is inserted
       */
      oIntervalHeader: CalendarAppointment
    ): this;
    /**
     * Adds some nonWorkingPeriod to the aggregation {@link #getNonWorkingPeriods nonWorkingPeriods}.
     *
     * @since 1.128
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addNonWorkingPeriod(
      /**
       * The nonWorkingPeriod to add; if empty, nothing is inserted
       */
      oNonWorkingPeriod: NonWorkingPeriod
    ): this;
    /**
     * Adds some specialDate to the aggregation {@link #getSpecialDates specialDates}.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addSpecialDate(
      /**
       * The specialDate to add; if empty, nothing is inserted
       */
      oSpecialDate: DateTypeRange
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:appointmentCreate appointmentCreate} event of
     * this `sap.m.PlanningCalendarRow`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendarRow` itself.
     *
     * Fired if an appointment is created.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAppointmentCreate(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PlanningCalendarRow$AppointmentCreateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendarRow` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:appointmentCreate appointmentCreate} event of
     * this `sap.m.PlanningCalendarRow`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendarRow` itself.
     *
     * Fired if an appointment is created.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAppointmentCreate(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PlanningCalendarRow$AppointmentCreateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendarRow` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:appointmentDragEnter appointmentDragEnter} event
     * of this `sap.m.PlanningCalendarRow`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendarRow` itself.
     *
     * Fired if an appointment is dropped.
     *
     * When this event handler is attached, the default behavior of the `enableAppointmentsDragAndDrop` property
     * to move appointments only within their original calendar row is no longer valid. You can move the appointment
     * around all rows for which `enableAppointmentsDragAndDrop` is set to true. In this case, the drop target
     * area is indicated by a placeholder. In the event handler you can call the `preventDefault` method of
     * the event to prevent this default behavior. In this case, the placeholder will no longer be available
     * and it will not be possible to drop the appointment in the row.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAppointmentDragEnter(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PlanningCalendarRow$AppointmentDragEnterEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendarRow` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:appointmentDragEnter appointmentDragEnter} event
     * of this `sap.m.PlanningCalendarRow`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendarRow` itself.
     *
     * Fired if an appointment is dropped.
     *
     * When this event handler is attached, the default behavior of the `enableAppointmentsDragAndDrop` property
     * to move appointments only within their original calendar row is no longer valid. You can move the appointment
     * around all rows for which `enableAppointmentsDragAndDrop` is set to true. In this case, the drop target
     * area is indicated by a placeholder. In the event handler you can call the `preventDefault` method of
     * the event to prevent this default behavior. In this case, the placeholder will no longer be available
     * and it will not be possible to drop the appointment in the row.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAppointmentDragEnter(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PlanningCalendarRow$AppointmentDragEnterEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendarRow` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:appointmentDrop appointmentDrop} event of this
     * `sap.m.PlanningCalendarRow`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendarRow` itself.
     *
     * Fired if an appointment is dropped.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAppointmentDrop(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PlanningCalendarRow$AppointmentDropEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendarRow` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:appointmentDrop appointmentDrop} event of this
     * `sap.m.PlanningCalendarRow`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendarRow` itself.
     *
     * Fired if an appointment is dropped.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAppointmentDrop(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PlanningCalendarRow$AppointmentDropEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendarRow` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:appointmentResize appointmentResize} event of
     * this `sap.m.PlanningCalendarRow`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendarRow` itself.
     *
     * Fired if an appointment is resized.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAppointmentResize(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PlanningCalendarRow$AppointmentResizeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendarRow` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:appointmentResize appointmentResize} event of
     * this `sap.m.PlanningCalendarRow`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PlanningCalendarRow` itself.
     *
     * Fired if an appointment is resized.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAppointmentResize(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PlanningCalendarRow$AppointmentResizeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PlanningCalendarRow` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the appointments in the aggregation {@link #getAppointments appointments}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyAppointments(): this;
    /**
     * Destroys all the headerContent in the aggregation {@link #getHeaderContent headerContent}.
     *
     * @since 1.67
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyHeaderContent(): this;
    /**
     * Destroys all the intervalHeaders in the aggregation {@link #getIntervalHeaders intervalHeaders}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyIntervalHeaders(): this;
    /**
     * Destroys all the nonWorkingPeriods in the aggregation {@link #getNonWorkingPeriods nonWorkingPeriods}.
     *
     * @since 1.128
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyNonWorkingPeriods(): this;
    /**
     * Destroys all the specialDates in the aggregation {@link #getSpecialDates specialDates}.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySpecialDates(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:appointmentCreate appointmentCreate} event
     * of this `sap.m.PlanningCalendarRow`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAppointmentCreate(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: PlanningCalendarRow$AppointmentCreateEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:appointmentDragEnter appointmentDragEnter }
     * event of this `sap.m.PlanningCalendarRow`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAppointmentDragEnter(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: PlanningCalendarRow$AppointmentDragEnterEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:appointmentDrop appointmentDrop} event of
     * this `sap.m.PlanningCalendarRow`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAppointmentDrop(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: PlanningCalendarRow$AppointmentDropEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:appointmentResize appointmentResize} event
     * of this `sap.m.PlanningCalendarRow`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAppointmentResize(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: PlanningCalendarRow$AppointmentResizeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:appointmentCreate appointmentCreate} to attached listeners.
     *
     * @since 1.56
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAppointmentCreate(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: PlanningCalendarRow$AppointmentCreateEventParameters
    ): this;
    /**
     * Fires event {@link #event:appointmentDragEnter appointmentDragEnter} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @since 1.56
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireAppointmentDragEnter(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: PlanningCalendarRow$AppointmentDragEnterEventParameters
    ): boolean;
    /**
     * Fires event {@link #event:appointmentDrop appointmentDrop} to attached listeners.
     *
     * @since 1.54
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAppointmentDrop(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: PlanningCalendarRow$AppointmentDropEventParameters
    ): this;
    /**
     * Fires event {@link #event:appointmentResize appointmentResize} to attached listeners.
     *
     * @since 1.56
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAppointmentResize(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: PlanningCalendarRow$AppointmentResizeEventParameters
    ): this;
    /**
     * Gets content of aggregation {@link #getAppointments appointments}.
     *
     * The appointments to be displayed in the row. Appointments that outside the visible time frame are not
     * rendered.
     *
     * **Note:** For performance reasons, only appointments in the visible time range or nearby should be assigned.
     */
    getAppointments(): CalendarAppointment[];
    /**
     * Gets current value of property {@link #getEnableAppointmentsCreate enableAppointmentsCreate}.
     *
     * Determines whether the appointments can be created by dragging on empty cells.
     *
     * See `enableAppointmentsResize` property documentation for the specific points for events snapping.
     *
     * **Notes:** In "One month" view, the appointments cannot be created on small screen (as there they are
     * displayed as a list below the dates).
     *
     * Default value is `false`.
     *
     * @since 1.56
     *
     * @returns Value of property `enableAppointmentsCreate`
     */
    getEnableAppointmentsCreate(): boolean;
    /**
     * Gets current value of property {@link #getEnableAppointmentsDragAndDrop enableAppointmentsDragAndDrop}.
     *
     * Determines whether the appointments in the row are draggable.
     *
     * The drag and drop interaction is visualized by a placeholder highlighting the area where the appointment
     * can be dropped by the user.
     *
     * By default, appointments can be dragged only within their original `PlanningCalendarRow`. When `enableAppointmentsDragAndDrop`
     * is set to true, attaching the {@link #event:appointmentDragEnter appointmentDragEnter} event can change
     * the default behavior and allow appointments to be dragged between calendar rows.
     *
     * Specifics based on the intervals (hours, days or months) displayed in the `PlanningCalendar` views:
     *
     * Hours:
     *  For views where the displayed intervals are hours, the placeholder snaps on every interval of 15 minutes.
     * After the appointment is dropped, the {@link #event:appointmentDrop appointmentDrop} event is fired,
     * containing the new start and end UI5Date or JavaScript Date objects.
     *  For example, an appointment with start date "Nov 13 2017 12:17:00" and end date "Nov 13 2017 12:45:30"
     * lasts for 27 minutes and 30 seconds. After dragging and dropping to a new time, the possible new start
     * date has time that is either "hh:00:00" or "hh:15:00" because of the placeholder that can snap on every
     * 15 minutes. The new end date is calculated to be 27 minutes and 30 seconds later and would be either
     * "hh:27:30" or "hh:57:30".
     *
     * Days:
     *  For views where intervals are days, the placeholder highlights the whole day and after the appointment
     * is dropped the {@link #event:appointmentDrop appointmentDrop} event is fired. The event contains the
     * new start and end UI5Date or JavaScript Date objects with changed date but the original time (hh:mm:ss)
     * is preserved.
     *
     * Months:
     *  For views where intervals are months, the placeholder highlights the whole month and after the appointment
     * is dropped the {@link #event:appointmentDrop appointmentDrop} event is fired. The event contains the
     * new start and end UI5Date or JavaScript Date objects with changed month but the original date and time
     * is preserved.
     *
     * **Note:** In "One month" view, the appointments are not draggable on small screen (as there they are
     * displayed as a list below the dates). Group appointments are also not draggable.
     *
     * **Note:** Additional application-level code will be needed to provide a keyboard alternative to drag
     * and drop mouse interactions. One possible option is by handling {@link sap.m.PlanningCalendar#event:appointmentSelect appointmentSelect }
     * event of the `sap.m.PlanningCalendar`, as shown in the following simplified example:
     *
     *
     * ```javascript
     *
     * 	new sap.m.PlanningCalendar({
     * 		...
     * 		rows: [
     * 			new sap.m.PlanningCalendarRow({
     * 				...
     * 				enableAppointmentsDragAndDrop: true,
     *         		...
     * 			}),
     * 			...
     * 		],
     * 		...
     * 		appointmentSelect: function(event) {
     * 			// Open edit {@link sap.m.Dialog Dialog} to modify the appointment properties
     * 			new sap.m.Dialog({ ... }).openBy(event.getParameter("appointment"));
     * 		}
     * 	});
     * ```
     *
     *
     * For a complete example, you can check out the following Demokit sample: {@link https://ui5.sap.com/#/entity/sap.m.PlanningCalendar/sample/sap.m.sample.PlanningCalendarModifyAppointments Planning Calendar - with appointments modification}
     *
     * Default value is `false`.
     *
     * @since 1.54
     *
     * @returns Value of property `enableAppointmentsDragAndDrop`
     */
    getEnableAppointmentsDragAndDrop(): boolean;
    /**
     * Gets current value of property {@link #getEnableAppointmentsResize enableAppointmentsResize}.
     *
     * Determines whether the appointments in the row are resizable.
     *
     * The resize interaction is visualized by making the appointment transparent.
     *
     * Specifics based on the intervals (hours, days or months) displayed in the `PlanningCalendar` views:
     *
     * Hours: For views where the displayed intervals are hours, the appointment snaps on every interval of
     * 15 minutes. After the resize is finished, the {@link #event:appointmentResize appointmentResize} event
     * is fired, containing the new start and end UI5Date or JavaScript Date objects.
     *
     * Days: For views where intervals are days, the appointment snaps to the end of the day. After the resize
     * is finished, the {@link #event:appointmentResize appointmentResize} event is fired, containing the new
     * start and end UI5Date or JavaScript Date objects. The `endDate` time is changed to 00:00:00
     *
     * Months: For views where intervals are months, the appointment snaps to the end of the month. The {@link #event:appointmentResize appointmentResize }
     * event is fired, containing the new start and end UI5Date or JavaScript Date objects. The `endDate` is
     * set to the 00:00:00 and first day of the following month.
     *
     * **Notes:** In "One month" view, the appointments are not resizable on small screen (as there they are
     * displayed as a list below the dates). Group appointments are also not resizable
     *
     * **Note:** Additional application-level code will be needed to provide a keyboard alternative to appointments
     * resizing interactions with mouse. It can be done in a similar way as described in the `enableAppointmentsDragAndDrop`
     * property documentation.
     *
     * Default value is `false`.
     *
     * @since 1.56
     *
     * @returns Value of property `enableAppointmentsResize`
     */
    getEnableAppointmentsResize(): boolean;
    /**
     * Gets content of aggregation {@link #getHeaderContent headerContent}.
     *
     * Holds the header content of the row.
     *
     * **Note:**
     * 	 - If the `headerContent` aggregation is added, then the set icon, description, title and tooltip are
     *     ignored.
     * 	 - The application developer has to ensure, that the size of the content conforms with the size of the
     *     header.
     *
     * @since 1.67
     */
    getHeaderContent(): Control[];
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Specifies the URI of an image or an icon registered in `sap.ui.core.IconPool`.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets content of aggregation {@link #getIntervalHeaders intervalHeaders}.
     *
     * The appointments to be displayed at the top of the intervals (for example, for public holidays). Appointments
     * outside the visible time frame are not rendered.
     *
     * Keep in mind that the `intervalHeaders` should always fill whole intervals. If they are shorter or longer
     * than one interval, they are not displayed.
     *
     * **Note:** For performance reasons, only appointments in the visible time range or nearby should be assigned.
     */
    getIntervalHeaders(): CalendarAppointment[];
    /**
     * Gets current value of property {@link #getKey key}.
     *
     * Defines the identifier of the row.
     *
     *
     * @returns Value of property `key`
     */
    getKey(): string;
    /**
     * Gets current value of property {@link #getNoAppointmentsText noAppointmentsText}.
     *
     * Defines the text that is displayed when no {@link sap.ui.unified.CalendarAppointment CalendarAppointments }
     * are assigned.
     *
     *
     * @returns Value of property `noAppointmentsText`
     */
    getNoAppointmentsText(): string;
    /**
     * Gets current value of property {@link #getNonWorkingDays nonWorkingDays}.
     *
     * Determines whether the provided weekdays are displayed as non-working days. Valid values inside the array
     * are from 0 to 6 (other values are ignored). If not set, the weekend defined in the locale settings is
     * displayed as non-working days.
     *
     * **Note:** The non-working days are visualized if the `intervalType` property of the {@link sap.m.PlanningCalendarView }
     * is set to `Day`.
     *
     *
     * @returns Value of property `nonWorkingDays`
     */
    getNonWorkingDays(): int[];
    /**
     * Gets current value of property {@link #getNonWorkingHours nonWorkingHours}.
     *
     * Determines whether the provided hours are displayed as non-working hours. Valid values inside the array
     * are from 0 to 23 (other values are ignored).
     *
     * **Note:** The non-working hours are visualized if `intervalType` property of the {@link sap.m.PlanningCalendarView }
     * is set to `Hour`.
     *
     *
     * @returns Value of property `nonWorkingHours`
     */
    getNonWorkingHours(): int[];
    /**
     * Gets content of aggregation {@link #getNonWorkingPeriods nonWorkingPeriods}.
     *
     * Sets the provided period to be displayed as a non-working.
     *
     * @since 1.128
     */
    getNonWorkingPeriods(): NonWorkingPeriod[];
    /**
     * Gets current value of property {@link #getRowHeaderDescription rowHeaderDescription}.
     *
     * Defines the text that will be announced by the screen reader when a user navigates to the row header.
     *
     *
     * @returns Value of property `rowHeaderDescription`
     */
    getRowHeaderDescription(): string;
    /**
     * Gets current value of property {@link #getSelected selected}.
     *
     * Defines the selected state of the `PlanningCalendarRow`.
     *
     * **Note:** Binding the `selected` property in single selection modes may cause unwanted results if you
     * have more than one selected row in your binding.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `selected`
     */
    getSelected(): boolean;
    /**
     * Gets content of aggregation {@link #getSpecialDates specialDates}.
     *
     * Holds the special dates in the context of a row. A single `sap.ui.unified.DateTypeRange` instance can
     * be set.
     *
     * **Note** Only `sap.ui.unified.DateTypeRange` isntances configured with `sap.ui.unified.CalendarDayType.NonWorking`
     * or `sap.ui.unified.CalendarDayType.Working` type will be visualized in the row. In all other cases the
     * `sap.ui.unified.DateTypeRange` instances will be ignored and will not be displayed in the control. Assigning
     * more than one of these values in combination for the same date will lead to unpredictable results.
     *
     * @since 1.56
     */
    getSpecialDates(): DateTypeRange[];
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Defines the text of the header (for example, the department of the person).
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Defines the title of the header (for example, the name of the person).
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Checks for the provided `sap.ui.unified.CalendarAppointment` in the aggregation {@link #getAppointments appointments}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfAppointment(
      /**
       * The appointment whose index is looked for
       */
      oAppointment: CalendarAppointment
    ): int;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getHeaderContent headerContent}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.67
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfHeaderContent(
      /**
       * The headerContent whose index is looked for
       */
      oHeaderContent: Control
    ): int;
    /**
     * Checks for the provided `sap.ui.unified.CalendarAppointment` in the aggregation {@link #getIntervalHeaders intervalHeaders}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfIntervalHeader(
      /**
       * The intervalHeader whose index is looked for
       */
      oIntervalHeader: CalendarAppointment
    ): int;
    /**
     * Checks for the provided `sap.ui.unified.NonWorkingPeriod` in the aggregation {@link #getNonWorkingPeriods nonWorkingPeriods}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.128
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfNonWorkingPeriod(
      /**
       * The nonWorkingPeriod whose index is looked for
       */
      oNonWorkingPeriod: NonWorkingPeriod
    ): int;
    /**
     * Checks for the provided `sap.ui.unified.DateTypeRange` in the aggregation {@link #getSpecialDates specialDates}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.56
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfSpecialDate(
      /**
       * The specialDate whose index is looked for
       */
      oSpecialDate: DateTypeRange
    ): int;
    /**
     * Inserts a appointment into the aggregation {@link #getAppointments appointments}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertAppointment(
      /**
       * The appointment to insert; if empty, nothing is inserted
       */
      oAppointment: CalendarAppointment,
      /**
       * The `0`-based index the appointment should be inserted at; for a negative value of `iIndex`, the appointment
       * is inserted at position 0; for a value greater than the current size of the aggregation, the appointment
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a headerContent into the aggregation {@link #getHeaderContent headerContent}.
     *
     * @since 1.67
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertHeaderContent(
      /**
       * The headerContent to insert; if empty, nothing is inserted
       */
      oHeaderContent: Control,
      /**
       * The `0`-based index the headerContent should be inserted at; for a negative value of `iIndex`, the headerContent
       * is inserted at position 0; for a value greater than the current size of the aggregation, the headerContent
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a intervalHeader into the aggregation {@link #getIntervalHeaders intervalHeaders}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertIntervalHeader(
      /**
       * The intervalHeader to insert; if empty, nothing is inserted
       */
      oIntervalHeader: CalendarAppointment,
      /**
       * The `0`-based index the intervalHeader should be inserted at; for a negative value of `iIndex`, the intervalHeader
       * is inserted at position 0; for a value greater than the current size of the aggregation, the intervalHeader
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a nonWorkingPeriod into the aggregation {@link #getNonWorkingPeriods nonWorkingPeriods}.
     *
     * @since 1.128
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertNonWorkingPeriod(
      /**
       * The nonWorkingPeriod to insert; if empty, nothing is inserted
       */
      oNonWorkingPeriod: NonWorkingPeriod,
      /**
       * The `0`-based index the nonWorkingPeriod should be inserted at; for a negative value of `iIndex`, the
       * nonWorkingPeriod is inserted at position 0; for a value greater than the current size of the aggregation,
       * the nonWorkingPeriod is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a specialDate into the aggregation {@link #getSpecialDates specialDates}.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertSpecialDate(
      /**
       * The specialDate to insert; if empty, nothing is inserted
       */
      oSpecialDate: DateTypeRange,
      /**
       * The `0`-based index the specialDate should be inserted at; for a negative value of `iIndex`, the specialDate
       * is inserted at position 0; for a value greater than the current size of the aggregation, the specialDate
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getAppointments appointments}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAppointments(): CalendarAppointment[];
    /**
     * Removes all the controls from the aggregation {@link #getHeaderContent headerContent}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.67
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllHeaderContent(): Control[];
    /**
     * Removes all the controls from the aggregation {@link #getIntervalHeaders intervalHeaders}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllIntervalHeaders(): CalendarAppointment[];
    /**
     * Removes all the controls from the aggregation {@link #getNonWorkingPeriods nonWorkingPeriods}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.128
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllNonWorkingPeriods(): NonWorkingPeriod[];
    /**
     * Removes all the controls from the aggregation {@link #getSpecialDates specialDates}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.56
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllSpecialDates(): DateTypeRange[];
    /**
     * Removes a appointment from the aggregation {@link #getAppointments appointments}.
     *
     *
     * @returns The removed appointment or `null`
     */
    removeAppointment(
      /**
       * The appointment to remove or its index or id
       */
      vAppointment: int | string | CalendarAppointment
    ): CalendarAppointment | null;
    /**
     * Removes a headerContent from the aggregation {@link #getHeaderContent headerContent}.
     *
     * @since 1.67
     *
     * @returns The removed headerContent or `null`
     */
    removeHeaderContent(
      /**
       * The headerContent to remove or its index or id
       */
      vHeaderContent: int | string | Control
    ): Control | null;
    /**
     * Removes a intervalHeader from the aggregation {@link #getIntervalHeaders intervalHeaders}.
     *
     *
     * @returns The removed intervalHeader or `null`
     */
    removeIntervalHeader(
      /**
       * The intervalHeader to remove or its index or id
       */
      vIntervalHeader: int | string | CalendarAppointment
    ): CalendarAppointment | null;
    /**
     * Removes a nonWorkingPeriod from the aggregation {@link #getNonWorkingPeriods nonWorkingPeriods}.
     *
     * @since 1.128
     *
     * @returns The removed nonWorkingPeriod or `null`
     */
    removeNonWorkingPeriod(
      /**
       * The nonWorkingPeriod to remove or its index or id
       */
      vNonWorkingPeriod: int | string | NonWorkingPeriod
    ): NonWorkingPeriod | null;
    /**
     * Removes a specialDate from the aggregation {@link #getSpecialDates specialDates}.
     *
     * @since 1.56
     *
     * @returns The removed specialDate or `null`
     */
    removeSpecialDate(
      /**
       * The specialDate to remove or its index or id
       */
      vSpecialDate: int | string | DateTypeRange
    ): DateTypeRange | null;
    /**
     * Sets a new value for property {@link #getEnableAppointmentsCreate enableAppointmentsCreate}.
     *
     * Determines whether the appointments can be created by dragging on empty cells.
     *
     * See `enableAppointmentsResize` property documentation for the specific points for events snapping.
     *
     * **Notes:** In "One month" view, the appointments cannot be created on small screen (as there they are
     * displayed as a list below the dates).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableAppointmentsCreate(
      /**
       * New value for property `enableAppointmentsCreate`
       */
      bEnableAppointmentsCreate?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnableAppointmentsDragAndDrop enableAppointmentsDragAndDrop}.
     *
     * Determines whether the appointments in the row are draggable.
     *
     * The drag and drop interaction is visualized by a placeholder highlighting the area where the appointment
     * can be dropped by the user.
     *
     * By default, appointments can be dragged only within their original `PlanningCalendarRow`. When `enableAppointmentsDragAndDrop`
     * is set to true, attaching the {@link #event:appointmentDragEnter appointmentDragEnter} event can change
     * the default behavior and allow appointments to be dragged between calendar rows.
     *
     * Specifics based on the intervals (hours, days or months) displayed in the `PlanningCalendar` views:
     *
     * Hours:
     *  For views where the displayed intervals are hours, the placeholder snaps on every interval of 15 minutes.
     * After the appointment is dropped, the {@link #event:appointmentDrop appointmentDrop} event is fired,
     * containing the new start and end UI5Date or JavaScript Date objects.
     *  For example, an appointment with start date "Nov 13 2017 12:17:00" and end date "Nov 13 2017 12:45:30"
     * lasts for 27 minutes and 30 seconds. After dragging and dropping to a new time, the possible new start
     * date has time that is either "hh:00:00" or "hh:15:00" because of the placeholder that can snap on every
     * 15 minutes. The new end date is calculated to be 27 minutes and 30 seconds later and would be either
     * "hh:27:30" or "hh:57:30".
     *
     * Days:
     *  For views where intervals are days, the placeholder highlights the whole day and after the appointment
     * is dropped the {@link #event:appointmentDrop appointmentDrop} event is fired. The event contains the
     * new start and end UI5Date or JavaScript Date objects with changed date but the original time (hh:mm:ss)
     * is preserved.
     *
     * Months:
     *  For views where intervals are months, the placeholder highlights the whole month and after the appointment
     * is dropped the {@link #event:appointmentDrop appointmentDrop} event is fired. The event contains the
     * new start and end UI5Date or JavaScript Date objects with changed month but the original date and time
     * is preserved.
     *
     * **Note:** In "One month" view, the appointments are not draggable on small screen (as there they are
     * displayed as a list below the dates). Group appointments are also not draggable.
     *
     * **Note:** Additional application-level code will be needed to provide a keyboard alternative to drag
     * and drop mouse interactions. One possible option is by handling {@link sap.m.PlanningCalendar#event:appointmentSelect appointmentSelect }
     * event of the `sap.m.PlanningCalendar`, as shown in the following simplified example:
     *
     *
     * ```javascript
     *
     * 	new sap.m.PlanningCalendar({
     * 		...
     * 		rows: [
     * 			new sap.m.PlanningCalendarRow({
     * 				...
     * 				enableAppointmentsDragAndDrop: true,
     *         		...
     * 			}),
     * 			...
     * 		],
     * 		...
     * 		appointmentSelect: function(event) {
     * 			// Open edit {@link sap.m.Dialog Dialog} to modify the appointment properties
     * 			new sap.m.Dialog({ ... }).openBy(event.getParameter("appointment"));
     * 		}
     * 	});
     * ```
     *
     *
     * For a complete example, you can check out the following Demokit sample: {@link https://ui5.sap.com/#/entity/sap.m.PlanningCalendar/sample/sap.m.sample.PlanningCalendarModifyAppointments Planning Calendar - with appointments modification}
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableAppointmentsDragAndDrop(
      /**
       * New value for property `enableAppointmentsDragAndDrop`
       */
      bEnableAppointmentsDragAndDrop?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnableAppointmentsResize enableAppointmentsResize}.
     *
     * Determines whether the appointments in the row are resizable.
     *
     * The resize interaction is visualized by making the appointment transparent.
     *
     * Specifics based on the intervals (hours, days or months) displayed in the `PlanningCalendar` views:
     *
     * Hours: For views where the displayed intervals are hours, the appointment snaps on every interval of
     * 15 minutes. After the resize is finished, the {@link #event:appointmentResize appointmentResize} event
     * is fired, containing the new start and end UI5Date or JavaScript Date objects.
     *
     * Days: For views where intervals are days, the appointment snaps to the end of the day. After the resize
     * is finished, the {@link #event:appointmentResize appointmentResize} event is fired, containing the new
     * start and end UI5Date or JavaScript Date objects. The `endDate` time is changed to 00:00:00
     *
     * Months: For views where intervals are months, the appointment snaps to the end of the month. The {@link #event:appointmentResize appointmentResize }
     * event is fired, containing the new start and end UI5Date or JavaScript Date objects. The `endDate` is
     * set to the 00:00:00 and first day of the following month.
     *
     * **Notes:** In "One month" view, the appointments are not resizable on small screen (as there they are
     * displayed as a list below the dates). Group appointments are also not resizable
     *
     * **Note:** Additional application-level code will be needed to provide a keyboard alternative to appointments
     * resizing interactions with mouse. It can be done in a similar way as described in the `enableAppointmentsDragAndDrop`
     * property documentation.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableAppointmentsResize(
      /**
       * New value for property `enableAppointmentsResize`
       */
      bEnableAppointmentsResize?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Specifies the URI of an image or an icon registered in `sap.ui.core.IconPool`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getKey key}.
     *
     * Defines the identifier of the row.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setKey(
      /**
       * New value for property `key`
       */
      sKey?: string
    ): this;
    /**
     * Sets a new value for property {@link #getNoAppointmentsText noAppointmentsText}.
     *
     * Defines the text that is displayed when no {@link sap.ui.unified.CalendarAppointment CalendarAppointments }
     * are assigned.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNoAppointmentsText(
      /**
       * New value for property `noAppointmentsText`
       */
      sNoAppointmentsText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getNonWorkingDays nonWorkingDays}.
     *
     * Determines whether the provided weekdays are displayed as non-working days. Valid values inside the array
     * are from 0 to 6 (other values are ignored). If not set, the weekend defined in the locale settings is
     * displayed as non-working days.
     *
     * **Note:** The non-working days are visualized if the `intervalType` property of the {@link sap.m.PlanningCalendarView }
     * is set to `Day`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNonWorkingDays(
      /**
       * New value for property `nonWorkingDays`
       */
      sNonWorkingDays?: int[]
    ): this;
    /**
     * Sets a new value for property {@link #getNonWorkingHours nonWorkingHours}.
     *
     * Determines whether the provided hours are displayed as non-working hours. Valid values inside the array
     * are from 0 to 23 (other values are ignored).
     *
     * **Note:** The non-working hours are visualized if `intervalType` property of the {@link sap.m.PlanningCalendarView }
     * is set to `Hour`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNonWorkingHours(
      /**
       * New value for property `nonWorkingHours`
       */
      sNonWorkingHours?: int[]
    ): this;
    /**
     * Sets a new value for property {@link #getRowHeaderDescription rowHeaderDescription}.
     *
     * Defines the text that will be announced by the screen reader when a user navigates to the row header.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRowHeaderDescription(
      /**
       * New value for property `rowHeaderDescription`
       */
      sRowHeaderDescription?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSelected selected}.
     *
     * Defines the selected state of the `PlanningCalendarRow`.
     *
     * **Note:** Binding the `selected` property in single selection modes may cause unwanted results if you
     * have more than one selected row in your binding.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSelected(
      /**
       * New value for property `selected`
       */
      bSelected?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Defines the text of the header (for example, the department of the person).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Defines the title of the header (for example, the name of the person).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the PlanningCalendarRow constructor.
   */
  export interface $PlanningCalendarRowSettings extends $ElementSettings {
    /**
     * Defines the title of the header (for example, the name of the person).
     */
    title?: string | PropertyBindingInfo;

    /**
     * Defines the text of the header (for example, the department of the person).
     */
    text?: string | PropertyBindingInfo;

    /**
     * Specifies the URI of an image or an icon registered in `sap.ui.core.IconPool`.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the provided weekdays are displayed as non-working days. Valid values inside the array
     * are from 0 to 6 (other values are ignored). If not set, the weekend defined in the locale settings is
     * displayed as non-working days.
     *
     * **Note:** The non-working days are visualized if the `intervalType` property of the {@link sap.m.PlanningCalendarView }
     * is set to `Day`.
     */
    nonWorkingDays?: int[] | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the provided hours are displayed as non-working hours. Valid values inside the array
     * are from 0 to 23 (other values are ignored).
     *
     * **Note:** The non-working hours are visualized if `intervalType` property of the {@link sap.m.PlanningCalendarView }
     * is set to `Hour`.
     */
    nonWorkingHours?: int[] | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the selected state of the `PlanningCalendarRow`.
     *
     * **Note:** Binding the `selected` property in single selection modes may cause unwanted results if you
     * have more than one selected row in your binding.
     */
    selected?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the identifier of the row.
     */
    key?: string | PropertyBindingInfo;

    /**
     * Determines whether the appointments in the row are draggable.
     *
     * The drag and drop interaction is visualized by a placeholder highlighting the area where the appointment
     * can be dropped by the user.
     *
     * By default, appointments can be dragged only within their original `PlanningCalendarRow`. When `enableAppointmentsDragAndDrop`
     * is set to true, attaching the {@link #event:appointmentDragEnter appointmentDragEnter} event can change
     * the default behavior and allow appointments to be dragged between calendar rows.
     *
     * Specifics based on the intervals (hours, days or months) displayed in the `PlanningCalendar` views:
     *
     * Hours:
     *  For views where the displayed intervals are hours, the placeholder snaps on every interval of 15 minutes.
     * After the appointment is dropped, the {@link #event:appointmentDrop appointmentDrop} event is fired,
     * containing the new start and end UI5Date or JavaScript Date objects.
     *  For example, an appointment with start date "Nov 13 2017 12:17:00" and end date "Nov 13 2017 12:45:30"
     * lasts for 27 minutes and 30 seconds. After dragging and dropping to a new time, the possible new start
     * date has time that is either "hh:00:00" or "hh:15:00" because of the placeholder that can snap on every
     * 15 minutes. The new end date is calculated to be 27 minutes and 30 seconds later and would be either
     * "hh:27:30" or "hh:57:30".
     *
     * Days:
     *  For views where intervals are days, the placeholder highlights the whole day and after the appointment
     * is dropped the {@link #event:appointmentDrop appointmentDrop} event is fired. The event contains the
     * new start and end UI5Date or JavaScript Date objects with changed date but the original time (hh:mm:ss)
     * is preserved.
     *
     * Months:
     *  For views where intervals are months, the placeholder highlights the whole month and after the appointment
     * is dropped the {@link #event:appointmentDrop appointmentDrop} event is fired. The event contains the
     * new start and end UI5Date or JavaScript Date objects with changed month but the original date and time
     * is preserved.
     *
     * **Note:** In "One month" view, the appointments are not draggable on small screen (as there they are
     * displayed as a list below the dates). Group appointments are also not draggable.
     *
     * **Note:** Additional application-level code will be needed to provide a keyboard alternative to drag
     * and drop mouse interactions. One possible option is by handling {@link sap.m.PlanningCalendar#event:appointmentSelect appointmentSelect }
     * event of the `sap.m.PlanningCalendar`, as shown in the following simplified example:
     *
     *
     * ```javascript
     *
     * 	new sap.m.PlanningCalendar({
     * 		...
     * 		rows: [
     * 			new sap.m.PlanningCalendarRow({
     * 				...
     * 				enableAppointmentsDragAndDrop: true,
     *         		...
     * 			}),
     * 			...
     * 		],
     * 		...
     * 		appointmentSelect: function(event) {
     * 			// Open edit {@link sap.m.Dialog Dialog} to modify the appointment properties
     * 			new sap.m.Dialog({ ... }).openBy(event.getParameter("appointment"));
     * 		}
     * 	});
     * ```
     *
     *
     * For a complete example, you can check out the following Demokit sample: {@link https://ui5.sap.com/#/entity/sap.m.PlanningCalendar/sample/sap.m.sample.PlanningCalendarModifyAppointments Planning Calendar - with appointments modification}
     *
     * @since 1.54
     */
    enableAppointmentsDragAndDrop?:
      | boolean
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines whether the appointments in the row are resizable.
     *
     * The resize interaction is visualized by making the appointment transparent.
     *
     * Specifics based on the intervals (hours, days or months) displayed in the `PlanningCalendar` views:
     *
     * Hours: For views where the displayed intervals are hours, the appointment snaps on every interval of
     * 15 minutes. After the resize is finished, the {@link #event:appointmentResize appointmentResize} event
     * is fired, containing the new start and end UI5Date or JavaScript Date objects.
     *
     * Days: For views where intervals are days, the appointment snaps to the end of the day. After the resize
     * is finished, the {@link #event:appointmentResize appointmentResize} event is fired, containing the new
     * start and end UI5Date or JavaScript Date objects. The `endDate` time is changed to 00:00:00
     *
     * Months: For views where intervals are months, the appointment snaps to the end of the month. The {@link #event:appointmentResize appointmentResize }
     * event is fired, containing the new start and end UI5Date or JavaScript Date objects. The `endDate` is
     * set to the 00:00:00 and first day of the following month.
     *
     * **Notes:** In "One month" view, the appointments are not resizable on small screen (as there they are
     * displayed as a list below the dates). Group appointments are also not resizable
     *
     * **Note:** Additional application-level code will be needed to provide a keyboard alternative to appointments
     * resizing interactions with mouse. It can be done in a similar way as described in the `enableAppointmentsDragAndDrop`
     * property documentation.
     *
     * @since 1.56
     */
    enableAppointmentsResize?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the appointments can be created by dragging on empty cells.
     *
     * See `enableAppointmentsResize` property documentation for the specific points for events snapping.
     *
     * **Notes:** In "One month" view, the appointments cannot be created on small screen (as there they are
     * displayed as a list below the dates).
     *
     * @since 1.56
     */
    enableAppointmentsCreate?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the text that is displayed when no {@link sap.ui.unified.CalendarAppointment CalendarAppointments }
     * are assigned.
     */
    noAppointmentsText?: string | PropertyBindingInfo;

    /**
     * Defines the text that will be announced by the screen reader when a user navigates to the row header.
     */
    rowHeaderDescription?: string | PropertyBindingInfo;

    /**
     * The appointments to be displayed in the row. Appointments that outside the visible time frame are not
     * rendered.
     *
     * **Note:** For performance reasons, only appointments in the visible time range or nearby should be assigned.
     */
    appointments?:
      | CalendarAppointment[]
      | CalendarAppointment
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Sets the provided period to be displayed as a non-working.
     *
     * @since 1.128
     */
    nonWorkingPeriods?:
      | NonWorkingPeriod[]
      | NonWorkingPeriod
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * The appointments to be displayed at the top of the intervals (for example, for public holidays). Appointments
     * outside the visible time frame are not rendered.
     *
     * Keep in mind that the `intervalHeaders` should always fill whole intervals. If they are shorter or longer
     * than one interval, they are not displayed.
     *
     * **Note:** For performance reasons, only appointments in the visible time range or nearby should be assigned.
     */
    intervalHeaders?:
      | CalendarAppointment[]
      | CalendarAppointment
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Holds the special dates in the context of a row. A single `sap.ui.unified.DateTypeRange` instance can
     * be set.
     *
     * **Note** Only `sap.ui.unified.DateTypeRange` isntances configured with `sap.ui.unified.CalendarDayType.NonWorking`
     * or `sap.ui.unified.CalendarDayType.Working` type will be visualized in the row. In all other cases the
     * `sap.ui.unified.DateTypeRange` instances will be ignored and will not be displayed in the control. Assigning
     * more than one of these values in combination for the same date will lead to unpredictable results.
     *
     * @since 1.56
     */
    specialDates?:
      | DateTypeRange[]
      | DateTypeRange
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Holds the header content of the row.
     *
     * **Note:**
     * 	 - If the `headerContent` aggregation is added, then the set icon, description, title and tooltip are
     *     ignored.
     * 	 - The application developer has to ensure, that the size of the content conforms with the size of the
     *     header.
     *
     * @since 1.67
     */
    headerContent?:
      | Control[]
      | Control
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Fired if an appointment is dropped.
     *
     * @since 1.54
     */
    appointmentDrop?: (
      oEvent: PlanningCalendarRow$AppointmentDropEvent
    ) => void;

    /**
     * Fired if an appointment is dropped.
     *
     * When this event handler is attached, the default behavior of the `enableAppointmentsDragAndDrop` property
     * to move appointments only within their original calendar row is no longer valid. You can move the appointment
     * around all rows for which `enableAppointmentsDragAndDrop` is set to true. In this case, the drop target
     * area is indicated by a placeholder. In the event handler you can call the `preventDefault` method of
     * the event to prevent this default behavior. In this case, the placeholder will no longer be available
     * and it will not be possible to drop the appointment in the row.
     *
     * @since 1.56
     */
    appointmentDragEnter?: (
      oEvent: PlanningCalendarRow$AppointmentDragEnterEvent
    ) => void;

    /**
     * Fired if an appointment is resized.
     *
     * @since 1.56
     */
    appointmentResize?: (
      oEvent: PlanningCalendarRow$AppointmentResizeEvent
    ) => void;

    /**
     * Fired if an appointment is created.
     *
     * @since 1.56
     */
    appointmentCreate?: (
      oEvent: PlanningCalendarRow$AppointmentCreateEvent
    ) => void;
  }

  /**
   * Parameters of the PlanningCalendarRow#appointmentCreate event.
   */
  export interface PlanningCalendarRow$AppointmentCreateEventParameters {
    /**
     * Start date of the created appointment, as a UI5Date or JavaScript Date object.
     */
    startDate?: object;

    /**
     * End date of the created appointment, as a UI5Date or JavaScript Date object.
     */
    endDate?: object;

    /**
     * The row of the appointment.
     */
    calendarRow?: PlanningCalendarRow;
  }

  /**
   * Event object of the PlanningCalendarRow#appointmentCreate event.
   */
  export type PlanningCalendarRow$AppointmentCreateEvent = Event<
    PlanningCalendarRow$AppointmentCreateEventParameters,
    PlanningCalendarRow
  >;

  /**
   * Parameters of the PlanningCalendarRow#appointmentDragEnter event.
   */
  export interface PlanningCalendarRow$AppointmentDragEnterEventParameters {
    /**
     * The dropped appointment.
     */
    appointment?: CalendarAppointment;

    /**
     * Start date of the dropped appointment, as a UI5Date or JavaScript Date object.
     */
    startDate?: object;

    /**
     * Dropped appointment end date as a UI5Date or JavaScript Date object.
     */
    endDate?: object;

    /**
     * The row of the appointment.
     */
    calendarRow?: PlanningCalendarRow;
  }

  /**
   * Event object of the PlanningCalendarRow#appointmentDragEnter event.
   */
  export type PlanningCalendarRow$AppointmentDragEnterEvent = Event<
    PlanningCalendarRow$AppointmentDragEnterEventParameters,
    PlanningCalendarRow
  >;

  /**
   * Parameters of the PlanningCalendarRow#appointmentDrop event.
   */
  export interface PlanningCalendarRow$AppointmentDropEventParameters {
    /**
     * The dropped appointment.
     */
    appointment?: CalendarAppointment;

    /**
     * Start date of the dropped appointment, as a UI5Date or JavaScript Date object.
     */
    startDate?: object;

    /**
     * Dropped appointment end date as a UI5Date or JavaScript Date object.
     */
    endDate?: object;

    /**
     * The row of the appointment.
     */
    calendarRow?: PlanningCalendarRow;

    /**
     * The drop type. If true - it's "Copy", if false - it's "Move".
     */
    copy?: boolean;
  }

  /**
   * Event object of the PlanningCalendarRow#appointmentDrop event.
   */
  export type PlanningCalendarRow$AppointmentDropEvent = Event<
    PlanningCalendarRow$AppointmentDropEventParameters,
    PlanningCalendarRow
  >;

  /**
   * Parameters of the PlanningCalendarRow#appointmentResize event.
   */
  export interface PlanningCalendarRow$AppointmentResizeEventParameters {
    /**
     * The resized appointment.
     */
    appointment?: CalendarAppointment;

    /**
     * Start date of the resized appointment, as a UI5Date or JavaScript Date object.
     */
    startDate?: object;

    /**
     * End date of the resized appointment, as a UI5Date or JavaScript Date object.
     */
    endDate?: object;
  }

  /**
   * Event object of the PlanningCalendarRow#appointmentResize event.
   */
  export type PlanningCalendarRow$AppointmentResizeEvent = Event<
    PlanningCalendarRow$AppointmentResizeEventParameters,
    PlanningCalendarRow
  >;
}

declare module "sap/m/PlanningCalendarView" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import {
    CalendarAppointmentHeight,
    CalendarIntervalType,
  } from "sap/ui/unified/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * View of the {@link sap.m.PlanningCalendar}.
   *
   * The `PlanningCalendarView` defines the type of the intervals (hours, days, months) and how many intervals
   * are displayed.
   *
   * @since 1.34.0
   */
  export default class PlanningCalendarView extends UI5Element {
    /**
     * Constructor for a new `PlanningCalendarView`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $PlanningCalendarViewSettings
    );
    /**
     * Constructor for a new `PlanningCalendarView`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $PlanningCalendarViewSettings
    );

    /**
     * Creates a new subclass of class sap.m.PlanningCalendarView with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, PlanningCalendarView>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.PlanningCalendarView.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getAppointmentHeight appointmentHeight}.
     *
     * Determines the different possible sizes for appointments.
     *
     * Default value is `Regular`.
     *
     * @since 1.81.0
     *
     * @returns Value of property `appointmentHeight`
     */
    getAppointmentHeight(): CalendarAppointmentHeight;
    /**
     * Gets current value of property {@link #getDescription description}.
     *
     * Defines the description of the `PlanningCalendarView`.
     *
     *
     * @returns Value of property `description`
     */
    getDescription(): string;
    /**
     * Gets current value of property {@link #getIntervalLabelFormatter intervalLabelFormatter}.
     *
     * A function that formats the interval.
     *
     * @since 1.93
     *
     * @returns Value of property `intervalLabelFormatter`
     */
    getIntervalLabelFormatter(): object;
    /**
     * Gets current value of property {@link #getIntervalSize intervalSize}.
     *
     * An integer that defines the period size.
     *
     * Default value is `1`.
     *
     * @since 1.93
     *
     * @returns Value of property `intervalSize`
     */
    getIntervalSize(): int;
    /**
     * Gets current value of property {@link #getIntervalsL intervalsL}.
     *
     * Defines the number of intervals that are displayed for a {@link sap.m.PlanningCalendar} that is more
     * than 1024 pixels wide.
     *
     * Default value is `12`.
     *
     *
     * @returns Value of property `intervalsL`
     */
    getIntervalsL(): int;
    /**
     * Gets current value of property {@link #getIntervalsM intervalsM}.
     *
     * Defines the number of intervals that are displayed for a {@link sap.m.PlanningCalendar} that is between
     * 600 and 1024 pixels wide.
     *
     * Default value is `8`.
     *
     *
     * @returns Value of property `intervalsM`
     */
    getIntervalsM(): int;
    /**
     * Gets current value of property {@link #getIntervalsS intervalsS}.
     *
     * Defines the number of intervals that are displayed for a {@link sap.m.PlanningCalendar} that is less
     * than 600 pixels wide. **Note:** On a phone the maximum visible intervals are 8.
     *
     * Default value is `6`.
     *
     *
     * @returns Value of property `intervalsS`
     */
    getIntervalsS(): int;
    /**
     * Gets current value of property {@link #getIntervalType intervalType}.
     *
     * Determines the type of the intervals of the row.
     *
     * **Note:** Not all predefined interval types are supported for this property. For more information, see
     * the descriptions in the {@link sap.ui.unified.CalendarIntervalType CalendarIntervalType} enumeration.
     *
     * Default value is `Hour`.
     *
     *
     * @returns Value of property `intervalType`
     */
    getIntervalType(): CalendarIntervalType;
    /**
     * Gets current value of property {@link #getKey key}.
     *
     * Defines the key of the view. This must be set to identify the used view in the {@link sap.m.PlanningCalendar}.
     *
     *
     * @returns Value of property `key`
     */
    getKey(): string;
    /**
     * Gets current value of property {@link #getRelative relative}.
     *
     * Defines if the view will be relative. NOTE: Relative views, can be only used with intervalType - Day
     * and when used they need intervalSize and intervalLabelFormatter defined.
     *
     * Default value is `false`.
     *
     * @since 1.93
     *
     * @returns Value of property `relative`
     */
    getRelative(): boolean;
    /**
     * Gets current value of property {@link #getShowSubIntervals showSubIntervals}.
     *
     * If set, subintervals are displayed as lines in the rows.
     *
     *
     * 	 - Quarter hour subintervals for interval type `Hour`.
     * 	 - Hour subintervals for interval types `Day`, `Week` and `OneMonth`.
     * 	 - Day subintervals for interval type `Month`.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showSubIntervals`
     */
    getShowSubIntervals(): boolean;
    /**
     * Sets a new value for property {@link #getAppointmentHeight appointmentHeight}.
     *
     * Determines the different possible sizes for appointments.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Regular`.
     *
     * @since 1.81.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAppointmentHeight(
      /**
       * New value for property `appointmentHeight`
       */
      sAppointmentHeight?:
        | CalendarAppointmentHeight
        | keyof typeof CalendarAppointmentHeight
    ): this;
    /**
     * Sets a new value for property {@link #getDescription description}.
     *
     * Defines the description of the `PlanningCalendarView`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDescription(
      /**
       * New value for property `description`
       */
      sDescription: string
    ): this;
    /**
     * Sets a new value for property {@link #getIntervalLabelFormatter intervalLabelFormatter}.
     *
     * A function that formats the interval.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.93
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIntervalLabelFormatter(
      /**
       * New value for property `intervalLabelFormatter`
       */
      oIntervalLabelFormatter: object
    ): this;
    /**
     * Sets a new value for property {@link #getIntervalSize intervalSize}.
     *
     * An integer that defines the period size.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `1`.
     *
     * @since 1.93
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIntervalSize(
      /**
       * New value for property `intervalSize`
       */
      iIntervalSize?: int
    ): this;
    /**
     * Sets a new value for property {@link #getIntervalsL intervalsL}.
     *
     * Defines the number of intervals that are displayed for a {@link sap.m.PlanningCalendar} that is more
     * than 1024 pixels wide.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `12`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIntervalsL(
      /**
       * New value for property `intervalsL`
       */
      iIntervalsL?: int
    ): this;
    /**
     * Sets a new value for property {@link #getIntervalsM intervalsM}.
     *
     * Defines the number of intervals that are displayed for a {@link sap.m.PlanningCalendar} that is between
     * 600 and 1024 pixels wide.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `8`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIntervalsM(
      /**
       * New value for property `intervalsM`
       */
      iIntervalsM?: int
    ): this;
    /**
     * Sets a new value for property {@link #getIntervalsS intervalsS}.
     *
     * Defines the number of intervals that are displayed for a {@link sap.m.PlanningCalendar} that is less
     * than 600 pixels wide. **Note:** On a phone the maximum visible intervals are 8.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `6`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIntervalsS(
      /**
       * New value for property `intervalsS`
       */
      iIntervalsS?: int
    ): this;
    /**
     * Sets a new value for property {@link #getIntervalType intervalType}.
     *
     * Determines the type of the intervals of the row.
     *
     * **Note:** Not all predefined interval types are supported for this property. For more information, see
     * the descriptions in the {@link sap.ui.unified.CalendarIntervalType CalendarIntervalType} enumeration.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Hour`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIntervalType(
      /**
       * New value for property `intervalType`
       */
      sIntervalType?: CalendarIntervalType
    ): this;
    /**
     * Sets a new value for property {@link #getKey key}.
     *
     * Defines the key of the view. This must be set to identify the used view in the {@link sap.m.PlanningCalendar}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setKey(
      /**
       * New value for property `key`
       */
      sKey?: string
    ): this;
    /**
     * Sets a new value for property {@link #getRelative relative}.
     *
     * Defines if the view will be relative. NOTE: Relative views, can be only used with intervalType - Day
     * and when used they need intervalSize and intervalLabelFormatter defined.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.93
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRelative(
      /**
       * New value for property `relative`
       */
      bRelative?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowSubIntervals showSubIntervals}.
     *
     * If set, subintervals are displayed as lines in the rows.
     *
     *
     * 	 - Quarter hour subintervals for interval type `Hour`.
     * 	 - Hour subintervals for interval types `Day`, `Week` and `OneMonth`.
     * 	 - Day subintervals for interval type `Month`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowSubIntervals(
      /**
       * New value for property `showSubIntervals`
       */
      bShowSubIntervals?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the PlanningCalendarView constructor.
   */
  export interface $PlanningCalendarViewSettings extends $ElementSettings {
    /**
     * Defines the key of the view. This must be set to identify the used view in the {@link sap.m.PlanningCalendar}.
     */
    key?: string | PropertyBindingInfo;

    /**
     * Determines the type of the intervals of the row.
     *
     * **Note:** Not all predefined interval types are supported for this property. For more information, see
     * the descriptions in the {@link sap.ui.unified.CalendarIntervalType CalendarIntervalType} enumeration.
     */
    intervalType?: CalendarIntervalType | PropertyBindingInfo | `{${string}}`;

    /**
     * An integer that defines the period size.
     *
     * @since 1.93
     */
    intervalSize?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * A function that formats the interval.
     *
     * @since 1.93
     */
    intervalLabelFormatter?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines if the view will be relative. NOTE: Relative views, can be only used with intervalType - Day
     * and when used they need intervalSize and intervalLabelFormatter defined.
     *
     * @since 1.93
     */
    relative?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the description of the `PlanningCalendarView`.
     */
    description?: string | PropertyBindingInfo;

    /**
     * Defines the number of intervals that are displayed for a {@link sap.m.PlanningCalendar} that is less
     * than 600 pixels wide. **Note:** On a phone the maximum visible intervals are 8.
     */
    intervalsS?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the number of intervals that are displayed for a {@link sap.m.PlanningCalendar} that is between
     * 600 and 1024 pixels wide.
     */
    intervalsM?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the number of intervals that are displayed for a {@link sap.m.PlanningCalendar} that is more
     * than 1024 pixels wide.
     */
    intervalsL?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * If set, subintervals are displayed as lines in the rows.
     *
     *
     * 	 - Quarter hour subintervals for interval type `Hour`.
     * 	 - Hour subintervals for interval types `Day`, `Week` and `OneMonth`.
     * 	 - Day subintervals for interval type `Month`.
     */
    showSubIntervals?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the different possible sizes for appointments.
     *
     * @since 1.81.0
     */
    appointmentHeight?:
      | (CalendarAppointmentHeight | keyof typeof CalendarAppointmentHeight)
      | PropertyBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/plugins/CellSelector" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Context from "sap/ui/model/Context";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The `CellSelector` plugin enables cell selection inside the table when it is added as a dependent to
   * the control. It allows the user to individually select a cell block.
   *
   * Currently, the `CellSelector` plugin does not offer touch support.
   *
   * The `CellSelector` plugin can be used with the {@link sap.ui.table.Table} and {@link sap.m.Table} unless
   * the following applies:
   * 	 - Drag for rows is active
   * 	 - If used in combination with {@link sap.ui.table.Table#cellClick} or {@link sap.m.Table#itemPress }
   *
   * 	 - If the `sap.m.ListType.SingleSelectMaster` mode is used in the `sap.m.Table`
   *
   * When the `CellSelector` is used in combination with the {@link sap.ui.mdc.Table}, modifying the following
   * settings on the {@link sap.ui.mdc.Table} may lead to problems:
   * 	 - attaching a {@link sap.ui.mdc.Table#rowPress rowPress} event to the table after initialization of
   *     table and plugin
   * 	 - changing {@link sap.ui.mdc.Table#getSelectionMode selectionMode} to something else than `Multi`
   *
   * @since 1.119
   */
  export default class CellSelector extends UI5Element {
    /**
     * Constructor for a new CellSelector plugin.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new `CellSelector`
       */
      mSettings?: $CellSelectorSettings
    );
    /**
     * Constructor for a new CellSelector plugin.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new `CellSelector`, generated automatically if no id is given
       */
      sId?: string,
      /**
       * Initial settings for the new `CellSelector`
       */
      mSettings?: $CellSelectorSettings
    );

    /**
     * Creates a new subclass of class sap.m.plugins.CellSelector with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, CellSelector>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Searches a plugin of the corresponding type in the aggregations of the given `Element` instance. The
     * first plugin that is found is returned.
     *
     *
     * @returns The found plugin instance or `undefined` if not found
     */
    static findOn(
      /**
       * The `Element` instance to check for
       */
      oElement: UI5Element
    ): UI5Element | undefined;
    /**
     * Returns a metadata object for class sap.m.plugins.CellSelector.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionChange selectionChange} event of this
     * `sap.m.plugins.CellSelector`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.CellSelector` itself.
     *
     * Fired when the selection changes
     *
     * @since 1.130
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.CellSelector` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionChange selectionChange} event of this
     * `sap.m.plugins.CellSelector`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.CellSelector` itself.
     *
     * Fired when the selection changes
     *
     * @since 1.130
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.CellSelector` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:selectionChange selectionChange} event of
     * this `sap.m.plugins.CellSelector`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.130
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelectionChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:selectionChange selectionChange} to attached listeners.
     *
     * @since 1.130
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelectionChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Indicates whether this plugin is active or not.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets current value of property {@link #getRangeLimit rangeLimit}.
     *
     * Defines the number of row contexts for the {@link sap.ui.table.Table} control that need to be retrieved
     * from the binding when the range selection (e.g. enhancing the cell selection block to cover all rows
     * of a column) is triggered by the user. This helps to make the contexts already available for the user
     * actions after the cell selection (e.g. copy to clipboard). This property accepts positive integer values.
     * **Note:** To avoid performance problems, the `rangeLimit` should only be set higher than the default
     * value of 200 in the following cases:
     * 	 - With client-side models
     * 	 - With server-side models if they are used in client mode
     * 	 - If the entity set is small  In other cases, it is recommended to set the `rangeLimit` to at
     *     least double the value of the {@link sap.ui.table.Table#getThreshold threshold} property.
     *
     * Default value is `200`.
     *
     *
     * @returns Value of property `rangeLimit`
     */
    getRangeLimit(): int;
    /**
     * Returns the selected cells separated into selected rows and columns.
     *
     * Example: If the cells from (0, 0) to (2, 4) are selected, this method will return the following object:
     *
     * ```javascript
     *
     * 	{
     * 		rows: [Row0_Context, Row1_Context, Row2_Context],
     * 		columns: [Column0, Column1, Column2, Column3, Column4]
     * 	}
     * ```
     *
     *
     * **Note:** The content of the `rows` and `columns` depends on the owner control. The type of the column
     * that is returned depends on the table type for which the plugin is used (for example, `sap.ui.table.Column`
     * for `sap.ui.table.Table`).
     *
     * @since 1.124
     *
     * @returns An object containing the selected cells separated into rows and columns
     */
    getSelection(
      /**
       * Ignores group headers from selection
       */
      bIgnore: boolean
    ): Selection;
    /**
     * Determines whether there is a cell selection.
     *
     *
     * @returns Whether there is a cell selection
     */
    hasSelection(): boolean;
    /**
     * Remove the current selection block.
     */
    removeSelection(): void;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Indicates whether this plugin is active or not.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getRangeLimit rangeLimit}.
     *
     * Defines the number of row contexts for the {@link sap.ui.table.Table} control that need to be retrieved
     * from the binding when the range selection (e.g. enhancing the cell selection block to cover all rows
     * of a column) is triggered by the user. This helps to make the contexts already available for the user
     * actions after the cell selection (e.g. copy to clipboard). This property accepts positive integer values.
     * **Note:** To avoid performance problems, the `rangeLimit` should only be set higher than the default
     * value of 200 in the following cases:
     * 	 - With client-side models
     * 	 - With server-side models if they are used in client mode
     * 	 - If the entity set is small  In other cases, it is recommended to set the `rangeLimit` to at
     *     least double the value of the {@link sap.ui.table.Table#getThreshold threshold} property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `200`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRangeLimit(
      /**
       * New value for property `rangeLimit`
       */
      iRangeLimit?: int
    ): this;
  }
  /**
   * A selection object representing the selected cells.
   *
   * The selection object contains the selected cells separated into rows and columns. Rows are represented
   * by their context, while columns are the column instance, which may vary depending on the table type.
   */
  export type Selection = {
    /**
     * The row contexts of the selected cells.
     */
    rows: Context[];
    /**
     * The column instances of the selected cells; the content is based on the owner control.
     */
    columns: UI5Element[];
  };

  /**
   * Describes the settings that can be provided to the CellSelector constructor.
   */
  export interface $CellSelectorSettings extends $ElementSettings {
    /**
     * Defines the number of row contexts for the {@link sap.ui.table.Table} control that need to be retrieved
     * from the binding when the range selection (e.g. enhancing the cell selection block to cover all rows
     * of a column) is triggered by the user. This helps to make the contexts already available for the user
     * actions after the cell selection (e.g. copy to clipboard). This property accepts positive integer values.
     * **Note:** To avoid performance problems, the `rangeLimit` should only be set higher than the default
     * value of 200 in the following cases:
     * 	 - With client-side models
     * 	 - With server-side models if they are used in client mode
     * 	 - If the entity set is small  In other cases, it is recommended to set the `rangeLimit` to at
     *     least double the value of the {@link sap.ui.table.Table#getThreshold threshold} property.
     */
    rangeLimit?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether this plugin is active or not.
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Fired when the selection changes
     *
     * @since 1.130
     */
    selectionChange?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the CellSelector#selectionChange event.
   */
  export interface CellSelector$SelectionChangeEventParameters {}

  /**
   * Event object of the CellSelector#selectionChange event.
   */
  export type CellSelector$SelectionChangeEvent = Event<
    CellSelector$SelectionChangeEventParameters,
    CellSelector
  >;
}

declare module "sap/m/plugins/ColumnAIAction" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Control from "sap/ui/core/Control";

  import Event from "sap/ui/base/Event";

  /**
   * This plugin adds an AI related action to a table column.
   *
   * @since 1.136
   */
  export default class ColumnAIAction extends UI5Element {
    /**
     * Constructor for a new `ColumnAIAction` plugin that can be used to add an AI related action for table
     * columns.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the `ColumnAIAction`
       */
      mSettings?: $ColumnAIActionSettings
    );
    /**
     * Constructor for a new `ColumnAIAction` plugin that can be used to add an AI related action for table
     * columns.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new `ColumnAIAction`, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the `ColumnAIAction`
       */
      mSettings?: $ColumnAIActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.plugins.ColumnAIAction with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ColumnAIAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Searches a plugin of the corresponding type in the aggregations of the given `Element` instance. The
     * first plugin that is found is returned.
     *
     *
     * @returns The found plugin instance or `undefined` if not found
     */
    static findOn(
      /**
       * The `Element` instance to check for
       */
      oElement: UI5Element
    ): UI5Element | undefined;
    /**
     * Returns a metadata object for class sap.m.plugins.ColumnAIAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.plugins.ColumnAIAction`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.ColumnAIAction` itself.
     *
     * Fired when the AI action is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ColumnAIAction$PressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.ColumnAIAction` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.plugins.ColumnAIAction`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.ColumnAIAction` itself.
     *
     * Fired when the AI action is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ColumnAIAction$PressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.ColumnAIAction` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.plugins.ColumnAIAction`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ColumnAIAction$PressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ColumnAIAction$PressEventParameters
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ColumnAIAction constructor.
   */
  export interface $ColumnAIActionSettings extends $ElementSettings {
    /**
     * Fired when the AI action is pressed.
     */
    press?: (oEvent: ColumnAIAction$PressEvent) => void;
  }

  /**
   * Parameters of the ColumnAIAction#press event.
   */
  export interface ColumnAIAction$PressEventParameters {
    /**
     * The column action that triggered the event.
     */
    action?: Control;
  }

  /**
   * Event object of the ColumnAIAction#press event.
   */
  export type ColumnAIAction$PressEvent = Event<
    ColumnAIAction$PressEventParameters,
    ColumnAIAction
  >;
}

declare module "sap/m/plugins/ColumnResizer" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { CSSSize } from "sap/ui/core/library";

  import Event from "sap/ui/base/Event";

  /**
   * Enables column resizing for the `sap.m.Table`. This plugin can be added to the control via its `dependents`
   * aggregation and there must only be 1 instance of the plugin per control.
   *
   * @since 1.91
   */
  export default class ColumnResizer extends UI5Element {
    /**
     * Constructor for a new ColumnResizer plugin.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the `ColumnResizer`
       */
      mSettings?: $ColumnResizerSettings
    );
    /**
     * Constructor for a new ColumnResizer plugin.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new `ColumnResizer`, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the `ColumnResizer`
       */
      mSettings?: $ColumnResizerSettings
    );

    /**
     * Creates a new subclass of class sap.m.plugins.ColumnResizer with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ColumnResizer>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Searches a plugin of the corresponding type in the aggregations of the given `Element` instance. The
     * first plugin that is found is returned.
     *
     *
     * @returns The found plugin instance or `undefined` if not found
     */
    static findOn(
      /**
       * The `Element` instance to check for
       */
      oElement: UI5Element
    ): UI5Element | undefined;
    /**
     * Returns a metadata object for class sap.m.plugins.ColumnResizer.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:columnResize columnResize} event of this `sap.m.plugins.ColumnResizer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.ColumnResizer` itself.
     *
     * This event is fired when the column is resized.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachColumnResize(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ColumnResizer$ColumnResizeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.ColumnResizer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:columnResize columnResize} event of this `sap.m.plugins.ColumnResizer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.ColumnResizer` itself.
     *
     * This event is fired when the column is resized.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachColumnResize(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ColumnResizer$ColumnResizeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.ColumnResizer` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:columnResize columnResize} event of this `sap.m.plugins.ColumnResizer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachColumnResize(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ColumnResizer$ColumnResizeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:columnResize columnResize} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireColumnResize(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ColumnResizer$ColumnResizeEventParameters
    ): boolean;
    /**
     * Displays the resize handle for the provided column `DOM` reference.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    startResizing(
      /**
       * column DOM reference
       */
      oDomRef: HTMLElement
    ): void;
  }
  /**
   * Describes the settings that can be provided to the ColumnResizer constructor.
   */
  export interface $ColumnResizerSettings extends $ElementSettings {
    /**
     * This event is fired when the column is resized.
     */
    columnResize?: (oEvent: ColumnResizer$ColumnResizeEvent) => void;
  }

  /**
   * Parameters of the ColumnResizer#columnResize event.
   */
  export interface ColumnResizer$ColumnResizeEventParameters {
    /**
     * The column being resized.
     */
    column?: UI5Element;

    /**
     * The new width of the column.
     */
    width?: CSSSize;
  }

  /**
   * Event object of the ColumnResizer#columnResize event.
   */
  export type ColumnResizer$ColumnResizeEvent = Event<
    ColumnResizer$ColumnResizeEventParameters,
    ColumnResizer
  >;
}

declare module "sap/m/plugins/ContextMenuSetting" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { plugins } from "sap/m/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Provides configuration options and an extended behavior for the context menu that is applied to the related
   * control.
   *
   * @since 1.121
   */
  export default class ContextMenuSetting extends UI5Element {
    /**
     * Constructs an instance of sap.m.plugins.ContextMenuSetting
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor();

    /**
     * Creates a new subclass of class sap.m.plugins.ContextMenuSetting with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ContextMenuSetting>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Searches a plugin of the corresponding type in the aggregations of the given `Element` instance. The
     * first plugin that is found is returned.
     *
     *
     * @returns The found plugin instance or `undefined` if not found
     */
    static findOn(
      /**
       * The `Element` instance to check for
       */
      oElement: UI5Element
    ): UI5Element | undefined;
    /**
     * Returns a metadata object for class sap.m.plugins.ContextMenuSetting.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getScope scope}.
     *
     * Defines the scope of the context menu actions.
     *
     * The scope of the context menu is visually represented to the user by providing a clear indication of
     * the affected items. The visual cues help users understand the potential impact of their actions.
     *
     * **Note:** The scope visualization is only supported if a `sap.m.Menu` is used as context menu.
     *
     * Default value is `Default`.
     *
     *
     * @returns Value of property `scope`
     */
    getScope(): plugins.ContextMenuScope;
    /**
     * Sets a new value for property {@link #getScope scope}.
     *
     * Defines the scope of the context menu actions.
     *
     * The scope of the context menu is visually represented to the user by providing a clear indication of
     * the affected items. The visual cues help users understand the potential impact of their actions.
     *
     * **Note:** The scope visualization is only supported if a `sap.m.Menu` is used as context menu.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Default`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setScope(
      /**
       * New value for property `scope`
       */
      sScope?: plugins.ContextMenuScope | keyof typeof plugins.ContextMenuScope
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ContextMenuSetting constructor.
   */
  export interface $ContextMenuSettingSettings extends $ElementSettings {
    /**
     * Defines the scope of the context menu actions.
     *
     * The scope of the context menu is visually represented to the user by providing a clear indication of
     * the affected items. The visual cues help users understand the potential impact of their actions.
     *
     * **Note:** The scope visualization is only supported if a `sap.m.Menu` is used as context menu.
     */
    scope?:
      | (plugins.ContextMenuScope | keyof typeof plugins.ContextMenuScope)
      | PropertyBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/plugins/CopyProvider" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import OverflowToolbarButton from "sap/m/OverflowToolbarButton";

  import { plugins } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Context from "sap/ui/model/Context";

  import ColumnListItem from "sap/m/ColumnListItem";

  import Column from "sap/m/Column";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * Provides copy to clipboard capabilities for the selected rows of the table. This plugin can copy individual
   * cells if the {@link sap.m.plugins.CellSelector CellSelector} plugin is also enabled for that table.
   *
   *
   * **Note:** If a `sap.ui.table.Table` control is used together with server-side models, the {@link sap.ui.table.plugins.MultiSelectionPlugin MultiSelectionPlugin }
   * must be set for that table to make this plugin work property with range selections. See also the {@link sap.ui.table.plugins.MultiSelectionPlugin#getLimit limit }
   * property of the `MultiSelectionPlugin`.
   *  **Note:** This plugin requires a secure origin, either HTTPS or localhost, in order to access the browser's
   * clipboard API. For more information, see {@link https://w3c.github.io/webappsec-secure-contexts/}. It
   * is recommended to check whether the application executes in a secure context before adding the `CopyProvider`
   * plugin and related functionality, such as the {@link #sap.m.plugins.CellSelector}.
   *
   * @since 1.110
   */
  export default class CopyProvider extends UI5Element {
    /**
     * Constructor for a new CopyProvider plugin that can be used to copy table rows to the clipboard.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the `CopyProvider`
       */
      mSettings?: $CopyProviderSettings
    );
    /**
     * Constructor for a new CopyProvider plugin that can be used to copy table rows to the clipboard.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new `CopyProvider`, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the `CopyProvider`
       */
      mSettings?: $CopyProviderSettings
    );

    /**
     * Creates a new subclass of class sap.m.plugins.CopyProvider with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, CopyProvider>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Searches a plugin of the corresponding type in the aggregations of the given `Element` instance. The
     * first plugin that is found is returned.
     *
     *
     * @returns The found plugin instance or `undefined` if not found
     */
    static findOn(
      /**
       * The `Element` instance to check for
       */
      oElement: UI5Element
    ): UI5Element | undefined;
    /**
     * Returns a metadata object for class sap.m.plugins.CopyProvider.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:copy copy} event of this `sap.m.plugins.CopyProvider`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.CopyProvider` itself.
     *
     * This event is fired if there is a selection, and the user triggers the copy action.
     *
     * This can be done with the standard paste keyboard shortcut when the focus is on a selected row or cell.
     * Also the {@link #copySelectionData} API can be called, for example, from the press handler of a copy
     * button in a table toolbar to start the copy action synthetically, which might cause this event to be
     * fired. To avoid writing the selection to the clipboard, call `preventDefault` on the event instance.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCopy(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: CopyProvider$CopyEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.CopyProvider` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:copy copy} event of this `sap.m.plugins.CopyProvider`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.CopyProvider` itself.
     *
     * This event is fired if there is a selection, and the user triggers the copy action.
     *
     * This can be done with the standard paste keyboard shortcut when the focus is on a selected row or cell.
     * Also the {@link #copySelectionData} API can be called, for example, from the press handler of a copy
     * button in a table toolbar to start the copy action synthetically, which might cause this event to be
     * fired. To avoid writing the selection to the clipboard, call `preventDefault` on the event instance.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCopy(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: CopyProvider$CopyEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.CopyProvider` itself
       */
      oListener?: object
    ): this;
    /**
     * Writes the selection data to the system clipboard and returns a `Promise` which resolves once the clipboard's
     * content has been updated.
     *
     * **Note:** The user has to interact with the page or a UI element when this API gets called. **Note:**
     * This plugin requires a secure context in order to access the browser's clipboard API.
     *
     *
     * @returns A `Promise` that is resolved after the selection data has been written to the clipboard
     */
    copySelectionData(
      /**
       * Whether the `copy` event should be triggered or not
       */
      bFireCopyEvent?: boolean
    ): Promise<any>;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:copy copy} event of this `sap.m.plugins.CopyProvider`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachCopy(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: CopyProvider$CopyEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:copy copy} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireCopy(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: CopyProvider$CopyEventParameters
    ): boolean;
    /**
     * Creates and returns a Copy button that can be used to trigger a copy action, for example, from the table
     * toolbar.
     *
     * **Note:** The `visible` and `enabled` properties of the Copy button must be managed through this plugin's
     * own `visible` and `enabled` properties.
     *
     * @since 1.114
     *
     * @returns The button instance
     */
    getCopyButton(
      /**
       * The settings of the button control
       */
      mSettings?: object
    ): OverflowToolbarButton;
    /**
     * Gets current value of property {@link #getCopyPreference copyPreference}.
     *
     * This property determines the copy preference when performing a copy operation.
     *
     * If the property is set to `Full`, all selected content is copied. This includes selected rows and cells.
     *
     * If the property is set to `Cells`, cell selection takes precedence during copying. If cells are selected
     * along with rows, only the cell selection is copied. If no cells are selected, the row selection is copied.
     *
     * Default value is `Cells`.
     *
     * @since 1.119
     *
     * @returns Value of property `copyPreference`
     */
    getCopyPreference(): plugins.CopyPreference;
    /**
     * Gets current value of property {@link #getCopySparse copySparse}.
     *
     * Determines whether unselected rows that are located between the selected rows are copied to the clipboard
     * as an empty row.
     *
     * This can be useful for maintaining the original structure of the data when it is pasted into a new location
     * (e.g. spreadsheets).
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `copySparse`
     */
    getCopySparse(): boolean;
    /**
     * Gets current value of property {@link #getExcludeContext excludeContext}.
     *
     * Defines a {@link sap.m.plugins.CopyProvider.excludeContextHandler callback function} which gets called
     * to exclude certain contexts from being copied to the clipboard.
     *
     * This callback function gets called with the binding context or the row instance if there is no binding.
     * Return `true` to exclude the context, `false` otherwise.
     *
     *
     * @returns Value of property `excludeContext`
     */
    getExcludeContext(): Function;
    /**
     * Gets current value of property {@link #getExtractData extractData}.
     *
     * Defines a {@link sap.m.plugins.CopyProvider.extractDataHandler callback function} that gets called for
     * each selected cell to extract the cell data that is copied to the clipboard.
     *
     * The callback function gets called with the binding context of the selected row and the column instance
     * parameters.
     *  For the `sap.ui.table.Table` control, the row context parameter can also be the context of an unselectable
     * row in case of a range selection, for example the context of grouping or sub-total row.
     *  For the `sap.m.Table` control, if the `items` aggregation of the table is not bound then the callback
     * function gets called with the row instance instead of the binding context.
     *  The callback function must return the cell data that is then stringified and copied to the clipboard.
     *  If an array is returned from the callback function, then each array value will be copied as a separate
     * cell into the clipboard.
     *  If a column should not be copied to the clipboard, then the callback function must return `undefined`
     * or `null` for each cell of the same column.
     *
     *  **Note:** This property is mandatory to make the `CopyProvider` plugin work, and it must be set in the
     * constructor.
     *
     *
     * @returns Value of property `extractData`
     */
    getExtractData(): Function;
    /**
     * Returns the extracted selection data as a two-dimensional array. This includes individual cell selections
     * if the {@link sap.m.plugins.CellSelector CellSelector} plugin is also enabled for the table. **Note:
     * ** The returned array might be a sparse array if the {@link #getCopySparse copySparse} property is `true`.
     *
     *
     * @returns Two-dimensional data extracted from the selection, or an object with `text` and `html` keys,
     * each with two-dimensional data extracted from the selection if `bIncludeHtmlMimeType` parameter is `true`
     * and the platform supports `text/html` MIME type as a clipboard item.
     */
    getSelectionData(
      /**
       * Determines whether the selection data to be returned includes `text/html` MIME type values, if the platform
       * supports `text/html` MIME type as a clipboard item
       */
      bIncludeHtmlMimeType: boolean
    ):
      | any[][]
      | {
          text: any[][];

          html: any[][];
        };
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * Defines the visibility of the Copy button created with the {@link #getCopyButton} API.
     *
     * Default value is `true`.
     *
     * @since 1.114
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Sets a new value for property {@link #getCopyPreference copyPreference}.
     *
     * This property determines the copy preference when performing a copy operation.
     *
     * If the property is set to `Full`, all selected content is copied. This includes selected rows and cells.
     *
     * If the property is set to `Cells`, cell selection takes precedence during copying. If cells are selected
     * along with rows, only the cell selection is copied. If no cells are selected, the row selection is copied.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Cells`.
     *
     * @since 1.119
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCopyPreference(
      /**
       * New value for property `copyPreference`
       */
      sCopyPreference?:
        | plugins.CopyPreference
        | keyof typeof plugins.CopyPreference
    ): this;
    /**
     * Sets a new value for property {@link #getCopySparse copySparse}.
     *
     * Determines whether unselected rows that are located between the selected rows are copied to the clipboard
     * as an empty row.
     *
     * This can be useful for maintaining the original structure of the data when it is pasted into a new location
     * (e.g. spreadsheets).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCopySparse(
      /**
       * New value for property `copySparse`
       */
      bCopySparse?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getExcludeContext excludeContext}.
     *
     * Defines a {@link sap.m.plugins.CopyProvider.excludeContextHandler callback function} which gets called
     * to exclude certain contexts from being copied to the clipboard.
     *
     * This callback function gets called with the binding context or the row instance if there is no binding.
     * Return `true` to exclude the context, `false` otherwise.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setExcludeContext(
      /**
       * New value for property `excludeContext`
       */
      fnExcludeContext: Function
    ): this;
    /**
     * Sets a new value for property {@link #getExtractData extractData}.
     *
     * Defines a {@link sap.m.plugins.CopyProvider.extractDataHandler callback function} that gets called for
     * each selected cell to extract the cell data that is copied to the clipboard.
     *
     * The callback function gets called with the binding context of the selected row and the column instance
     * parameters.
     *  For the `sap.ui.table.Table` control, the row context parameter can also be the context of an unselectable
     * row in case of a range selection, for example the context of grouping or sub-total row.
     *  For the `sap.m.Table` control, if the `items` aggregation of the table is not bound then the callback
     * function gets called with the row instance instead of the binding context.
     *  The callback function must return the cell data that is then stringified and copied to the clipboard.
     *  If an array is returned from the callback function, then each array value will be copied as a separate
     * cell into the clipboard.
     *  If a column should not be copied to the clipboard, then the callback function must return `undefined`
     * or `null` for each cell of the same column.
     *
     *  **Note:** This property is mandatory to make the `CopyProvider` plugin work, and it must be set in the
     * constructor.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setExtractData(
      /**
       * New value for property `extractData`
       */
      fnExtractData: Function
    ): this;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * Defines the visibility of the Copy button created with the {@link #getCopyButton} API.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.114
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible?: boolean
    ): this;
  }
  /**
   * Callback function to exclude certain contexts from being copied to the clipboard.
   */
  export type excludeContextHandler = (
    oContextOrRow: Context | ColumnListItem
  ) => boolean;

  /**
   * Callback function to extract the cell data that is copied to the clipboard.
   * 	 - If an array is returned, then each array value will be copied as a separate cell into the clipboard.
   *
   * 	 - If `undefined` or `null` is returned, then the cell will be excluded from copying.
   * 	 - If an object is returned, then it must have the following properties:
   * 	`text`: (mandatory) The cell data to be copied to the clipboard as `text/plain` MIME type.
   * 	 - `html`: (optional) The cell data to be copied to the clipboard as `text/html` MIME type.
   *
   *
   * **Note:** The `CopyProvider` uses the `text/html` MIME type to display the merged cell data shown in
   * a UI5 table as a single cell in the clipboard. This allows users in applications supporting `text/html`
   * MIME type, such as `Spreadsheet`, to preserve the cell data format that appears in a UI5 table. The `CopyProvider`
   * also uses the `text/plain` MIME type to display the merged cell data shown in a UI5 table as separate
   * clipboard cells. This allows users to edit plain data with applications like `SpreadSheet`, then copy
   * and paste the data back into a UI5 table, preserving data integrity without in-cell formatting.
   *  Spreadsheet-like applications supporting `text/html` MIME type typically prioritize `text/html` clipboard
   * data during paste. This means that the data format copied from a UI5 table is preserved with the default
   * paste operation. Users wanting to make edits can access the individual and unformatted cell data in the
   * clipboard, which is stored in the text/plain MIME type, by selecting the "Paste Special" option and then
   * choosing "Unicode Text" in spreadsheet applications.
   *
   *
   * **Note:** Using `text/html` MIME type as a clipboard item might not be supported on all platforms. In
   * such cases, the `CopyProvider` writes only `text/plain` data to the clipboard. Refer to the `bIncludeHtmlMimeType`
   * parameter and do not return the object type if this value is `false`.
   *
   *
   * **Note:** Even if the user is on a platform supporting `text/html` MIME type as a clipboard item, currently,
   * any HTML tags are not allowed; all data is encoded.
   */
  export type extractDataHandler = (
    oContextOrRow: Context | ColumnListItem,
    oColumn:
      | Column
      | /* was: sap.ui.table.Column */ any
      | /* was: sap.ui.mdc.table.Column */ any,
    bIncludeHtmlMimeType: boolean
  ) =>
    | any
    | {
        text: any;

        html: any;
      }
    | any[]
    | undefined
    | null;

  /**
   * Describes the settings that can be provided to the CopyProvider constructor.
   */
  export interface $CopyProviderSettings extends $ElementSettings {
    /**
     * Defines a {@link sap.m.plugins.CopyProvider.extractDataHandler callback function} that gets called for
     * each selected cell to extract the cell data that is copied to the clipboard.
     *
     * The callback function gets called with the binding context of the selected row and the column instance
     * parameters.
     *  For the `sap.ui.table.Table` control, the row context parameter can also be the context of an unselectable
     * row in case of a range selection, for example the context of grouping or sub-total row.
     *  For the `sap.m.Table` control, if the `items` aggregation of the table is not bound then the callback
     * function gets called with the row instance instead of the binding context.
     *  The callback function must return the cell data that is then stringified and copied to the clipboard.
     *  If an array is returned from the callback function, then each array value will be copied as a separate
     * cell into the clipboard.
     *  If a column should not be copied to the clipboard, then the callback function must return `undefined`
     * or `null` for each cell of the same column.
     *
     *  **Note:** This property is mandatory to make the `CopyProvider` plugin work, and it must be set in the
     * constructor.
     */
    extractData?: Function | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether unselected rows that are located between the selected rows are copied to the clipboard
     * as an empty row.
     *
     * This can be useful for maintaining the original structure of the data when it is pasted into a new location
     * (e.g. spreadsheets).
     */
    copySparse?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines a {@link sap.m.plugins.CopyProvider.excludeContextHandler callback function} which gets called
     * to exclude certain contexts from being copied to the clipboard.
     *
     * This callback function gets called with the binding context or the row instance if there is no binding.
     * Return `true` to exclude the context, `false` otherwise.
     */
    excludeContext?: Function | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the visibility of the Copy button created with the {@link #getCopyButton} API.
     *
     * @since 1.114
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This property determines the copy preference when performing a copy operation.
     *
     * If the property is set to `Full`, all selected content is copied. This includes selected rows and cells.
     *
     * If the property is set to `Cells`, cell selection takes precedence during copying. If cells are selected
     * along with rows, only the cell selection is copied. If no cells are selected, the row selection is copied.
     *
     * @since 1.119
     */
    copyPreference?:
      | (plugins.CopyPreference | keyof typeof plugins.CopyPreference)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * This event is fired if there is a selection, and the user triggers the copy action.
     *
     * This can be done with the standard paste keyboard shortcut when the focus is on a selected row or cell.
     * Also the {@link #copySelectionData} API can be called, for example, from the press handler of a copy
     * button in a table toolbar to start the copy action synthetically, which might cause this event to be
     * fired. To avoid writing the selection to the clipboard, call `preventDefault` on the event instance.
     */
    copy?: (oEvent: CopyProvider$CopyEvent) => void;
  }

  /**
   * Parameters of the CopyProvider#copy event.
   */
  export interface CopyProvider$CopyEventParameters {
    /**
     * Two-dimensional mutable array of selection data to be copied to the clipboard. The first dimension represents
     * the selected rows, and the second dimension represents the cells of the selected rows.
     */
    data?: any[][];
  }

  /**
   * Event object of the CopyProvider#copy event.
   */
  export type CopyProvider$CopyEvent = Event<
    CopyProvider$CopyEventParameters,
    CopyProvider
  >;
}

declare module "sap/m/plugins/DataStateIndicator" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { ValueState } from "sap/ui/core/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Filter from "sap/ui/model/Filter";

  import DataState from "sap/ui/model/DataState";

  /**
   * This plugin implements a message strip used to show binding-related messages.
   *
   * @since 1.73
   */
  export default class DataStateIndicator extends UI5Element {
    /**
     * Constructor for a new DataStateIndicator plugin.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the `DataStateIndicator`
       */
      mSettings?: $DataStateIndicatorSettings
    );
    /**
     * Constructor for a new DataStateIndicator plugin.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new `DataStateIndicator`, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the `DataStateIndicator`
       */
      mSettings?: $DataStateIndicatorSettings
    );

    /**
     * Creates a new subclass of class sap.m.plugins.DataStateIndicator with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, DataStateIndicator>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Searches a plugin of the corresponding type in the aggregations of the given `Element` instance. The
     * first plugin that is found is returned.
     *
     *
     * @returns The found plugin instance or `undefined` if not found
     */
    static findOn(
      /**
       * The `Element` instance to check for
       */
      oElement: UI5Element
    ): UI5Element | undefined;
    /**
     * Returns a metadata object for class sap.m.plugins.DataStateIndicator.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:applyFilter applyFilter} event of this `sap.m.plugins.DataStateIndicator`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.DataStateIndicator` itself.
     *
     * This event is fired when the user filters data state messages and if the `enableFiltering` property is
     * set to `true`.
     *
     * @since 1.89
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachApplyFilter(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: DataStateIndicator$ApplyFilterEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.DataStateIndicator` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:applyFilter applyFilter} event of this `sap.m.plugins.DataStateIndicator`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.DataStateIndicator` itself.
     *
     * This event is fired when the user filters data state messages and if the `enableFiltering` property is
     * set to `true`.
     *
     * @since 1.89
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachApplyFilter(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: DataStateIndicator$ApplyFilterEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.DataStateIndicator` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:clearFilter clearFilter} event of this `sap.m.plugins.DataStateIndicator`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.DataStateIndicator` itself.
     *
     * This event is fired when the user clears the data state message filter and if the `enableFiltering` property
     * is set to `true`.
     *
     * @since 1.89
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachClearFilter(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.DataStateIndicator` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:clearFilter clearFilter} event of this `sap.m.plugins.DataStateIndicator`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.DataStateIndicator` itself.
     *
     * This event is fired when the user clears the data state message filter and if the `enableFiltering` property
     * is set to `true`.
     *
     * @since 1.89
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachClearFilter(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.DataStateIndicator` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:close close} event of this `sap.m.plugins.DataStateIndicator`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.DataStateIndicator` itself.
     *
     * This event is fired when the user presses the `Close` button of the `MessageStrip` control which is managed
     * by this plugin.
     *
     * @since 1.103
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.DataStateIndicator` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:close close} event of this `sap.m.plugins.DataStateIndicator`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.DataStateIndicator` itself.
     *
     * This event is fired when the user presses the `Close` button of the `MessageStrip` control which is managed
     * by this plugin.
     *
     * @since 1.103
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.DataStateIndicator` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:dataStateChange dataStateChange} event of this
     * `sap.m.plugins.DataStateIndicator`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.DataStateIndicator` itself.
     *
     * This event is fired when the {@link sap.ui.model.DataState data state} of the plugin parent is changed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDataStateChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: DataStateIndicator$DataStateChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.DataStateIndicator` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:dataStateChange dataStateChange} event of this
     * `sap.m.plugins.DataStateIndicator`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.DataStateIndicator` itself.
     *
     * This event is fired when the {@link sap.ui.model.DataState data state} of the plugin parent is changed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDataStateChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: DataStateIndicator$DataStateChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.DataStateIndicator` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:applyFilter applyFilter} event of this `sap.m.plugins.DataStateIndicator`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.89
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachApplyFilter(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: DataStateIndicator$ApplyFilterEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:clearFilter clearFilter} event of this `sap.m.plugins.DataStateIndicator`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.89
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachClearFilter(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:close close} event of this `sap.m.plugins.DataStateIndicator`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.103
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:dataStateChange dataStateChange} event of
     * this `sap.m.plugins.DataStateIndicator`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachDataStateChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: DataStateIndicator$DataStateChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:applyFilter applyFilter} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @since 1.89
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireApplyFilter(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: DataStateIndicator$ApplyFilterEventParameters
    ): boolean;
    /**
     * Fires event {@link #event:clearFilter clearFilter} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @since 1.89
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireClearFilter(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): boolean;
    /**
     * Fires event {@link #event:close close} to attached listeners.
     *
     * @since 1.103
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:dataStateChange dataStateChange} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireDataStateChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: DataStateIndicator$DataStateChangeEventParameters
    ): boolean;
    /**
     * Gets current value of property {@link #getEnableFiltering enableFiltering}.
     *
     * Enables filtering for data state messages if this property is set to `true`. A link is provided to the
     * user that allows them to filter. After the binding-related messages have been filtered by the user, all
     * the existing filters are only taken into account once the message filter has been cleared again.
     *
     * **Note:** This feature must be enabled for OData models only.
     *
     * Default value is `false`.
     *
     * @since 1.89
     *
     * @returns Value of property `enableFiltering`
     */
    getEnableFiltering(): boolean;
    /**
     * Gets current value of property {@link #getFilter filter}.
     *
     * Defines a predicate to test each message of the data state.
     *
     * This callback gets called using the {@link sap.ui.core.message.Message message} and {@link sap.ui.core.Control related control }
     * parameters. Return `true` to keep the message, `false` otherwise.
     *
     *
     * @returns Value of property `filter`
     */
    getFilter(): Function;
    /**
     * Return whether message filtering is active or not.
     *
     * @since 1.89
     *
     * @returns Whether message filtering is active or not
     */
    isFiltering(): boolean;
    /**
     * Refreshes the messages displayed for the current data state. The current data state is evaluated again,
     * and the filters are applied.
     */
    refresh(): void;
    /**
     * Sets a new value for property {@link #getEnableFiltering enableFiltering}.
     *
     * Enables filtering for data state messages if this property is set to `true`. A link is provided to the
     * user that allows them to filter. After the binding-related messages have been filtered by the user, all
     * the existing filters are only taken into account once the message filter has been cleared again.
     *
     * **Note:** This feature must be enabled for OData models only.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.89
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableFiltering(
      /**
       * New value for property `enableFiltering`
       */
      bEnableFiltering?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getFilter filter}.
     *
     * Defines a predicate to test each message of the data state.
     *
     * This callback gets called using the {@link sap.ui.core.message.Message message} and {@link sap.ui.core.Control related control }
     * parameters. Return `true` to keep the message, `false` otherwise.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFilter(
      /**
       * New value for property `filter`
       */
      fnFilter: Function
    ): this;
    /**
     * Shows a message.
     */
    showMessage(
      /**
       * The message text, if empty, the message is hidden
       */
      sText?: string,
      /**
       * The message type
       */
      sType?: ValueState | keyof typeof ValueState
    ): void;
  }
  /**
   * Describes the settings that can be provided to the DataStateIndicator constructor.
   */
  export interface $DataStateIndicatorSettings extends $ElementSettings {
    /**
     * Defines a predicate to test each message of the data state.
     *
     * This callback gets called using the {@link sap.ui.core.message.Message message} and {@link sap.ui.core.Control related control }
     * parameters. Return `true` to keep the message, `false` otherwise.
     */
    filter?: Function | PropertyBindingInfo | `{${string}}`;

    /**
     * Enables filtering for data state messages if this property is set to `true`. A link is provided to the
     * user that allows them to filter. After the binding-related messages have been filtered by the user, all
     * the existing filters are only taken into account once the message filter has been cleared again.
     *
     * **Note:** This feature must be enabled for OData models only.
     *
     * @since 1.89
     */
    enableFiltering?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This event is fired when the {@link sap.ui.model.DataState data state} of the plugin parent is changed.
     */
    dataStateChange?: (oEvent: DataStateIndicator$DataStateChangeEvent) => void;

    /**
     * This event is fired when the user filters data state messages and if the `enableFiltering` property is
     * set to `true`.
     *
     * @since 1.89
     */
    applyFilter?: (oEvent: DataStateIndicator$ApplyFilterEvent) => void;

    /**
     * This event is fired when the user clears the data state message filter and if the `enableFiltering` property
     * is set to `true`.
     *
     * @since 1.89
     */
    clearFilter?: (oEvent: Event) => void;

    /**
     * This event is fired when the user presses the `Close` button of the `MessageStrip` control which is managed
     * by this plugin.
     *
     * @since 1.103
     */
    close?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the DataStateIndicator#applyFilter event.
   */
  export interface DataStateIndicator$ApplyFilterEventParameters {
    /**
     * The filter object representing the entries with messages.
     */
    filter?: Filter;
  }

  /**
   * Event object of the DataStateIndicator#applyFilter event.
   */
  export type DataStateIndicator$ApplyFilterEvent = Event<
    DataStateIndicator$ApplyFilterEventParameters,
    DataStateIndicator
  >;

  /**
   * Parameters of the DataStateIndicator#clearFilter event.
   */
  export interface DataStateIndicator$ClearFilterEventParameters {}

  /**
   * Event object of the DataStateIndicator#clearFilter event.
   */
  export type DataStateIndicator$ClearFilterEvent = Event<
    DataStateIndicator$ClearFilterEventParameters,
    DataStateIndicator
  >;

  /**
   * Parameters of the DataStateIndicator#close event.
   */
  export interface DataStateIndicator$CloseEventParameters {}

  /**
   * Event object of the DataStateIndicator#close event.
   */
  export type DataStateIndicator$CloseEvent = Event<
    DataStateIndicator$CloseEventParameters,
    DataStateIndicator
  >;

  /**
   * Parameters of the DataStateIndicator#dataStateChange event.
   */
  export interface DataStateIndicator$DataStateChangeEventParameters {
    /**
     * The data state object.
     */
    dataState?: DataState;

    /**
     * The messages ({@link sap.ui.core.message.Message}) from the current `dataState` object filtered by the
     * given `filter` function.
     */
    filteredMessages?: object[];
  }

  /**
   * Event object of the DataStateIndicator#dataStateChange event.
   */
  export type DataStateIndicator$DataStateChangeEvent = Event<
    DataStateIndicator$DataStateChangeEventParameters,
    DataStateIndicator
  >;
}

declare module "sap/m/plugins/PasteProvider" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { ID } from "sap/ui/core/library";

  import Control from "sap/ui/core/Control";

  import Event from "sap/ui/base/Event";

  /**
   * Provides cross-platform paste capabilities for the `sap.m.Button` control which allows the user to initiate
   * a paste action.
   *
   * @since 1.91
   */
  export default class PasteProvider extends UI5Element {
    /**
     * Constructor for a new PasteProvider plugin.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the `PasteProvider`
       */
      mSettings?: $PasteProviderSettings
    );
    /**
     * Constructor for a new PasteProvider plugin.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new `PasteProvider`, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the `PasteProvider`
       */
      mSettings?: $PasteProviderSettings
    );

    /**
     * Creates a new subclass of class sap.m.plugins.PasteProvider with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, PasteProvider>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Searches a plugin of the corresponding type in the aggregations of the given `Element` instance. The
     * first plugin that is found is returned.
     *
     *
     * @returns The found plugin instance or `undefined` if not found
     */
    static findOn(
      /**
       * The `Element` instance to check for
       */
      oElement: UI5Element
    ): UI5Element | undefined;
    /**
     * Returns a metadata object for class sap.m.plugins.PasteProvider.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:paste paste} event of this `sap.m.plugins.PasteProvider`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.PasteProvider` itself.
     *
     * This event gets fired when the user pastes content from the clipboard or when the Paste button is pressed
     * if the clipboard access has already been granted. Pasting can be done via the paste feature of the mobile
     * device or the standard paste keyboard shortcut while the popover is open. By default, a synthetic `Clipboard`
     * event that represents the paste data gets dispatched for the control defined in the `pasteFor` association.
     * To avoid this, call `preventDefault` on the event instance.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPaste(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PasteProvider$PasteEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.PasteProvider` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:paste paste} event of this `sap.m.plugins.PasteProvider`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.PasteProvider` itself.
     *
     * This event gets fired when the user pastes content from the clipboard or when the Paste button is pressed
     * if the clipboard access has already been granted. Pasting can be done via the paste feature of the mobile
     * device or the standard paste keyboard shortcut while the popover is open. By default, a synthetic `Clipboard`
     * event that represents the paste data gets dispatched for the control defined in the `pasteFor` association.
     * To avoid this, call `preventDefault` on the event instance.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPaste(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: PasteProvider$PasteEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.PasteProvider` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:paste paste} event of this `sap.m.plugins.PasteProvider`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPaste(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: PasteProvider$PasteEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:paste paste} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    firePaste(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: PasteProvider$PasteEventParameters
    ): boolean;
    /**
     * ID of the element which is the current target of the association {@link #getPasteFor pasteFor}, or `null`.
     */
    getPasteFor(): ID | null;
    /**
     * Sets the associated {@link #getPasteFor pasteFor}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPasteFor(
      /**
       * ID of an element which becomes the new target of this pasteFor association; alternatively, an element
       * instance may be given
       */
      oPasteFor: ID | Control
    ): this;
  }
  /**
   * Describes the settings that can be provided to the PasteProvider constructor.
   */
  export interface $PasteProviderSettings extends $ElementSettings {
    /**
     * Defines the control which the paste is associated with.
     */
    pasteFor?: Control | string;

    /**
     * This event gets fired when the user pastes content from the clipboard or when the Paste button is pressed
     * if the clipboard access has already been granted. Pasting can be done via the paste feature of the mobile
     * device or the standard paste keyboard shortcut while the popover is open. By default, a synthetic `Clipboard`
     * event that represents the paste data gets dispatched for the control defined in the `pasteFor` association.
     * To avoid this, call `preventDefault` on the event instance.
     */
    paste?: (oEvent: PasteProvider$PasteEvent) => void;
  }

  /**
   * Parameters of the PasteProvider#paste event.
   */
  export interface PasteProvider$PasteEventParameters {
    /**
     * Two-dimentional array of strings with data from the clipboard. The first dimension represents the rows,
     * and the second dimension represents the cells of the tabular data.
     */
    data?: string[][];

    /**
     * The text data, with all special characters, from the clipboard.
     */
    text?: string;
  }

  /**
   * Event object of the PasteProvider#paste event.
   */
  export type PasteProvider$PasteEvent = Event<
    PasteProvider$PasteEventParameters,
    PasteProvider
  >;
}

declare module "sap/m/plugins/UploadSetwithTable" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import { ID, URI } from "sap/ui/core/library";

  import ActionsPlaceholder from "sap/m/upload/ActionsPlaceholder";

  import Item from "sap/ui/core/Item";

  import Context from "sap/ui/model/Context";

  import FileUploader from "sap/ui/unified/FileUploader";

  import UploaderHttpRequestMethod from "sap/m/upload/UploaderHttpRequestMethod";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import IllustratedMessage from "sap/m/IllustratedMessage";

  import UploadItemConfiguration from "sap/m/upload/UploadItemConfiguration";

  import UploaderTableItem from "sap/m/upload/UploaderTableItem";

  import FilePreviewDialog from "sap/m/upload/FilePreviewDialog";

  import UploadItem from "sap/m/upload/UploadItem";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  import Control from "sap/ui/core/Control";

  /**
   * The `UploadSetwithTable` plugin enables uploading within a table when it is added as a dependent to the
   * table control.
   *  This plugin provides an Upload button to upload files from the local file system. To do so, the user
   * of the plugin must place {@link sap.m.upload.ActionsPlaceholder Actions Placeholder} control at the desired
   * table area and then associate the actions of the plugin with the placeholder.
   *  The plugin provides the ability to upload files from the local system as well as from cloud file picker
   * and includes other notable features such as validation, file preview, download.
   *
   *
   *  The following controls support this plugin:
   * 	 - {@link sap.ui.mdc.Table MDC Table}
   * 	 - {@link sap.m.Table Responsive Table}
   * 	 - {@link sap.m.GridTable Grid Table}
   *
   * Consider the following before using the plugin:
   * 	 - It gets activated when it is added as a dependent to the table control. It gets deactivated when
   *     it is removed from the table control or when the table control is destroyed.
   * 	 - It fires onActivated and onDeactivated events when it is activated and deactivated, respectively.
   *
   * 	 - Configuring the rowConfiguration aggregation (type {@link sap.m.upload.UploadItemConfiguration UploadItemConfiguration})
   *     of this plugin is mandatory to use the features such as file preview, download etc.
   * 	 - It works only with the table control when the table is bound to the model to perform the operations
   *     such as rename, download etc.
   *
   * @since 1.124
   */
  export default class UploadSetwithTable extends UI5Element {
    /**
     * Constructor for a new UploadSetwithTable plugin.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new `UploadSetwithTable`
       */
      mSettings?: $UploadSetwithTableSettings
    );
    /**
     * Constructor for a new UploadSetwithTable plugin.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new `UploadSetwithTable`, generated automatically if no id is given
       */
      sId?: string,
      /**
       * Initial settings for the new `UploadSetwithTable`
       */
      mSettings?: $UploadSetwithTableSettings
    );

    /**
     * Creates a new subclass of class sap.m.plugins.UploadSetwithTable with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, UploadSetwithTable>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Searches a plugin of the corresponding type in the aggregations of the given `Element` instance. The
     * first plugin that is found is returned.
     *
     *
     * @returns The found plugin instance or `undefined` if not found
     */
    static findOn(
      /**
       * The `Element` instance to check for
       */
      oElement: UI5Element
    ): UI5Element | undefined;
    /**
     * API to determine the unit for file size in KB/MB/GB. API recommended for file size formatting purpose.
     *
     *
     * @returns sFileSizeWithUnit file size in KB/MB/GB default unit is KB
     */
    static getFileSizeWithUnits(
      /**
       * fileSize to determine units
       */
      iFileSize: int
    ): string;
    /**
     * Returns sap icon based on the passed mediaType and filename
     *
     *
     * @returns sap icon.
     */
    static getIconForFileType(
      /**
       * The media type of the selected file
       */
      mediaType: string,
      /**
       * The name of the selected file
       */
      fileName: string
    ): string;
    /**
     * Returns a metadata object for class sap.m.plugins.UploadSetwithTable.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some action into the association {@link #getActions actions}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAction(
      /**
       * The actions to add; if empty, nothing is inserted
       */
      vAction: ID | ActionsPlaceholder
    ): this;
    /**
     * Adds some headerField to the aggregation {@link #getHeaderFields headerFields}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addHeaderField(
      /**
       * The headerField to add; if empty, nothing is inserted
       */
      oHeaderField: Item
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeInitiatingItemUpload beforeInitiatingItemUpload }
     * event of this `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * This event is fired just before initiating the file upload process when a file is selected to be uploaded.
     * Use this event to set additional info dynamically, specific for each item before upload process is initiated.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeInitiatingItemUpload(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (
        p1: UploadSetwithTable$BeforeInitiatingItemUploadEvent
      ) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeInitiatingItemUpload beforeInitiatingItemUpload }
     * event of this `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * This event is fired just before initiating the file upload process when a file is selected to be uploaded.
     * Use this event to set additional info dynamically, specific for each item before upload process is initiated.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeInitiatingItemUpload(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (
        p1: UploadSetwithTable$BeforeInitiatingItemUploadEvent
      ) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeUploadStarts beforeUploadStarts} event
     * of this `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * This event is fired right before the upload process begins.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeUploadStarts(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$BeforeUploadStartsEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeUploadStarts beforeUploadStarts} event
     * of this `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * This event is fired right before the upload process begins.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeUploadStarts(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$BeforeUploadStartsEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileNameLengthExceeded fileNameLengthExceeded }
     * event of this `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the file name length restriction specified
     *     in the `maxFileNameLength` property.
     * 	 - When the file name length restriction changes, and the file to be uploaded fails to meet the new
     *     restriction.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileNameLengthExceeded(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$FileNameLengthExceededEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileNameLengthExceeded fileNameLengthExceeded }
     * event of this `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the file name length restriction specified
     *     in the `maxFileNameLength` property.
     * 	 - When the file name length restriction changes, and the file to be uploaded fails to meet the new
     *     restriction.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileNameLengthExceeded(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$FileNameLengthExceededEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileSizeExceeded fileSizeExceeded} event of
     * this `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the file size restriction specified in
     *     the `maxFileSize` property.
     * 	 - When the file size restriction changes, and the file to be uploaded fails to meet the new restriction.
     *
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileSizeExceeded(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$FileSizeExceededEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileSizeExceeded fileSizeExceeded} event of
     * this `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the file size restriction specified in
     *     the `maxFileSize` property.
     * 	 - When the file size restriction changes, and the file to be uploaded fails to meet the new restriction.
     *
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileSizeExceeded(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$FileSizeExceededEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileTypeMismatch fileTypeMismatch} event of
     * this `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the file type restriction (`fileType` property).
     *
     * 	 - When the file type restriction changes, and the file to be uploaded fails to meet the new restriction.
     *
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileTypeMismatch(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$FileTypeMismatchEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileTypeMismatch fileTypeMismatch} event of
     * this `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the file type restriction (`fileType` property).
     *
     * 	 - When the file type restriction changes, and the file to be uploaded fails to meet the new restriction.
     *
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileTypeMismatch(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$FileTypeMismatchEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemRenamed itemRenamed} event of this `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * The event is triggered when the file name is changed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemRenamed(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$ItemRenamedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemRenamed itemRenamed} event of this `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * The event is triggered when the file name is changed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemRenamed(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$ItemRenamedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:mediaTypeMismatch mediaTypeMismatch} event of
     * this `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the media type restriction specified in
     *     the `mediaTypes` property.
     * 	 - When the media type restriction changes, and the file to be uploaded fails to meet the new restriction.
     *
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachMediaTypeMismatch(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$MediaTypeMismatchEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:mediaTypeMismatch mediaTypeMismatch} event of
     * this `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the media type restriction specified in
     *     the `mediaTypes` property.
     * 	 - When the media type restriction changes, and the file to be uploaded fails to meet the new restriction.
     *
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachMediaTypeMismatch(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$MediaTypeMismatchEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:onActivated onActivated} event of this `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * This event is fired when plugin is activated.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachOnActivated(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$OnActivatedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:onActivated onActivated} event of this `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * This event is fired when plugin is activated.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachOnActivated(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$OnActivatedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:onDeactivated onDeactivated} event of this `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * This event is fired when plugin is deactivated.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachOnDeactivated(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$OnDeactivatedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:onDeactivated onDeactivated} event of this `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * This event is fired when plugin is deactivated.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachOnDeactivated(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$OnDeactivatedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadCompleted uploadCompleted} event of this
     * `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * This event is fired right after the upload process is finished.
     * Based on the backend response of the application, listeners can use the parameters to determine if the
     * upload was successful or if it failed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadCompleted(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$UploadCompletedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadCompleted uploadCompleted} event of this
     * `sap.m.plugins.UploadSetwithTable`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.plugins.UploadSetwithTable` itself.
     *
     * This event is fired right after the upload process is finished.
     * Based on the backend response of the application, listeners can use the parameters to determine if the
     * upload was successful or if it failed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadCompleted(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$UploadCompletedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.plugins.UploadSetwithTable` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the headerFields in the aggregation {@link #getHeaderFields headerFields}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyHeaderFields(): this;
    /**
     * Destroys the noDataIllustration in the aggregation {@link #getNoDataIllustration noDataIllustration}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyNoDataIllustration(): this;
    /**
     * Destroys the rowConfiguration in the aggregation {@link #getRowConfiguration rowConfiguration}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyRowConfiguration(): this;
    /**
     * Destroys the uploader in the aggregation {@link #getUploader uploader}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyUploader(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeInitiatingItemUpload beforeInitiatingItemUpload }
     * event of this `sap.m.plugins.UploadSetwithTable`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeInitiatingItemUpload(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (
        p1: UploadSetwithTable$BeforeInitiatingItemUploadEvent
      ) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeUploadStarts beforeUploadStarts} event
     * of this `sap.m.plugins.UploadSetwithTable`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeUploadStarts(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$BeforeUploadStartsEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:fileNameLengthExceeded fileNameLengthExceeded }
     * event of this `sap.m.plugins.UploadSetwithTable`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachFileNameLengthExceeded(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$FileNameLengthExceededEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:fileSizeExceeded fileSizeExceeded} event of
     * this `sap.m.plugins.UploadSetwithTable`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachFileSizeExceeded(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$FileSizeExceededEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:fileTypeMismatch fileTypeMismatch} event of
     * this `sap.m.plugins.UploadSetwithTable`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachFileTypeMismatch(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$FileTypeMismatchEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:itemRenamed itemRenamed} event of this `sap.m.plugins.UploadSetwithTable`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachItemRenamed(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$ItemRenamedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:mediaTypeMismatch mediaTypeMismatch} event
     * of this `sap.m.plugins.UploadSetwithTable`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachMediaTypeMismatch(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$MediaTypeMismatchEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:onActivated onActivated} event of this `sap.m.plugins.UploadSetwithTable`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachOnActivated(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$OnActivatedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:onDeactivated onDeactivated} event of this
     * `sap.m.plugins.UploadSetwithTable`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachOnDeactivated(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$OnDeactivatedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:uploadCompleted uploadCompleted} event of
     * this `sap.m.plugins.UploadSetwithTable`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUploadCompleted(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSetwithTable$UploadCompletedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Downloads the file. Only possible when the context passed has a valid URL specified.
     */
    download(
      /**
       * Context of the item to be downloaded.
       */
      oBindingContext: Context,
      /**
       * Whether to ask for a location where to download the file or not.
       */
      bAskForLocation: boolean
    ): void;
    /**
     * Invokes native files selection handler.
     */
    fileSelectionHandler(): void;
    /**
     * Fires event {@link #event:beforeInitiatingItemUpload beforeInitiatingItemUpload} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforeInitiatingItemUpload(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSetwithTable$BeforeInitiatingItemUploadEventParameters
    ): this;
    /**
     * Fires event {@link #event:beforeUploadStarts beforeUploadStarts} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireBeforeUploadStarts(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSetwithTable$BeforeUploadStartsEventParameters
    ): boolean;
    /**
     * Fires event {@link #event:fileNameLengthExceeded fileNameLengthExceeded} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireFileNameLengthExceeded(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSetwithTable$FileNameLengthExceededEventParameters
    ): this;
    /**
     * Fires event {@link #event:fileSizeExceeded fileSizeExceeded} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireFileSizeExceeded(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSetwithTable$FileSizeExceededEventParameters
    ): this;
    /**
     * Fires event {@link #event:fileTypeMismatch fileTypeMismatch} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireFileTypeMismatch(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSetwithTable$FileTypeMismatchEventParameters
    ): this;
    /**
     * Fires event {@link #event:itemRenamed itemRenamed} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireItemRenamed(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSetwithTable$ItemRenamedEventParameters
    ): this;
    /**
     * Fires event {@link #event:mediaTypeMismatch mediaTypeMismatch} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireMediaTypeMismatch(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSetwithTable$MediaTypeMismatchEventParameters
    ): this;
    /**
     * Fires event {@link #event:onActivated onActivated} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireOnActivated(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSetwithTable$OnActivatedEventParameters
    ): this;
    /**
     * Fires event {@link #event:onDeactivated onDeactivated} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireOnDeactivated(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSetwithTable$OnDeactivatedEventParameters
    ): this;
    /**
     * Fires event {@link #event:uploadCompleted uploadCompleted} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUploadCompleted(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSetwithTable$UploadCompletedEventParameters
    ): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getActions actions}.
     */
    getActions(): ID[];
    /**
     * Gets current value of property {@link #getCloudFilePickerButtonText cloudFilePickerButtonText}.
     *
     * The text of the CloudFile picker button. The default text is "Upload from cloud" (translated to the respective
     * language).
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `cloudFilePickerButtonText`
     */
    getCloudFilePickerButtonText(): string;
    /**
     * Gets current value of property {@link #getCloudFilePickerEnabled cloudFilePickerEnabled}.
     *
     * Enables CloudFile picker feature to upload files from cloud.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `cloudFilePickerEnabled`
     */
    getCloudFilePickerEnabled(): boolean;
    /**
     * Gets current value of property {@link #getCloudFilePickerServiceUrl cloudFilePickerServiceUrl}.
     *
     * Url of the FileShare OData V4 service supplied for CloudFile picker control.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `cloudFilePickerServiceUrl`
     */
    getCloudFilePickerServiceUrl(): URI;
    /**
     * Returns an instance of the default `sap.ui.unified.FileUploader` icon/button, used for adding files from
     * the open file dialog of the operating system. It can be customized, for example made invisible or assigned
     * a different icon.
     *
     *
     * @returns Instance of the default `sap.ui.unified.FileUploader`.
     */
    getDefaultFileUploader(): FileUploader;
    /**
     * Gets current value of property {@link #getDirectory directory}.
     *
     * Lets the user upload entire files from directories and sub directories.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `directory`
     */
    getDirectory(): boolean;
    /**
     * Gets current value of property {@link #getFileNameValidationConfig fileNameValidationConfig}.
     *
     * File name validation configuration.
     *  Set this property to configure the file name validation characters and the validation mode.
     *  This configuration is used to validate the file name when a file is selected for renaming.
     *  For the plugin to pick up this configuration, mode and characters of the property must be set to validate
     * the file name.
     *  see {@link sap.m.plugins.UploadSetwithTable.FilenameValidationConfigMode mode} to configure the file
     * name validation mode.
     *
     *  The default restricted filename character set is: \:/*?"<>|[]{}@#$
     *
     * @since 1.136
     *
     * @returns Value of property `fileNameValidationConfig`
     */
    getFileNameValidationConfig(): FilenameValidationConfig;
    /**
     * Gets current value of property {@link #getFileTypes fileTypes}.
     *
     * File types that are allowed to be uploaded.
     * If this property is not set, any file can be uploaded.
     *
     *
     * @returns Value of property `fileTypes`
     */
    getFileTypes(): string[];
    /**
     * Gets content of aggregation {@link #getHeaderFields headerFields}.
     *
     * Header fields to be included in the header section of an XHR request.
     */
    getHeaderFields(): Item[];
    /**
     * Gets current value of property {@link #getHttpRequestMethod httpRequestMethod}.
     *
     * HTTP request method chosen for file upload.
     *
     * Default value is `Post`.
     *
     *
     * @returns Value of property `httpRequestMethod`
     */
    getHttpRequestMethod(): UploaderHttpRequestMethod;
    /**
     * Gets current value of property {@link #getItemValidationHandler itemValidationHandler}.
     *
     * Defines a {@link sap.m.plugins.UploadSetwithTable.itemValidationHandler callback function} that is invoked
     * when each UploadItem is queued up for upload. This callback is invoked with {@link sap.m.plugins.UploadSetwithTable.ItemInfo parameters }
     * and the callback is expected to return a promise to the plugin. Once the promise is resolved, the plugin
     * initiates the upload process. Configure this property only when any additional configuration or validations
     * are to be performed before the upload of each item. The upload process is triggered manually by resolving
     * the promise returned to the plugin.
     *
     *
     * @returns Value of property `itemValidationHandler`
     */
    getItemValidationHandler(): Function;
    /**
     * Gets current value of property {@link #getMaxFileNameLength maxFileNameLength}.
     *
     * Defined maximum length for a name of files that are to be uploaded.
     * If set to `null` or `0`, any file can be uploaded regardless length of its name.
     *
     *
     * @returns Value of property `maxFileNameLength`
     */
    getMaxFileNameLength(): int;
    /**
     * Gets current value of property {@link #getMaxFileSize maxFileSize}.
     *
     * Defined size limit in megabytes for files that are to be uploaded.
     * If set to `null` or `0`, files of any size can be uploaded.
     *
     *
     * @returns Value of property `maxFileSize`
     */
    getMaxFileSize(): float;
    /**
     * Gets current value of property {@link #getMediaTypes mediaTypes}.
     *
     * Media types of files that are allowed to be uploaded.
     * If this property is not set, any file can be uploaded.
     *
     *
     * @returns Value of property `mediaTypes`
     */
    getMediaTypes(): string[];
    /**
     * Gets current value of property {@link #getMultiple multiple}.
     *
     * Lets the user select multiple files from the same folder and then upload them.
     *
     * If multiple property is set to false, the plugin shows an error message if more than one file is chosen
     * for drag & drop.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `multiple`
     */
    getMultiple(): boolean;
    /**
     * Gets content of aggregation {@link #getNoDataIllustration noDataIllustration}.
     *
     * An illustrated message is displayed when no data is loaded.
     */
    getNoDataIllustration(): IllustratedMessage;
    /**
     * ID of the element which is the current target of the association {@link #getPreviewDialog previewDialog},
     * or `null`.
     */
    getPreviewDialog(): ID | null;
    /**
     * Gets content of aggregation {@link #getRowConfiguration rowConfiguration}.
     *
     * Row configuration information for each uploadItem in the model.
     */
    getRowConfiguration(): UploadItemConfiguration;
    /**
     * Gets current value of property {@link #getUploadButtonInvisible uploadButtonInvisible}.
     *
     * If set to true, the button used for uploading files becomes invisible.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `uploadButtonInvisible`
     */
    getUploadButtonInvisible(): boolean;
    /**
     * Gets current value of property {@link #getUploadEnabled uploadEnabled}.
     *
     * Defines whether the upload action is allowed.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `uploadEnabled`
     */
    getUploadEnabled(): boolean;
    /**
     * Gets content of aggregation {@link #getUploader uploader}.
     *
     * Defines the uploader to be used. If not specified, the default implementation is used.
     */
    getUploader(): UploaderTableItem;
    /**
     * Gets current value of property {@link #getUploadUrl uploadUrl}.
     *
     * Url where the uploaded files are stored.
     *
     *
     * @returns Value of property `uploadUrl`
     */
    getUploadUrl(): string;
    /**
     * Checks for the provided `sap.ui.core.Item` in the aggregation {@link #getHeaderFields headerFields}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfHeaderField(
      /**
       * The headerField whose index is looked for
       */
      oHeaderField: Item
    ): int;
    /**
     * Inserts a headerField into the aggregation {@link #getHeaderFields headerFields}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertHeaderField(
      /**
       * The headerField to insert; if empty, nothing is inserted
       */
      oHeaderField: Item,
      /**
       * The `0`-based index the headerField should be inserted at; for a negative value of `iIndex`, the headerField
       * is inserted at position 0; for a value greater than the current size of the aggregation, the headerField
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Previews file.
     */
    openFilePreview(
      /**
       * Context of the row containing the file to be previewed.
       */
      oBindingContext: Context
    ): void;
    /**
     * Attaches all necessary handlers to the given uploader instance, so that the progress and status of the
     * upload can be displayed and monitored. This is necessary in case when custom uploader is used.
     */
    registerUploaderEvents(
      /**
       * Instance of `sap.m.upload.UploaderTableItem` to which the default request handlers are attached.
       */
      oUploader: UploaderTableItem
    ): void;
    /**
     * Removes an action from the association named {@link #getActions actions}.
     *
     *
     * @returns The removed action or `null`
     */
    removeAction(
      /**
       * The action to be removed or its index or ID
       */
      vAction: int | ID | ActionsPlaceholder
    ): ID | null;
    /**
     * Removes all the controls in the association named {@link #getActions actions}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllActions(): ID[];
    /**
     * Removes all the controls from the aggregation {@link #getHeaderFields headerFields}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllHeaderFields(): Item[];
    /**
     * Removes a headerField from the aggregation {@link #getHeaderFields headerFields}.
     *
     *
     * @returns The removed headerField or `null`
     */
    removeHeaderField(
      /**
       * The headerField to remove or its index or id
       */
      vHeaderField: int | string | Item
    ): Item | null;
    /**
     * API to rename the document of an item.
     */
    renameItem(
      /**
       * Context of the item to be renamed.
       */
      oBindingContext: Context
    ): void;
    /**
     * Sets a new value for property {@link #getCloudFilePickerButtonText cloudFilePickerButtonText}.
     *
     * The text of the CloudFile picker button. The default text is "Upload from cloud" (translated to the respective
     * language).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCloudFilePickerButtonText(
      /**
       * New value for property `cloudFilePickerButtonText`
       */
      sCloudFilePickerButtonText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getCloudFilePickerEnabled cloudFilePickerEnabled}.
     *
     * Enables CloudFile picker feature to upload files from cloud.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCloudFilePickerEnabled(
      /**
       * New value for property `cloudFilePickerEnabled`
       */
      bCloudFilePickerEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getCloudFilePickerServiceUrl cloudFilePickerServiceUrl}.
     *
     * Url of the FileShare OData V4 service supplied for CloudFile picker control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCloudFilePickerServiceUrl(
      /**
       * New value for property `cloudFilePickerServiceUrl`
       */
      sCloudFilePickerServiceUrl?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getDirectory directory}.
     *
     * Lets the user upload entire files from directories and sub directories.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDirectory(
      /**
       * New value for property `directory`
       */
      bDirectory?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getFileNameValidationConfig fileNameValidationConfig}.
     *
     * File name validation configuration.
     *  Set this property to configure the file name validation characters and the validation mode.
     *  This configuration is used to validate the file name when a file is selected for renaming.
     *  For the plugin to pick up this configuration, mode and characters of the property must be set to validate
     * the file name.
     *  see {@link sap.m.plugins.UploadSetwithTable.FilenameValidationConfigMode mode} to configure the file
     * name validation mode.
     *
     *  The default restricted filename character set is: \:/*?"<>|[]{}@#$
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.136
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFileNameValidationConfig(
      /**
       * New value for property `fileNameValidationConfig`
       */
      sFileNameValidationConfig?: FilenameValidationConfig
    ): this;
    /**
     * Sets a new value for property {@link #getFileTypes fileTypes}.
     *
     * File types that are allowed to be uploaded.
     * If this property is not set, any file can be uploaded.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFileTypes(
      /**
       * New value for property `fileTypes`
       */
      sFileTypes?: string[]
    ): this;
    /**
     * Sets a new value for property {@link #getHttpRequestMethod httpRequestMethod}.
     *
     * HTTP request method chosen for file upload.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Post`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHttpRequestMethod(
      /**
       * New value for property `httpRequestMethod`
       */
      sHttpRequestMethod?: UploaderHttpRequestMethod
    ): this;
    /**
     * Sets a new value for property {@link #getItemValidationHandler itemValidationHandler}.
     *
     * Defines a {@link sap.m.plugins.UploadSetwithTable.itemValidationHandler callback function} that is invoked
     * when each UploadItem is queued up for upload. This callback is invoked with {@link sap.m.plugins.UploadSetwithTable.ItemInfo parameters }
     * and the callback is expected to return a promise to the plugin. Once the promise is resolved, the plugin
     * initiates the upload process. Configure this property only when any additional configuration or validations
     * are to be performed before the upload of each item. The upload process is triggered manually by resolving
     * the promise returned to the plugin.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setItemValidationHandler(
      /**
       * New value for property `itemValidationHandler`
       */
      fnItemValidationHandler?: Function
    ): this;
    /**
     * Sets a new value for property {@link #getMaxFileNameLength maxFileNameLength}.
     *
     * Defined maximum length for a name of files that are to be uploaded.
     * If set to `null` or `0`, any file can be uploaded regardless length of its name.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxFileNameLength(
      /**
       * New value for property `maxFileNameLength`
       */
      iMaxFileNameLength?: int
    ): this;
    /**
     * Sets a new value for property {@link #getMaxFileSize maxFileSize}.
     *
     * Defined size limit in megabytes for files that are to be uploaded.
     * If set to `null` or `0`, files of any size can be uploaded.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxFileSize(
      /**
       * New value for property `maxFileSize`
       */
      fMaxFileSize?: float
    ): this;
    /**
     * Sets a new value for property {@link #getMediaTypes mediaTypes}.
     *
     * Media types of files that are allowed to be uploaded.
     * If this property is not set, any file can be uploaded.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMediaTypes(
      /**
       * New value for property `mediaTypes`
       */
      sMediaTypes?: string[]
    ): this;
    /**
     * Sets a new value for property {@link #getMultiple multiple}.
     *
     * Lets the user select multiple files from the same folder and then upload them.
     *
     * If multiple property is set to false, the plugin shows an error message if more than one file is chosen
     * for drag & drop.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMultiple(
      /**
       * New value for property `multiple`
       */
      bMultiple?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getNoDataIllustration noDataIllustration}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNoDataIllustration(
      /**
       * The noDataIllustration to set
       */
      oNoDataIllustration: IllustratedMessage
    ): this;
    /**
     * Sets the associated {@link #getPreviewDialog previewDialog}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPreviewDialog(
      /**
       * ID of an element which becomes the new target of this previewDialog association; alternatively, an element
       * instance may be given
       */
      oPreviewDialog: ID | FilePreviewDialog
    ): this;
    /**
     * Sets the aggregated {@link #getRowConfiguration rowConfiguration}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRowConfiguration(
      /**
       * The rowConfiguration to set
       */
      oRowConfiguration: UploadItemConfiguration
    ): this;
    /**
     * Sets a new value for property {@link #getUploadButtonInvisible uploadButtonInvisible}.
     *
     * If set to true, the button used for uploading files becomes invisible.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUploadButtonInvisible(
      /**
       * New value for property `uploadButtonInvisible`
       */
      bUploadButtonInvisible?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getUploadEnabled uploadEnabled}.
     *
     * Defines whether the upload action is allowed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUploadEnabled(
      /**
       * New value for property `uploadEnabled`
       */
      bUploadEnabled?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getUploader uploader}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUploader(
      /**
       * The uploader to set
       */
      oUploader: UploaderTableItem
    ): this;
    /**
     * Sets a new value for property {@link #getUploadUrl uploadUrl}.
     *
     * Url where the uploaded files are stored.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUploadUrl(
      /**
       * New value for property `uploadUrl`
       */
      sUploadUrl?: string
    ): this;
    /**
     * API to upload file using URL
     *
     *
     * @returns oItem, UploadItem instance created with the file object.
     */
    uploadItemViaUrl(
      /**
       * file name to be set for the file that is to be uploaded.
       */
      sName: string,
      /**
       * Url for the file.
       */
      sUrl: string,
      /**
       * Promise when resolved, the control initiates the upload process.
       */
      oPromise: Promise<any>
    ): UploadItem;
    /**
     * API to upload Item without file
     *
     *
     * @returns oItem, UploadItem instance created with the file object.
     */
    uploadItemWithoutFile(
      /**
       * Promise when resolved, control initiates the upload process.
       */
      oPromise: Promise<any>
    ): UploadItem;
  }
  /**
   * This property type is used to define the file name validation configuration. Object is passed to {@link sap.m.plugins.UploadSetwithTable fileNameValidationConfig property}
   */
  export type FilenameValidationConfig = {
    /**
     * The file name validation config mode.
     */
    mode: FilenameValidationConfigMode;
    /**
     * The file name validation configuration characters.
     *
     *  The default restricted filename character set is: \:/*?"<>|[]{}@#$
     */
    characters: string;
  };

  /**
   * Key property of {@link sap.m.plugins.UploadSetwithTable.FilenameValidationConfig FileNameValidationConfig}.
   * Used to determine the mode for file name validation.
   *
   * @since 1.136
   */
  export type FilenameValidationConfigMode = {
    /**
     * The file name validation mode. The allowed values are 'include', 'exclude', or 'override'.
     *
     *  If the mode is 'include', the specified characters are added to the default restricted character set.
     *
     *  If the mode is 'exclude', the specified characters are excluded from the default resrtricted character
     * set.
     *  If the mode is 'override', the specified characters replace the entire default restricted character
     * set.
     *  If the mode is not set, the default restricted file name character set is used.
     */
    mode: string;
  };

  /**
   * Item info object sent as paramter to {@link sap.m.plugins.UploadSetwithTable.itemValidationHandler itemValidationHandler callback}
   */
  export type ItemInfo = {
    /**
     * Current item queued for upload.
     */
    oItem: UploadItem;
    /**
     * Total count of items queued for upload.
     */
    iTotalItemsForUpload: number;
    /**
     * Source on which the callback was invoked.
     */
    oSource: UploadSetwithTable;
  };

  /**
   * Callback function to perform additional validations or configurations for the item queued up for upload
   * and to finally trigger the upload.
   */
  export type itemValidationHandler = (
    oItemInfo: ItemInfo
  ) => Promise<UploadItem>;

  /**
   * Describes the settings that can be provided to the UploadSetwithTable constructor.
   */
  export interface $UploadSetwithTableSettings extends $ElementSettings {
    /**
     * File types that are allowed to be uploaded.
     * If this property is not set, any file can be uploaded.
     */
    fileTypes?: string[] | PropertyBindingInfo | `{${string}}`;

    /**
     * Defined maximum length for a name of files that are to be uploaded.
     * If set to `null` or `0`, any file can be uploaded regardless length of its name.
     */
    maxFileNameLength?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Defined size limit in megabytes for files that are to be uploaded.
     * If set to `null` or `0`, files of any size can be uploaded.
     */
    maxFileSize?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * Media types of files that are allowed to be uploaded.
     * If this property is not set, any file can be uploaded.
     */
    mediaTypes?: string[] | PropertyBindingInfo | `{${string}}`;

    /**
     * Url where the uploaded files are stored.
     */
    uploadUrl?: string | PropertyBindingInfo;

    /**
     * HTTP request method chosen for file upload.
     */
    httpRequestMethod?:
      | UploaderHttpRequestMethod
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Lets the user select multiple files from the same folder and then upload them.
     *
     * If multiple property is set to false, the plugin shows an error message if more than one file is chosen
     * for drag & drop.
     */
    multiple?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * If set to true, the button used for uploading files becomes invisible.
     */
    uploadButtonInvisible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether the upload action is allowed.
     */
    uploadEnabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines a {@link sap.m.plugins.UploadSetwithTable.itemValidationHandler callback function} that is invoked
     * when each UploadItem is queued up for upload. This callback is invoked with {@link sap.m.plugins.UploadSetwithTable.ItemInfo parameters }
     * and the callback is expected to return a promise to the plugin. Once the promise is resolved, the plugin
     * initiates the upload process. Configure this property only when any additional configuration or validations
     * are to be performed before the upload of each item. The upload process is triggered manually by resolving
     * the promise returned to the plugin.
     */
    itemValidationHandler?: Function | PropertyBindingInfo | `{${string}}`;

    /**
     * Lets the user upload entire files from directories and sub directories.
     */
    directory?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Enables CloudFile picker feature to upload files from cloud.
     */
    cloudFilePickerEnabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Url of the FileShare OData V4 service supplied for CloudFile picker control.
     */
    cloudFilePickerServiceUrl?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * The text of the CloudFile picker button. The default text is "Upload from cloud" (translated to the respective
     * language).
     */
    cloudFilePickerButtonText?: string | PropertyBindingInfo;

    /**
     * File name validation configuration.
     *  Set this property to configure the file name validation characters and the validation mode.
     *  This configuration is used to validate the file name when a file is selected for renaming.
     *  For the plugin to pick up this configuration, mode and characters of the property must be set to validate
     * the file name.
     *  see {@link sap.m.plugins.UploadSetwithTable.FilenameValidationConfigMode mode} to configure the file
     * name validation mode.
     *
     *  The default restricted filename character set is: \:/*?"<>|[]{}@#$
     *
     * @since 1.136
     */
    fileNameValidationConfig?:
      | FilenameValidationConfig
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the uploader to be used. If not specified, the default implementation is used.
     */
    uploader?: UploaderTableItem;

    /**
     * Header fields to be included in the header section of an XHR request.
     */
    headerFields?: Item[] | Item | AggregationBindingInfo | `{${string}}`;

    /**
     * Row configuration information for each uploadItem in the model.
     */
    rowConfiguration?: UploadItemConfiguration;

    /**
     * An illustrated message is displayed when no data is loaded.
     */
    noDataIllustration?: IllustratedMessage;

    /**
     * Dialog with a carousel to preview files uploaded.
     * If it is not defined, the plugin creates and uses the instance of {@link sap.m.upload.FilePreviewDialog FilePreviewDialog}.
     */
    previewDialog?: FilePreviewDialog | string;

    /**
     * Actions provided by the plugin.
     *  {@link sap.m.UploadSetwithTableActionPlaceHolder UploadSetwithTableActionPlaceHolder} enum is used to
     * determine the action control to be rendered.
     *  Action buttons are rendered instead of the placeholder.
     *  For example, if the "placeholderFor" property is set to UploadButtonPlaceholder, the Upload button is
     * rendered.
     *  Note: The action buttons are rendered only when the association to the placeholder control is set.
     */
    actions?: Array<ActionsPlaceholder | string>;

    /**
     * The event is triggered when the file name is changed.
     */
    itemRenamed?: (oEvent: UploadSetwithTable$ItemRenamedEvent) => void;

    /**
     * This event is fired right before the upload process begins.
     */
    beforeUploadStarts?: (
      oEvent: UploadSetwithTable$BeforeUploadStartsEvent
    ) => void;

    /**
     * This event is fired right after the upload process is finished.
     * Based on the backend response of the application, listeners can use the parameters to determine if the
     * upload was successful or if it failed.
     */
    uploadCompleted?: (oEvent: UploadSetwithTable$UploadCompletedEvent) => void;

    /**
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the file type restriction (`fileType` property).
     *
     * 	 - When the file type restriction changes, and the file to be uploaded fails to meet the new restriction.
     */
    fileTypeMismatch?: (
      oEvent: UploadSetwithTable$FileTypeMismatchEvent
    ) => void;

    /**
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the file name length restriction specified
     *     in the `maxFileNameLength` property.
     * 	 - When the file name length restriction changes, and the file to be uploaded fails to meet the new
     *     restriction.
     */
    fileNameLengthExceeded?: (
      oEvent: UploadSetwithTable$FileNameLengthExceededEvent
    ) => void;

    /**
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the file size restriction specified in
     *     the `maxFileSize` property.
     * 	 - When the file size restriction changes, and the file to be uploaded fails to meet the new restriction.
     */
    fileSizeExceeded?: (
      oEvent: UploadSetwithTable$FileSizeExceededEvent
    ) => void;

    /**
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the media type restriction specified in
     *     the `mediaTypes` property.
     * 	 - When the media type restriction changes, and the file to be uploaded fails to meet the new restriction.
     */
    mediaTypeMismatch?: (
      oEvent: UploadSetwithTable$MediaTypeMismatchEvent
    ) => void;

    /**
     * This event is fired just before initiating the file upload process when a file is selected to be uploaded.
     * Use this event to set additional info dynamically, specific for each item before upload process is initiated.
     */
    beforeInitiatingItemUpload?: (
      oEvent: UploadSetwithTable$BeforeInitiatingItemUploadEvent
    ) => void;

    /**
     * This event is fired when plugin is activated.
     */
    onActivated?: (oEvent: UploadSetwithTable$OnActivatedEvent) => void;

    /**
     * This event is fired when plugin is deactivated.
     */
    onDeactivated?: (oEvent: UploadSetwithTable$OnDeactivatedEvent) => void;
  }

  /**
   * Parameters of the UploadSetwithTable#beforeInitiatingItemUpload event.
   */
  export interface UploadSetwithTable$BeforeInitiatingItemUploadEventParameters {
    /**
     * Items in ready state for upload process
     */
    item?: UploadItem;
  }

  /**
   * Event object of the UploadSetwithTable#beforeInitiatingItemUpload event.
   */
  export type UploadSetwithTable$BeforeInitiatingItemUploadEvent = Event<
    UploadSetwithTable$BeforeInitiatingItemUploadEventParameters,
    UploadSetwithTable
  >;

  /**
   * Parameters of the UploadSetwithTable#beforeUploadStarts event.
   */
  export interface UploadSetwithTable$BeforeUploadStartsEventParameters {
    /**
     * The file whose upload is just about to start.
     */
    item?: UploadItem;
  }

  /**
   * Event object of the UploadSetwithTable#beforeUploadStarts event.
   */
  export type UploadSetwithTable$BeforeUploadStartsEvent = Event<
    UploadSetwithTable$BeforeUploadStartsEventParameters,
    UploadSetwithTable
  >;

  /**
   * Parameters of the UploadSetwithTable#fileNameLengthExceeded event.
   */
  export interface UploadSetwithTable$FileNameLengthExceededEventParameters {
    /**
     * The file that fails to meet the file name length restriction specified in the `maxFileNameLength` property.
     */
    item?: UploadItem;
  }

  /**
   * Event object of the UploadSetwithTable#fileNameLengthExceeded event.
   */
  export type UploadSetwithTable$FileNameLengthExceededEvent = Event<
    UploadSetwithTable$FileNameLengthExceededEventParameters,
    UploadSetwithTable
  >;

  /**
   * Parameters of the UploadSetwithTable#fileSizeExceeded event.
   */
  export interface UploadSetwithTable$FileSizeExceededEventParameters {
    /**
     * The file that fails to meet the file size restriction specified in the `maxFileSize` property.
     */
    item?: UploadItem;
  }

  /**
   * Event object of the UploadSetwithTable#fileSizeExceeded event.
   */
  export type UploadSetwithTable$FileSizeExceededEvent = Event<
    UploadSetwithTable$FileSizeExceededEventParameters,
    UploadSetwithTable
  >;

  /**
   * Parameters of the UploadSetwithTable#fileTypeMismatch event.
   */
  export interface UploadSetwithTable$FileTypeMismatchEventParameters {
    /**
     * The file that fails to meet the file type restriction specified in the `fileType` property.
     */
    item?: UploadItem;
  }

  /**
   * Event object of the UploadSetwithTable#fileTypeMismatch event.
   */
  export type UploadSetwithTable$FileTypeMismatchEvent = Event<
    UploadSetwithTable$FileTypeMismatchEventParameters,
    UploadSetwithTable
  >;

  /**
   * Parameters of the UploadSetwithTable#itemRenamed event.
   */
  export interface UploadSetwithTable$ItemRenamedEventParameters {
    /**
     * The renamed UI element is of UploadItem type.
     */
    item?: UploadItem;
  }

  /**
   * Event object of the UploadSetwithTable#itemRenamed event.
   */
  export type UploadSetwithTable$ItemRenamedEvent = Event<
    UploadSetwithTable$ItemRenamedEventParameters,
    UploadSetwithTable
  >;

  /**
   * Parameters of the UploadSetwithTable#mediaTypeMismatch event.
   */
  export interface UploadSetwithTable$MediaTypeMismatchEventParameters {
    /**
     * The file that fails to meet the media type restriction specified in the `mediaTypes` property.
     */
    item?: UploadItem;
  }

  /**
   * Event object of the UploadSetwithTable#mediaTypeMismatch event.
   */
  export type UploadSetwithTable$MediaTypeMismatchEvent = Event<
    UploadSetwithTable$MediaTypeMismatchEventParameters,
    UploadSetwithTable
  >;

  /**
   * Parameters of the UploadSetwithTable#onActivated event.
   */
  export interface UploadSetwithTable$OnActivatedEventParameters {
    /**
     * The activated plugin instance.
     */
    oPlugin?: UploadSetwithTable;
  }

  /**
   * Event object of the UploadSetwithTable#onActivated event.
   */
  export type UploadSetwithTable$OnActivatedEvent = Event<
    UploadSetwithTable$OnActivatedEventParameters,
    UploadSetwithTable
  >;

  /**
   * Parameters of the UploadSetwithTable#onDeactivated event.
   */
  export interface UploadSetwithTable$OnDeactivatedEventParameters {
    /**
     * Control to which the plugin was connected.
     */
    control?: Control;
  }

  /**
   * Event object of the UploadSetwithTable#onDeactivated event.
   */
  export type UploadSetwithTable$OnDeactivatedEvent = Event<
    UploadSetwithTable$OnDeactivatedEventParameters,
    UploadSetwithTable
  >;

  /**
   * Parameters of the UploadSetwithTable#uploadCompleted event.
   */
  export interface UploadSetwithTable$UploadCompletedEventParameters {
    /**
     * The file whose upload has just been completed.
     */
    item?: UploadItem;

    /**
     * Response message that comes from the server.
     *
     * On the server side this response has to be put within the "body" tags of the response document
     * of the iFrame. It can consist of a return code and an optional message. This does not work in cross-domain
     * scenarios.
     */
    response?: string;

    /**
     * ReadyState of the XHR request.
     *
     * Required for receiving a `readyState` is to set the property `sendXHR` to true. This property is not
     * supported by Internet Explorer 9.
     */
    readyState?: string;

    /**
     * Status of the XHR request.
     *
     * Required for receiving a `status` is to set the property `sendXHR` to true. This property is not supported
     * by Internet Explorer 9.
     */
    status?: string;

    /**
     * Http-Response which comes from the server.
     *
     * Required for receiving `responseXML` is to set the property `sendXHR` to true.
     *
     * This property is not supported by Internet Explorer 9.
     */
    responseXML?: string;

    /**
     * Http-Response which comes from the server.
     *
     * Required for receiving `responseText` is to set the property `sendXHR` to true.
     *
     * This property is not supported by Internet Explorer 9.
     */
    responseText?: string;

    /**
     * Http-Response-Headers which come from the server.
     *
     * Provided as a JSON-map, i.e. each header-field is reflected by a property in the `headers` object, with
     * the property value reflecting the header-field's content.
     *
     * Required for receiving `headers` is to set the property `sendXHR` to true. This property is not supported
     * by Internet Explorer 9.
     */
    headers?: object;
  }

  /**
   * Event object of the UploadSetwithTable#uploadCompleted event.
   */
  export type UploadSetwithTable$UploadCompletedEvent = Event<
    UploadSetwithTable$UploadCompletedEventParameters,
    UploadSetwithTable
  >;
}

declare module "sap/m/Popover" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { PopupInterface, ID, CSSSize } from "sap/ui/core/library";

  import Bar from "sap/m/Bar";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PlacementType, TitleAlignment } from "sap/m/library";

  import Button from "sap/m/Button";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * Displays additional information for an object in a compact way.
   *
   * Overview: The popover displays additional information for an object in a compact way and without leaving
   * the page. The popover can contain various UI elements such as fields, tables, images, and charts. It
   * can also include actions in the footer. Structure: The popover has three main areas:
   * 	 - Header (optional) - with a back button and a title
   * 	 - Content - holds all the controls
   * 	 - Footer (optional) - with additional action buttons  Guidelines:
   * 	 - Do not overlap popovers.
   * 	 - You can determine the {@link sap.m.PlacementType placement} of the popover relative to the control
   *     that opens it.
   * 	 - Ensure that the content has a basic design and shows only the most important information.  Usage:
   *     When to use::
   * 	 - You need to define your own structure of controls within the popover.  When not to use::
   *
   * 	 - The {@link sap.m.QuickView QuickView} is more appropriate for your use case.  Responsive Behavior:
   *     The popover is closed when the user clicks or taps outside the popover or selects an action within the
   *     popover, which calls the popover's `close()` method. You can prevent this with the `modal` property.
   *     The popover can be resized when the `resizable` property is enabled.
   *
   * When using the sap.m.Popover in Sap Quartz theme, the breakpoints and layout paddings could be determined
   * by the container's width. To enable this concept and add responsive paddings to an element of the Popover
   * control, you may add the following classes depending on your use case: `sapUiResponsivePadding--header`,
   * `sapUiResponsivePadding--subHeader`, `sapUiResponsivePadding--content`, `sapUiResponsivePadding--footer`.
   *
   * 	 - {@link sap.m.Popover} is not responsive on mobile devices - it will always be rendered as
   *     a popover and you have to take care of its size and position.
   * 	 - {@link sap.m.ResponsivePopover} is adaptive and responsive. It renders as a dialog with a close button
   *     in the header on phones, and as a popover on tablets.
   */
  export default class Popover extends Control implements PopupInterface {
    __implements__sap_ui_core_PopupInterface: boolean;
    /**
     * Constructor for a new Popover.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/popover/ Popover}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $PopoverSettings
    );
    /**
     * Constructor for a new Popover.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/popover/ Popover}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $PopoverSettings
    );

    /**
     * Creates a new subclass of class sap.m.Popover with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Popover>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Popover.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Calculate outerHeight of the element; used as hook for SVG elements
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The outer height of the element
     */
    static outerHeight(
      /**
       * An Element for which outerHeight will be calculated.
       */
      oElement: HTMLElement,
      /**
       * Determines if the margins should be included in the calculated outerHeight
       */
      bIncludeMargin?: boolean
    ): number;
    /**
     * Calculate outerWidth of the element; used as hook for SVG elements
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The outer width of the element
     */
    static outerWidth(
      /**
       * An Element for which outerWidth will be calculated
       */
      oElement: HTMLElement,
      /**
       * Determines if the margins should be included in the calculated outerWidth
       */
      bIncludeMargin?: boolean
    ): number;
    /**
     * Hook called after adjusment of the Popover position.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    _afterAdjustPositionAndArrowHook(): void;
    /**
     * Hook called before adjusment of the Popover position.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    _beforeAdjustPositionAndArrowHook(): void;
    /**
     * If customHeader is set, this will return the customHeaer. Otherwise it creates a header and put the title
     * and buttons if needed inside, and finally return this newly create header.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The created header
     */
    _getAnyHeader(): Control | Bar;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds some content to the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContent(
      /**
       * The content to add; if empty, nothing is inserted
       */
      oContent: Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterClose afterClose} event of this `sap.m.Popover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Popover` itself.
     *
     * This event will be fired after the popover is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Popover$AfterCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Popover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterClose afterClose} event of this `sap.m.Popover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Popover` itself.
     *
     * This event will be fired after the popover is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Popover$AfterCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Popover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterOpen afterOpen} event of this `sap.m.Popover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Popover` itself.
     *
     * This event will be fired after the popover is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Popover$AfterOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Popover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterOpen afterOpen} event of this `sap.m.Popover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Popover` itself.
     *
     * This event will be fired after the popover is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Popover$AfterOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Popover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.Popover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Popover` itself.
     *
     * This event will be fired before the popover is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Popover$BeforeCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Popover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.Popover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Popover` itself.
     *
     * This event will be fired before the popover is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Popover$BeforeCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Popover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.Popover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Popover` itself.
     *
     * This event will be fired before the popover is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Popover$BeforeOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Popover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.Popover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Popover` itself.
     *
     * This event will be fired before the popover is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Popover$BeforeOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Popover` itself
       */
      oListener?: object
    ): this;
    /**
     * Closes the popover when it's already opened.
     *
     *
     * @returns Reference to the control instance for chaining
     */
    close(): this;
    /**
     * Destroys the beginButton in the aggregation {@link #getBeginButton beginButton}.
     *
     * @since 1.15.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyBeginButton(): this;
    /**
     * Destroys all the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Destroys the customHeader in the aggregation {@link #getCustomHeader customHeader}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCustomHeader(): this;
    /**
     * Destroys the endButton in the aggregation {@link #getEndButton endButton}.
     *
     * @since 1.15.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyEndButton(): this;
    /**
     * Destroys the footer in the aggregation {@link #getFooter footer}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyFooter(): this;
    /**
     * Destroys the subHeader in the aggregation {@link #getSubHeader subHeader}.
     *
     * @since 1.15.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySubHeader(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterClose afterClose} event of this `sap.m.Popover`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Popover$AfterCloseEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterOpen afterOpen} event of this `sap.m.Popover`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Popover$AfterOpenEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeClose beforeClose} event of this `sap.m.Popover`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Popover$BeforeCloseEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeOpen beforeOpen} event of this `sap.m.Popover`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Popover$BeforeOpenEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:afterClose afterClose} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Popover$AfterCloseEventParameters
    ): this;
    /**
     * Fires event {@link #event:afterOpen afterOpen} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Popover$AfterOpenEventParameters
    ): this;
    /**
     * Fires event {@link #event:beforeClose beforeClose} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforeClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Popover$BeforeCloseEventParameters
    ): this;
    /**
     * Fires event {@link #event:beforeOpen beforeOpen} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforeOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Popover$BeforeOpenEventParameters
    ): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets content of aggregation {@link #getBeginButton beginButton}.
     *
     * BeginButton is shown at the left side (right side in RTL mode) inside the header. When showHeader is
     * set to false, the property is ignored.
     *
     * @since 1.15.1
     */
    getBeginButton(): Control;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * The content inside the popover.
     */
    getContent(): Control[];
    /**
     * Gets current value of property {@link #getContentHeight contentHeight}.
     *
     * Set the height of the content area inside Popover. When controls which adapt their size to the parent
     * control are added directly into Popover, for example sap.m.Page control, a size needs to be specified
     * to the content area of the Popover. Otherwise, Popover control isn't able to display the content in the
     * right way. This values isn't necessary for controls added to Popover directly which can decide their
     * size by themselves, for exmaple sap.m.List, sap.m.Image etc., only needed for controls that adapt their
     * size to the parent control.
     *
     * @since 1.9.0
     *
     * @returns Value of property `contentHeight`
     */
    getContentHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getContentMinWidth contentMinWidth}.
     *
     * Sets the minimum width of the content area inside popover.
     *
     * Default value is `empty string`.
     *
     * @since 1.36
     *
     * @returns Value of property `contentMinWidth`
     */
    getContentMinWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getContentWidth contentWidth}.
     *
     * Set the width of the content area inside Popover. When controls which adapt their size to the parent
     * control are added directly into Popover, for example sap.m.Page control, a size needs to be specified
     * to the content area of the Popover. Otherwise, Popover control isn't able to display the content in the
     * right way. This values isn't necessary for controls added to Popover directly which can decide their
     * size by themselves, for exmaple sap.m.List, sap.m.Image etc., only needed for controls that adapt their
     * size to the parent control.
     *
     * @since 1.9.0
     *
     * @returns Value of property `contentWidth`
     */
    getContentWidth(): CSSSize;
    /**
     * Gets content of aggregation {@link #getCustomHeader customHeader}.
     *
     * Any control that needed to be displayed in the header area. When this is set, the showHeader property
     * is ignored, and only this customHeader is shown on the top of popover.
     */
    getCustomHeader(): Control;
    /**
     * Gets current value of property {@link #getEnableScrolling enableScrolling}.
     *
     * This property is deprecated. Please use properties verticalScrolling and horizontalScrolling instead.
     * If you still use this property it will be mapped on the new properties verticalScrolling and horizontalScrolling.
     *
     * Default value is `true`.
     *
     * @deprecated As of version 1.15.0. replaced by verticalScrolling and horizontalScrolling properties.
     *
     * @returns Value of property `enableScrolling`
     */
    getEnableScrolling(): boolean;
    /**
     * Gets content of aggregation {@link #getEndButton endButton}.
     *
     * EndButton is always shown at the right side (left side in RTL mode) inside the header. When showHeader
     * is set to false, the property is ignored.
     *
     * @since 1.15.1
     */
    getEndButton(): Control;
    /**
     * Gets content of aggregation {@link #getFooter footer}.
     *
     * This is optional footer which is shown on the bottom of the popover.
     */
    getFooter(): Control;
    /**
     * Gets current value of property {@link #getHorizontalScrolling horizontalScrolling}.
     *
     * This property indicates if user can scroll horizontally inside popover when the content is bigger than
     * the content area. However, when scrollable control (sap.m.ScrollContainer, sap.m.Page) is in the popover,
     * this property needs to be set to false to disable the scrolling in popover in order to make the scrolling
     * in the child control work properly. Popover detects if there's sap.m.NavContainer, sap.m.Page, or sap.m.ScrollContainer
     * as direct child added to Popover. If there is, Popover will turn off scrolling by setting this property
     * to false automatically ignoring the existing value of this property.
     *
     * Default value is `true`.
     *
     * @since 1.15.0
     *
     * @returns Value of property `horizontalScrolling`
     */
    getHorizontalScrolling(): boolean;
    /**
     * ID of the element which is the current target of the association {@link #getInitialFocus initialFocus},
     * or `null`.
     *
     * @since 1.15.0
     */
    getInitialFocus(): ID | null;
    /**
     * ID of the element which is the current target of the association {@link #getLeftButton leftButton}, or
     * `null`.
     *
     * @deprecated As of version 1.15.1. This property has been deprecated since 1.15.1. Please use the beginButton
     * instead.
     */
    getLeftButton(): ID | null;
    /**
     * Gets current value of property {@link #getModal modal}.
     *
     * If the popover will not be closed when tapping outside the popover. It also blocks any interaction with
     * the background. The default value is false.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `modal`
     */
    getModal(): boolean;
    /**
     * Gets current value of property {@link #getOffsetX offsetX}.
     *
     * The offset for the popover placement in the x axis. It's with unit pixel.
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `offsetX`
     */
    getOffsetX(): int;
    /**
     * Gets current value of property {@link #getOffsetY offsetY}.
     *
     * The offset for the popover placement in the y axis. It's with unit pixel.
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `offsetY`
     */
    getOffsetY(): int;
    /**
     * Gets current value of property {@link #getPlacement placement}.
     *
     * This is the information about on which side will the popover be placed at. Possible values are sap.m.PlacementType.Left,
     * sap.m.PlacementType.Right, sap.m.PlacementType.Top, sap.m.PlacementType.Bottom, sap.m.PlacementType.Horizontal,
     * sap.m.PlacementType.HorizontalPreferredLeft, sap.m.PlacementType.HorizontalPreferredRight, sap.m.PlacementType.Vertical,
     * sap.m.PlacementType.VerticalPreferredTop, sap.m.PlacementType.VerticalPreferredBottom, sap.m.PlacementType.Auto.
     * The default value is sap.m.PlacementType.Right. Setting this property while popover is open won't cause
     * any rerendering of the popover, but it will take effect when it's opened again.
     *
     * Default value is `Right`.
     *
     *
     * @returns Value of property `placement`
     */
    getPlacement(): PlacementType;
    /**
     * Gets current value of property {@link #getResizable resizable}.
     *
     * Whether resize option is enabled. NOTE: This property is effective only on Desktop
     *
     * Default value is `false`.
     *
     * @since 1.36.4
     *
     * @returns Value of property `resizable`
     */
    getResizable(): boolean;
    /**
     * ID of the element which is the current target of the association {@link #getRightButton rightButton},
     * or `null`.
     *
     * @deprecated As of version 1.15.1. This property has been deprecated since 1.15.1. Please use the endButton
     * instead.
     */
    getRightButton(): ID | null;
    /**
     * Gets current value of property {@link #getShowArrow showArrow}.
     *
     * Whether Popover arrow should be visible
     *
     * Default value is `true`.
     *
     * @since 1.31
     *
     * @returns Value of property `showArrow`
     */
    getShowArrow(): boolean;
    /**
     * Gets current value of property {@link #getShowHeader showHeader}.
     *
     * If a header should be shown at the top of the popover. Note:* The heading level of the popover is H1.
     * Headings in the popover content should start with H2 heading level.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showHeader`
     */
    getShowHeader(): boolean;
    /**
     * Gets content of aggregation {@link #getSubHeader subHeader}.
     *
     * When subHeader is assigned to Popover, it's rendered directly after the main header if there is, or at
     * the beginning of Popover when there's no main header. SubHeader is out of the content area and won't
     * be scrolled when content's size is bigger than the content area's size.
     *
     * @since 1.15.1
     */
    getSubHeader(): Control;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Title text appears in the header. This property will be ignored when `showHeader` is set to `false`.
     * If you want to show a header in the `sap.m.Popover`, don't forget to set the {@link #setShowHeader showHeader }
     * property to `true`.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getTitleAlignment titleAlignment}.
     *
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * Default value is `Auto`.
     *
     * @since 1.72
     *
     * @returns Value of property `titleAlignment`
     */
    getTitleAlignment(): TitleAlignment;
    /**
     * Gets current value of property {@link #getVerticalScrolling verticalScrolling}.
     *
     * This property indicates if user can scroll vertically inside popover when the content is bigger than
     * the content area. However, when scrollable control (sap.m.ScrollContainer, sap.m.Page) is in the popover,
     * this property needs to be set to false to disable the scrolling in popover in order to make the scrolling
     * in the child control work properly. Popover detects if there's sap.m.NavContainer, sap.m.Page, or sap.m.ScrollContainer
     * as direct child added to Popover. If there is, Popover will turn off scrolling by setting this property
     * to false automatically ignoring the existing value of this property.
     *
     * Default value is `true`.
     *
     * @since 1.15.0
     *
     * @returns Value of property `verticalScrolling`
     */
    getVerticalScrolling(): boolean;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContent content}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContent(
      /**
       * The content whose index is looked for
       */
      oContent: Control
    ): int;
    /**
     * Inserts a content into the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContent(
      /**
       * The content to insert; if empty, nothing is inserted
       */
      oContent: Control,
      /**
       * The `0`-based index the content should be inserted at; for a negative value of `iIndex`, the content
       * is inserted at position 0; for a value greater than the current size of the aggregation, the content
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * The method checks if the Popover is open. It returns true when the Popover is currently open (this includes
     * opening and closing animations), otherwise it returns false.
     *
     * @since 1.9.1
     *
     * @returns whether the Popover is currently opened
     */
    isOpen(): boolean;
    /**
     * Opens the Popover and sets the Popover position according to the {@link #getPlacement() placement} property
     * around the `oControl` parameter.
     *
     *
     * @returns Reference to the control instance for chaining
     */
    openBy(
      /**
       * This is the control to which the Popover will be placed. It can be not only a UI5 control, but also an
       * existing DOM reference. The side of the placement depends on the placement property set in the Popover.
       */
      oControl: Control | HTMLElement,
      /**
       * Indicates whether popover should be managed by InstanceManager or not.
       */
      bSkipInstanceManager?: boolean
    ): this;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all the controls from the aggregation {@link #getContent content}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContent(): Control[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes a content from the aggregation {@link #getContent content}.
     *
     *
     * @returns The removed content or `null`
     */
    removeContent(
      /**
       * The content to remove or its index or id
       */
      vContent: int | string | Control
    ): Control | null;
    /**
     * Sets the aggregated {@link #getBeginButton beginButton}.
     *
     * @since 1.15.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBeginButton(
      /**
       * The beginButton to set
       */
      oBeginButton: Control
    ): this;
    /**
     * Setter for property `bounce`.
     *
     * Default value is empty
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to the control instance for chaining
     */
    setBounce(
      /**
       * New value for property `bounce`
       */
      bBounce: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getContentHeight contentHeight}.
     *
     * Set the height of the content area inside Popover. When controls which adapt their size to the parent
     * control are added directly into Popover, for example sap.m.Page control, a size needs to be specified
     * to the content area of the Popover. Otherwise, Popover control isn't able to display the content in the
     * right way. This values isn't necessary for controls added to Popover directly which can decide their
     * size by themselves, for exmaple sap.m.List, sap.m.Image etc., only needed for controls that adapt their
     * size to the parent control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.9.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContentHeight(
      /**
       * New value for property `contentHeight`
       */
      sContentHeight?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getContentMinWidth contentMinWidth}.
     *
     * Sets the minimum width of the content area inside popover.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.36
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContentMinWidth(
      /**
       * New value for property `contentMinWidth`
       */
      sContentMinWidth?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getContentWidth contentWidth}.
     *
     * Set the width of the content area inside Popover. When controls which adapt their size to the parent
     * control are added directly into Popover, for example sap.m.Page control, a size needs to be specified
     * to the content area of the Popover. Otherwise, Popover control isn't able to display the content in the
     * right way. This values isn't necessary for controls added to Popover directly which can decide their
     * size by themselves, for exmaple sap.m.List, sap.m.Image etc., only needed for controls that adapt their
     * size to the parent control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.9.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContentWidth(
      /**
       * New value for property `contentWidth`
       */
      sContentWidth?: CSSSize
    ): this;
    /**
     * Sets the aggregated {@link #getCustomHeader customHeader}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomHeader(
      /**
       * The customHeader to set
       */
      oCustomHeader: Control
    ): this;
    /**
     * Sets a new value for property {@link #getEnableScrolling enableScrolling}.
     *
     * This property is deprecated. Please use properties verticalScrolling and horizontalScrolling instead.
     * If you still use this property it will be mapped on the new properties verticalScrolling and horizontalScrolling.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @deprecated As of version 1.15.0. replaced by verticalScrolling and horizontalScrolling properties.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableScrolling(
      /**
       * New value for property `enableScrolling`
       */
      bEnableScrolling?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getEndButton endButton}.
     *
     * @since 1.15.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEndButton(
      /**
       * The endButton to set
       */
      oEndButton: Control
    ): this;
    /**
     * The followOf feature closes the Popover when the position of the control that opened the Popover changes
     * by at least 32 pixels (on desktop browsers). This may lead to unwanted closing of the Popover.
     *
     * This function is for enabling/disabling the followOf feature.
     *
     * @since 1.16.8
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to the control instance for chaining
     */
    setFollowOf(
      /**
       * Enables the followOf feature
       */
      bValue: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getFooter footer}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFooter(
      /**
       * The footer to set
       */
      oFooter: Control
    ): this;
    /**
     * Sets a new value for property {@link #getHorizontalScrolling horizontalScrolling}.
     *
     * This property indicates if user can scroll horizontally inside popover when the content is bigger than
     * the content area. However, when scrollable control (sap.m.ScrollContainer, sap.m.Page) is in the popover,
     * this property needs to be set to false to disable the scrolling in popover in order to make the scrolling
     * in the child control work properly. Popover detects if there's sap.m.NavContainer, sap.m.Page, or sap.m.ScrollContainer
     * as direct child added to Popover. If there is, Popover will turn off scrolling by setting this property
     * to false automatically ignoring the existing value of this property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.15.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHorizontalScrolling(
      /**
       * New value for property `horizontalScrolling`
       */
      bHorizontalScrolling?: boolean
    ): this;
    /**
     * Sets the associated {@link #getInitialFocus initialFocus}.
     *
     * @since 1.15.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInitialFocus(
      /**
       * ID of an element which becomes the new target of this initialFocus association; alternatively, an element
       * instance may be given
       */
      oInitialFocus: ID | Control
    ): this;
    /**
     * Sets the associated {@link #getLeftButton leftButton}.
     *
     * @deprecated As of version 1.15.1. This property has been deprecated since 1.15.1. Please use the beginButton
     * instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLeftButton(
      /**
       * ID of an element which becomes the new target of this leftButton association; alternatively, an element
       * instance may be given
       */
      oLeftButton: ID | Button
    ): this;
    /**
     * Setter for property `modal`. This overwrites the default setter of the property `modal` to avoid rerendering
     * the whole popover control.
     *
     * Default value is `false`
     *
     *
     * @returns Reference to the control instance for chaining
     */
    setModal(
      /**
       * New value for property `modal`.
       */
      bModal: boolean,
      /**
       * A CSS class (or space-separated list of classes) that should be added to the block layer.
       */
      sModalCSSClass?: string
    ): this;
    /**
     * Sets a new value for property {@link #getOffsetX offsetX}.
     *
     * The offset for the popover placement in the x axis. It's with unit pixel.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setOffsetX(
      /**
       * New value for property `offsetX`
       */
      iOffsetX?: int
    ): this;
    /**
     * Sets a new value for property {@link #getOffsetY offsetY}.
     *
     * The offset for the popover placement in the y axis. It's with unit pixel.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setOffsetY(
      /**
       * New value for property `offsetY`
       */
      iOffsetY?: int
    ): this;
    /**
     * Set the placement of the Popover.
     *
     *
     * @returns Reference to the control instance for chaining
     */
    setPlacement(
      /**
       * The position of the Popover
       */
      sPlacement: PlacementType | keyof typeof PlacementType
    ): this;
    /**
     * Sets a new value for property {@link #getResizable resizable}.
     *
     * Whether resize option is enabled. NOTE: This property is effective only on Desktop
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.36.4
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setResizable(
      /**
       * New value for property `resizable`
       */
      bResizable?: boolean
    ): this;
    /**
     * Sets the associated {@link #getRightButton rightButton}.
     *
     * @deprecated As of version 1.15.1. This property has been deprecated since 1.15.1. Please use the endButton
     * instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRightButton(
      /**
       * ID of an element which becomes the new target of this rightButton association; alternatively, an element
       * instance may be given
       */
      oRightButton: ID | Button
    ): this;
    /**
     * Sets a new value for property {@link #getShowArrow showArrow}.
     *
     * Whether Popover arrow should be visible
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.31
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowArrow(
      /**
       * New value for property `showArrow`
       */
      bShowArrow?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowHeader showHeader}.
     *
     * If a header should be shown at the top of the popover. Note:* The heading level of the popover is H1.
     * Headings in the popover content should start with H2 heading level.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowHeader(
      /**
       * New value for property `showHeader`
       */
      bShowHeader?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getSubHeader subHeader}.
     *
     * @since 1.15.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSubHeader(
      /**
       * The subHeader to set
       */
      oSubHeader: Control
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Title text appears in the header. This property will be ignored when `showHeader` is set to `false`.
     * If you want to show a header in the `sap.m.Popover`, don't forget to set the {@link #setShowHeader showHeader }
     * property to `true`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitleAlignment titleAlignment}.
     *
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     * @since 1.72
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleAlignment(
      /**
       * New value for property `titleAlignment`
       */
      sTitleAlignment?: TitleAlignment | keyof typeof TitleAlignment
    ): this;
    /**
     * Sets a new value for property {@link #getVerticalScrolling verticalScrolling}.
     *
     * This property indicates if user can scroll vertically inside popover when the content is bigger than
     * the content area. However, when scrollable control (sap.m.ScrollContainer, sap.m.Page) is in the popover,
     * this property needs to be set to false to disable the scrolling in popover in order to make the scrolling
     * in the child control work properly. Popover detects if there's sap.m.NavContainer, sap.m.Page, or sap.m.ScrollContainer
     * as direct child added to Popover. If there is, Popover will turn off scrolling by setting this property
     * to false automatically ignoring the existing value of this property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.15.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVerticalScrolling(
      /**
       * New value for property `verticalScrolling`
       */
      bVerticalScrolling?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Popover constructor.
   */
  export interface $PopoverSettings extends $ControlSettings {
    /**
     * This is the information about on which side will the popover be placed at. Possible values are sap.m.PlacementType.Left,
     * sap.m.PlacementType.Right, sap.m.PlacementType.Top, sap.m.PlacementType.Bottom, sap.m.PlacementType.Horizontal,
     * sap.m.PlacementType.HorizontalPreferredLeft, sap.m.PlacementType.HorizontalPreferredRight, sap.m.PlacementType.Vertical,
     * sap.m.PlacementType.VerticalPreferredTop, sap.m.PlacementType.VerticalPreferredBottom, sap.m.PlacementType.Auto.
     * The default value is sap.m.PlacementType.Right. Setting this property while popover is open won't cause
     * any rerendering of the popover, but it will take effect when it's opened again.
     */
    placement?:
      | (PlacementType | keyof typeof PlacementType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * If a header should be shown at the top of the popover. *Note:* The heading level of the popover is H1.
     * Headings in the popover content should start with H2 heading level.
     */
    showHeader?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Title text appears in the header. This property will be ignored when `showHeader` is set to `false`.
     * If you want to show a header in the `sap.m.Popover`, don't forget to set the {@link #setShowHeader showHeader }
     * property to `true`.
     */
    title?: string | PropertyBindingInfo;

    /**
     * If the popover will not be closed when tapping outside the popover. It also blocks any interaction with
     * the background. The default value is false.
     */
    modal?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The offset for the popover placement in the x axis. It's with unit pixel.
     */
    offsetX?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * The offset for the popover placement in the y axis. It's with unit pixel.
     */
    offsetY?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Whether Popover arrow should be visible
     *
     * @since 1.31
     */
    showArrow?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Set the width of the content area inside Popover. When controls which adapt their size to the parent
     * control are added directly into Popover, for example sap.m.Page control, a size needs to be specified
     * to the content area of the Popover. Otherwise, Popover control isn't able to display the content in the
     * right way. This values isn't necessary for controls added to Popover directly which can decide their
     * size by themselves, for exmaple sap.m.List, sap.m.Image etc., only needed for controls that adapt their
     * size to the parent control.
     *
     * @since 1.9.0
     */
    contentWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the minimum width of the content area inside popover.
     *
     * @since 1.36
     */
    contentMinWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Set the height of the content area inside Popover. When controls which adapt their size to the parent
     * control are added directly into Popover, for example sap.m.Page control, a size needs to be specified
     * to the content area of the Popover. Otherwise, Popover control isn't able to display the content in the
     * right way. This values isn't necessary for controls added to Popover directly which can decide their
     * size by themselves, for exmaple sap.m.List, sap.m.Image etc., only needed for controls that adapt their
     * size to the parent control.
     *
     * @since 1.9.0
     */
    contentHeight?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * This property is deprecated. Please use properties verticalScrolling and horizontalScrolling instead.
     * If you still use this property it will be mapped on the new properties verticalScrolling and horizontalScrolling.
     *
     * @deprecated As of version 1.15.0. replaced by verticalScrolling and horizontalScrolling properties.
     */
    enableScrolling?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This property indicates if user can scroll vertically inside popover when the content is bigger than
     * the content area. However, when scrollable control (sap.m.ScrollContainer, sap.m.Page) is in the popover,
     * this property needs to be set to false to disable the scrolling in popover in order to make the scrolling
     * in the child control work properly. Popover detects if there's sap.m.NavContainer, sap.m.Page, or sap.m.ScrollContainer
     * as direct child added to Popover. If there is, Popover will turn off scrolling by setting this property
     * to false automatically ignoring the existing value of this property.
     *
     * @since 1.15.0
     */
    verticalScrolling?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This property indicates if user can scroll horizontally inside popover when the content is bigger than
     * the content area. However, when scrollable control (sap.m.ScrollContainer, sap.m.Page) is in the popover,
     * this property needs to be set to false to disable the scrolling in popover in order to make the scrolling
     * in the child control work properly. Popover detects if there's sap.m.NavContainer, sap.m.Page, or sap.m.ScrollContainer
     * as direct child added to Popover. If there is, Popover will turn off scrolling by setting this property
     * to false automatically ignoring the existing value of this property.
     *
     * @since 1.15.0
     */
    horizontalScrolling?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Whether bouncing is enabled.
     *
     * @since 1.16.5
     * @deprecated As of version 1.42. This parameter is obsolete and has no effect.
     */
    bounce?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Whether resize option is enabled. NOTE: This property is effective only on Desktop
     *
     * @since 1.36.4
     */
    resizable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * @since 1.72
     */
    titleAlignment?:
      | (TitleAlignment | keyof typeof TitleAlignment)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The content inside the popover.
     */
    content?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * Any control that needed to be displayed in the header area. When this is set, the showHeader property
     * is ignored, and only this customHeader is shown on the top of popover.
     */
    customHeader?: Control;

    /**
     * When subHeader is assigned to Popover, it's rendered directly after the main header if there is, or at
     * the beginning of Popover when there's no main header. SubHeader is out of the content area and won't
     * be scrolled when content's size is bigger than the content area's size.
     *
     * @since 1.15.1
     */
    subHeader?: Control;

    /**
     * This is optional footer which is shown on the bottom of the popover.
     */
    footer?: Control;

    /**
     * BeginButton is shown at the left side (right side in RTL mode) inside the header. When showHeader is
     * set to false, the property is ignored.
     *
     * @since 1.15.1
     */
    beginButton?: Control;

    /**
     * EndButton is always shown at the right side (left side in RTL mode) inside the header. When showHeader
     * is set to false, the property is ignored.
     *
     * @since 1.15.1
     */
    endButton?: Control;

    /**
     * LeftButton is shown at the left edge of the bar in iOS, and at the right side of the bar for the other
     * platforms. Please set this to null if you want to remove the left button from the bar. And the button
     * is only removed from the bar, not destroyed. When showHeader is set to false, this property will be ignored.
     *
     * @deprecated As of version 1.15.1. This property has been deprecated since 1.15.1. Please use the beginButton
     * instead.
     */
    leftButton?: Button | string;

    /**
     * RightButton is always shown at the right edge of the bar. Please set this to null if you want to remove
     * the right button from the bar. And the button is only removed from the bar, not destroyed. When showHeader
     * is set to false, this property will be ignored.
     *
     * @deprecated As of version 1.15.1. This property has been deprecated since 1.15.1. Please use the endButton
     * instead.
     */
    rightButton?: Button | string;

    /**
     * Focus on the popover is set in the sequence of `beginButton` and `endButton`, when available. But if
     * a control other than these two buttons needs to get the focus, set the `initialFocus` with the control
     * which should be focused on.
     *
     * @since 1.15.0
     */
    initialFocus?: Control | string;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Association to controls / ids which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * This event will be fired after the popover is opened.
     */
    afterOpen?: (oEvent: Popover$AfterOpenEvent) => void;

    /**
     * This event will be fired after the popover is closed.
     */
    afterClose?: (oEvent: Popover$AfterCloseEvent) => void;

    /**
     * This event will be fired before the popover is opened.
     */
    beforeOpen?: (oEvent: Popover$BeforeOpenEvent) => void;

    /**
     * This event will be fired before the popover is closed.
     */
    beforeClose?: (oEvent: Popover$BeforeCloseEvent) => void;
  }

  /**
   * Parameters of the Popover#afterClose event.
   */
  export interface Popover$AfterCloseEventParameters {
    /**
     * This refers to the control which opens the popover.
     */
    openBy?: Control;
  }

  /**
   * Event object of the Popover#afterClose event.
   */
  export type Popover$AfterCloseEvent = Event<
    Popover$AfterCloseEventParameters,
    Popover
  >;

  /**
   * Parameters of the Popover#afterOpen event.
   */
  export interface Popover$AfterOpenEventParameters {
    /**
     * This refers to the control which opens the popover.
     */
    openBy?: Control;
  }

  /**
   * Event object of the Popover#afterOpen event.
   */
  export type Popover$AfterOpenEvent = Event<
    Popover$AfterOpenEventParameters,
    Popover
  >;

  /**
   * Parameters of the Popover#beforeClose event.
   */
  export interface Popover$BeforeCloseEventParameters {
    /**
     * This refers to the control which opens the popover.
     */
    openBy?: Control;
  }

  /**
   * Event object of the Popover#beforeClose event.
   */
  export type Popover$BeforeCloseEvent = Event<
    Popover$BeforeCloseEventParameters,
    Popover
  >;

  /**
   * Parameters of the Popover#beforeOpen event.
   */
  export interface Popover$BeforeOpenEventParameters {
    /**
     * This refers to the control which opens the popover.
     */
    openBy?: Control;
  }

  /**
   * Event object of the Popover#beforeOpen event.
   */
  export type Popover$BeforeOpenEvent = Event<
    Popover$BeforeOpenEventParameters,
    Popover
  >;
}

declare module "sap/m/ProgressIndicator" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IFormContent,
    ID,
    AccessibilityInfo,
    CSSSize,
    ValueState,
    TextDirection,
  } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Shows the progress of a process in a graphical way. To indicate the progress, the inside of the ProgressIndicator
   * is filled with a color. Additionally, a user-defined string can be displayed on the ProgressIndicator.
   *
   * @since 1.13.1
   */
  export default class ProgressIndicator
    extends Control
    implements IFormContent
  {
    __implements__sap_ui_core_IFormContent: boolean;
    /**
     * Constructor for a new ProgressIndicator.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/progress-indicator/ Progress Indicator}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ProgressIndicatorSettings
    );
    /**
     * Constructor for a new ProgressIndicator.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/progress-indicator/ Progress Indicator}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ProgressIndicatorSettings
    );

    /**
     * Creates a new subclass of class sap.m.ProgressIndicator with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ProgressIndicator>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ProgressIndicator.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     * @since 1.69
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.69
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Returns the `sap.m.ProgressIndicator` accessibility information.
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The object contains the accessibility information of `sap.m.ProgressIndicator`
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     * @since 1.69
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.69
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getDisplayAnimation displayAnimation}.
     *
     * Determines whether a percentage change is displayed with animation.
     *
     * Default value is `true`.
     *
     * @since 1.73
     *
     * @returns Value of property `displayAnimation`
     */
    getDisplayAnimation(): boolean;
    /**
     * Gets current value of property {@link #getDisplayOnly displayOnly}.
     *
     * Determines whether the control is in display-only state where the control has different visualization
     * and cannot be focused.
     *
     * Default value is `false`.
     *
     * @since 1.50
     *
     * @returns Value of property `displayOnly`
     */
    getDisplayOnly(): boolean;
    /**
     * Gets current value of property {@link #getDisplayValue displayValue}.
     *
     * Specifies the text value to be displayed in the bar.
     *
     *
     * @returns Value of property `displayValue`
     */
    getDisplayValue(): string;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Switches enabled state of the control. Disabled fields have different colors, and cannot be focused.
     *
     * Default value is `true`.
     *
     * @deprecated As of version 1.130. with no replacement.
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets current value of property {@link #getHeight height}.
     *
     * Specifies the height of the control. The default value depends on the theme. Suggested size for normal
     * use is 2.5rem (40px). Suggested size for small size (like for use in ObjectHeader) is 1.375rem (22px).
     *
     * @since 1.15.0
     *
     * @returns Value of property `height`
     */
    getHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getPercentValue percentValue}.
     *
     * Specifies the numerical value in percent for the length of the progress bar.
     *
     * **Note:** If a value greater than 100 is provided, the `percentValue` is set to 100. In other cases of
     * invalid value, `percentValue` is set to its default of 0.
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `percentValue`
     */
    getPercentValue(): float;
    /**
     * Gets current value of property {@link #getShowValue showValue}.
     *
     * Indicates whether the displayValue should be shown in the ProgressIndicator.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showValue`
     */
    getShowValue(): boolean;
    /**
     * Gets current value of property {@link #getState state}.
     *
     * Specifies the state of the bar. Enumeration sap.ui.core.ValueState provides Error, Warning, Success,
     * Information, None (default value). The color for each state depends on the theme.
     *
     * Default value is `None`.
     *
     *
     * @returns Value of property `state`
     */
    getState(): ValueState;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * Specifies the element's text directionality with enumerated options (RTL or LTR). By default, the control
     * inherits text direction from the DOM.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Specifies the width of the control.
     *
     * Default value is `'100%'`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     * @since 1.69
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.69
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     * @since 1.69
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.69
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getDisplayAnimation displayAnimation}.
     *
     * Determines whether a percentage change is displayed with animation.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.73
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisplayAnimation(
      /**
       * New value for property `displayAnimation`
       */
      bDisplayAnimation?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getDisplayOnly displayOnly}.
     *
     * Determines whether the control is in display-only state where the control has different visualization
     * and cannot be focused.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.50
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisplayOnly(
      /**
       * New value for property `displayOnly`
       */
      bDisplayOnly?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getDisplayValue displayValue}.
     *
     * Specifies the text value to be displayed in the bar.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisplayValue(
      /**
       * New value for property `displayValue`
       */
      sDisplayValue?: string
    ): this;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Switches enabled state of the control. Disabled fields have different colors, and cannot be focused.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @deprecated As of version 1.130. with no replacement.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getHeight height}.
     *
     * Specifies the height of the control. The default value depends on the theme. Suggested size for normal
     * use is 2.5rem (40px). Suggested size for small size (like for use in ObjectHeader) is 1.375rem (22px).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.15.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeight(
      /**
       * New value for property `height`
       */
      sHeight?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getPercentValue percentValue}.
     *
     * Specifies the numerical value in percent for the length of the progress bar.
     *
     * **Note:** If a value greater than 100 is provided, the `percentValue` is set to 100. In other cases of
     * invalid value, `percentValue` is set to its default of 0.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPercentValue(
      /**
       * New value for property `percentValue`
       */
      fPercentValue?: float
    ): this;
    /**
     * Sets a new value for property {@link #getShowValue showValue}.
     *
     * Indicates whether the displayValue should be shown in the ProgressIndicator.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowValue(
      /**
       * New value for property `showValue`
       */
      bShowValue?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getState state}.
     *
     * Specifies the state of the bar. Enumeration sap.ui.core.ValueState provides Error, Warning, Success,
     * Information, None (default value). The color for each state depends on the theme.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setState(
      /**
       * New value for property `state`
       */
      sState?: ValueState | keyof typeof ValueState
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * Specifies the element's text directionality with enumerated options (RTL or LTR). By default, the control
     * inherits text direction from the DOM.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Specifies the width of the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `'100%'`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ProgressIndicator constructor.
   */
  export interface $ProgressIndicatorSettings extends $ControlSettings {
    /**
     * Switches enabled state of the control. Disabled fields have different colors, and cannot be focused.
     *
     * @deprecated As of version 1.130. with no replacement.
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the state of the bar. Enumeration sap.ui.core.ValueState provides Error, Warning, Success,
     * Information, None (default value). The color for each state depends on the theme.
     */
    state?:
      | (ValueState | keyof typeof ValueState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies the text value to be displayed in the bar.
     */
    displayValue?: string | PropertyBindingInfo;

    /**
     * Specifies the numerical value in percent for the length of the progress bar.
     *
     * **Note:** If a value greater than 100 is provided, the `percentValue` is set to 100. In other cases of
     * invalid value, `percentValue` is set to its default of 0.
     */
    percentValue?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether the displayValue should be shown in the ProgressIndicator.
     */
    showValue?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the width of the control.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the height of the control. The default value depends on the theme. Suggested size for normal
     * use is 2.5rem (40px). Suggested size for small size (like for use in ObjectHeader) is 1.375rem (22px).
     *
     * @since 1.15.0
     */
    height?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the element's text directionality with enumerated options (RTL or LTR). By default, the control
     * inherits text direction from the DOM.
     *
     * @since 1.28.0
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines whether the control is in display-only state where the control has different visualization
     * and cannot be focused.
     *
     * @since 1.50
     */
    displayOnly?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether a percentage change is displayed with animation.
     *
     * @since 1.73
     */
    displayAnimation?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Association to controls / IDs which describe this control (see WAI-ARIA attribute aria-describedby).
     *
     * @since 1.69
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Association to controls / IDs which label this control (see WAI-ARIA attribute aria-labelledBy).
     *
     * @since 1.69
     */
    ariaLabelledBy?: Array<Control | string>;
  }
}

declare module "sap/m/PullToRefresh" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import Event from "sap/ui/base/Event";

  import { URI } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * PullToRefresh control. Put it as the first control in contents of a scroll container or a scrollable
   * page. Do not place it into a page with disabled scrolling. On touch devices it gets hidden by default
   * and when the user pulls down the page far enough, it gets visible and triggers the "refresh" event. In
   * non-touch browsers where scrollbars are used for scrolling, it is always visible and triggers the "refresh"
   * event when clicked.
   *
   * @since 1.9.2
   */
  export default class PullToRefresh extends Control {
    /**
     * Constructor for a new PullToRefresh.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/fde40159afce478eb488ee4d0f9ebb99 Pull to Refresh}
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $PullToRefreshSettings
    );
    /**
     * Constructor for a new PullToRefresh.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/fde40159afce478eb488ee4d0f9ebb99 Pull to Refresh}
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $PullToRefreshSettings
    );

    /**
     * Creates a new subclass of class sap.m.PullToRefresh with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, PullToRefresh>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.PullToRefresh.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:refresh refresh} event of this `sap.m.PullToRefresh`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PullToRefresh` itself.
     *
     * Event indicates that the user has requested new data
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachRefresh(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PullToRefresh` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:refresh refresh} event of this `sap.m.PullToRefresh`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.PullToRefresh` itself.
     *
     * Event indicates that the user has requested new data
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachRefresh(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.PullToRefresh` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:refresh refresh} event of this `sap.m.PullToRefresh`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachRefresh(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:refresh refresh} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireRefresh(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getCustomIcon customIcon}.
     *
     * Provide a URI to a custom icon image to replace the SAP logo. Large images are scaled down to max 50px
     * height.
     *
     *
     * @returns Value of property `customIcon`
     */
    getCustomIcon(): URI;
    /**
     * Gets current value of property {@link #getDescription description}.
     *
     * Optional description. May be used to inform a user, for example, when the list has been updated last
     * time.
     *
     *
     * @returns Value of property `description`
     */
    getDescription(): string;
    /**
     * Gets current value of property {@link #getIconDensityAware iconDensityAware}.
     *
     * By default, this is set to true but then one or more requests are sent trying to get the density perfect
     * version of image if this version of image doesn't exist on the server.
     *
     * If bandwidth is the key for the application, set this value to false.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `iconDensityAware`
     */
    getIconDensityAware(): boolean;
    /**
     * Gets current value of property {@link #getShowIcon showIcon}.
     *
     * Set to true to display an icon/logo. Icon must be set either in the customIcon property or in the CSS
     * theme for the PullToRefresh control.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showIcon`
     */
    getShowIcon(): boolean;
    /**
     * Hides the control and resets it to the normal state. In non-touch environments the control is not hidden.
     */
    hide(): void;
    /**
     * Sets a new value for property {@link #getCustomIcon customIcon}.
     *
     * Provide a URI to a custom icon image to replace the SAP logo. Large images are scaled down to max 50px
     * height.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomIcon(
      /**
       * New value for property `customIcon`
       */
      sCustomIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getDescription description}.
     *
     * Optional description. May be used to inform a user, for example, when the list has been updated last
     * time.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDescription(
      /**
       * New value for property `description`
       */
      sDescription?: string
    ): this;
    /**
     * Sets a new value for property {@link #getIconDensityAware iconDensityAware}.
     *
     * By default, this is set to true but then one or more requests are sent trying to get the density perfect
     * version of image if this version of image doesn't exist on the server.
     *
     * If bandwidth is the key for the application, set this value to false.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconDensityAware(
      /**
       * New value for property `iconDensityAware`
       */
      bIconDensityAware?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowIcon showIcon}.
     *
     * Set to true to display an icon/logo. Icon must be set either in the customIcon property or in the CSS
     * theme for the PullToRefresh control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowIcon(
      /**
       * New value for property `showIcon`
       */
      bShowIcon?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the PullToRefresh constructor.
   */
  export interface $PullToRefreshSettings extends $ControlSettings {
    /**
     * Optional description. May be used to inform a user, for example, when the list has been updated last
     * time.
     */
    description?: string | PropertyBindingInfo;

    /**
     * Set to true to display an icon/logo. Icon must be set either in the customIcon property or in the CSS
     * theme for the PullToRefresh control.
     */
    showIcon?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Provide a URI to a custom icon image to replace the SAP logo. Large images are scaled down to max 50px
     * height.
     */
    customIcon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * By default, this is set to true but then one or more requests are sent trying to get the density perfect
     * version of image if this version of image doesn't exist on the server.
     *
     * If bandwidth is the key for the application, set this value to false.
     */
    iconDensityAware?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Event indicates that the user has requested new data
     */
    refresh?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the PullToRefresh#refresh event.
   */
  export interface PullToRefresh$RefreshEventParameters {}

  /**
   * Event object of the PullToRefresh#refresh event.
   */
  export type PullToRefresh$RefreshEvent = Event<
    PullToRefresh$RefreshEventParameters,
    PullToRefresh
  >;
}

declare module "sap/m/QuickView" {
  import {
    default as QuickViewBase,
    $QuickViewBaseSettings,
  } from "sap/m/QuickViewBase";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PlacementType } from "sap/m/library";

  import { CSSSize } from "sap/ui/core/library";

  import Control from "sap/ui/core/Control";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Button from "sap/m/Button";

  import Event from "sap/ui/base/Event";

  /**
   * A responsive popover that displays information on an object in a business-card format. Overview: The
   * quick view is used to show business information on either a person or an entity (e.g. a company). It
   * uses a set of pre-defined controls. Objects can be linked together and you can navigate between several
   * objects. An unlimited number of objects can be linked. Structure: Each card is represented by a {@link sap.m.QuickViewPage }
   * which holds all the information (avatar, title, header, description) for the object. A single quick view
   * can hold multiple objects, each showing information on a single entity. Usage: When to use:
   * 	 - You want to display a concise overview of an object (an employee or a company).
   * 	 - Information on the object can be split into concrete groups.  When not to use:
   * 	 - You want to display complex information about an object.  Responsive Behavior: The quick view
   *     is displayed in a {@link sap.m.Popover popover} on desktop and a full-screen {@link sap.m.Dialog dialog }
   *     on mobile devices.
   *
   * @since 1.28.11
   */
  export default class QuickView extends QuickViewBase {
    /**
     * Constructor for a new QuickView.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/quickview/ Quick View}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $QuickViewSettings
    );
    /**
     * Constructor for a new QuickView.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/quickview/ Quick View}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $QuickViewSettings
    );

    /**
     * Creates a new subclass of class sap.m.QuickView with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.QuickViewBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, QuickView>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.QuickView.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterClose afterClose} event of this `sap.m.QuickView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.QuickView` itself.
     *
     * This event fires after the QuickView is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: QuickView$AfterCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.QuickView` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterClose afterClose} event of this `sap.m.QuickView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.QuickView` itself.
     *
     * This event fires after the QuickView is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: QuickView$AfterCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.QuickView` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterOpen afterOpen} event of this `sap.m.QuickView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.QuickView` itself.
     *
     * This event fires after the QuickView is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: QuickView$AfterOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.QuickView` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterOpen afterOpen} event of this `sap.m.QuickView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.QuickView` itself.
     *
     * This event fires after the QuickView is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: QuickView$AfterOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.QuickView` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.QuickView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.QuickView` itself.
     *
     * This event fires before the QuickView is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: QuickView$BeforeCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.QuickView` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.QuickView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.QuickView` itself.
     *
     * This event fires before the QuickView is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: QuickView$BeforeCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.QuickView` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.QuickView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.QuickView` itself.
     *
     * This event fires before the QuickView is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: QuickView$BeforeOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.QuickView` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.QuickView`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.QuickView` itself.
     *
     * This event fires before the QuickView is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: QuickView$BeforeOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.QuickView` itself
       */
      oListener?: object
    ): this;
    /**
     * Closes the QuickView.
     *
     *
     * @returns Pointer to the control instance for chaining
     */
    close(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterClose afterClose} event of this `sap.m.QuickView`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: QuickView$AfterCloseEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterOpen afterOpen} event of this `sap.m.QuickView`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: QuickView$AfterOpenEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeClose beforeClose} event of this `sap.m.QuickView`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: QuickView$BeforeCloseEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeOpen beforeOpen} event of this `sap.m.QuickView`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: QuickView$BeforeOpenEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:afterClose afterClose} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: QuickView$AfterCloseEventParameters
    ): this;
    /**
     * Fires event {@link #event:afterOpen afterOpen} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: QuickView$AfterOpenEventParameters
    ): this;
    /**
     * Fires event {@link #event:beforeClose beforeClose} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforeClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: QuickView$BeforeCloseEventParameters
    ): this;
    /**
     * Fires event {@link #event:beforeOpen beforeOpen} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforeOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: QuickView$BeforeOpenEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getPlacement placement}.
     *
     * This property is reused from sap.m.Popover and only takes effect when running on desktop or tablet. Please
     * refer the documentation of the placement property of sap.m.Popover.
     *
     * Default value is `Right`.
     *
     *
     * @returns Value of property `placement`
     */
    getPlacement(): PlacementType;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * The width of the QuickView. The property takes effect only when running on desktop or tablet.
     *
     * Default value is `'320px'`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Opens the QuickView.
     *
     *
     * @returns Pointer to the control instance for chaining
     */
    openBy(
      /**
       * The control which opens the QuickView.
       */
      oControl: Control | HTMLElement
    ): this;
    /**
     * The method sets placement position of the QuickView.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    setPlacement(
      /**
       * The side from which the QuickView appears relative to the control that opens it.
       */
      sPlacement: PlacementType | keyof typeof PlacementType
    ): this;
    /**
     * The method sets the width of the QuickView. Works only on desktop or tablet.
     *
     *
     * @returns Pointer to the control instance for chaining
     */
    setWidth(
      /**
       * The new width of the QuickView.
       */
      sWidth: CSSSize
    ): this;
  }
  /**
   * Describes the settings that can be provided to the QuickView constructor.
   */
  export interface $QuickViewSettings extends $QuickViewBaseSettings {
    /**
     * This property is reused from sap.m.Popover and only takes effect when running on desktop or tablet. Please
     * refer the documentation of the placement property of sap.m.Popover.
     */
    placement?:
      | (PlacementType | keyof typeof PlacementType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The width of the QuickView. The property takes effect only when running on desktop or tablet.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * This event fires after the QuickView is opened.
     */
    afterOpen?: (oEvent: QuickView$AfterOpenEvent) => void;

    /**
     * This event fires after the QuickView is closed.
     */
    afterClose?: (oEvent: QuickView$AfterCloseEvent) => void;

    /**
     * This event fires before the QuickView is opened.
     */
    beforeOpen?: (oEvent: QuickView$BeforeOpenEvent) => void;

    /**
     * This event fires before the QuickView is closed.
     */
    beforeClose?: (oEvent: QuickView$BeforeCloseEvent) => void;
  }

  /**
   * Parameters of the QuickView#afterClose event.
   */
  export interface QuickView$AfterCloseEventParameters {
    /**
     * This parameter refers to the control, which opens the QuickView.
     */
    openBy?: Control;

    /**
     * This parameter contains the control, which triggers the close of the QuickView. It is undefined when
     * running on desktop or tablet.
     */
    origin?: Button;
  }

  /**
   * Event object of the QuickView#afterClose event.
   */
  export type QuickView$AfterCloseEvent = Event<
    QuickView$AfterCloseEventParameters,
    QuickView
  >;

  /**
   * Parameters of the QuickView#afterOpen event.
   */
  export interface QuickView$AfterOpenEventParameters {
    /**
     * This parameter refers to the control, which opens the QuickView.
     */
    openBy?: Control;
  }

  /**
   * Event object of the QuickView#afterOpen event.
   */
  export type QuickView$AfterOpenEvent = Event<
    QuickView$AfterOpenEventParameters,
    QuickView
  >;

  /**
   * Parameters of the QuickView#beforeClose event.
   */
  export interface QuickView$BeforeCloseEventParameters {
    /**
     * This parameter refers to the control, which opens the QuickView.
     */
    openBy?: Control;

    /**
     * This parameter contains the control, which triggers the close of the QuickView. It is undefined when
     * running on desktop or tablet.
     */
    origin?: Button;
  }

  /**
   * Event object of the QuickView#beforeClose event.
   */
  export type QuickView$BeforeCloseEvent = Event<
    QuickView$BeforeCloseEventParameters,
    QuickView
  >;

  /**
   * Parameters of the QuickView#beforeOpen event.
   */
  export interface QuickView$BeforeOpenEventParameters {
    /**
     * This parameter refers to the control, which opens the QuickView.
     */
    openBy?: Control;
  }

  /**
   * Event object of the QuickView#beforeOpen event.
   */
  export type QuickView$BeforeOpenEvent = Event<
    QuickView$BeforeOpenEventParameters,
    QuickView
  >;
}

declare module "sap/m/QuickViewBase" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import QuickViewPage from "sap/m/QuickViewPage";

  import { AggregationBindingInfo } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Event from "sap/ui/base/Event";

  /**
   * QuickViewBase class provides base functionality for QuickView and QuickViewCard. Do not use it directly.
   *
   * @since 1.28.11
   */
  export default class QuickViewBase extends Control {
    /**
     * Constructor for a new QuickViewBase.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $QuickViewBaseSettings
    );
    /**
     * Constructor for a new QuickViewBase.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $QuickViewBaseSettings
    );

    /**
     * Creates a new subclass of class sap.m.QuickViewBase with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, QuickViewBase>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.QuickViewBase.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some page to the aggregation {@link #getPages pages}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addPage(
      /**
       * The page to add; if empty, nothing is inserted
       */
      oPage: QuickViewPage
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterNavigate afterNavigate} event of this `sap.m.QuickViewBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.QuickViewBase` itself.
     *
     * The event is fired when navigation between two pages has completed. In case of animated transitions this
     * event is fired with some delay after the "navigate" event.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterNavigate(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: QuickViewBase$AfterNavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.QuickViewBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterNavigate afterNavigate} event of this `sap.m.QuickViewBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.QuickViewBase` itself.
     *
     * The event is fired when navigation between two pages has completed. In case of animated transitions this
     * event is fired with some delay after the "navigate" event.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterNavigate(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: QuickViewBase$AfterNavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.QuickViewBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navigate navigate} event of this `sap.m.QuickViewBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.QuickViewBase` itself.
     *
     * The event is fired when navigation between two pages has been triggered. The transition (if any) to the
     * new page has not started yet.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavigate(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: QuickViewBase$NavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.QuickViewBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navigate navigate} event of this `sap.m.QuickViewBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.QuickViewBase` itself.
     *
     * The event is fired when navigation between two pages has been triggered. The transition (if any) to the
     * new page has not started yet.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavigate(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: QuickViewBase$NavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.QuickViewBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getPages pages} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindPages(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the pages in the aggregation {@link #getPages pages}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyPages(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterNavigate afterNavigate} event of this
     * `sap.m.QuickViewBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterNavigate(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: QuickViewBase$AfterNavigateEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:navigate navigate} event of this `sap.m.QuickViewBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachNavigate(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: QuickViewBase$NavigateEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:afterNavigate afterNavigate} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterNavigate(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: QuickViewBase$AfterNavigateEventParameters
    ): this;
    /**
     * Fires event {@link #event:navigate navigate} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireNavigate(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: QuickViewBase$NavigateEventParameters
    ): boolean;
    /**
     * Gets content of aggregation {@link #getPages pages}.
     *
     * Displays a page header, object icon or image, object name with short description, and object information
     * divided in groups
     */
    getPages(): QuickViewPage[];
    /**
     * Checks for the provided `sap.m.QuickViewPage` in the aggregation {@link #getPages pages}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfPage(
      /**
       * The page whose index is looked for
       */
      oPage: QuickViewPage
    ): int;
    /**
     * Inserts a page into the aggregation {@link #getPages pages}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertPage(
      /**
       * The page to insert; if empty, nothing is inserted
       */
      oPage: QuickViewPage,
      /**
       * The `0`-based index the page should be inserted at; for a negative value of `iIndex`, the page is inserted
       * at position 0; for a value greater than the current size of the aggregation, the page is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Navigates to the previous page if there is such.
     */
    navigateBack(): void;
    /**
     * Removes all the controls from the aggregation {@link #getPages pages}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllPages(): QuickViewPage[];
    /**
     * Removes a page from the aggregation {@link #getPages pages}.
     *
     *
     * @returns The removed page or `null`
     */
    removePage(
      /**
       * The page to remove or its index or id
       */
      vPage: int | string | QuickViewPage
    ): QuickViewPage | null;
    /**
     * Unbinds aggregation {@link #getPages pages} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindPages(): this;
  }
  /**
   * Describes the settings that can be provided to the QuickViewBase constructor.
   */
  export interface $QuickViewBaseSettings extends $ControlSettings {
    /**
     * Displays a page header, object icon or image, object name with short description, and object information
     * divided in groups
     */
    pages?:
      | QuickViewPage[]
      | QuickViewPage
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * The event is fired when navigation between two pages has been triggered. The transition (if any) to the
     * new page has not started yet.
     */
    navigate?: (oEvent: QuickViewBase$NavigateEvent) => void;

    /**
     * The event is fired when navigation between two pages has completed. In case of animated transitions this
     * event is fired with some delay after the "navigate" event.
     */
    afterNavigate?: (oEvent: QuickViewBase$AfterNavigateEvent) => void;
  }

  /**
   * Parameters of the QuickViewBase#afterNavigate event.
   */
  export interface QuickViewBase$AfterNavigateEventParameters {
    /**
     * Determines the page, which has been displayed before navigation.
     */
    from?: Control;

    /**
     * Determines the ID of the page, which has been displayed before navigation.
     */
    fromId?: string;

    /**
     * Determines the page, which is now displayed after navigation.
     */
    to?: Control;

    /**
     * Determines the ID of the page, which is now displayed after navigation.
     */
    toId?: string;

    /**
     * Determines whether the "to" page (a control with the ID of the page, which has been navigated to) has
     * not been displayed/navigated to before.
     */
    firstTime?: boolean;

    /**
     * Determines whether this was a forward navigation.
     */
    isTo?: boolean;

    /**
     * Determines whether this was a back navigation.
     */
    isBack?: boolean;

    /**
     * Determines whether this was a navigation to the root page.
     */
    isBackToTop?: boolean;

    /**
     * Determines whether this was a navigation to a specific page.
     */
    isBackToPage?: boolean;

    /**
     * Determines how the navigation was triggered, possible values are "to", "back", "backToPage", and "backToTop".
     */
    direction?: string;

    /**
     * Determines whether this is a navigation to the top page.
     */
    isTopPage?: boolean;

    /**
     * Determines which link initiated the navigation.
     */
    navOrigin?: Control;
  }

  /**
   * Event object of the QuickViewBase#afterNavigate event.
   */
  export type QuickViewBase$AfterNavigateEvent = Event<
    QuickViewBase$AfterNavigateEventParameters,
    QuickViewBase
  >;

  /**
   * Parameters of the QuickViewBase#navigate event.
   */
  export interface QuickViewBase$NavigateEventParameters {
    /**
     * The page which was displayed before the current navigation.
     */
    from?: Control;

    /**
     * The ID of the page which was displayed before the current navigation.
     */
    fromId?: string;

    /**
     * The page which will be displayed after the current navigation.
     */
    to?: Control;

    /**
     * The ID of the page which will be displayed after the current navigation.
     */
    toId?: string;

    /**
     * Determines whether the "to" page (a control with the ID of the page which is currently navigated to)
     * has not been displayed/navigated to before.
     */
    firstTime?: boolean;

    /**
     * Determines whether this is a forward navigation.
     */
    isTo?: boolean;

    /**
     * Determines whether this is a back navigation.
     */
    isBack?: boolean;

    /**
     * Determines whether this is a navigation to the root page.
     */
    isBackToTop?: boolean;

    /**
     * Determines whether this was a navigation to a specific page.
     */
    isBackToPage?: boolean;

    /**
     * Determines how the navigation was triggered, possible values are "to", "back", "backToPage", and "backToTop".
     */
    direction?: string;

    /**
     * Determines which link initiated the navigation.
     */
    navOrigin?: Control;
  }

  /**
   * Event object of the QuickViewBase#navigate event.
   */
  export type QuickViewBase$NavigateEvent = Event<
    QuickViewBase$NavigateEventParameters,
    QuickViewBase
  >;
}

declare module "sap/m/QuickViewCard" {
  import {
    default as QuickViewBase,
    $QuickViewBaseSettings,
  } from "sap/m/QuickViewBase";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The QuickViewCard control displays information of an object in a business-card format. It also allows
   * this object to be linked to another object using one of the links. Clicking that link updates the information
   * with the data of the linked object. Unlimited number of objects can be linked.
   *
   * @since 1.28.11
   */
  export default class QuickViewCard extends QuickViewBase {
    /**
     * Constructor for a new QuickViewCard.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $QuickViewCardSettings
    );
    /**
     * Constructor for a new QuickViewCard.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $QuickViewCardSettings
    );

    /**
     * Creates a new subclass of class sap.m.QuickViewCard with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.QuickViewBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, QuickViewCard>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.QuickViewCard.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getShowVerticalScrollBar showVerticalScrollBar}.
     *
     * Determines whether the browser displays the vertical scroll bar or simply cuts the content of the QuickViewCard.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showVerticalScrollBar`
     */
    getShowVerticalScrollBar(): boolean;
    /**
     * Sets a new value for property {@link #getShowVerticalScrollBar showVerticalScrollBar}.
     *
     * Determines whether the browser displays the vertical scroll bar or simply cuts the content of the QuickViewCard.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowVerticalScrollBar(
      /**
       * New value for property `showVerticalScrollBar`
       */
      bShowVerticalScrollBar?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the QuickViewCard constructor.
   */
  export interface $QuickViewCardSettings extends $QuickViewBaseSettings {
    /**
     * Determines whether the browser displays the vertical scroll bar or simply cuts the content of the QuickViewCard.
     */
    showVerticalScrollBar?: boolean | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/QuickViewGroup" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import QuickViewGroupElement from "sap/m/QuickViewGroupElement";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * QuickViewGroup consists of a title (optional) and an entity of group elements.
   *
   * @since 1.28.11
   */
  export default class QuickViewGroup extends UI5Element {
    /**
     * Constructor for a new QuickViewGroup.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $QuickViewGroupSettings
    );
    /**
     * Constructor for a new QuickViewGroup.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $QuickViewGroupSettings
    );

    /**
     * Creates a new subclass of class sap.m.QuickViewGroup with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, QuickViewGroup>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.QuickViewGroup.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some element to the aggregation {@link #getElements elements}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addElement(
      /**
       * The element to add; if empty, nothing is inserted
       */
      oElement: QuickViewGroupElement
    ): this;
    /**
     * Binds aggregation {@link #getElements elements} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindElements(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the elements in the aggregation {@link #getElements elements}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyElements(): this;
    /**
     * Gets content of aggregation {@link #getElements elements}.
     *
     * A combination of one label and another control (Link or Text) associated to this label.
     */
    getElements(): QuickViewGroupElement[];
    /**
     * Gets current value of property {@link #getHeading heading}.
     *
     * The title of the group
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `heading`
     */
    getHeading(): string;
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * Determines whether the group is visible on the screen.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Checks for the provided `sap.m.QuickViewGroupElement` in the aggregation {@link #getElements elements}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfElement(
      /**
       * The element whose index is looked for
       */
      oElement: QuickViewGroupElement
    ): int;
    /**
     * Inserts a element into the aggregation {@link #getElements elements}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertElement(
      /**
       * The element to insert; if empty, nothing is inserted
       */
      oElement: QuickViewGroupElement,
      /**
       * The `0`-based index the element should be inserted at; for a negative value of `iIndex`, the element
       * is inserted at position 0; for a value greater than the current size of the aggregation, the element
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getElements elements}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllElements(): QuickViewGroupElement[];
    /**
     * Removes a element from the aggregation {@link #getElements elements}.
     *
     *
     * @returns The removed element or `null`
     */
    removeElement(
      /**
       * The element to remove or its index or id
       */
      vElement: int | string | QuickViewGroupElement
    ): QuickViewGroupElement | null;
    /**
     * Sets a new value for property {@link #getHeading heading}.
     *
     * The title of the group
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeading(
      /**
       * New value for property `heading`
       */
      sHeading?: string
    ): this;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * Determines whether the group is visible on the screen.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible?: boolean
    ): this;
    /**
     * Unbinds aggregation {@link #getElements elements} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindElements(): this;
  }
  /**
   * Describes the settings that can be provided to the QuickViewGroup constructor.
   */
  export interface $QuickViewGroupSettings extends $ElementSettings {
    /**
     * Determines whether the group is visible on the screen.
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The title of the group
     */
    heading?: string | PropertyBindingInfo;

    /**
     * A combination of one label and another control (Link or Text) associated to this label.
     */
    elements?:
      | QuickViewGroupElement[]
      | QuickViewGroupElement
      | AggregationBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/QuickViewGroupElement" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { QuickViewGroupElementType } from "sap/m/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * QuickViewGroupElement is a combination of one label and another control (Link or Text) associated to
   * this label.
   *
   * @since 1.28.11
   */
  export default class QuickViewGroupElement extends UI5Element {
    /**
     * Constructor for a new QuickViewGroupElement.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $QuickViewGroupElementSettings
    );
    /**
     * Constructor for a new QuickViewGroupElement.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $QuickViewGroupElementSettings
    );

    /**
     * Creates a new subclass of class sap.m.QuickViewGroupElement with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, QuickViewGroupElement>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.QuickViewGroupElement.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getEmailSubject emailSubject}.
     *
     * The subject of the email. Works only with QuickViewGroupElement of type email.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `emailSubject`
     */
    getEmailSubject(): string;
    /**
     * Gets current value of property {@link #getLabel label}.
     *
     * Specifies the text displayed below the associated label.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `label`
     */
    getLabel(): string;
    /**
     * Gets current value of property {@link #getPageLinkId pageLinkId}.
     *
     * Specifies the ID of the QuickViewPage, which is opened from the link in the QuickViewGroupElement. Works
     * only with QuickViewGroupElement of type pageLink.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `pageLinkId`
     */
    getPageLinkId(): string;
    /**
     * Gets current value of property {@link #getTarget target}.
     *
     * Specifies the target of the link - it works like the target property of the HTML  tag. Works only
     * with QuickViewGroupElement of type link.
     *
     * Default value is `"_blank"`.
     *
     *
     * @returns Value of property `target`
     */
    getTarget(): string;
    /**
     * Gets current value of property {@link #getType type}.
     *
     * Specifies the type of the displayed information - phone number, mobile number, e-mail, link, text or
     * a link to another QuickViewPage. Default value is 'text'.
     *
     * Default value is `text`.
     *
     *
     * @returns Value of property `type`
     */
    getType(): QuickViewGroupElementType;
    /**
     * Gets current value of property {@link #getUrl url}.
     *
     * Specifies the address of the QuickViewGroupElement link. Works only with QuickViewGroupElement of type
     * link.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `url`
     */
    getUrl(): string;
    /**
     * Gets current value of property {@link #getValue value}.
     *
     * Specifies the text of the control that associates with the label.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `value`
     */
    getValue(): string;
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * Determines whether the element should be visible on the screen.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Sets a new value for property {@link #getEmailSubject emailSubject}.
     *
     * The subject of the email. Works only with QuickViewGroupElement of type email.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEmailSubject(
      /**
       * New value for property `emailSubject`
       */
      sEmailSubject?: string
    ): this;
    /**
     * Sets a new value for property {@link #getLabel label}.
     *
     * Specifies the text displayed below the associated label.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLabel(
      /**
       * New value for property `label`
       */
      sLabel?: string
    ): this;
    /**
     * Sets a new value for property {@link #getPageLinkId pageLinkId}.
     *
     * Specifies the ID of the QuickViewPage, which is opened from the link in the QuickViewGroupElement. Works
     * only with QuickViewGroupElement of type pageLink.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPageLinkId(
      /**
       * New value for property `pageLinkId`
       */
      sPageLinkId?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTarget target}.
     *
     * Specifies the target of the link - it works like the target property of the HTML  tag. Works only
     * with QuickViewGroupElement of type link.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"_blank"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTarget(
      /**
       * New value for property `target`
       */
      sTarget?: string
    ): this;
    /**
     * Sets a new value for property {@link #getType type}.
     *
     * Specifies the type of the displayed information - phone number, mobile number, e-mail, link, text or
     * a link to another QuickViewPage. Default value is 'text'.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `text`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setType(
      /**
       * New value for property `type`
       */
      sType?: QuickViewGroupElementType | keyof typeof QuickViewGroupElementType
    ): this;
    /**
     * Sets a new value for property {@link #getUrl url}.
     *
     * Specifies the address of the QuickViewGroupElement link. Works only with QuickViewGroupElement of type
     * link.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUrl(
      /**
       * New value for property `url`
       */
      sUrl?: string
    ): this;
    /**
     * Sets a new value for property {@link #getValue value}.
     *
     * Specifies the text of the control that associates with the label.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValue(
      /**
       * New value for property `value`
       */
      sValue?: string
    ): this;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * Determines whether the element should be visible on the screen.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the QuickViewGroupElement constructor.
   */
  export interface $QuickViewGroupElementSettings extends $ElementSettings {
    /**
     * Determines whether the element should be visible on the screen.
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the text displayed below the associated label.
     */
    label?: string | PropertyBindingInfo;

    /**
     * Specifies the text of the control that associates with the label.
     */
    value?: string | PropertyBindingInfo;

    /**
     * Specifies the address of the QuickViewGroupElement link. Works only with QuickViewGroupElement of type
     * link.
     */
    url?: string | PropertyBindingInfo;

    /**
     * Specifies the target of the link - it works like the target property of the HTML  tag. Works only
     * with QuickViewGroupElement of type link.
     */
    target?: string | PropertyBindingInfo;

    /**
     * Specifies the type of the displayed information - phone number, mobile number, e-mail, link, text or
     * a link to another QuickViewPage. Default value is 'text'.
     */
    type?:
      | (QuickViewGroupElementType | keyof typeof QuickViewGroupElementType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies the ID of the QuickViewPage, which is opened from the link in the QuickViewGroupElement. Works
     * only with QuickViewGroupElement of type pageLink.
     */
    pageLinkId?: string | PropertyBindingInfo;

    /**
     * The subject of the email. Works only with QuickViewGroupElement of type email.
     */
    emailSubject?: string | PropertyBindingInfo;
  }
}

declare module "sap/m/QuickViewPage" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import QuickViewGroup from "sap/m/QuickViewGroup";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Avatar from "sap/m/Avatar";

  import { URI } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * QuickViewPage consists of a page header, an avatar, an object name with short description, and an object
   * information divided in groups. The control uses the sap.m.SimpleForm control to display information.
   *
   * @since 1.28.11
   */
  export default class QuickViewPage extends Control {
    /**
     * Constructor for a new QuickViewPage.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $QuickViewPageSettings
    );
    /**
     * Constructor for a new QuickViewPage.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $QuickViewPageSettings
    );

    /**
     * Creates a new subclass of class sap.m.QuickViewPage with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, QuickViewPage>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.QuickViewPage.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some group to the aggregation {@link #getGroups groups}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addGroup(
      /**
       * The group to add; if empty, nothing is inserted
       */
      oGroup: QuickViewGroup
    ): this;
    /**
     * Binds aggregation {@link #getAvatar avatar} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     * @since 1.92
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindAvatar(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Binds aggregation {@link #getGroups groups} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindGroups(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys the avatar in the aggregation {@link #getAvatar avatar}.
     *
     * @since 1.92
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyAvatar(): this;
    /**
     * Destroys all the groups in the aggregation {@link #getGroups groups}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyGroups(): this;
    /**
     * Gets content of aggregation {@link #getAvatar avatar}.
     *
     * Specifies the avatar displayed under the header of the page. **Note:** To achieve the recommended design
     * and behavior don't use the `displaySize`, `customDisplaySize`, `customFontSize` properties and `detailBox`
     * aggregation of `sap.m.Avatar`.
     *
     * @since 1.92
     */
    getAvatar(): Avatar;
    /**
     * Gets current value of property {@link #getCrossAppNavCallback crossAppNavCallback}.
     *
     * Specifies the application which provides target and param configuration for cross-application navigation
     * from the 'page header'.
     *
     * @deprecated As of version 1.111. Attach listener to the avatar `press` event and perform navigation as
     * appropriate in your environment instead.
     *
     * @returns Value of property `crossAppNavCallback`
     */
    getCrossAppNavCallback(): () => {
      target: object;

      params: object;
    };
    /**
     * Gets current value of property {@link #getDescription description}.
     *
     * Specifies the text displayed under the header of the content section.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `description`
     */
    getDescription(): string;
    /**
     * Gets current value of property {@link #getFallbackIcon fallbackIcon}.
     *
     * Defines the fallback icon displayed in case of wrong image src or loading issues.
     *
     * **Note:** Accepted values are only icons from the SAP icon font.
     *
     * @since 1.69
     * @deprecated As of version 1.92. Use the `avatar` aggregation and use its property `fallbackIcon` instead.
     *
     * @returns Value of property `fallbackIcon`
     */
    getFallbackIcon(): URI;
    /**
     * Gets content of aggregation {@link #getGroups groups}.
     *
     * QuickViewGroup consists of a title (optional) and an entity of group elements.
     */
    getGroups(): QuickViewGroup[];
    /**
     * Gets current value of property {@link #getHeader header}.
     *
     * Specifies the text displayed in the header of the control.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `header`
     */
    getHeader(): string;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Specifies the URL of the icon or image displayed under the header of the page.
     *
     * Default value is `empty string`.
     *
     * @deprecated As of version 1.92. Use the `avatar` aggregation instead.
     *
     * @returns Value of property `icon`
     */
    getIcon(): string;
    /**
     * Gets current value of property {@link #getPageId pageId}.
     *
     * Page id
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `pageId`
     */
    getPageId(): string;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Specifies the text displayed in the header of the content section of the control.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getTitleUrl titleUrl}.
     *
     * Specifies the URL which opens when the title or the avatar is clicked. **Note:** If the avatar has `press`
     * listeners this URL is not opened automatically.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `titleUrl`
     */
    getTitleUrl(): string;
    /**
     * Checks for the provided `sap.m.QuickViewGroup` in the aggregation {@link #getGroups groups}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfGroup(
      /**
       * The group whose index is looked for
       */
      oGroup: QuickViewGroup
    ): int;
    /**
     * Inserts a group into the aggregation {@link #getGroups groups}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertGroup(
      /**
       * The group to insert; if empty, nothing is inserted
       */
      oGroup: QuickViewGroup,
      /**
       * The `0`-based index the group should be inserted at; for a negative value of `iIndex`, the group is inserted
       * at position 0; for a value greater than the current size of the aggregation, the group is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getGroups groups}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllGroups(): QuickViewGroup[];
    /**
     * Removes a group from the aggregation {@link #getGroups groups}.
     *
     *
     * @returns The removed group or `null`
     */
    removeGroup(
      /**
       * The group to remove or its index or id
       */
      vGroup: int | string | QuickViewGroup
    ): QuickViewGroup | null;
    /**
     * Sets the aggregated {@link #getAvatar avatar}.
     *
     * @since 1.92
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAvatar(
      /**
       * The avatar to set
       */
      oAvatar: Avatar
    ): this;
    /**
     * Sets a new value for property {@link #setCrossAppNavCallback crossAppNavCallback}.
     *
     * Specifies the application which provides target and param configuration for cross-application navigation
     * from the 'page header'.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @deprecated As of version 1.111. Attach listener to the avatar `press` event and perform navigation as
     * appropriate in your environment instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCrossAppNavCallback(
      /**
       * New value for property `crossAppNavCallback`
       */
      oCrossAppNavCallback?: () => {
        target: object;

        params: object;
      }
    ): this;
    /**
     * Sets a new value for property {@link #getDescription description}.
     *
     * Specifies the text displayed under the header of the content section.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDescription(
      /**
       * New value for property `description`
       */
      sDescription?: string
    ): this;
    /**
     * Sets a new value for property {@link #getFallbackIcon fallbackIcon}.
     *
     * Defines the fallback icon displayed in case of wrong image src or loading issues.
     *
     * **Note:** Accepted values are only icons from the SAP icon font.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.69
     * @deprecated As of version 1.92. Use the `avatar` aggregation and use its property `fallbackIcon` instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFallbackIcon(
      /**
       * New value for property `fallbackIcon`
       */
      sFallbackIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getHeader header}.
     *
     * Specifies the text displayed in the header of the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeader(
      /**
       * New value for property `header`
       */
      sHeader?: string
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Specifies the URL of the icon or image displayed under the header of the page.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @deprecated As of version 1.92. Use the `avatar` aggregation instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: string
    ): this;
    /**
     * Sets a new value for property {@link #getPageId pageId}.
     *
     * Page id
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPageId(
      /**
       * New value for property `pageId`
       */
      sPageId?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Specifies the text displayed in the header of the content section of the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitleUrl titleUrl}.
     *
     * Specifies the URL which opens when the title or the avatar is clicked. **Note:** If the avatar has `press`
     * listeners this URL is not opened automatically.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleUrl(
      /**
       * New value for property `titleUrl`
       */
      sTitleUrl?: string
    ): this;
    /**
     * Unbinds aggregation {@link #getAvatar avatar} from model data.
     *
     * @since 1.92
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindAvatar(): this;
    /**
     * Unbinds aggregation {@link #getGroups groups} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindGroups(): this;
  }
  /**
   * Describes the settings that can be provided to the QuickViewPage constructor.
   */
  export interface $QuickViewPageSettings extends $ControlSettings {
    /**
     * Page id
     */
    pageId?: string | PropertyBindingInfo;

    /**
     * Specifies the text displayed in the header of the control.
     */
    header?: string | PropertyBindingInfo;

    /**
     * Specifies the text displayed in the header of the content section of the control.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Specifies the URL which opens when the title or the avatar is clicked. **Note:** If the avatar has `press`
     * listeners this URL is not opened automatically.
     */
    titleUrl?: string | PropertyBindingInfo;

    /**
     * Specifies the application which provides target and param configuration for cross-application navigation
     * from the 'page header'.
     *
     * @deprecated As of version 1.111. Attach listener to the avatar `press` event and perform navigation as
     * appropriate in your environment instead.
     */
    crossAppNavCallback?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the text displayed under the header of the content section.
     */
    description?: string | PropertyBindingInfo;

    /**
     * Specifies the URL of the icon or image displayed under the header of the page.
     *
     * @deprecated As of version 1.92. Use the `avatar` aggregation instead.
     */
    icon?: string | PropertyBindingInfo;

    /**
     * Defines the fallback icon displayed in case of wrong image src or loading issues.
     *
     * **Note:** Accepted values are only icons from the SAP icon font.
     *
     * @since 1.69
     * @deprecated As of version 1.92. Use the `avatar` aggregation and use its property `fallbackIcon` instead.
     */
    fallbackIcon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * QuickViewGroup consists of a title (optional) and an entity of group elements.
     */
    groups?:
      | QuickViewGroup[]
      | QuickViewGroup
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Specifies the avatar displayed under the header of the page. **Note:** To achieve the recommended design
     * and behavior don't use the `displaySize`, `customDisplaySize`, `customFontSize` properties and `detailBox`
     * aggregation of `sap.m.Avatar`.
     *
     * @since 1.92
     */
    avatar?: Avatar;
  }
}

declare module "sap/m/RadioButton" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IFormContent,
    ID,
    AccessibilityInfo,
    TextAlign,
    TextDirection,
    ValueState,
    CSSSize,
  } from "sap/ui/core/library";

  import { IToolbarInteractiveControl, WrappingType } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * RadioButton is a control similar to a {@link sap.m.CheckBox checkbox}, but it allows you to choose only
   * one of the predefined set of options. Multiple radio buttons have to belong to the same group (have the
   * same value for `groupName`) in order to be mutually exclusive.
   *
   * It is recommended to use the wrapper control {@link sap.m.RadioButtonGroup RadioButtonGroup} instead
   * of individual radio buttons. This will provide better screen reader support for the user. Use the `RadioButton`
   * control on its own only if there is a wrapper control that handles the screen reader support. For example,
   * such wrappers are sap.m.List, sap.m.Table and sap.f.GridList.
   *
   * Structure:
   * 	 - Radio buttons can have a value state like Error or Warning.
   * 	 - Radio buttons can be arranged vertically by setting the `column` to a number higher than 1.
   * 	 - Radio button options need to have a {@link sap.m.Label label}.  Usage: When to use::
   * 	 - You quickly need to choose between at least two alternatives.
   * 	 - You need to place other controls between the radio button options.  When not to use::
   * 	 - You want to select multiple values for the same option. Use {@link sap.m.CheckBox checkboxes} instead.
   *
   * 	 - When the default value is recommended for most users in most situations. Use a {@link sap.m.Select drop-down }
   *     instead as is saves space by not showing all the alternatives.
   * 	 - You want have more than 8 options. Use a {@link sap.m.Select drop-down} instead.
   * 	 - When the options are mutually exclusive e.g. ON/OFF. Use a {@link sap.m.Switch switch} instead.
   * 	 - Avoid using horizontally aligned radio buttons as they will be cut off on phones.
   *
   * **Note:** The order in which the RadioButtons will be selected one after another is determined upon instantiation
   * of the control. This order is consistent with the ARIA attributes for position, which the same button
   * will receive when added to specific group.
   *
   * **Example:** If three buttons are created (`button1, button2, button3`) in consecutive order, initially
   * they will have the same positions and TAB order. However if after that `button1` and `button3` are moved
   * to a new group and then `button2` is added to the same group, their TAB order and position in this group
   * will be `button1, button3, button2`.
   */
  export default class RadioButton
    extends Control
    implements IFormContent, IToolbarInteractiveControl
  {
    __implements__sap_ui_core_IFormContent: boolean;
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new RadioButton.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/radio-button/ Radio Button}
     */
    constructor(
      /**
       * Initial settings for the new control Enables users to select a single option from a set of options.
       */
      mSettings?: $RadioButtonSettings
    );
    /**
     * Constructor for a new RadioButton.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/radio-button/ Radio Button}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control Enables users to select a single option from a set of options.
       */
      mSettings?: $RadioButtonSettings
    );

    /**
     * Creates a new subclass of class sap.m.RadioButton with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, RadioButton>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.RadioButton.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Maintains the RadioButton's internal Label's text property.
     */
    _updateLabelProperties(
      /**
       * The text to be set
       */
      sText: string
    ): void;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:select select} event of this `sap.m.RadioButton`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.RadioButton` itself.
     *
     * Event is triggered when the user makes a change on the radio button (selecting or unselecting it).
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: RadioButton$SelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.RadioButton` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:select select} event of this `sap.m.RadioButton`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.RadioButton` itself.
     *
     * Event is triggered when the user makes a change on the radio button (selecting or unselecting it).
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: RadioButton$SelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.RadioButton` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:select select} event of this `sap.m.RadioButton`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: RadioButton$SelectEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:select select} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: RadioButton$SelectEventParameters
    ): this;
    /**
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The `sap.m.RadioButton` accessibility information
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Gets current value of property {@link #getActiveHandling activeHandling}.
     *
     * This is a flag to switch on activeHandling. When it is switched off, there will not be visual changes
     * on active state. Default value is 'true'
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `activeHandling`
     */
    getActiveHandling(): boolean;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getEditable editable}.
     *
     * Specifies whether the user can select the radio button.
     *
     * Default value is `true`.
     *
     * @since 1.25
     *
     * @returns Value of property `editable`
     */
    getEditable(): boolean;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Specifies if the radio button is disabled.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets current value of property {@link #getGroupName groupName}.
     *
     * Name of the radio button group the current radio button belongs to. You can define a new name for the
     * group. If no new name is specified, this radio button belongs to the sapMRbDefaultGroup per default.
     * Default behavior of a radio button in a group is that when one of the radio buttons in a group is selected,
     * all others are unselected.
     *
     * **Note** To ensure screen reader support it is recommended to use the {@link sap.m.RadioButtonGroup RadioButtonGroup }
     * wrapper instead of using the `groupName` property. Use this property only in cases where a wrapper control
     * will handle the screen reader support. For example such wrappers are `sap.m.List`, `sap.m.Table` and
     * `sap.f.GridList`.
     *
     * Default value is `'sapMRbDefaultGroup'`.
     *
     *
     * @returns Value of property `groupName`
     */
    getGroupName(): string;
    /**
     * Gets current value of property {@link #getSelected selected}.
     *
     * Specifies the select state of the radio button
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `selected`
     */
    getSelected(): boolean;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Specifies the text displayed next to the RadioButton
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getTextAlign textAlign}.
     *
     * Specifies the alignment of the radio button. Available alignment settings are "Begin", "Center", "End",
     * "Left", and "Right".
     *
     * Default value is `Begin`.
     *
     * @since 1.28
     *
     * @returns Value of property `textAlign`
     */
    getTextAlign(): TextAlign;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * Options for the text direction are RTL and LTR. Alternatively, the control can inherit the text direction
     * from its parent container.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getUseEntireWidth useEntireWidth}.
     *
     * Indicates if the given width will be applied for the whole RadioButton or only it's label. By Default
     * width is set only for the label.
     *
     * Default value is `false`.
     *
     * @since 1.42
     *
     * @returns Value of property `useEntireWidth`
     */
    getUseEntireWidth(): boolean;
    /**
     * Gets current value of property {@link #getValueState valueState}.
     *
     * Marker for the correctness of the current value e.g., Error, Success, etc.
     *
     * Default value is `None`.
     *
     * @since 1.25
     *
     * @returns Value of property `valueState`
     */
    getValueState(): ValueState;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Width of the RadioButton or it's label depending on the useEntireWidth property. By Default width is
     * set only for the label.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getWrapping wrapping}.
     *
     * Determines the wrapping of the text within the `Radio Button` label. When set to `false` (default), the
     * label text will be truncated and an ellipsis will be added at the end. If set to `true`, the label text
     * will wrap.
     *
     * Default value is `false`.
     *
     * @since 1.126
     *
     * @returns Value of property `wrapping`
     */
    getWrapping(): boolean;
    /**
     * Gets current value of property {@link #getWrappingType wrappingType}.
     *
     * Defines the type of wrapping to be used for the label text (hyphenated or normal).
     *
     * Default value is `Normal`.
     *
     * @since 1.126
     *
     * @returns Value of property `wrappingType`
     */
    getWrappingType(): WrappingType;
    /**
     * Pseudo event for pseudo 'select' event... space, enter, ... without modifiers (Ctrl, Alt or Shift)
     */
    onsapselect(
      /**
       * provides information for the event
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getActiveHandling activeHandling}.
     *
     * This is a flag to switch on activeHandling. When it is switched off, there will not be visual changes
     * on active state. Default value is 'true'
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setActiveHandling(
      /**
       * New value for property `activeHandling`
       */
      bActiveHandling?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEditable editable}.
     *
     * Specifies whether the user can select the radio button.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.25
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEditable(
      /**
       * New value for property `editable`
       */
      bEditable?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Specifies if the radio button is disabled.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets RadioButton's groupName. Only one radioButton from the same group can be selected
     *
     *
     * @returns Reference to the control instance for chaining
     */
    setGroupName(
      /**
       * Name of the group to which the RadioButton will belong.
       */
      sGroupName: string
    ): this;
    /**
     * Sets the state of the RadioButton to selected.
     *
     *
     * @returns Reference to the control instance for chaining
     */
    setSelected(
      /**
       * defines if the radio button is selected
       */
      bSelected: boolean
    ): this;
    /**
     * Sets the tab index of the control
     *
     * @since 1.16
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    setTabIndex(
      /**
       * Greater than or equal to -1
       */
      iTabIndex: int
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Specifies the text displayed next to the RadioButton
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTextAlign textAlign}.
     *
     * Specifies the alignment of the radio button. Available alignment settings are "Begin", "Center", "End",
     * "Left", and "Right".
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Begin`.
     *
     * @since 1.28
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextAlign(
      /**
       * New value for property `textAlign`
       */
      sTextAlign?: TextAlign | keyof typeof TextAlign
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * Options for the text direction are RTL and LTR. Alternatively, the control can inherit the text direction
     * from its parent container.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getUseEntireWidth useEntireWidth}.
     *
     * Indicates if the given width will be applied for the whole RadioButton or only it's label. By Default
     * width is set only for the label.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.42
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUseEntireWidth(
      /**
       * New value for property `useEntireWidth`
       */
      bUseEntireWidth?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getValueState valueState}.
     *
     * Marker for the correctness of the current value e.g., Error, Success, etc.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     * @since 1.25
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueState(
      /**
       * New value for property `valueState`
       */
      sValueState?: ValueState | keyof typeof ValueState
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Width of the RadioButton or it's label depending on the useEntireWidth property. By Default width is
     * set only for the label.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getWrapping wrapping}.
     *
     * Determines the wrapping of the text within the `Radio Button` label. When set to `false` (default), the
     * label text will be truncated and an ellipsis will be added at the end. If set to `true`, the label text
     * will wrap.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.126
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWrapping(
      /**
       * New value for property `wrapping`
       */
      bWrapping?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getWrappingType wrappingType}.
     *
     * Defines the type of wrapping to be used for the label text (hyphenated or normal).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Normal`.
     *
     * @since 1.126
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWrappingType(
      /**
       * New value for property `wrappingType`
       */
      sWrappingType?: WrappingType | keyof typeof WrappingType
    ): this;
  }
  /**
   * Describes the settings that can be provided to the RadioButton constructor.
   */
  export interface $RadioButtonSettings extends $ControlSettings {
    /**
     * Specifies if the radio button is disabled.
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the select state of the radio button
     */
    selected?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Name of the radio button group the current radio button belongs to. You can define a new name for the
     * group. If no new name is specified, this radio button belongs to the sapMRbDefaultGroup per default.
     * Default behavior of a radio button in a group is that when one of the radio buttons in a group is selected,
     * all others are unselected.
     *
     * **Note** To ensure screen reader support it is recommended to use the {@link sap.m.RadioButtonGroup RadioButtonGroup }
     * wrapper instead of using the `groupName` property. Use this property only in cases where a wrapper control
     * will handle the screen reader support. For example such wrappers are `sap.m.List`, `sap.m.Table` and
     * `sap.f.GridList`.
     */
    groupName?: string | PropertyBindingInfo;

    /**
     * Specifies the text displayed next to the RadioButton
     */
    text?: string | PropertyBindingInfo;

    /**
     * Options for the text direction are RTL and LTR. Alternatively, the control can inherit the text direction
     * from its parent container.
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Width of the RadioButton or it's label depending on the useEntireWidth property. By Default width is
     * set only for the label.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates if the given width will be applied for the whole RadioButton or only it's label. By Default
     * width is set only for the label.
     *
     * @since 1.42
     */
    useEntireWidth?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This is a flag to switch on activeHandling. When it is switched off, there will not be visual changes
     * on active state. Default value is 'true'
     */
    activeHandling?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies whether the user can select the radio button.
     *
     * @since 1.25
     */
    editable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Marker for the correctness of the current value e.g., Error, Success, etc.
     *
     * @since 1.25
     */
    valueState?:
      | (ValueState | keyof typeof ValueState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies the alignment of the radio button. Available alignment settings are "Begin", "Center", "End",
     * "Left", and "Right".
     *
     * @since 1.28
     */
    textAlign?:
      | (TextAlign | keyof typeof TextAlign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the wrapping of the text within the `Radio Button` label. When set to `false` (default), the
     * label text will be truncated and an ellipsis will be added at the end. If set to `true`, the label text
     * will wrap.
     *
     * @since 1.126
     */
    wrapping?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the type of wrapping to be used for the label text (hyphenated or normal).
     *
     * @since 1.126
     */
    wrappingType?:
      | (WrappingType | keyof typeof WrappingType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Association to controls / IDs which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Association to controls / IDs which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Event is triggered when the user makes a change on the radio button (selecting or unselecting it).
     */
    select?: (oEvent: RadioButton$SelectEvent) => void;
  }

  /**
   * Parameters of the RadioButton#select event.
   */
  export interface RadioButton$SelectEventParameters {
    /**
     * Checks whether the RadioButton is active or not.
     */
    selected?: boolean;
  }

  /**
   * Event object of the RadioButton#select event.
   */
  export type RadioButton$SelectEvent = Event<
    RadioButton$SelectEventParameters,
    RadioButton
  >;
}

declare module "sap/m/RadioButtonGroup" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IFormContent,
    ISemanticFormContent,
    ID,
    TextDirection,
    ValueState,
    CSSSize,
  } from "sap/ui/core/library";

  import RadioButton from "sap/m/RadioButton";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Event from "sap/ui/base/Event";

  /**
   * This control is used as a wrapper for a group of {@link sap.m.RadioButton} controls, which can be used
   * as a single UI element. You can select only one of the grouped radio buttons at a time. Structure:
   *
   * 	 - The radio buttons are stored in the `buttons` aggregation.
   * 	 - By setting the `columns` property, you can create layouts like a 'matrix', 'vertical' or 'horizontal'.
   *
   * 	 - **Note:**For proper display on all devices, we recommend creating radio button groups with only one
   *     row or only one column.  Usage: When to use::
   * 	 - You want to attach a single event handler on a group of buttons, rather than on each individual button.
   *      When not to use::
   * 	 - Do not put two radio button groups right next to each other as it is difficult to determine which
   *     buttons belong to which group.
   *
   * @since 1.25.0
   */
  export default class RadioButtonGroup
    extends Control
    implements IFormContent, ISemanticFormContent
  {
    __implements__sap_ui_core_IFormContent: boolean;
    __implements__sap_ui_core_ISemanticFormContent: boolean;
    /**
     * Constructor for a new RadioButtonGroup.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control A wrapper control for a group of radio buttons.
       */
      mSettings?: $RadioButtonGroupSettings
    );
    /**
     * Constructor for a new RadioButtonGroup.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control A wrapper control for a group of radio buttons.
       */
      mSettings?: $RadioButtonGroupSettings
    );

    /**
     * Creates a new subclass of class sap.m.RadioButtonGroup with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, RadioButtonGroup>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.RadioButtonGroup.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds a new radio button to the group.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    addButton(
      /**
       * The button which will be added to the group.
       */
      oButton: RadioButton
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:select select} event of this `sap.m.RadioButtonGroup`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.RadioButtonGroup` itself.
     *
     * Fires when selection is changed by user interaction.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: RadioButtonGroup$SelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.RadioButtonGroup` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:select select} event of this `sap.m.RadioButtonGroup`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.RadioButtonGroup` itself.
     *
     * Fires when selection is changed by user interaction.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: RadioButtonGroup$SelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.RadioButtonGroup` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getButtons buttons} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindButtons(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Creates a new instance of RadioButtonGroup, with the same settings as the RadioButtonGroup on which the
     * method is called. Event handlers are not cloned.
     *
     *
     * @returns New instance of RadioButtonGroup
     */
    clone(): this;
    /**
     * Destroys all radio buttons.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    destroyButtons(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:select select} event of this `sap.m.RadioButtonGroup`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: RadioButtonGroup$SelectEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Exits the radio button group.
     */
    exit(): void;
    /**
     * Fires event {@link #event:select select} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: RadioButtonGroup$SelectEventParameters
    ): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets content of aggregation {@link #getButtons buttons}.
     *
     * Returns a list of the RadioButtons in a RadioButtonGroup
     */
    getButtons(): RadioButton[];
    /**
     * Gets current value of property {@link #getColumns columns}.
     *
     * Specifies the maximum number of radio buttons displayed in one line.
     *
     * Default value is `1`.
     *
     *
     * @returns Value of property `columns`
     */
    getColumns(): int;
    /**
     * Gets current value of property {@link #getEditable editable}.
     *
     * Specifies whether the user can change the selected value of the RadioButtonGroup. When the property is
     * set to false, the control obtains visual styles different from its visual styles for the normal and the
     * disabled state. Additionally, the control is no longer interactive, but can receive focus.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `editable`
     */
    getEditable(): boolean;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Switches the enabled state of the control. All radio buttons inside a disabled group are disabled.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Returns the selected radio button.
     *
     *
     * @returns The selected radio button.
     */
    getSelectedButton(): RadioButton;
    /**
     * Gets current value of property {@link #getSelectedIndex selectedIndex}.
     *
     * Determines the index of the selected/checked RadioButton. Default is 0. If no radio button is selected,
     * the selectedIndex property will return -1.
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `selectedIndex`
     */
    getSelectedIndex(): int;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * This property specifies the element's text directionality with enumerated options. By default, the control
     * inherits text direction from the DOM.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getValueState valueState}.
     *
     * Marker for the correctness of the current value e.g., Error, Success, etc. Changing this property will
     * also change the state of all radio buttons inside the group. Note: Setting this attribute to sap.ui.core.ValueState.Error
     * when the accessibility feature is enabled, sets the value of the invalid property for the whole RadioButtonGroup
     * to "true".
     *
     * Default value is `None`.
     *
     *
     * @returns Value of property `valueState`
     */
    getValueState(): ValueState;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Specifies the width of the RadioButtonGroup.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Checks for the provided `sap.m.RadioButton` in the aggregation {@link #getButtons buttons}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfButton(
      /**
       * The button whose index is looked for
       */
      oButton: RadioButton
    ): int;
    /**
     * Adds a new radio button to the group at a specified index.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    insertButton(
      /**
       * The radio button which will be added to the group.
       */
      oButton: RadioButton,
      /**
       * The index, at which the radio button will be added.
       */
      iIndex: number
    ): this;
    /**
     * Overwrites the onAfterRendering
     */
    onAfterRendering(): void;
    /**
     * Overwrites the onBeforeRendering method.
     */
    onBeforeRendering(): void;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all radio buttons.
     *
     *
     * @returns Array of removed buttons.
     */
    removeAllButtons(): RadioButton[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes a radio button from the group.
     *
     *
     * @returns vElement The removed radio button.
     */
    removeButton(
      /**
       * The button to remove
       */
      vElement: int | ID | RadioButton
    ): RadioButton;
    /**
     * Sets a new value for property {@link #getColumns columns}.
     *
     * Specifies the maximum number of radio buttons displayed in one line.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `1`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setColumns(
      /**
       * New value for property `columns`
       */
      iColumns?: int
    ): this;
    /**
     * Sets the editable property of the RadioButtonGroup. Single buttons preserve the value of their editable
     * property. If the group is set to editable=false the buttons are also displayed and function as read only.
     * Non editable radio buttons can still obtain focus.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    setEditable(
      /**
       * Defines whether the radio buttons should be interactive.
       */
      bEditable: boolean
    ): this;
    /**
     * Sets the enabled property of the RadioButtonGroup. Single buttons preserve internally the value of their
     * enabled property. If the group is set to enabled=false the buttons are also displayed as disabled and
     * getEnabled returns false.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    setEnabled(
      /**
       * Defines whether the radio buttons should be interactive.
       */
      bEnabled: boolean
    ): this;
    /**
     * Sets the selected sap.m.RadioButton using sap.m.RadioButton.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    setSelectedButton(
      /**
       * The item to be selected.
       */
      oSelectedButton: RadioButton
    ): this;
    /**
     * Sets the selected sap.m.RadioButton using index.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    setSelectedIndex(
      /**
       * The index of the radio button which has to be selected.
       */
      iSelectedIndex: number
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * This property specifies the element's text directionality with enumerated options. By default, the control
     * inherits text direction from the DOM.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getValueState valueState}.
     *
     * Marker for the correctness of the current value e.g., Error, Success, etc. Changing this property will
     * also change the state of all radio buttons inside the group. Note: Setting this attribute to sap.ui.core.ValueState.Error
     * when the accessibility feature is enabled, sets the value of the invalid property for the whole RadioButtonGroup
     * to "true".
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueState(
      /**
       * New value for property `valueState`
       */
      sValueState?: ValueState | keyof typeof ValueState
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Specifies the width of the RadioButtonGroup.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Unbinds aggregation {@link #getButtons buttons} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindButtons(): this;
    /**
     * Updates the buttons in the group.
     */
    updateButtons(): void;
  }
  /**
   * Describes the settings that can be provided to the RadioButtonGroup constructor.
   */
  export interface $RadioButtonGroupSettings extends $ControlSettings {
    /**
     * Specifies the width of the RadioButtonGroup.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the maximum number of radio buttons displayed in one line.
     */
    columns?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies whether the user can change the selected value of the RadioButtonGroup. When the property is
     * set to false, the control obtains visual styles different from its visual styles for the normal and the
     * disabled state. Additionally, the control is no longer interactive, but can receive focus.
     */
    editable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Marker for the correctness of the current value e.g., Error, Success, etc. Changing this property will
     * also change the state of all radio buttons inside the group. Note: Setting this attribute to sap.ui.core.ValueState.Error
     * when the accessibility feature is enabled, sets the value of the invalid property for the whole RadioButtonGroup
     * to "true".
     */
    valueState?:
      | (ValueState | keyof typeof ValueState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the index of the selected/checked RadioButton. Default is 0. If no radio button is selected,
     * the selectedIndex property will return -1.
     */
    selectedIndex?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Switches the enabled state of the control. All radio buttons inside a disabled group are disabled.
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This property specifies the element's text directionality with enumerated options. By default, the control
     * inherits text direction from the DOM.
     *
     * @since 1.28.0
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Returns a list of the RadioButtons in a RadioButtonGroup
     */
    buttons?:
      | RadioButton[]
      | RadioButton
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Association to controls / IDs which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Association to controls / IDs which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Fires when selection is changed by user interaction.
     */
    select?: (oEvent: RadioButtonGroup$SelectEvent) => void;
  }

  /**
   * Parameters of the RadioButtonGroup#select event.
   */
  export interface RadioButtonGroup$SelectEventParameters {
    /**
     * Index of the selected RadioButton.
     */
    selectedIndex?: int;
  }

  /**
   * Event object of the RadioButtonGroup#select event.
   */
  export type RadioButtonGroup$SelectEvent = Event<
    RadioButtonGroup$SelectEventParameters,
    RadioButtonGroup
  >;
}

declare module "sap/m/RangeSlider" {
  import { default as Slider, $SliderSettings } from "sap/m/Slider";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Represents a numerical interval and two handles to select a sub-range within it. Overview: The purpose
   * of the control is to enable visual selection of sub-ranges within a given interval. Notes:
   *
   * 	 - The RangeSlider extends the functionality of the {@link sap.m.Slider Slider}
   * 	 - The right and left handle can be moved individually and their positions could therefore switch.
   * 	 - The entire range can be moved along the interval.
   * 	 - The right and left handle can select the same value
   *
   * Usage: The most common usecase is to select and move sub-ranges on a continuous numerical scale.
   *
   * Responsive Behavior: You can move the currently selected range by clicking on it and dragging it along
   * the interval.
   *
   * @since 1.38
   */
  export default class RangeSlider extends Slider {
    /**
     * Constructor for a new `RangeSlider`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/range-slider/ Range Slider}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $RangeSliderSettings
    );
    /**
     * Constructor for a new `RangeSlider`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/range-slider/ Range Slider}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $RangeSliderSettings
    );

    /**
     * Creates a new subclass of class sap.m.RangeSlider with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.Slider.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, RangeSlider>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.RangeSlider.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getRange range}.
     *
     * Determines the currently selected range on the slider.
     *
     * If the value is lower/higher than the allowed minimum/maximum, a warning message will be output to the
     * console.
     *
     * Default value is `[0, 100]`.
     *
     *
     * @returns Value of property `range`
     */
    getRange(): float[];
    /**
     * Gets current value of property {@link #getValue2 value2}.
     *
     * Current second value of the slider. (Position of the second handle.)
     *
     * **Note:** If the value is not in the valid range (between `min` and `max`) it will be changed to be in
     * the valid range. If it is smaller than `value` it will be set to the same value.
     *
     * Default value is `100`.
     *
     *
     * @returns Value of property `value2`
     */
    getValue2(): float;
    /**
     * Sets a new value for property {@link #getRange range}.
     *
     * Determines the currently selected range on the slider.
     *
     * If the value is lower/higher than the allowed minimum/maximum, a warning message will be output to the
     * console.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `[0, 100]`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRange(
      /**
       * New value for property `range`
       */
      sRange?: float[]
    ): this;
    /**
     * Sets a new value for property {@link #getValue2 value2}.
     *
     * Current second value of the slider. (Position of the second handle.)
     *
     * **Note:** If the value is not in the valid range (between `min` and `max`) it will be changed to be in
     * the valid range. If it is smaller than `value` it will be set to the same value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `100`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValue2(
      /**
       * New value for property `value2`
       */
      fValue2?: float
    ): this;
    /**
     * Updates values of the advanced tooltips.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    updateAdvancedTooltipDom(): void;
  }
  /**
   * Describes the settings that can be provided to the RangeSlider constructor.
   */
  export interface $RangeSliderSettings extends $SliderSettings {
    /**
     * Current second value of the slider. (Position of the second handle.)
     *
     * **Note:** If the value is not in the valid range (between `min` and `max`) it will be changed to be in
     * the valid range. If it is smaller than `value` it will be set to the same value.
     */
    value2?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the currently selected range on the slider.
     *
     * If the value is lower/higher than the allowed minimum/maximum, a warning message will be output to the
     * console.
     */
    range?: float[] | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/RatingIndicator" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { IFormContent, ID, URI, CSSSize } from "sap/ui/core/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { RatingIndicatorVisualMode } from "sap/m/library";

  import Event from "sap/ui/base/Event";

  /**
   * The rating indicator is used to display a specific number of icons that are used to rate an item. Additionally
   * it is also used to display the average over all ratings. Structure:
   * 	 - The rating indicator can use different icons (default: stars) which are defined as URIs in the properties
   *     `iconHovered`, `iconSelected` and `iconUnselected`.
   * 	 - The rating indicator can display half-values ({@link sap.m.RatingIndicatorVisualMode visualMode }
   *     = Half) when it is used to show the average. Half-values can't be selected by the user.  Usage:
   *     The preferred number of icons is between 5 (default) and 7. Responsive Behavior: You can display icons
   *     in 4 recommended sizes:
   * 	 - large - 32px
   * 	 - medium(default) - 24px
   * 	 - small - 22px
   * 	 - XS - 12px  **Note:** It is not recommended to use the XS size as an editable rating indicator.
   *     If an editable rating indicator is needed then it is recommended to set the size S or above to be compliant
   *     with minimum touch size. **Note:** If no icon size is set, the rating indicator will set it according
   *     to the content density.
   *
   * @since 1.14
   */
  export default class RatingIndicator extends Control implements IFormContent {
    __implements__sap_ui_core_IFormContent: boolean;
    /**
     * Constructor for a new RatingIndicator.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/rating-indicator/ Rating Indicator}
     */
    constructor(
      /**
       * Initial settings for the new control Enables users to rate an item on a numeric scale.
       */
      mSettings?: $RatingIndicatorSettings
    );
    /**
     * Constructor for a new RatingIndicator.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/rating-indicator/ Rating Indicator}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control Enables users to rate an item on a numeric scale.
       */
      mSettings?: $RatingIndicatorSettings
    );

    /**
     * Creates a new subclass of class sap.m.RatingIndicator with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, RatingIndicator>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.RatingIndicator.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.RatingIndicator`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.RatingIndicator` itself.
     *
     * The event is fired when the user has done a rating.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: RatingIndicator$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.RatingIndicator` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.RatingIndicator`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.RatingIndicator` itself.
     *
     * The event is fired when the user has done a rating.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: RatingIndicator$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.RatingIndicator` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.RatingIndicator`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.RatingIndicator` itself.
     *
     * This event is triggered during the dragging period, each time the rating value changes.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: RatingIndicator$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.RatingIndicator` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.RatingIndicator`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.RatingIndicator` itself.
     *
     * This event is triggered during the dragging period, each time the rating value changes.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: RatingIndicator$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.RatingIndicator` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds property {@link #getValue value} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindProperty ManagedObject.bindProperty} for a detailed description
     * of the possible properties of `oBindingInfo`
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindValue(
      /**
       * The binding information
       */
      oBindingInfo: PropertyBindingInfo
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:change change} event of this `sap.m.RatingIndicator`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: RatingIndicator$ChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:liveChange liveChange} event of this `sap.m.RatingIndicator`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLiveChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: RatingIndicator$LiveChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:change change} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: RatingIndicator$ChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:liveChange liveChange} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLiveChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: RatingIndicator$LiveChangeEventParameters
    ): this;
    /**
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Current accessibility state of the control
     */
    getAccessibilityInfo(): {
      role: string;

      type: string;

      description: string;

      focusable: boolean;

      enabled: boolean;

      editable: boolean;
    };
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getDisplayOnly displayOnly}.
     *
     * The RatingIndicator in displayOnly mode is not interactive, not editable, not focusable, and not in the
     * tab chain. This setting is used for forms in review mode.
     *
     * Default value is `false`.
     *
     * @since 1.50.0
     *
     * @returns Value of property `displayOnly`
     */
    getDisplayOnly(): boolean;
    /**
     * Gets current value of property {@link #getEditable editable}.
     *
     * Defines whether the user is allowed to edit the RatingIndicator. If editable is false the control is
     * focusable, and in the tab chain but not interactive.
     *
     * Default value is `true`.
     *
     * @since 1.52.0
     *
     * @returns Value of property `editable`
     */
    getEditable(): boolean;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Value "true" is required to let the user rate with this control. It is recommended to set this parameter
     * to "false" for the "Small" size which is meant for indicating a value only
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets current value of property {@link #getIconHovered iconHovered}.
     *
     * The URI to the icon font icon or image that will be displayed for hovered rating symbols. A star icon
     * will be used if the property is not set
     *
     *
     * @returns Value of property `iconHovered`
     */
    getIconHovered(): URI;
    /**
     * Gets current value of property {@link #getIconSelected iconSelected}.
     *
     * The URI to the icon font icon or image that will be displayed for selected rating symbols. A star icon
     * will be used if the property is not set
     *
     *
     * @returns Value of property `iconSelected`
     */
    getIconSelected(): URI;
    /**
     * Gets current value of property {@link #getIconSize iconSize}.
     *
     * The Size of the image or icon to be displayed. The default value depends on the theme. Please be sure
     * that the size is corresponding to a full pixel value as some browsers don't support subpixel calculations.
     * Recommended size is 1.5rem (24px) for normal, 1.375rem (22px) for small, and 2rem (32px) for large icons
     * correspondingly.
     *
     *
     * @returns Value of property `iconSize`
     */
    getIconSize(): CSSSize;
    /**
     * Gets current value of property {@link #getIconUnselected iconUnselected}.
     *
     * The URI to the icon font icon or image that will be displayed for all unselected rating symbols. A star
     * icon will be used if the property is not set
     *
     *
     * @returns Value of property `iconUnselected`
     */
    getIconUnselected(): URI;
    /**
     * Gets current value of property {@link #getMaxValue maxValue}.
     *
     * The number of displayed rating symbols
     *
     * Default value is `5`.
     *
     *
     * @returns Value of property `maxValue`
     */
    getMaxValue(): int;
    /**
     * Gets current value of property {@link #getRequired required}.
     *
     * Indicates that the control is required. This property is only needed for accessibility purposes when
     * a single relationship between the control and a label (see aggregation `labelFor` of `sap.m.Label`) cannot
     * be established (e.g. one label should label multiple controls).
     *
     * Default value is `false`.
     *
     * @since 1.116
     *
     * @returns Value of property `required`
     */
    getRequired(): boolean;
    /**
     * Gets current value of property {@link #getValue value}.
     *
     * The indicated value of the rating
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `value`
     */
    getValue(): float;
    /**
     * Gets current value of property {@link #getVisualMode visualMode}.
     *
     * Defines how float values are visualized: Full, Half (see enumeration RatingIndicatorVisualMode)
     *
     * Default value is `Half`.
     *
     *
     * @returns Value of property `visualMode`
     */
    getVisualMode(): RatingIndicatorVisualMode;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getDisplayOnly displayOnly}.
     *
     * The RatingIndicator in displayOnly mode is not interactive, not editable, not focusable, and not in the
     * tab chain. This setting is used for forms in review mode.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.50.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisplayOnly(
      /**
       * New value for property `displayOnly`
       */
      bDisplayOnly?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEditable editable}.
     *
     * Defines whether the user is allowed to edit the RatingIndicator. If editable is false the control is
     * focusable, and in the tab chain but not interactive.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.52.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEditable(
      /**
       * New value for property `editable`
       */
      bEditable?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Value "true" is required to let the user rate with this control. It is recommended to set this parameter
     * to "false" for the "Small" size which is meant for indicating a value only
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIconHovered iconHovered}.
     *
     * The URI to the icon font icon or image that will be displayed for hovered rating symbols. A star icon
     * will be used if the property is not set
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconHovered(
      /**
       * New value for property `iconHovered`
       */
      sIconHovered?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getIconSelected iconSelected}.
     *
     * The URI to the icon font icon or image that will be displayed for selected rating symbols. A star icon
     * will be used if the property is not set
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconSelected(
      /**
       * New value for property `iconSelected`
       */
      sIconSelected?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getIconSize iconSize}.
     *
     * The Size of the image or icon to be displayed. The default value depends on the theme. Please be sure
     * that the size is corresponding to a full pixel value as some browsers don't support subpixel calculations.
     * Recommended size is 1.5rem (24px) for normal, 1.375rem (22px) for small, and 2rem (32px) for large icons
     * correspondingly.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconSize(
      /**
       * New value for property `iconSize`
       */
      sIconSize?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getIconUnselected iconUnselected}.
     *
     * The URI to the icon font icon or image that will be displayed for all unselected rating symbols. A star
     * icon will be used if the property is not set
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconUnselected(
      /**
       * New value for property `iconUnselected`
       */
      sIconUnselected?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getMaxValue maxValue}.
     *
     * The number of displayed rating symbols
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `5`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxValue(
      /**
       * New value for property `maxValue`
       */
      iMaxValue?: int
    ): this;
    /**
     * Sets a new value for property {@link #getRequired required}.
     *
     * Indicates that the control is required. This property is only needed for accessibility purposes when
     * a single relationship between the control and a label (see aggregation `labelFor` of `sap.m.Label`) cannot
     * be established (e.g. one label should label multiple controls).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.116
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRequired(
      /**
       * New value for property `required`
       */
      bRequired?: boolean
    ): this;
    /**
     * Sets the rating value. The method is automatically checking whether the value is in the valid range of
     * 0-{@link #getMaxValue maxValue} and if it is a valid number. Calling the setter with null or undefined
     * will reset the value to it's default.
     *
     *
     * @returns Returns `this` to facilitate method chaining.
     */
    setValue(
      /**
       * The rating value to be set.
       */
      vValue: float | string
    ): this;
    /**
     * Sets a new value for property {@link #getVisualMode visualMode}.
     *
     * Defines how float values are visualized: Full, Half (see enumeration RatingIndicatorVisualMode)
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Half`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisualMode(
      /**
       * New value for property `visualMode`
       */
      sVisualMode?:
        | RatingIndicatorVisualMode
        | keyof typeof RatingIndicatorVisualMode
    ): this;
    /**
     * Unbinds property {@link #getValue value} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindValue(): this;
  }
  /**
   * Describes the settings that can be provided to the RatingIndicator constructor.
   */
  export interface $RatingIndicatorSettings extends $ControlSettings {
    /**
     * Value "true" is required to let the user rate with this control. It is recommended to set this parameter
     * to "false" for the "Small" size which is meant for indicating a value only
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The number of displayed rating symbols
     */
    maxValue?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * The indicated value of the rating
     */
    value?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * The Size of the image or icon to be displayed. The default value depends on the theme. Please be sure
     * that the size is corresponding to a full pixel value as some browsers don't support subpixel calculations.
     * Recommended size is 1.5rem (24px) for normal, 1.375rem (22px) for small, and 2rem (32px) for large icons
     * correspondingly.
     */
    iconSize?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * The URI to the icon font icon or image that will be displayed for selected rating symbols. A star icon
     * will be used if the property is not set
     */
    iconSelected?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * The URI to the icon font icon or image that will be displayed for all unselected rating symbols. A star
     * icon will be used if the property is not set
     */
    iconUnselected?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * The URI to the icon font icon or image that will be displayed for hovered rating symbols. A star icon
     * will be used if the property is not set
     */
    iconHovered?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines how float values are visualized: Full, Half (see enumeration RatingIndicatorVisualMode)
     */
    visualMode?:
      | (RatingIndicatorVisualMode | keyof typeof RatingIndicatorVisualMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The RatingIndicator in displayOnly mode is not interactive, not editable, not focusable, and not in the
     * tab chain. This setting is used for forms in review mode.
     *
     * @since 1.50.0
     */
    displayOnly?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether the user is allowed to edit the RatingIndicator. If editable is false the control is
     * focusable, and in the tab chain but not interactive.
     *
     * @since 1.52.0
     */
    editable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates that the control is required. This property is only needed for accessibility purposes when
     * a single relationship between the control and a label (see aggregation `labelFor` of `sap.m.Label`) cannot
     * be established (e.g. one label should label multiple controls).
     *
     * @since 1.116
     */
    required?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Association to controls / ids which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * The event is fired when the user has done a rating.
     */
    change?: (oEvent: RatingIndicator$ChangeEvent) => void;

    /**
     * This event is triggered during the dragging period, each time the rating value changes.
     */
    liveChange?: (oEvent: RatingIndicator$LiveChangeEvent) => void;
  }

  /**
   * Parameters of the RatingIndicator#change event.
   */
  export interface RatingIndicator$ChangeEventParameters {
    /**
     * The rated value
     */
    value?: int;
  }

  /**
   * Event object of the RatingIndicator#change event.
   */
  export type RatingIndicator$ChangeEvent = Event<
    RatingIndicator$ChangeEventParameters,
    RatingIndicator
  >;

  /**
   * Parameters of the RatingIndicator#liveChange event.
   */
  export interface RatingIndicator$LiveChangeEventParameters {
    /**
     * The current value of the rating after a live change event.
     */
    value?: float;
  }

  /**
   * Event object of the RatingIndicator#liveChange event.
   */
  export type RatingIndicator$LiveChangeEvent = Event<
    RatingIndicator$LiveChangeEventParameters,
    RatingIndicator
  >;
}

declare module "sap/m/ResponsivePopover" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { ID, CSSSize, URI } from "sap/ui/core/library";

  import Button from "sap/m/Button";

  import { IBar, PlacementType, TitleAlignment } from "sap/m/library";

  import Toolbar from "sap/m/Toolbar";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Popover from "sap/m/Popover";

  import Dialog from "sap/m/Dialog";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * Overview: The responsive popover acts as a {@link sap.m.Popover popover} on desktop and tablet, while
   * on phone it acts as a {@link sap.m.Dialog dialog} with `stretch` set to true.
   *
   * **Note:** It is recommended that `ResponsivePopover` is used in fragments otherwise there might be some
   * implications on the user experience. For example, on desktop, open or close functions of the `Popover`
   * might not be called.
   *
   * Usage: When you want to make sure that all content is visible on any device.
   *
   * @since 1.15.1
   */
  export default class ResponsivePopover extends Control {
    /**
     * Constructor for a new ResponsivePopover.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/popover/ Responsive Popover}
     */
    constructor(
      /**
       * Initial settings for the new control A popover-based control that behaves differently according to the
       * device it is on.
       */
      mSettings?: $ResponsivePopoverSettings
    );
    /**
     * Constructor for a new ResponsivePopover.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/popover/ Responsive Popover}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control A popover-based control that behaves differently according to the
       * device it is on.
       */
      mSettings?: $ResponsivePopoverSettings
    );

    /**
     * Creates a new subclass of class sap.m.ResponsivePopover with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ResponsivePopover>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ResponsivePopover.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds content to the ResponsivePopover
     */
    addContent(
      /**
       * The control to be added to the content
       */
      oControl: Control
    ): void;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterClose afterClose} event of this `sap.m.ResponsivePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ResponsivePopover` itself.
     *
     * Event is fired after popover or dialog is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ResponsivePopover$AfterCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ResponsivePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterClose afterClose} event of this `sap.m.ResponsivePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ResponsivePopover` itself.
     *
     * Event is fired after popover or dialog is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ResponsivePopover$AfterCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ResponsivePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterOpen afterOpen} event of this `sap.m.ResponsivePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ResponsivePopover` itself.
     *
     * Event is fired after popover or dialog is open.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ResponsivePopover$AfterOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ResponsivePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterOpen afterOpen} event of this `sap.m.ResponsivePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ResponsivePopover` itself.
     *
     * Event is fired after popover or dialog is open.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ResponsivePopover$AfterOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ResponsivePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.ResponsivePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ResponsivePopover` itself.
     *
     * Event is fired before popover or dialog is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ResponsivePopover$BeforeCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ResponsivePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.ResponsivePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ResponsivePopover` itself.
     *
     * Event is fired before popover or dialog is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ResponsivePopover$BeforeCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ResponsivePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.ResponsivePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ResponsivePopover` itself.
     *
     * Event is fired before popover or dialog is open.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ResponsivePopover$BeforeOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ResponsivePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.ResponsivePopover`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ResponsivePopover` itself.
     *
     * Event is fired before popover or dialog is open.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ResponsivePopover$BeforeOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ResponsivePopover` itself
       */
      oListener?: object
    ): this;
    /**
     * Closes the ResponsivePopover.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    close(): this;
    /**
     * Destroys the beginButton in the aggregation {@link #getBeginButton beginButton}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyBeginButton(): this;
    /**
     * Destroys all the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Destroys the customHeader in the aggregation {@link #getCustomHeader customHeader}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCustomHeader(): this;
    /**
     * Destroys the endButton in the aggregation {@link #getEndButton endButton}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyEndButton(): this;
    /**
     * Destroys the footer in the aggregation {@link #getFooter footer}.
     *
     * @since 1.129
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyFooter(): this;
    /**
     * Destroys the subHeader in the aggregation {@link #getSubHeader subHeader}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySubHeader(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterClose afterClose} event of this `sap.m.ResponsivePopover`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ResponsivePopover$AfterCloseEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterOpen afterOpen} event of this `sap.m.ResponsivePopover`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ResponsivePopover$AfterOpenEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeClose beforeClose} event of this `sap.m.ResponsivePopover`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ResponsivePopover$BeforeCloseEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeOpen beforeOpen} event of this `sap.m.ResponsivePopover`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ResponsivePopover$BeforeOpenEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:afterClose afterClose} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ResponsivePopover$AfterCloseEventParameters
    ): this;
    /**
     * Fires event {@link #event:afterOpen afterOpen} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ResponsivePopover$AfterOpenEventParameters
    ): this;
    /**
     * Fires event {@link #event:beforeClose beforeClose} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforeClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ResponsivePopover$BeforeCloseEventParameters
    ): this;
    /**
     * Fires event {@link #event:beforeOpen beforeOpen} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforeOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ResponsivePopover$BeforeOpenEventParameters
    ): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Getter for beginButton aggregation
     *
     *
     * @returns The button that is set as a beginButton aggregation
     */
    getBeginButton(): Button;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * Content is supported by both variants. Please see the documentation on sap.m.Popover#content and sap.m.Dialog#content
     */
    getContent(): Control[];
    /**
     * Gets current value of property {@link #getContentHeight contentHeight}.
     *
     * This property is supported by both variants. Please see the documentation on sap.m.Popover#contentHeight
     * and sap.m.Dialog#contentHeight
     *
     *
     * @returns Value of property `contentHeight`
     */
    getContentHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getContentWidth contentWidth}.
     *
     * This property is supported by both variants. Please see the documentation on sap.m.Popover#contentWidth
     * and sap.m.Dialog#contentWidth
     *
     *
     * @returns Value of property `contentWidth`
     */
    getContentWidth(): CSSSize;
    /**
     * Gets content of aggregation {@link #getCustomHeader customHeader}.
     *
     * CustomHeader is supported by both variants. Please see the documentation on sap.m.Popover#customHeader
     * and sap.m.Dialog#customHeader
     */
    getCustomHeader(): IBar;
    /**
     * Getter for endButton aggregation
     *
     *
     * @returns The button that is set as an endButton aggregation
     */
    getEndButton(): Button;
    /**
     * Gets content of aggregation {@link #getFooter footer}.
     *
     * The footer of this popover.
     *
     * @since 1.129
     */
    getFooter(): Toolbar;
    /**
     * Gets current value of property {@link #getHorizontalScrolling horizontalScrolling}.
     *
     * This property is supported by both variants. Please see the documentation on sap.m.Popover#horizontalScrolling
     * and sap.m.Dialog#horizontalScrolling
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `horizontalScrolling`
     */
    getHorizontalScrolling(): boolean;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * This property only takes effect on phone. Please see the documentation sap.m.Dialog#icon.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * ID of the element which is the current target of the association {@link #getInitialFocus initialFocus},
     * or `null`.
     */
    getInitialFocus(): ID | null;
    /**
     * Gets current value of property {@link #getModal modal}.
     *
     * This property only takes effect on desktop or tablet. Please see the documentation sap.m.Popover#modal.
     *
     *
     * @returns Value of property `modal`
     */
    getModal(): boolean;
    /**
     * Gets current value of property {@link #getOffsetX offsetX}.
     *
     * This property only takes effect on desktop or tablet. Please see the documentation sap.m.Popover#offsetX.
     *
     *
     * @returns Value of property `offsetX`
     */
    getOffsetX(): int;
    /**
     * Gets current value of property {@link #getOffsetY offsetY}.
     *
     * This property only takes effect on desktop or tablet. Please see the documentation sap.m.Popover#offsetY.
     *
     *
     * @returns Value of property `offsetY`
     */
    getOffsetY(): int;
    /**
     * Gets current value of property {@link #getPlacement placement}.
     *
     * This property only takes effect on desktop or tablet. Please see the documentation sap.m.Popover#placement.
     *
     * Default value is `Right`.
     *
     *
     * @returns Value of property `placement`
     */
    getPlacement(): PlacementType;
    /**
     * Gets current value of property {@link #getResizable resizable}.
     *
     * Whether resize option is enabled.
     *
     * Default value is `false`.
     *
     * @since 1.36.4
     *
     * @returns Value of property `resizable`
     */
    getResizable(): boolean;
    /**
     * Gets current value of property {@link #getShowArrow showArrow}.
     *
     * This property only takes effect on desktop or tablet. Please see the documentation sap.m.Popover#showArrow.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showArrow`
     */
    getShowArrow(): boolean;
    /**
     * Gets current value of property {@link #getShowCloseButton showCloseButton}.
     *
     * Determines if a close button should be inserted into the dialog's header dynamically to close the dialog.
     * This property only takes effect on phone. **Note:** The close button could be placed only in a sap.m.Bar
     * if a sap.m.Toolbar is passed as a header - the property will not take effect.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showCloseButton`
     */
    getShowCloseButton(): boolean;
    /**
     * Gets current value of property {@link #getShowHeader showHeader}.
     *
     * This property is supported by both variants. Please see the documentation on sap.m.Popover#showHeader
     * and sap.m.Dialog#showHeader
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showHeader`
     */
    getShowHeader(): boolean;
    /**
     * Gets content of aggregation {@link #getSubHeader subHeader}.
     *
     * SubHeader is supported by both variants. Please see the documentation on sap.m.Popover#subHeader and
     * sap.m.Dialog#subHeader
     */
    getSubHeader(): IBar;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * This property is supported by both variants. Please see the documentation on sap.m.Popover#title and
     * sap.m.Dialog#title
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getTitleAlignment titleAlignment}.
     *
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * Default value is `Auto`.
     *
     * @since 1.72
     *
     * @returns Value of property `titleAlignment`
     */
    getTitleAlignment(): TitleAlignment;
    /**
     * Gets current value of property {@link #getVerticalScrolling verticalScrolling}.
     *
     * This property is supported by both variants. Please see the documentation on sap.m.Popover#verticalScrolling
     * and sap.m.Dialog#verticalScrolling
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `verticalScrolling`
     */
    getVerticalScrolling(): boolean;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContent content}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContent(
      /**
       * The content whose index is looked for
       */
      oContent: Control
    ): int;
    /**
     * Inserts a content into the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContent(
      /**
       * The content to insert; if empty, nothing is inserted
       */
      oContent: Control,
      /**
       * The `0`-based index the content should be inserted at; for a negative value of `iIndex`, the content
       * is inserted at position 0; for a value greater than the current size of the aggregation, the content
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Checks whether the ResponsivePopover is currently open.
     *
     *
     * @returns whether the ResponsivePopover is currently opened
     */
    isOpen(): boolean;
    /**
     * Opens the ResponsivePopover. The ResponsivePopover is positioned relatively to the control parameter
     * on tablet or desktop and is full screen on phone. Therefore the control parameter is only used on tablet
     * or desktop and is ignored on phone.
     *
     *
     * @returns Reference to the opening control
     */
    openBy(
      /**
       * When this control is displayed on tablet or desktop, the ResponsivePopover is positioned relative to
       * this UI5 control or DOM element.
       */
      oParent: Control | HTMLElement
    ): Popover | Dialog;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all the controls from the aggregation {@link #getContent content}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContent(): Control[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes a content from the aggregation {@link #getContent content}.
     *
     *
     * @returns The removed content or `null`
     */
    removeContent(
      /**
       * The content to remove or its index or id
       */
      vContent: int | string | Control
    ): Control | null;
    /**
     * Setter for beginButton aggregation
     *
     *
     * @returns Pointer to the control instance for chaining
     */
    setBeginButton(
      /**
       * The button that will be set as an aggregation
       */
      oButton: Button
    ): this;
    /**
     * Sets a new value for property {@link #getContentHeight contentHeight}.
     *
     * This property is supported by both variants. Please see the documentation on sap.m.Popover#contentHeight
     * and sap.m.Dialog#contentHeight
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContentHeight(
      /**
       * New value for property `contentHeight`
       */
      sContentHeight?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getContentWidth contentWidth}.
     *
     * This property is supported by both variants. Please see the documentation on sap.m.Popover#contentWidth
     * and sap.m.Dialog#contentWidth
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContentWidth(
      /**
       * New value for property `contentWidth`
       */
      sContentWidth?: CSSSize
    ): this;
    /**
     * Sets the aggregated {@link #getCustomHeader customHeader}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomHeader(
      /**
       * The customHeader to set
       */
      oCustomHeader: IBar
    ): this;
    /**
     * Setter for endButton aggregation
     *
     *
     * @returns Pointer to the control instance for chaining
     */
    setEndButton(
      /**
       * The button that will be set as an aggregation
       */
      oButton: Button
    ): this;
    /**
     * Sets the aggregated {@link #getFooter footer}.
     *
     * @since 1.129
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFooter(
      /**
       * The footer to set
       */
      oFooter: Toolbar
    ): this;
    /**
     * Sets a new value for property {@link #getHorizontalScrolling horizontalScrolling}.
     *
     * This property is supported by both variants. Please see the documentation on sap.m.Popover#horizontalScrolling
     * and sap.m.Dialog#horizontalScrolling
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHorizontalScrolling(
      /**
       * New value for property `horizontalScrolling`
       */
      bHorizontalScrolling?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * This property only takes effect on phone. Please see the documentation sap.m.Dialog#icon.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets the associated {@link #getInitialFocus initialFocus}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInitialFocus(
      /**
       * ID of an element which becomes the new target of this initialFocus association; alternatively, an element
       * instance may be given
       */
      oInitialFocus: ID | Control
    ): this;
    /**
     * Sets a new value for property {@link #getModal modal}.
     *
     * This property only takes effect on desktop or tablet. Please see the documentation sap.m.Popover#modal.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setModal(
      /**
       * New value for property `modal`
       */
      bModal?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getOffsetX offsetX}.
     *
     * This property only takes effect on desktop or tablet. Please see the documentation sap.m.Popover#offsetX.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setOffsetX(
      /**
       * New value for property `offsetX`
       */
      iOffsetX?: int
    ): this;
    /**
     * Sets a new value for property {@link #getOffsetY offsetY}.
     *
     * This property only takes effect on desktop or tablet. Please see the documentation sap.m.Popover#offsetY.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setOffsetY(
      /**
       * New value for property `offsetY`
       */
      iOffsetY?: int
    ): this;
    /**
     * Sets a new value for property {@link #getPlacement placement}.
     *
     * This property only takes effect on desktop or tablet. Please see the documentation sap.m.Popover#placement.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Right`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPlacement(
      /**
       * New value for property `placement`
       */
      sPlacement?: PlacementType | keyof typeof PlacementType
    ): this;
    /**
     * Sets a new value for property {@link #getResizable resizable}.
     *
     * Whether resize option is enabled.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.36.4
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setResizable(
      /**
       * New value for property `resizable`
       */
      bResizable?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowArrow showArrow}.
     *
     * This property only takes effect on desktop or tablet. Please see the documentation sap.m.Popover#showArrow.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowArrow(
      /**
       * New value for property `showArrow`
       */
      bShowArrow?: boolean
    ): this;
    /**
     * Determines if the close button to the ResponsivePopover is shown or not. Works only when ResponsivePopover
     * is used as a dialog
     *
     *
     * @returns Pointer to the control instance for chaining
     */
    setShowCloseButton(
      /**
       * Defines whether the close button is shown
       */
      bShowCloseButton: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowHeader showHeader}.
     *
     * This property is supported by both variants. Please see the documentation on sap.m.Popover#showHeader
     * and sap.m.Dialog#showHeader
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowHeader(
      /**
       * New value for property `showHeader`
       */
      bShowHeader?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getSubHeader subHeader}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSubHeader(
      /**
       * The subHeader to set
       */
      oSubHeader: IBar
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * This property is supported by both variants. Please see the documentation on sap.m.Popover#title and
     * sap.m.Dialog#title
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitleAlignment titleAlignment}.
     *
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     * @since 1.72
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleAlignment(
      /**
       * New value for property `titleAlignment`
       */
      sTitleAlignment?: TitleAlignment | keyof typeof TitleAlignment
    ): this;
    /**
     * Sets a new value for property {@link #getVerticalScrolling verticalScrolling}.
     *
     * This property is supported by both variants. Please see the documentation on sap.m.Popover#verticalScrolling
     * and sap.m.Dialog#verticalScrolling
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVerticalScrolling(
      /**
       * New value for property `verticalScrolling`
       */
      bVerticalScrolling?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ResponsivePopover constructor.
   */
  export interface $ResponsivePopoverSettings extends $ControlSettings {
    /**
     * This property only takes effect on desktop or tablet. Please see the documentation sap.m.Popover#placement.
     */
    placement?:
      | (PlacementType | keyof typeof PlacementType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * This property is supported by both variants. Please see the documentation on sap.m.Popover#showHeader
     * and sap.m.Dialog#showHeader
     */
    showHeader?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This property is supported by both variants. Please see the documentation on sap.m.Popover#title and
     * sap.m.Dialog#title
     */
    title?: string | PropertyBindingInfo;

    /**
     * This property only takes effect on phone. Please see the documentation sap.m.Dialog#icon.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * This property only takes effect on desktop or tablet. Please see the documentation sap.m.Popover#modal.
     */
    modal?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This property only takes effect on desktop or tablet. Please see the documentation sap.m.Popover#offsetX.
     */
    offsetX?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * This property only takes effect on desktop or tablet. Please see the documentation sap.m.Popover#offsetY.
     */
    offsetY?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * This property only takes effect on desktop or tablet. Please see the documentation sap.m.Popover#showArrow.
     */
    showArrow?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This property is supported by both variants. Please see the documentation on sap.m.Popover#contentWidth
     * and sap.m.Dialog#contentWidth
     */
    contentWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * This property is supported by both variants. Please see the documentation on sap.m.Popover#contentHeight
     * and sap.m.Dialog#contentHeight
     */
    contentHeight?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * This property is supported by both variants. Please see the documentation on sap.m.Popover#horizontalScrolling
     * and sap.m.Dialog#horizontalScrolling
     */
    horizontalScrolling?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This property is supported by both variants. Please see the documentation on sap.m.Popover#verticalScrolling
     * and sap.m.Dialog#verticalScrolling
     */
    verticalScrolling?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines if a close button should be inserted into the dialog's header dynamically to close the dialog.
     * This property only takes effect on phone. **Note:** The close button could be placed only in a sap.m.Bar
     * if a sap.m.Toolbar is passed as a header - the property will not take effect.
     */
    showCloseButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Whether resize option is enabled.
     *
     * @since 1.36.4
     */
    resizable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * @since 1.72
     */
    titleAlignment?:
      | (TitleAlignment | keyof typeof TitleAlignment)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Content is supported by both variants. Please see the documentation on sap.m.Popover#content and sap.m.Dialog#content
     */
    content?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * CustomHeader is supported by both variants. Please see the documentation on sap.m.Popover#customHeader
     * and sap.m.Dialog#customHeader
     */
    customHeader?: IBar;

    /**
     * SubHeader is supported by both variants. Please see the documentation on sap.m.Popover#subHeader and
     * sap.m.Dialog#subHeader
     */
    subHeader?: IBar;

    /**
     * BeginButton is supported by both variants. It is always show in the left part (right part in RTL mode)
     * of the footer which is located at the bottom of the ResponsivePopover. If buttons need to be displayed
     * in header, please use customHeader instead.
     */
    beginButton?: Button;

    /**
     * EndButton is supported by both variants. It is always show in the right part (left part in RTL mode)
     * of the footer which is located at the bottom of the ResponsivePopover. If buttons need to be displayed
     * in header, please use customHeader instead.
     */
    endButton?: Button;

    /**
     * The footer of this popover.
     *
     * @since 1.129
     */
    footer?: Toolbar;

    /**
     * InitialFocus is supported by both variants. Please see the documentation on sap.m.Popover#initialFocus
     * and sap.m.Dialog#initialFocus
     */
    initialFocus?: Control | string;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Association to controls / IDs which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Event is fired before popover or dialog is open.
     */
    beforeOpen?: (oEvent: ResponsivePopover$BeforeOpenEvent) => void;

    /**
     * Event is fired after popover or dialog is open.
     */
    afterOpen?: (oEvent: ResponsivePopover$AfterOpenEvent) => void;

    /**
     * Event is fired before popover or dialog is closed.
     */
    beforeClose?: (oEvent: ResponsivePopover$BeforeCloseEvent) => void;

    /**
     * Event is fired after popover or dialog is closed.
     */
    afterClose?: (oEvent: ResponsivePopover$AfterCloseEvent) => void;
  }

  /**
   * Parameters of the ResponsivePopover#afterClose event.
   */
  export interface ResponsivePopover$AfterCloseEventParameters {
    /**
     * This parameter contains the control which is passed as the parameter when calling openBy method. When
     * runs on the phone, this parameter is undefined.
     */
    openBy?: Control;

    /**
     * This parameter contains the control which triggers the close of the ResponsivePopover. This parameter
     * is undefined when runs on desktop or tablet.
     */
    origin?: Button;
  }

  /**
   * Event object of the ResponsivePopover#afterClose event.
   */
  export type ResponsivePopover$AfterCloseEvent = Event<
    ResponsivePopover$AfterCloseEventParameters,
    ResponsivePopover
  >;

  /**
   * Parameters of the ResponsivePopover#afterOpen event.
   */
  export interface ResponsivePopover$AfterOpenEventParameters {
    /**
     * This parameter contains the control which is passed as the parameter when calling openBy method. When
     * runs on the phone, this parameter is undefined.
     */
    openBy?: Control;
  }

  /**
   * Event object of the ResponsivePopover#afterOpen event.
   */
  export type ResponsivePopover$AfterOpenEvent = Event<
    ResponsivePopover$AfterOpenEventParameters,
    ResponsivePopover
  >;

  /**
   * Parameters of the ResponsivePopover#beforeClose event.
   */
  export interface ResponsivePopover$BeforeCloseEventParameters {
    /**
     * This parameter contains the control which is passed as the parameter when calling openBy method. When
     * runs on the phone, this parameter is undefined.
     */
    openBy?: Control;

    /**
     * This parameter contains the control which triggers the close of the ResponsivePopover. This parameter
     * is undefined when runs on desktop or tablet.
     */
    origin?: Button;
  }

  /**
   * Event object of the ResponsivePopover#beforeClose event.
   */
  export type ResponsivePopover$BeforeCloseEvent = Event<
    ResponsivePopover$BeforeCloseEventParameters,
    ResponsivePopover
  >;

  /**
   * Parameters of the ResponsivePopover#beforeOpen event.
   */
  export interface ResponsivePopover$BeforeOpenEventParameters {
    /**
     * This parameter contains the control which is passed as the parameter when calling openBy method. When
     * runs on the phone, this parameter is undefined.
     */
    openBy?: Control;
  }

  /**
   * Event object of the ResponsivePopover#beforeOpen event.
   */
  export type ResponsivePopover$BeforeOpenEvent = Event<
    ResponsivePopover$BeforeOpenEventParameters,
    ResponsivePopover
  >;
}

declare module "sap/m/ResponsiveScale" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import { IScale } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * **Overview**
   *
   * A {@link sap.m.Slider} element represents a scale with tickmarks and labels. The purpose of the element
   * is to decouple the scale logic from other controls i.e. Slider / RangeSlider
   *
   * The most important properties of the ResponsiveScale are:
   * 	 -  tickmarksBetweenLabels - Puts a label on every N-th tickmark.
   *
   * @since 1.46
   */
  export default class ResponsiveScale extends UI5Element implements IScale {
    __implements__sap_m_IScale: boolean;
    /**
     * Constructor for a new `ResponsiveScale`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ResponsiveScaleSettings
    );
    /**
     * Constructor for a new `ResponsiveScale`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ResponsiveScaleSettings
    );

    /**
     * Creates a new subclass of class sap.m.ResponsiveScale with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ResponsiveScale>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ResponsiveScale.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * How many tickmarks could be placed on the axis/scale?
     *
     *
     * @returns The max number of possible tickmarks
     */
    calcNumberOfTickmarks(
      /**
       * Size of the scale. This is the distance between the start and end point i.e. 0..100
       */
      fSize: float,
      /**
       * The step walking from start to end.
       */
      fStep: float,
      /**
       * Limits the number of tickmarks.
       */
      iTickmarksThreshold: int
    ): number;
    /**
     * Gets current value of property {@link #getTickmarksBetweenLabels tickmarksBetweenLabels}.
     *
     * Put a label on every N-th tickmark.
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `tickmarksBetweenLabels`
     */
    getTickmarksBetweenLabels(): int;
    /**
     * Sets a new value for property {@link #getTickmarksBetweenLabels tickmarksBetweenLabels}.
     *
     * Put a label on every N-th tickmark.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTickmarksBetweenLabels(
      /**
       * New value for property `tickmarksBetweenLabels`
       */
      iTickmarksBetweenLabels?: int
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ResponsiveScale constructor.
   */
  export interface $ResponsiveScaleSettings extends $ElementSettings {
    /**
     * Put a label on every N-th tickmark.
     */
    tickmarksBetweenLabels?: int | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/routing/RouteMatchedHandler" {
  import BaseObject from "sap/ui/base/Object";

  import Router from "sap/ui/core/routing/Router";

  import Metadata from "sap/ui/base/Metadata";

  /**
   * This class will attach to the Events of a provided router and add the views created by it to a {@link sap.m.SplitContainer }
   * or a {@link sap.m.NavContainer} Control, if this is the target control of the route.
   *  If the targetControl is no {@link sap.m.SplitContainer} or a {@link sap.m.NavContainer}, It will only
   * close the dialogs, according to the property value.
   *
   *  When a navigation is triggered, this class will try to determine the transition of the pages based on
   * the history.
   *  Eg: if a user presses browser back, it will show a backwards animation.
   *
   *  The navigation on the container takes place in the RoutePatternMatched event of the Router. If you register
   * on the RouteMatched event of the Router, the visual navigation did not take place yet.
   *
   *  Since it is hard to detect if a user has pressed browser back, this transitions will not be reliable,
   * for example if someone bookmarked a detail page, and wants to navigate to a masterPage.
   *  If you want this case to always show a backwards transition, you should specify a "viewLevel" property
   * on your Route.
   *  The viewLevel has to be an integer. The Master should have a lower number than the detail.
   *  These levels should represent the user process of your application and they do not have to match the
   * container structure of your Routes.
   *  If the user navigates between views with the same viewLevel, the history is asked for the direction.
   *
   *  You can specify a property "transition" in a route to define which transition will be applied when navigating.
   * If it is not defined, the nav container will take its default transition.
   *  You can also specify "transitionParameters" on a Route, to give the transition parameters.
   *
   *  preservePageInSplitContainer is deprecated since 1.28 since Targets make this parameter obsolete. If
   * you want to preserve the current view when navigating, but you want to navigate to it when nothing is
   * displayed in the navContainer, you can set preservePageInSplitContainer = true
   *  When the route that has this flag directly matches the pattern, the view will still be switched by the
   * splitContainer.
   *
   *
   * @deprecated As of version 1.28. use {@link sap.m.routing.Router} or {@link sap.m.routing.Targets} instead.
   * The functionality of the routematched handler is built in into these two classes, there is no need to
   * create this anymore.
   */
  export default class RouteMatchedHandler extends BaseObject {
    /**
     * Instantiates a RouteMatchedHandler.
     * See:
     * 	sap.m.NavContainer
     */
    constructor(
      /**
       * A router that creates views
       */
      router: Router,
      /**
       * If set to `true` it will close all open dialogs before navigating. If set to `false` it will just navigate
       * without closing dialogs.
       */
      closeDialogs?: boolean
    );

    /**
     * Creates a new subclass of class sap.m.routing.RouteMatchedHandler with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.base.Object.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, RouteMatchedHandler>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.routing.RouteMatchedHandler.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): Metadata;
    /**
     * Removes the routeMatchedHandler from the Router
     *
     *
     * @returns for chaining
     */
    destroy(): this;
    /**
     * Gets if a navigation should close dialogs
     *
     *
     * @returns a flag indication if dialogs will be closed
     */
    getCloseDialogs(): boolean;
    /**
     * Sets if a navigation should close dialogs
     *
     *
     * @returns for chaining
     */
    setCloseDialogs(
      /**
       * close dialogs if true
       */
      bCloseDialogs: boolean
    ): this;
  }
}

declare module "sap/m/routing/Router" {
  import Router1 from "sap/ui/core/routing/Router";

  import UIComponent from "sap/ui/core/UIComponent";

  import Metadata from "sap/ui/base/Metadata";

  import TargetHandler from "sap/m/routing/TargetHandler";

  /**
   * SAPUI5 mobile `Router`. The difference to the {@link sap.ui.core.routing.Router} are the `level`, `transition`,
   * and `transitionParameters` properties that you can specify in every Route or Target created by this router.
   *
   * @since 1.28.1
   */
  export default class Router extends Router1 {
    /**
     * Constructor for a new `sap.m.routing.Router`. See `{@link sap.ui.core.routing.Router}` for the constructor
     * arguments.
     */
    constructor(
      /**
       * may contain many Route configurations as {@link sap.ui.core.routing.Route#constructor}.
       *  Each of the routes contained in the array/object will be added to the router.
       *
       *
       * One way of defining routes is an array:
       * ```javascript
       *
       * [
       *     //Will create a route called 'firstRouter' you can later use this name in navTo to navigate to this route
       *     {
       *         name: "firstRoute"
       *         pattern : "usefulPattern"
       *     },
       *     //Will create a route called 'anotherRoute'
       *     {
       *         name: "anotherRoute"
       *         pattern : "anotherPattern"
       *     },
       *     //Will create a route for a nested component with the prefix 'componentPrefix'
       *     {
       *         pattern: "componentPattern",
       *         name: "componentRoute",
       *         target: [
       *              {
       *                  name: "subComponent",
       *                  prefix: "componentPrefix"
       *              }
       *         ]
       *     }
       * ]
       * ```
       *
       *
       * The alternative way of defining routes is an Object.
       *  If you choose this way, the name attribute is the name of the property.
       * ```javascript
       *
       * {
       *     //Will create a route called 'firstRouter' you can later use this name in navTo to navigate to this route
       *     firstRoute : {
       *         pattern : "usefulPattern"
       *     },
       *     //Will create a route called 'anotherRoute'
       *     anotherRoute : {
       *         pattern : "anotherPattern"
       *     },
       *     //Will create a route for a nested component with the prefix 'componentPrefix'
       *     componentRoute{
       *         pattern: "componentPattern",
       *         target: [
       *              {
       *                  name: "subComponent",
       *                  prefix: "componentPrefix"
       *              }
       *         ]
       *     }
       * }
       * ```
       *  The values that may be provided are the same as in {@link sap.ui.core.routing.Route#constructor}
       */
      oRoutes?: object | object[],
      /**
       * Default values for route configuration - also takes the same parameters as {@link sap.ui.core.routing.Target#constructor}.
       *  This config will be used for routes and for targets, used in the router
       *  Eg: if the config object specifies :
       * ```javascript
       *
       *
       * { viewType : "XML" }
       *
       * ```
       *  The targets look like this:
       * ```javascript
       *
       * {
       *     xmlTarget : {
       *         ...
       *     },
       *     jsTarget : {
       *         viewType : "JS"
       *         ...
       *     },
       *     componentTarget: {
       *         type: "Component",
       *         name: "subComponent",
       *         id: "mySubComponent",
       *         options: {
       *             // the Component configuration:
       *             manifest: true
       *             ...
       *         },
       *         controlId: "myRootView",
       *         controlAggregation: "content"
       *     }
       * }
       * ```
       *  Then the effective config will look like this:
       * ```javascript
       *
       * {
       *     xmlTarget : {
       *         viewType : "XML"
       *         ...
       *     },
       *     jsTarget : {
       *         viewType : "JS"
       *         ...
       *     },
       * 	   componentTarget: {
       *         type: "Component",
       *         name: "subComponent",
       *         id: "mySubComponent",
       *         options: {
       *             // the Component configuration:
       *             manifest: true
       *             ...
       *         },
       *         controlId: "myRootView",
       *         controlAggregation: "content"
       *     }
       * }
       * ```
       *
       *
       * Since the xmlTarget does not specify its viewType, XML is taken from the config object. The jsTarget
       * is specifying it, so the viewType will be JS.
       */
      oConfig?: {
        /**
         * @since 1.34. Whether the views which are loaded within this router instance asyncly.
         */
        async?: boolean;
      },
      /**
       * the Component of all the views that will be created by this Router,
       *  will get forwarded to the {@link sap.ui.core.routing.Views#constructor}.
       *  If you are using the componentMetadata to define your routes you should skip this parameter.
       */
      oOwner?: UIComponent,
      /**
       * the target configuration, see {@link sap.m.routing.Targets#constructor} documentation (the options object).
       *  You should use Targets to create and display views. The route should only contain routing relevant properties.
       *  **Example:**
       * ```javascript
       *
       *
       *     new Router(
       *     // Routes
       *     [
       *         {
       *             // no view creation related properties are in the route
       *             name: "startRoute",
       *             //no hash
       *             pattern: "",
       *             // you can find this target in the targetConfig
       *             target: "welcome"
       *         }
       *     ],
       *     // Default values shared by routes and Targets
       *     {
       *         path: "my.application.namespace",
       *         viewType: "XML"
       *     },
       *     // You should only use this constructor when you are not using a router with a component.
       *     // Please use the metadata of a component to define your routes and targets.
       *     // The documentation can be found here: {@link sap.ui.core.UIComponent.extend}.
       *     null,
       *     // Target config
       *     {
       *          //same name as in the route called 'startRoute'
       *          welcome: {
       *              // All properties for creating and placing a view go here or in the config
       *              type: "View",
       *              name: "Welcome",
       *              controlId: "app",
       *              controlAggregation: "pages"
       *          }
       *     })
       *
       * ```
       */
      oTargetsConfig?: object
    );

    /**
     * Creates a new subclass of class sap.m.routing.Router with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.routing.Router.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Router>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.routing.Router.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): Metadata;
    /**
     * Returns the TargetHandler instance.
     *
     *
     * @returns the TargetHandler instance
     */
    getTargetHandler(): TargetHandler;
  }
}

declare module "sap/m/routing/TargetHandler" {
  import BaseObject from "sap/ui/base/Object";

  import Metadata from "sap/ui/base/Metadata";

  /**
   * Used for closing dialogs and showing transitions in `NavContainers` when targets are displayed.
   *
   * **Note:** You should not create an own instance of this class. It is created when using `{@link sap.m.routing.Router}`
   * or `{@link sap.m.routing.Targets}`.
   *
   * **Note:** You may use the `{@link #setCloseDialogs}` function to specify if dialogs should be closed
   * on displaying other views. The dialogs are closed when a different target is displayed than the previously
   * displayed one, otherwise the dialogs are kept open.
   *
   * @since 1.28.1
   */
  export default class TargetHandler extends BaseObject {
    /**
     * Constructor for a new `TargetHandler`.
     */
    constructor(
      /**
       * Closes all open dialogs before navigating to a different target, if set to `true` (default). If set to
       * `false`, it will just navigate without closing dialogs.
       */
      closeDialogs: boolean
    );

    /**
     * Creates a new subclass of class sap.m.routing.TargetHandler with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.base.Object.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, TargetHandler>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.routing.TargetHandler.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): Metadata;
    /**
     * Gets if a navigation should close dialogs.
     *
     *
     * @returns A flag indication if dialogs will be closed.
     */
    getCloseDialogs(): boolean;
    /**
     * Sets if a navigation should close dialogs.
     *
     * **Note:** The dialogs are closed when a different target is displayed than the previous one, otherwise
     * the dialogs are kept open even when `bCloseDialogs` is `true`.
     *
     *
     * @returns For chaining
     */
    setCloseDialogs(
      /**
       * Close dialogs if `true`
       */
      bCloseDialogs: boolean
    ): this;
  }
}

declare module "sap/m/routing/Targets" {
  import Targets1 from "sap/ui/core/routing/Targets";

  import Views from "sap/ui/core/routing/Views";

  import Metadata from "sap/ui/base/Metadata";

  import TargetHandler from "sap/m/routing/TargetHandler";

  /**
   * Provides a convenient way for placing views into the correct containers of your app.
   *
   * The mobile extension of `Targets` also handles the triggering of page navigation when the target control
   * is an `{@link sap.m.SplitContainer}`, an `{@link sap.m.NavContainer}` or a control which extends one
   * of these. Other controls are also allowed, but the extra parameters `level`, `transition` and `transitionParameters`
   * are ignored and it behaves as `{@link sap.ui.core.routing.Targets}`.
   *
   * When a target is displayed, dialogs will be closed. To change this use `{@link #getTargetHandler}` and
   * `{@link sap.m.routing.TargetHandler#setCloseDialogs}`.
   *
   * @since 1.28.1
   */
  export default class Targets extends Targets1 {
    /**
     * Constructor for a new `Targets` class.
     */
    constructor(oOptions: {
      /**
       * the views instance will create the views of all the targets defined, so if 2 targets have the same name,
       * the same instance of the view will be displayed.
       */
      views: Views;
      /**
       * this config allows all the values oOptions.targets.anyName allows, these will be the default values for
       * properties used in the target.
       *  For example if you are only using xmlViews in your app you can specify viewType="XML" so you don't have
       * to repeat this in every target.
       *  If a target specifies viewType="JS", the JS will be stronger than the XML here is an example.
       *
       *
       * ```javascript
       *
       *
       * {
       *     config: {
       *         viewType : "XML"
       *     }
       *     targets : {
       *         xmlTarget : {
       *             ...
       *         },
       *         jsTarget : {
       *             viewType : "JS"
       *             ...
       *         }
       *     }
       * }
       *
       * ```
       *  Then the effective config that will be used looks like this:
       * ```javascript
       *
       *
       * {
       *     xmlTarget : {
       *         // coming from the defaults
       *         viewType : "XML"
       *         ...
       *     },
       *     jsTarget : {
       *        // XML is overwritten by the "JS" of the targets property
       *        viewType : "JS"
       *       ...
       *     }
       * }
       *
       * ```
       */
      config?: {
        /**
         * The id of the rootView - This should be the id of the view that contains the control with the controlId
         * since the control will be retrieved by calling the {@link sap.ui.core.mvc.View#byId} function of the
         * rootView. If you are using a component and add the routing.targets **do not set this parameter**, since
         * the component will set the rootView to the view created by the {@link sap.ui.core.UIComponent#createContent }
         * function. If you specify the "parent" property of a target, the control will not be searched in the root
         * view but in the view Created by the parent (see parent documentation).
         */
        rootView?: string;
        /**
         * @since 1.34 Whether the views which are created through this Targets are loaded asyncly. This option
         * can be set only when the Targets is used standalone without the involvement of a Router. Otherwise the
         * async option is inherited from the Router.
         */
        async?: boolean;
      };
      /**
       * One or multiple targets in a map.
       */
      targets: {
        /**
         * a new target, the key severs as a name. An example:
         * ```javascript
         *
         *
         * {
         *     targets: {
         *         welcome: {
         *             type: "View",
         *             name: "Welcome",
         *             viewType: "XML",
         *             ....
         *             // Other target parameters
         *         },
         *         goodbye: {
         *             type: "View",
         *             name: "Bye",
         *             viewType: "JS",
         *             ....
         *             // Other target parameters
         *         }
         *     }
         * }
         *
         * ```
         *
         *
         * This will create two targets named 'welcome' and 'goodbye' you can display both of them or one of them
         * using the {@link #display} function.
         */
        anyName: {
          /**
           * Defines whether the target creates an instance of 'View' or 'Component'.
           */
          type: string;
          /**
           * Defines the name of the View or Component that will be created. For type 'Component', use option `usage`
           * instead if an owner component exists. To place the view or component into a Control, use the options
           * `controlAggregation` and `controlId`. Instance of View or Component will only be created once per `name`
           * or `usage` combined with `id`.
           * ```javascript
           *
           *
           * {
           *     targets: {
           *         // If display("masterWelcome") is called, the master view will be placed in the 'MasterPages' of a control with the id splitContainter
           *         masterWelcome: {
           *             type: "View",
           *             name: "Welcome",
           *             controlId: "splitContainer",
           *             controlAggregation: "masterPages"
           *         },
           *         // If display("detailWelcome") is called after the masterWelcome, the view will be removed from the master pages and added to the detail pages, since the same instance is used. Also the controls inside of the view will have the same state.
           *         detailWelcome: {
           *             // same view here, that's why the same instance is used
           *             type: "View",
           *             name: "Welcome",
           *             controlId: "splitContainer",
           *             controlAggregation: "detailPages"
           *         }
           *     }
           * }
           *
           * ```
           *
           *
           * If you want to have a second instance of the welcome view you can assign the targets with different ids:
           *
           *
           * ```javascript
           *
           *
           * {
           *     targets: {
           *         // If display("masterWelcome") is called, the "masterWelcome" view will be placed in the 'MasterPages' of a control with the id splitContainter
           *         masterWelcome: {
           *             type: "View",
           *             name: "Welcome",
           *             id: "masterWelcome",
           *             controlId: "splitContainer",
           *             controlAggregation: "masterPages"
           *         },
           *         // If display("detailWelcome") is called after the "masterWelcome", a second instance with an own controller instance will be added in the detail pages.
           *         detailWelcome: {
           *             type: "View",
           *             name: "Welcome",
           *             // another instance will be created because a different id is used
           *             id: "detailWelcome",
           *             controlId: "splitContainer",
           *             controlAggregation: "detailPages"
           *         }
           *     }
           * }
           *
           * ```
           */
          name?: string;
          /**
           * Defines the 'usage' name for 'Component' target which refers to the '/sap.ui5/componentUsages' entry
           * in the owner component's manifest.
           */
          usage?: string;
          /**
           * The type of the view that is going to be created. These are the supported types: {@link sap.ui.core.mvc.ViewType}.
           * You always have to provide a viewType except if `oOptions.config.viewType` is set or using {@link sap.ui.core.routing.Views#setView}.
           */
          viewType?: string;
          /**
           * A prefix that will be prepended in front of the `name`.
           *  **Example:** `name` is set to "myView" and `path` is set to "myApp" - the created view's name will be
           * "myApp.myView".
           */
          path?: string;
          /**
           * The id of the created view or component. This is will be prefixed with the id of the component set to
           * the views instance provided in oOptions.views. For details see {@link sap.ui.core.routing.Views#getView}.
           */
          id?: string;
          /**
           * The id of the parent of the controlId - This should be the id of the view that contains your controlId,
           * since the target control will be retrieved by calling the {@link sap.ui.core.mvc.View#byId} function
           * of the targetParent. By default, this will be the view created by a component, so you do not have to
           * provide this parameter. If you are using children, the view created by the parent of the child is taken.
           * You only need to specify this, if you are not using a Targets instance created by a component and you
           * should give the id of root view of your application to this property.
           */
          targetParent?: string;
          /**
           * The id of the control where you want to place the view created by this target. The view of the target
           * will be put into this container Control, using the controlAggregation property. You have to specify both
           * properties or the target will not be able to place itself. An example for containers are {@link sap.ui.ux3.Shell }
           * with the aggregation 'content' or a {@link sap.m.NavContainer} with the aggregation 'pages'.
           */
          controlId?: string;
          /**
           * The name of an aggregation of the controlId, that contains views. Eg: a {@link sap.m.NavContainer} has
           * an aggregation 'pages', another Example is the {@link sap.ui.ux3.Shell} it has 'content'.
           */
          controlAggregation?: string;
          /**
           * Defines a boolean that can be passed to specify if the aggregation should be cleared - all items will
           * be removed - before adding the View to it. When using a {@link sap.ui.ux3.Shell} this should be true.
           * For a {@link sap.m.NavContainer} it should be false. When you use the {@link sap.m.routing.Router} the
           * default will be false.
           */
          clearControlAggregation?: boolean;
          /**
           * A reference to another target, using the name of the target. If you display a target that has a parent,
           * the parent will also be displayed. Also the control you specify with the controlId parameter, will be
           * searched inside of the view of the parent not in the rootView, provided in the config. The control will
           * be searched using the byId function of a view. When it is not found, the global id is checked.
           *  The main usecase for the parent property is placing a view inside a smaller container of a view, which
           * is also created by targets. This is useful for lazy loading views, only if the user really navigates
           * to this part of your application.
           *  **Example:** Our aim is to lazy load a tab of an IconTabBar (a control that displays a view initially
           * and when a user clicks on it the view changes). It's a perfect candidate to lazy load something inside
           * of it.
           *  **Example app structure:**
           *  We have a rootView that is returned by the createContent function of our UIComponent. This view contains
           * an sap.m.App control with the id 'myApp'
           * ```javascript
           *
           *
           * <View xmlns="sap.m">
           *     <App id="myApp"/>
           * </View>
           *
           * ```
           *  an xml view called 'Detail'
           * ```javascript
           *
           *
           * <View xmlns="sap.m">
           *     <IconTabBar>
           *         <items>
           *             <IconTabFilter>
           *                 <!-- content of our first tab -->
           *             <IconTabFilter>
           *             <IconTabFilter id="mySecondTab">
           *                 <!-- nothing here, since we will lazy load this one with a target -->
           *             <IconTabFilter>
           *         </items>
           *     </IconTabBar>
           * </View>
           *
           * ```
           *  and a view called 'SecondTabContent', this one contains our content we want to have lazy loaded. Now
           * we need to create our Targets instance with a config matching our app:
           * ```javascript
           *
           *
           *     new Targets({
           *         //Creates our views except for root, we created this one before - when using a component you
           *         views: new Views(),
           *         config: {
           *             // all of our views have that type
           *             viewType: 'XML',
           *             // a reference to the app control in the rootView created by our UIComponent
           *             controlId: 'myApp',
           *             // An app has a pages aggregation where the views need to be put into
           *             controlAggregation: 'pages',
           *             // all targets have type "View"
           *             type: "View"
           *         },
           *         targets: {
           *             detail: {
           *                 name: 'Detail'
           *             },
           *             secondTabContent: {
           *                 // A reference to the detail target defined above
           *                 parent: 'detail',
           *                 // A reference to the second Tab container in the Detail view. Here the target does not look in the rootView, it looks in the Parent view (Detail).
           *                 controlId: 'mySecondTab',
           *                 // An IconTabFilter has an aggregation called content so we need to overwrite the pages set in the config as default.
           *                 controlAggregation: 'content',
           *                 // A view containing the content
           *                 name: 'SecondTabContent'
           *             }
           *         }
           *     });
           *
           * ```
           *
           *
           * Now if we call ` oTargets.display("secondTabContent") `, 2 views will be created: Detail and SecondTabContent.
           * The 'Detail' view will be put into the pages aggregation of the App. And afterwards the 'SecondTabContent'
           * view will be put into the content Aggregation of the second IconTabFilter. So a parent will always be
           * created before the target referencing it.
           */
          parent?: string;
          /**
           * If you are having an application that has a logical order of views (eg: a create account process, first
           * provide user data, then review and confirm them). You always want to show a backwards transition if a
           * navigation from the confirm to the userData page takes place. Therefore you may use the `level`. The
           * `level` has to be an integer. The user data page should have a lower number than the confirm page. These
           * levels should represent the user process of your application and they do not have to match the container
           * structure of your Targets. If the user navigates between targets with the same `level`, a forward transition
           * is taken. If you pass a direction into the display function, the `level` will be ignored.
           *  **Example:**
           *
           * ```javascript
           *
           *
           *     {
           *         targets: {
           *             startPage: {
           *                 level: 0
           *                 // more properties
           *             },
           *             userData: {
           *                 level: 1
           *                 // more properties
           *             },
           *             confirmRegistration: {
           *                 level: 2
           *                 // more properties
           *             },
           *             settings: {
           *                 //no view level here
           *             }
           *         }
           *     }
           *
           * ```
           *
           *
           * Currently the 'userData' target is displayed.
           * 	 -  If we navigate to 'startPage' the navContainer will show a backwards navigation, since the `level`
           *     is lower.
           * 	 -  If we navigate to 'userData' the navContainer will show a forwards navigation, since the `level`
           *     is higher.
           * 	 -  If we navigate to 'settings' the navContainer will show a forwards navigation, since the `level`
           *     is not defined and cannot be compared.
           */
          level?: int;
          /**
           * define which transition of the {@link sap.m.NavContainer} will be applied when navigating. If it is not
           * defined, the nav container will take its default transition.
           */
          transition?: string;
          /**
           * define the transitionParameters of the {@link sap.m.NavContainer}
           */
          transitionParameters?: string;
        };
      };
    });

    /**
     * Creates a new subclass of class sap.m.routing.Targets with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.routing.Targets.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Targets>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.routing.Targets.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): Metadata;
    /**
     * Returns the TargetHandler instance.
     *
     *
     * @returns the TargetHandler instance
     */
    getTargetHandler(): TargetHandler;
  }
}

declare module "sap/m/ScrollContainer" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { CSSSize } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import UI5Element from "sap/ui/core/Element";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * The ScrollContainer is a control that can display arbitrary content within a limited screen area and
   * provides scrolling to make all content accessible. When not to use: Do not nest scrolling areas that
   * scroll in the same direction (e.g. a ScrollContainer that scrolls vertically inside a Page control with
   * scrolling enabled).
   */
  export default class ScrollContainer extends Control {
    /**
     * Constructor for a new ScrollContainer.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ScrollContainerSettings
    );
    /**
     * Constructor for a new ScrollContainer.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ScrollContainerSettings
    );

    /**
     * Creates a new subclass of class sap.m.ScrollContainer with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ScrollContainer>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ScrollContainer.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some content to the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContent(
      /**
       * The content to add; if empty, nothing is inserted
       */
      oContent: Control
    ): this;
    /**
     * Destroys all the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * The content of the ScrollContainer.
     */
    getContent(): Control[];
    /**
     * Gets current value of property {@link #getFocusable focusable}.
     *
     * Whether the scroll container can be focused.
     *
     * Note that it should be set to "true" when there are no focusable elements inside or when keyboard interaction
     * requires an additional tab stop on the container.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `focusable`
     */
    getFocusable(): boolean;
    /**
     * Gets current value of property {@link #getHeight height}.
     *
     * The height of the ScrollContainer. By default the height equals the content height. If only horizontal
     * scrolling is used, do not set the height or make sure the height is always larger than the height of
     * the content.
     *
     * Note that when a percentage is given, for the height to work as expected, the height of the surrounding
     * container must be defined.
     *
     * Default value is `'auto'`.
     *
     *
     * @returns Value of property `height`
     */
    getHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getHorizontal horizontal}.
     *
     * Whether horizontal scrolling should be possible.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `horizontal`
     */
    getHorizontal(): boolean;
    /**
     * Gets current value of property {@link #getVertical vertical}.
     *
     * Whether vertical scrolling should be possible.
     *
     * Note that this is off by default because typically a Page is used as fullscreen element which can handle
     * vertical scrolling. If this is not the case and vertical scrolling is required, this flag needs to be
     * set to "true". Important: it is not supported to have nested controls that both enable scrolling into
     * the same dimension.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `vertical`
     */
    getVertical(): boolean;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * The width of the ScrollContainer. If not set, it consumes the complete available width, behaving like
     * normal HTML block elements. If only vertical scrolling is enabled, make sure the content always fits
     * or wraps.
     *
     * Default value is `'auto'`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContent content}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContent(
      /**
       * The content whose index is looked for
       */
      oContent: Control
    ): int;
    /**
     * Inserts a content into the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContent(
      /**
       * The content to insert; if empty, nothing is inserted
       */
      oContent: Control,
      /**
       * The `0`-based index the content should be inserted at; for a negative value of `iIndex`, the content
       * is inserted at position 0; for a value greater than the current size of the aggregation, the content
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getContent content}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContent(): Control[];
    /**
     * Removes a content from the aggregation {@link #getContent content}.
     *
     *
     * @returns The removed content or `null`
     */
    removeContent(
      /**
       * The content to remove or its index or id
       */
      vContent: int | string | Control
    ): Control | null;
    /**
     * Scrolls to the given position. When called while the control is not rendered (yet), the scrolling position
     * is still applied, but there is no animation.
     *
     *
     * @returns `this` to facilitate method chaining
     */
    scrollTo(
      /**
       * The horizontal pixel position to scroll to. Scrolling to the right happens with positive values. In right-to-left
       * mode scrolling starts at the right side and higher values scroll to the left. If only vertical scrolling
       * is enabled, give 0 as value.
       */
      x: int,
      /**
       * The vertical pixel position to scroll to. Scrolling down happens with positive values. If only horizontal
       * scrolling is enabled, give 0 as value.
       */
      y: int,
      /**
       * The duration of animated scrolling in milliseconds. The value `0` results in immediate scrolling without
       * animation.
       */
      time?: int
    ): this;
    /**
     * Scrolls to an element(DOM or sap.ui.core.Element) within the page if the element is rendered.
     *
     * @since 1.30
     *
     * @returns `this` to facilitate method chaining.
     */
    scrollToElement(
      /**
       * The element to which should be scrolled.
       */
      element: HTMLElement | UI5Element,
      /**
       * The duration of animated scrolling. To scroll immediately without animation, give 0 as value or leave
       * it default.
       */
      time?: int
    ): this;
    /**
     * Sets a new value for property {@link #getFocusable focusable}.
     *
     * Whether the scroll container can be focused.
     *
     * Note that it should be set to "true" when there are no focusable elements inside or when keyboard interaction
     * requires an additional tab stop on the container.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFocusable(
      /**
       * New value for property `focusable`
       */
      bFocusable?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getHeight height}.
     *
     * The height of the ScrollContainer. By default the height equals the content height. If only horizontal
     * scrolling is used, do not set the height or make sure the height is always larger than the height of
     * the content.
     *
     * Note that when a percentage is given, for the height to work as expected, the height of the surrounding
     * container must be defined.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `'auto'`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeight(
      /**
       * New value for property `height`
       */
      sHeight?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getHorizontal horizontal}.
     *
     * Whether horizontal scrolling should be possible.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHorizontal(
      /**
       * New value for property `horizontal`
       */
      bHorizontal?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getVertical vertical}.
     *
     * Whether vertical scrolling should be possible.
     *
     * Note that this is off by default because typically a Page is used as fullscreen element which can handle
     * vertical scrolling. If this is not the case and vertical scrolling is required, this flag needs to be
     * set to "true". Important: it is not supported to have nested controls that both enable scrolling into
     * the same dimension.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVertical(
      /**
       * New value for property `vertical`
       */
      bVertical?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * The width of the ScrollContainer. If not set, it consumes the complete available width, behaving like
     * normal HTML block elements. If only vertical scrolling is enabled, make sure the content always fits
     * or wraps.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `'auto'`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ScrollContainer constructor.
   */
  export interface $ScrollContainerSettings extends $ControlSettings {
    /**
     * The width of the ScrollContainer. If not set, it consumes the complete available width, behaving like
     * normal HTML block elements. If only vertical scrolling is enabled, make sure the content always fits
     * or wraps.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * The height of the ScrollContainer. By default the height equals the content height. If only horizontal
     * scrolling is used, do not set the height or make sure the height is always larger than the height of
     * the content.
     *
     * Note that when a percentage is given, for the height to work as expected, the height of the surrounding
     * container must be defined.
     */
    height?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Whether horizontal scrolling should be possible.
     */
    horizontal?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Whether vertical scrolling should be possible.
     *
     * Note that this is off by default because typically a Page is used as fullscreen element which can handle
     * vertical scrolling. If this is not the case and vertical scrolling is required, this flag needs to be
     * set to "true". Important: it is not supported to have nested controls that both enable scrolling into
     * the same dimension.
     */
    vertical?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Whether the scroll container can be focused.
     *
     * Note that it should be set to "true" when there are no focusable elements inside or when keyboard interaction
     * requires an additional tab stop on the container.
     */
    focusable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The content of the ScrollContainer.
     */
    content?: Control[] | Control | AggregationBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/SearchField" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { IFormContent, ID, CSSSize } from "sap/ui/core/library";

  import { IShellBar } from "sap/f/library";

  import { IToolbarInteractiveControl } from "sap/m/library";

  import SuggestionItem from "sap/m/SuggestionItem";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Event from "sap/ui/base/Event";

  /**
   * An input field to search for a specific item. Overview: A search field is needed when the user needs
   * to find specific information in large amounts of data. The search field is also the control of choice
   * for filtering down a given amount of information. Structure: The search input field can be used in two
   * ways:
   * 	 - Manual search - The search is triggered after the user presses the search button. Manual search uses
   *     a “starts with” approach.
   * 	 - Live search (search-as-you-type) - The search is triggered after each button press. A suggestion
   *     list is shown below the search field. Live search uses a “contains” approach.  Usage: When to use::
   *
   * 	 -  Use live search whenever possible.
   * 	 -  Use a manual search only if the amount of data is too large and if your app would otherwise run
   *     into performance issues.   Responsive Behavior: On mobile devices, there is no refresh button in
   *     the search field. "Pull Down to Refresh" is used instead. The "Pull Down to Refresh" arrow icon is animated
   *     and spins to signal that the user should release it.
   */
  export default class SearchField
    extends Control
    implements IFormContent, IShellBar, IToolbarInteractiveControl
  {
    __implements__sap_ui_core_IFormContent: boolean;
    __implements__sap_f_IShellBar: boolean;
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new SearchField.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/search/ Search Field}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SearchFieldSettings
    );
    /**
     * Constructor for a new SearchField.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/search/ Search Field}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SearchFieldSettings
    );

    /**
     * Creates a new subclass of class sap.m.SearchField with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SearchField>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SearchField.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds some suggestionItem to the aggregation {@link #getSuggestionItems suggestionItems}.
     *
     * @since 1.34
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addSuggestionItem(
      /**
       * The suggestionItem to add; if empty, nothing is inserted
       */
      oSuggestionItem: SuggestionItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.SearchField`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SearchField` itself.
     *
     * This event is fired when the user changes the value of the search field. Unlike the `liveChange` event,
     * the `change` event is not fired for each key press.
     *
     * @since 1.77
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SearchField$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SearchField` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.SearchField`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SearchField` itself.
     *
     * This event is fired when the user changes the value of the search field. Unlike the `liveChange` event,
     * the `change` event is not fired for each key press.
     *
     * @since 1.77
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SearchField$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SearchField` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.SearchField`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SearchField` itself.
     *
     * This event is fired each time when the value of the search field is changed by the user - e.g. at each
     * key press. Do not invalidate a focused search field, especially during the liveChange event.
     *
     * @since 1.9.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SearchField$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SearchField` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.SearchField`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SearchField` itself.
     *
     * This event is fired each time when the value of the search field is changed by the user - e.g. at each
     * key press. Do not invalidate a focused search field, especially during the liveChange event.
     *
     * @since 1.9.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SearchField$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SearchField` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:search search} event of this `sap.m.SearchField`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SearchField` itself.
     *
     * Event which is fired when the user triggers a search.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSearch(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SearchField$SearchEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SearchField` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:search search} event of this `sap.m.SearchField`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SearchField` itself.
     *
     * Event which is fired when the user triggers a search.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSearch(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SearchField$SearchEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SearchField` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:suggest suggest} event of this `sap.m.SearchField`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SearchField` itself.
     *
     * This event is fired when the search field is initially focused or its value is changed by the user. This
     * event means that suggestion data should be updated, in case if suggestions are used. Use the value parameter
     * to create new suggestions for it.
     *
     * @since 1.34
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSuggest(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SearchField$SuggestEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SearchField` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:suggest suggest} event of this `sap.m.SearchField`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SearchField` itself.
     *
     * This event is fired when the search field is initially focused or its value is changed by the user. This
     * event means that suggestion data should be updated, in case if suggestions are used. Use the value parameter
     * to create new suggestions for it.
     *
     * @since 1.34
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSuggest(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SearchField$SuggestEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SearchField` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds property {@link #getValue value} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindProperty ManagedObject.bindProperty} for a detailed description
     * of the possible properties of `oBindingInfo`
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindValue(
      /**
       * The binding information
       */
      oBindingInfo: PropertyBindingInfo
    ): this;
    /**
     * Destroys all the suggestionItems in the aggregation {@link #getSuggestionItems suggestionItems}.
     *
     * @since 1.34
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySuggestionItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:change change} event of this `sap.m.SearchField`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.77
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SearchField$ChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:liveChange liveChange} event of this `sap.m.SearchField`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.9.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLiveChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SearchField$LiveChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:search search} event of this `sap.m.SearchField`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSearch(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SearchField$SearchEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:suggest suggest} event of this `sap.m.SearchField`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.34
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSuggest(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SearchField$SuggestEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:change change} to attached listeners.
     *
     * @since 1.77
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SearchField$ChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:liveChange liveChange} to attached listeners.
     *
     * @since 1.9.1
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLiveChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SearchField$LiveChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:search search} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSearch(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SearchField$SearchEventParameters
    ): this;
    /**
     * Fires event {@link #event:suggest suggest} to attached listeners.
     *
     * @since 1.34
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSuggest(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SearchField$SuggestEventParameters
    ): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Boolean property to enable the control (default is true).
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets current value of property {@link #getEnableSuggestions enableSuggestions}.
     *
     * If `true`, a `suggest` event is fired when user types in the input and when the input is focused. On
     * a phone device, a full screen dialog with suggestions is always shown even if the suggestions list is
     * empty.
     *
     * Default value is `false`.
     *
     * @since 1.34
     *
     * @returns Value of property `enableSuggestions`
     */
    getEnableSuggestions(): boolean;
    /**
     * Gets current value of property {@link #getMaxLength maxLength}.
     *
     * Maximum number of characters. Value '0' means the feature is switched off.
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `maxLength`
     */
    getMaxLength(): int;
    /**
     * Gets current value of property {@link #getPlaceholder placeholder}.
     *
     * Text shown when no value available. If no placeholder value is set, the word "Search" in the current
     * local language (if supported) or in English will be displayed as a placeholder (property value will still
     * be `null` in that case).
     *
     *
     * @returns Value of property `placeholder`
     */
    getPlaceholder(): string;
    /**
     * Function returns DOM element which acts as reference point for the opening suggestion menu
     *
     * @since 1.34
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns the DOM element at which to open the suggestion list
     */
    getPopupAnchorDomRef(): Element;
    /**
     * Gets current value of property {@link #getRefreshButtonTooltip refreshButtonTooltip}.
     *
     * Tooltip text of the refresh button. If it is not set, the Default tooltip text is the word "Refresh"
     * in the current local language (if supported) or in English. Tooltips are not displayed on touch devices.
     *
     * @since 1.16
     * @deprecated As of version 1.110.0. the concept has been discarded.
     *
     * @returns Value of property `refreshButtonTooltip`
     */
    getRefreshButtonTooltip(): string;
    /**
     * Gets current value of property {@link #getSelectOnFocus selectOnFocus}.
     *
     * Normally, search text is selected for copy when the SearchField is focused by keyboard navigation. If
     * an application re-renders the SearchField during the liveChange event, set this property to `false` to
     * disable text selection by focus.
     *
     * Default value is `true`.
     *
     * @since 1.20
     * @deprecated As of version 1.38. This parameter is deprecated and has no effect in run time. The cursor
     * position of a focused search field is restored after re-rendering automatically.
     *
     * @returns Value of property `selectOnFocus`
     */
    getSelectOnFocus(): boolean;
    /**
     * Gets current value of property {@link #getShowMagnifier showMagnifier}.
     *
     * Set to `false` to hide the magnifier icon.
     *
     * Default value is `true`.
     *
     * @deprecated As of version 1.16.0. This parameter is deprecated. Use "showSearchButton" instead.
     *
     * @returns Value of property `showMagnifier`
     */
    getShowMagnifier(): boolean;
    /**
     * Gets current value of property {@link #getShowRefreshButton showRefreshButton}.
     *
     * Set to `true` to display a refresh button in place of the search icon. By pressing the refresh button
     * or F5 key on keyboard, the user can reload the results list without changing the search string. Note:
     * if "showSearchButton" property is set to `false`, both the search and refresh buttons are not displayed
     * even if the "showRefreshButton" property is true.
     *
     * Default value is `false`.
     *
     * @since 1.16
     *
     * @returns Value of property `showRefreshButton`
     */
    getShowRefreshButton(): boolean;
    /**
     * Gets current value of property {@link #getShowSearchButton showSearchButton}.
     *
     * Set to `true` to show the search button with the magnifier icon. If `false`, both the search and refresh
     * buttons are not displayed even if the "showRefreshButton" property is `true`.
     *
     * Default value is `true`.
     *
     * @since 1.23
     *
     * @returns Value of property `showSearchButton`
     */
    getShowSearchButton(): boolean;
    /**
     * Gets content of aggregation {@link #getSuggestionItems suggestionItems}.
     *
     * `SuggestionItems` are the items which will be shown in the suggestions list. The following properties
     * can be used:
     * 	 - `key` is not displayed and may be used as internal technical field
     * 	 - `text` is displayed as normal suggestion text
     * 	 - `icon`
     * 	 - `description` - additional text may be used to visually display search item type or category
     *
     * @since 1.34
     */
    getSuggestionItems(): SuggestionItem[];
    /**
     * Gets current value of property {@link #getValue value}.
     *
     * Input Value.
     *
     *
     * @returns Value of property `value`
     */
    getValue(): string;
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * Invisible inputs are not rendered.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Defines the CSS width of the input. If not set, width is 100%.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Checks for the provided `sap.m.SuggestionItem` in the aggregation {@link #getSuggestionItems suggestionItems}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.34
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfSuggestionItem(
      /**
       * The suggestionItem whose index is looked for
       */
      oSuggestionItem: SuggestionItem
    ): int;
    /**
     * Inserts a suggestionItem into the aggregation {@link #getSuggestionItems suggestionItems}.
     *
     * @since 1.34
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertSuggestionItem(
      /**
       * The suggestionItem to insert; if empty, nothing is inserted
       */
      oSuggestionItem: SuggestionItem,
      /**
       * The `0`-based index the suggestionItem should be inserted at; for a negative value of `iIndex`, the suggestionItem
       * is inserted at position 0; for a value greater than the current size of the aggregation, the suggestionItem
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all the controls from the aggregation {@link #getSuggestionItems suggestionItems}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.34
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllSuggestionItems(): SuggestionItem[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes a suggestionItem from the aggregation {@link #getSuggestionItems suggestionItems}.
     *
     * @since 1.34
     *
     * @returns The removed suggestionItem or `null`
     */
    removeSuggestionItem(
      /**
       * The suggestionItem to remove or its index or id
       */
      vSuggestionItem: int | string | SuggestionItem
    ): SuggestionItem | null;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Boolean property to enable the control (default is true).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnableSuggestions enableSuggestions}.
     *
     * If `true`, a `suggest` event is fired when user types in the input and when the input is focused. On
     * a phone device, a full screen dialog with suggestions is always shown even if the suggestions list is
     * empty.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.34
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableSuggestions(
      /**
       * New value for property `enableSuggestions`
       */
      bEnableSuggestions?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getMaxLength maxLength}.
     *
     * Maximum number of characters. Value '0' means the feature is switched off.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxLength(
      /**
       * New value for property `maxLength`
       */
      iMaxLength?: int
    ): this;
    /**
     * Sets a new value for property {@link #getPlaceholder placeholder}.
     *
     * Text shown when no value available. If no placeholder value is set, the word "Search" in the current
     * local language (if supported) or in English will be displayed as a placeholder (property value will still
     * be `null` in that case).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPlaceholder(
      /**
       * New value for property `placeholder`
       */
      sPlaceholder?: string
    ): this;
    /**
     * Sets a new value for property {@link #getRefreshButtonTooltip refreshButtonTooltip}.
     *
     * Tooltip text of the refresh button. If it is not set, the Default tooltip text is the word "Refresh"
     * in the current local language (if supported) or in English. Tooltips are not displayed on touch devices.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.16
     * @deprecated As of version 1.110.0. the concept has been discarded.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRefreshButtonTooltip(
      /**
       * New value for property `refreshButtonTooltip`
       */
      sRefreshButtonTooltip?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSelectOnFocus selectOnFocus}.
     *
     * Normally, search text is selected for copy when the SearchField is focused by keyboard navigation. If
     * an application re-renders the SearchField during the liveChange event, set this property to `false` to
     * disable text selection by focus.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.20
     * @deprecated As of version 1.38. This parameter is deprecated and has no effect in run time. The cursor
     * position of a focused search field is restored after re-rendering automatically.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSelectOnFocus(
      /**
       * New value for property `selectOnFocus`
       */
      bSelectOnFocus?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowMagnifier showMagnifier}.
     *
     * Set to `false` to hide the magnifier icon.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @deprecated As of version 1.16.0. This parameter is deprecated. Use "showSearchButton" instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowMagnifier(
      /**
       * New value for property `showMagnifier`
       */
      bShowMagnifier?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowRefreshButton showRefreshButton}.
     *
     * Set to `true` to display a refresh button in place of the search icon. By pressing the refresh button
     * or F5 key on keyboard, the user can reload the results list without changing the search string. Note:
     * if "showSearchButton" property is set to `false`, both the search and refresh buttons are not displayed
     * even if the "showRefreshButton" property is true.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowRefreshButton(
      /**
       * New value for property `showRefreshButton`
       */
      bShowRefreshButton?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowSearchButton showSearchButton}.
     *
     * Set to `true` to show the search button with the magnifier icon. If `false`, both the search and refresh
     * buttons are not displayed even if the "showRefreshButton" property is `true`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.23
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowSearchButton(
      /**
       * New value for property `showSearchButton`
       */
      bShowSearchButton?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getValue value}.
     *
     * Input Value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValue(
      /**
       * New value for property `value`
       */
      sValue?: string
    ): this;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * Invisible inputs are not rendered.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Defines the CSS width of the input. If not set, width is 100%.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Toggle visibility of the suggestion list.
     *
     * @since 1.34
     *
     * @returns `this` to allow method chaining
     */
    suggest(
      /**
       * If the value is `true` the suggestions are displayed. If the value is `false` the suggestions are hidden.
       * An empty suggestion list is not shown on desktop and tablet devices.
       *
       *
       * This method may be called only as a response to the `suggest` event to ensure that the suggestion list
       * is shown at the moment when the user expects it.
       */
      bShow?: boolean
    ): this;
    /**
     * Unbinds property {@link #getValue value} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindValue(): this;
  }
  /**
   * Describes the settings that can be provided to the SearchField constructor.
   */
  export interface $SearchFieldSettings extends $ControlSettings {
    /**
     * Input Value.
     */
    value?: string | PropertyBindingInfo;

    /**
     * Defines the CSS width of the input. If not set, width is 100%.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Boolean property to enable the control (default is true).
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Invisible inputs are not rendered.
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Maximum number of characters. Value '0' means the feature is switched off.
     */
    maxLength?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Text shown when no value available. If no placeholder value is set, the word "Search" in the current
     * local language (if supported) or in English will be displayed as a placeholder (property value will still
     * be `null` in that case).
     */
    placeholder?: string | PropertyBindingInfo;

    /**
     * Set to `false` to hide the magnifier icon.
     *
     * @deprecated As of version 1.16.0. This parameter is deprecated. Use "showSearchButton" instead.
     */
    showMagnifier?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Set to `true` to display a refresh button in place of the search icon. By pressing the refresh button
     * or F5 key on keyboard, the user can reload the results list without changing the search string. Note:
     * if "showSearchButton" property is set to `false`, both the search and refresh buttons are not displayed
     * even if the "showRefreshButton" property is true.
     *
     * @since 1.16
     */
    showRefreshButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Tooltip text of the refresh button. If it is not set, the Default tooltip text is the word "Refresh"
     * in the current local language (if supported) or in English. Tooltips are not displayed on touch devices.
     *
     * @since 1.16
     * @deprecated As of version 1.110.0. the concept has been discarded.
     */
    refreshButtonTooltip?: string | PropertyBindingInfo;

    /**
     * Set to `true` to show the search button with the magnifier icon. If `false`, both the search and refresh
     * buttons are not displayed even if the "showRefreshButton" property is `true`.
     *
     * @since 1.23
     */
    showSearchButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * If `true`, a `suggest` event is fired when user types in the input and when the input is focused. On
     * a phone device, a full screen dialog with suggestions is always shown even if the suggestions list is
     * empty.
     *
     * @since 1.34
     */
    enableSuggestions?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Normally, search text is selected for copy when the SearchField is focused by keyboard navigation. If
     * an application re-renders the SearchField during the liveChange event, set this property to `false` to
     * disable text selection by focus.
     *
     * @since 1.20
     * @deprecated As of version 1.38. This parameter is deprecated and has no effect in run time. The cursor
     * position of a focused search field is restored after re-rendering automatically.
     */
    selectOnFocus?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * `SuggestionItems` are the items which will be shown in the suggestions list. The following properties
     * can be used:
     * 	 - `key` is not displayed and may be used as internal technical field
     * 	 - `text` is displayed as normal suggestion text
     * 	 - `icon`
     * 	 - `description` - additional text may be used to visually display search item type or category
     *
     * @since 1.34
     */
    suggestionItems?:
      | SuggestionItem[]
      | SuggestionItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Association to controls / ids which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Event which is fired when the user triggers a search.
     */
    search?: (oEvent: SearchField$SearchEvent) => void;

    /**
     * This event is fired when the user changes the value of the search field. Unlike the `liveChange` event,
     * the `change` event is not fired for each key press.
     *
     * @since 1.77
     */
    change?: (oEvent: SearchField$ChangeEvent) => void;

    /**
     * This event is fired each time when the value of the search field is changed by the user - e.g. at each
     * key press. Do not invalidate a focused search field, especially during the liveChange event.
     *
     * @since 1.9.1
     */
    liveChange?: (oEvent: SearchField$LiveChangeEvent) => void;

    /**
     * This event is fired when the search field is initially focused or its value is changed by the user. This
     * event means that suggestion data should be updated, in case if suggestions are used. Use the value parameter
     * to create new suggestions for it.
     *
     * @since 1.34
     */
    suggest?: (oEvent: SearchField$SuggestEvent) => void;
  }

  /**
   * Parameters of the SearchField#change event.
   */
  export interface SearchField$ChangeEventParameters {
    /**
     * The new value of the control.
     */
    value?: string;
  }

  /**
   * Event object of the SearchField#change event.
   */
  export type SearchField$ChangeEvent = Event<
    SearchField$ChangeEventParameters,
    SearchField
  >;

  /**
   * Parameters of the SearchField#liveChange event.
   */
  export interface SearchField$LiveChangeEventParameters {
    /**
     * Current search string.
     */
    newValue?: string;
  }

  /**
   * Event object of the SearchField#liveChange event.
   */
  export type SearchField$LiveChangeEvent = Event<
    SearchField$LiveChangeEventParameters,
    SearchField
  >;

  /**
   * Parameters of the SearchField#search event.
   */
  export interface SearchField$SearchEventParameters {
    /**
     * The search query string.
     */
    query?: string;

    /**
     * Suggestion list item in case if the user has selected an item from the suggestions list.
     */
    suggestionItem?: SuggestionItem;

    /**
     * Indicates if the user pressed the refresh icon.
     */
    refreshButtonPressed?: boolean;

    /**
     * Indicates if the user pressed the clear icon.
     */
    clearButtonPressed?: boolean;

    /**
     * Indicates if the user pressed the search button.
     */
    searchButtonPressed?: boolean;

    /**
     * Indicates that ESC key triggered the event. **Note:** This parameter will not be sent unless the ESC
     * key is pressed.
     */
    escPressed?: boolean;
  }

  /**
   * Event object of the SearchField#search event.
   */
  export type SearchField$SearchEvent = Event<
    SearchField$SearchEventParameters,
    SearchField
  >;

  /**
   * Parameters of the SearchField#suggest event.
   */
  export interface SearchField$SuggestEventParameters {
    /**
     * Current search string of the search field.
     */
    suggestValue?: string;
  }

  /**
   * Event object of the SearchField#suggest event.
   */
  export type SearchField$SuggestEvent = Event<
    SearchField$SuggestEventParameters,
    SearchField
  >;
}

declare module "sap/m/SegmentedButton" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IFormContent,
    ID,
    URI,
    TextDirection,
    AccessibilityInfo,
    CSSSize,
  } from "sap/ui/core/library";

  import {
    IOverflowToolbarContent,
    IToolbarInteractiveControl,
  } from "sap/m/library";

  import Button from "sap/m/Button";

  import SegmentedButtonItem from "sap/m/SegmentedButtonItem";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Event from "sap/ui/base/Event";

  /**
   * A horizontal control made of multiple buttons, which can display a title or an image.
   *
   * Overview:
   *
   * The `SegmentedButton` shows a group of buttons. When the user clicks or taps one of the buttons, it stays
   * in a pressed state. It automatically resizes the buttons to fit proportionally within the control. When
   * no width is set, the control uses the available width.
   */
  export default class SegmentedButton
    extends Control
    implements IFormContent, IOverflowToolbarContent, IToolbarInteractiveControl
  {
    __implements__sap_ui_core_IFormContent: boolean;
    __implements__sap_m_IOverflowToolbarContent: boolean;
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new `SegmentedButton`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/button/ Segmented Button}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SegmentedButtonSettings
    );
    /**
     * Constructor for a new `SegmentedButton`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/button/ Segmented Button}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SegmentedButtonSettings
    );

    /**
     * Creates a new subclass of class sap.m.SegmentedButton with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SegmentedButton>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SegmentedButton.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds some button to the aggregation {@link #getButtons buttons}.
     *
     * @deprecated As of version 1.28.0. replaced by `items` aggregation
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addButton(
      /**
       * The button to add; if empty, nothing is inserted
       */
      oButton: Button
    ): this;
    /**
     * Adds item to `items` aggregation.
     *
     *
     * @returns `this` pointer for chaining
     */
    addItem(
      /**
       * The item to be added
       */
      oItem: SegmentedButtonItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:select select} event of this `sap.m.SegmentedButton`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SegmentedButton` itself.
     *
     * Fires when the user selects a button, which returns the ID and button object.
     *
     * @deprecated As of version 1.52. replaced by `selectionChange` event
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SegmentedButton$SelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SegmentedButton` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:select select} event of this `sap.m.SegmentedButton`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SegmentedButton` itself.
     *
     * Fires when the user selects a button, which returns the ID and button object.
     *
     * @deprecated As of version 1.52. replaced by `selectionChange` event
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SegmentedButton$SelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SegmentedButton` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionChange selectionChange} event of this
     * `sap.m.SegmentedButton`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SegmentedButton` itself.
     *
     * Fires when the user selects an item, which returns the item object.
     *
     * @since 1.52
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SegmentedButton$SelectionChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SegmentedButton` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionChange selectionChange} event of this
     * `sap.m.SegmentedButton`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SegmentedButton` itself.
     *
     * Fires when the user selects an item, which returns the item object.
     *
     * @since 1.52
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SegmentedButton$SelectionChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SegmentedButton` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getItems items} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     * @since 1.28
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Binds property {@link #getSelectedKey selectedKey} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindProperty ManagedObject.bindProperty} for a detailed description
     * of the possible properties of `oBindingInfo`
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindSelectedKey(
      /**
       * The binding information
       */
      oBindingInfo: PropertyBindingInfo
    ): this;
    /**
     * Adds a Button with a text as title, a URI for an icon, enabled and textDirection. Only one is allowed.
     *
     * @since 1.28.0
     *
     * @returns The created Button
     */
    createButton(
      /**
       * Defines the title text of the newly created Button
       */
      sText: string,
      /**
       * Icon to be displayed as graphical element within the Button. Density related image will be loaded if
       * image with density awareness name in format [imageName]@[densityValue].[extension] is provided.
       */
      sURI?: URI,
      /**
       * Enables the control. Buttons that are disabled have other colors than enabled ones, depending on custom
       * settings.
       */
      bEnabled?: boolean,
      /**
       * Element's text directionality with enumerated options
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): Button;
    /**
     * Destroys all the buttons in the aggregation {@link #getButtons buttons}.
     *
     * @deprecated As of version 1.28.0. replaced by `items` aggregation
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyButtons(): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     * @since 1.28
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:select select} event of this `sap.m.SegmentedButton`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @deprecated As of version 1.52. replaced by `selectionChange` event
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SegmentedButton$SelectEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:selectionChange selectionChange} event of
     * this `sap.m.SegmentedButton`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.52
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelectionChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SegmentedButton$SelectionChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:select select} to attached listeners.
     *
     * @deprecated As of version 1.52. replaced by `selectionChange` event
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SegmentedButton$SelectEventParameters
    ): this;
    /**
     * Fires event {@link #event:selectionChange selectionChange} to attached listeners.
     *
     * @since 1.52
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelectionChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SegmentedButton$SelectionChangeEventParameters
    ): this;
    /**
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Current accessibility state of the control
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets content of aggregation {@link #getButtons buttons}.
     *
     * The buttons of the SegmentedButton control. The items set in this aggregation are used as an interface
     * for the buttons displayed by the control. Only the properties ID, icon, text, enabled and textDirections
     * of the Button control are evaluated. Setting other properties of the button will have no effect. Alternatively,
     * you can use the createButton method to add buttons.
     *
     * @deprecated As of version 1.28.0. replaced by `items` aggregation
     */
    getButtons(): Button[];
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Disables all the buttons in the SegmentedButton control. When disabled all the buttons look grey and
     * you cannot focus or click on them.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * `SegmentedButton` must not be stretched in Form because ResizeHandler is used internally in order to
     * manage the width of the SegmentedButton depending on the container size
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns True this method always returns `true`
     */
    getFormDoNotAdjustWidth(): boolean;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * Aggregation of items to be displayed. The items set in this aggregation are used as an interface for
     * the buttons displayed by the control. The "items" and "buttons" aggregations should NOT be used simultaneously
     * as it causes the control to work incorrectly. Note: If `width` is supplied in percetange to `SegmentedButtonItem`
     * instances and the sum of all percentages exeeds 100%, then the buttons display could overlap other elements
     * in the page.
     *
     * @since 1.28
     */
    getItems(): SegmentedButtonItem[];
    /**
     * ID of the element which is the current target of the association {@link #getSelectedButton selectedButton},
     * or `null`.
     *
     * @deprecated As of version 1.52. replaced by `selectedItem` association
     */
    getSelectedButton(): ID | null;
    /**
     * ID of the element which is the current target of the association {@link #getSelectedItem selectedItem},
     * or `null`.
     *
     * @since 1.52
     */
    getSelectedItem(): ID | null;
    /**
     * Gets the `selectedKey` and is usable only when the control is initiated with the `items` aggregation.
     *
     * @since 1.28
     *
     * @returns Current selected key
     */
    getSelectedKey(): string;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Defines the width of the SegmentedButton control. If not set, it uses the minimum required width to make
     * all buttons inside of the same size (based on the biggest button).
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Checks for the provided `sap.m.Button` in the aggregation {@link #getButtons buttons}. and returns its
     * index if found or -1 otherwise.
     *
     * @deprecated As of version 1.28.0. replaced by `items` aggregation
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfButton(
      /**
       * The button whose index is looked for
       */
      oButton: Button
    ): int;
    /**
     * Checks for the provided `sap.m.SegmentedButtonItem` in the aggregation {@link #getItems items}. and returns
     * its index if found or -1 otherwise.
     *
     * @since 1.28
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: SegmentedButtonItem
    ): int;
    /**
     * Inserts a button into the aggregation {@link #getButtons buttons}.
     *
     * @deprecated As of version 1.28.0. replaced by `items` aggregation
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertButton(
      /**
       * The button to insert; if empty, nothing is inserted
       */
      oButton: Button,
      /**
       * The `0`-based index the button should be inserted at; for a negative value of `iIndex`, the button is
       * inserted at position 0; for a value greater than the current size of the aggregation, the button is inserted
       * at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts item into `items` aggregation.
     *
     *
     * @returns `this` pointer for chaining
     */
    insertItem(
      /**
       * The item to be inserted
       */
      oItem: SegmentedButtonItem,
      /**
       * index the item should be inserted at
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all the controls from the aggregation {@link #getButtons buttons}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @deprecated As of version 1.28.0. replaced by `items` aggregation
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllButtons(): Button[];
    /**
     * Removes all items from `items` aggregation
     */
    removeAllItems(
      /**
       * If `true` the control invalidation will be suppressed
       */
      bSuppressInvalidate?: boolean
    ): void;
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes a button from the aggregation {@link #getButtons buttons}.
     *
     * @deprecated As of version 1.28.0. replaced by `items` aggregation
     *
     * @returns The removed button or `null`
     */
    removeButton(
      /**
       * The button to remove or its index or id
       */
      vButton: int | string | Button
    ): Button | null;
    /**
     * Removes an item from `items` aggregation.
     */
    removeItem(
      /**
       * The item to be removed
       */
      oItem: SegmentedButtonItem
    ): void;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Disables all the buttons in the SegmentedButton control. When disabled all the buttons look grey and
     * you cannot focus or click on them.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Setter for association `selectedButton`.
     *
     *
     * @returns `this` pointer for chaining
     */
    setSelectedButton(
      /**
       * New value for association `setSelectedButton` An sap.m.Button instance which becomes the new target of
       * this `selectedButton` association. Alternatively, the ID of an sap.m.Button instance may be given as
       * a string. If the value of null, undefined, or an empty string is provided the first item will be selected.
       */
      vButton: ID | Button | null | undefined
    ): this;
    /**
     * Setter for association `selectedItem`.
     *
     *
     * @returns `this` pointer for chaining
     */
    setSelectedItem(
      /**
       * New value for association `setSelectedItem` An sap.m.SegmentedButtonItem instance which becomes the new
       * target of this `selectedItem` association. Alternatively, the ID of an `sap.m.SegmentedButtonItem` instance
       * may be given as a string. If the value of null, undefined, or an empty string is provided, the first
       * item will be selected.
       */
      vItem: ID | SegmentedButtonItem | null | undefined
    ): this;
    /**
     * Sets the `selectedKey` and is usable only when the control is initiated with the `items` aggregation.
     *
     * @since 1.28
     *
     * @returns `this` pointer for chaining
     */
    setSelectedKey(
      /**
       * The key of the button to be selected
       */
      sKey: string
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Defines the width of the SegmentedButton control. If not set, it uses the minimum required width to make
     * all buttons inside of the same size (based on the biggest button).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Unbinds aggregation {@link #getItems items} from model data.
     *
     * @since 1.28
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindItems(): this;
    /**
     * Unbinds property {@link #getSelectedKey selectedKey} from model data.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindSelectedKey(): this;
  }
  /**
   * Describes the settings that can be provided to the SegmentedButton constructor.
   */
  export interface $SegmentedButtonSettings extends $ControlSettings {
    /**
     * Defines the width of the SegmentedButton control. If not set, it uses the minimum required width to make
     * all buttons inside of the same size (based on the biggest button).
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Disables all the buttons in the SegmentedButton control. When disabled all the buttons look grey and
     * you cannot focus or click on them.
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Key of the selected item. If no item to this key is found in the items aggregation, no changes will apply.
     * Only the items aggregation is affected. If duplicate keys exist, the first item matching the key is used.
     *
     * @since 1.28.0
     */
    selectedKey?: string | PropertyBindingInfo;

    /**
     * The buttons of the SegmentedButton control. The items set in this aggregation are used as an interface
     * for the buttons displayed by the control. Only the properties ID, icon, text, enabled and textDirections
     * of the Button control are evaluated. Setting other properties of the button will have no effect. Alternatively,
     * you can use the createButton method to add buttons.
     *
     * @deprecated As of version 1.28.0. replaced by `items` aggregation
     */
    buttons?: Button[] | Button | AggregationBindingInfo | `{${string}}`;

    /**
     * Aggregation of items to be displayed. The items set in this aggregation are used as an interface for
     * the buttons displayed by the control. The "items" and "buttons" aggregations should NOT be used simultaneously
     * as it causes the control to work incorrectly. Note: If `width` is supplied in percetange to `SegmentedButtonItem`
     * instances and the sum of all percentages exeeds 100%, then the buttons display could overlap other elements
     * in the page.
     *
     * @since 1.28
     */
    items?:
      | SegmentedButtonItem[]
      | SegmentedButtonItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * A reference to the currently selected button control. By default or if the association is set to false
     * (null, undefined, "", false), the first button will be selected. If the association is set to an invalid
     * value (for example, an ID of a button that does not exist) the selection on the SegmentedButton will
     * be removed.
     *
     * @deprecated As of version 1.52. replaced by `selectedItem` association
     */
    selectedButton?: Button | string;

    /**
     * A reference to the currently selected item control.
     *
     * @since 1.52
     */
    selectedItem?: SegmentedButtonItem | string;

    /**
     * Association to controls / IDs, which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Association to controls / IDs, which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Fires when the user selects a button, which returns the ID and button object.
     *
     * @deprecated As of version 1.52. replaced by `selectionChange` event
     */
    select?: (oEvent: SegmentedButton$SelectEvent) => void;

    /**
     * Fires when the user selects an item, which returns the item object.
     *
     * @since 1.52
     */
    selectionChange?: (oEvent: SegmentedButton$SelectionChangeEvent) => void;
  }

  /**
   * Parameters of the SegmentedButton#select event.
   *
   * @deprecated As of version 1.52. replaced by `selectionChange` event
   */
  export interface SegmentedButton$SelectEventParameters {
    /**
     * Reference to the button, that has been selected.
     */
    button?: Button;

    /**
     * ID of the button, which has been selected.
     */
    id?: string;

    /**
     * Key of the button, which has been selected. This property is only filled when the control is initiated
     * with the items aggregation.
     */
    key?: string;
  }

  /**
   * Event object of the SegmentedButton#select event.
   *
   * @deprecated As of version 1.52. replaced by `selectionChange` event
   */
  export type SegmentedButton$SelectEvent = Event<
    SegmentedButton$SelectEventParameters,
    SegmentedButton
  >;

  /**
   * Parameters of the SegmentedButton#selectionChange event.
   */
  export interface SegmentedButton$SelectionChangeEventParameters {
    /**
     * Reference to the item, that has been selected.
     */
    item?: SegmentedButtonItem;
  }

  /**
   * Event object of the SegmentedButton#selectionChange event.
   */
  export type SegmentedButton$SelectionChangeEvent = Event<
    SegmentedButton$SelectionChangeEventParameters,
    SegmentedButton
  >;
}

declare module "sap/m/SegmentedButtonItem" {
  import { default as Item, $ItemSettings } from "sap/ui/core/Item";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { CSSSize } from "sap/ui/core/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Used for creating buttons for the {@link sap.m.SegmentedButton}. It is derived from the {@link sap.ui.core.Item}.
   *
   * @since 1.28
   */
  export default class SegmentedButtonItem extends Item {
    /**
     * Constructor for a new `SegmentedButtonItem`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SegmentedButtonItemSettings
    );
    /**
     * Constructor for a new `SegmentedButtonItem`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SegmentedButtonItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.SegmentedButtonItem with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Item.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SegmentedButtonItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SegmentedButtonItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.SegmentedButtonItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SegmentedButtonItem` itself.
     *
     * Fires when the user clicks on an individual button.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SegmentedButtonItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.SegmentedButtonItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SegmentedButtonItem` itself.
     *
     * Fires when the user clicks on an individual button.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SegmentedButtonItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.SegmentedButtonItem`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Cleanup
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    exit(): void;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * The icon, which belongs to the button. This can be a URI to an image or an icon font URI.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): string;
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * Whether the button should be visible on the screen. If set to false, a placeholder is rendered instead
     * of the real button.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Sets the width of the buttons.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Called once during the element's initialization
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    init(): void;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * The icon, which belongs to the button. This can be a URI to an image or an icon font URI.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: string
    ): this;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * Whether the button should be visible on the screen. If set to false, a placeholder is rendered instead
     * of the real button.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Sets the width of the buttons.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
  }
  /**
   * Describes the settings that can be provided to the SegmentedButtonItem constructor.
   */
  export interface $SegmentedButtonItemSettings extends $ItemSettings {
    /**
     * The icon, which belongs to the button. This can be a URI to an image or an icon font URI.
     */
    icon?: string | PropertyBindingInfo;

    /**
     * Whether the button should be visible on the screen. If set to false, a placeholder is rendered instead
     * of the real button.
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the width of the buttons.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Fires when the user clicks on an individual button.
     */
    press?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the SegmentedButtonItem#press event.
   */
  export interface SegmentedButtonItem$PressEventParameters {}

  /**
   * Event object of the SegmentedButtonItem#press event.
   */
  export type SegmentedButtonItem$PressEvent = Event<
    SegmentedButtonItem$PressEventParameters,
    SegmentedButtonItem
  >;
}

declare module "sap/m/Select" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IFormContent,
    ISemanticFormContent,
    ILabelable,
    ID,
    AccessibilityInfo,
    URI,
    CSSSize,
    TextAlign,
    TextDirection,
    ValueState,
  } from "sap/ui/core/library";

  import {
    IOverflowToolbarContent,
    IToolbarInteractiveControl,
    SelectColumnRatio,
    OverflowToolbarConfig,
    SelectType,
  } from "sap/m/library";

  import { IShellBar } from "sap/f/library";

  import Item from "sap/ui/core/Item";

  import Event from "sap/ui/base/Event";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * The `sap.m.Select` control provides a list of items that allows users to select an item.
   */
  export default class Select
    extends Control
    implements
      IFormContent,
      ISemanticFormContent,
      ILabelable,
      IOverflowToolbarContent,
      IToolbarInteractiveControl,
      IShellBar
  {
    __implements__sap_ui_core_IFormContent: boolean;
    __implements__sap_ui_core_ISemanticFormContent: boolean;
    __implements__sap_ui_core_ILabelable: boolean;
    __implements__sap_m_IOverflowToolbarContent: boolean;
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    __implements__sap_f_IShellBar: boolean;
    /**
     * Constructor for a new `sap.m.Select`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/select/ Select}
     */
    constructor(
      /**
       * Initial settings for the new control.
       */
      mSettings?: $SelectSettings
    );
    /**
     * Constructor for a new `sap.m.Select`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/select/ Select}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given.
       */
      sId?: string,
      /**
       * Initial settings for the new control.
       */
      mSettings?: $SelectSettings
    );

    /**
     * Creates a new subclass of class sap.m.Select with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Select>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Select.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds an item to the aggregation named `items`.
     *
     *
     * @returns `this` to allow method chaining.
     */
    addItem(
      /**
       * The item to be added; if empty, nothing is added.
       */
      oItem: Item
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.Select`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Select` itself.
     *
     * This event is triggered prior to the opening of the `sap.m.SelectList`.
     *
     * @since 1.130
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Select` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.Select`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Select` itself.
     *
     * This event is triggered prior to the opening of the `sap.m.SelectList`.
     *
     * @since 1.130
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Select` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.Select`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Select` itself.
     *
     * This event is fired when the value in the selection field is changed in combination with one of the following
     * actions:
     * 	 - The focus leaves the selection field
     * 	 - The Enter key is pressed
     * 	 - The item is pressed
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Select$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Select` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.Select`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Select` itself.
     *
     * This event is fired when the value in the selection field is changed in combination with one of the following
     * actions:
     * 	 - The focus leaves the selection field
     * 	 - The Enter key is pressed
     * 	 - The item is pressed
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Select$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Select` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.Select`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Select` itself.
     *
     * Fires when the user navigates through the `Select` items. It's also fired on revert of the currently
     * selected item.
     *
     * **Note:** Revert occurs in some of the following actions:
     * 	 - The user clicks outside of the `Select`
     * 	 - The Escape key is pressed
     *
     * @since 1.100
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Select$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Select` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.Select`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Select` itself.
     *
     * Fires when the user navigates through the `Select` items. It's also fired on revert of the currently
     * selected item.
     *
     * **Note:** Revert occurs in some of the following actions:
     * 	 - The user clicks outside of the `Select`
     * 	 - The Escape key is pressed
     *
     * @since 1.100
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Select$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Select` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getItems items} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Closes the control's picker popup.
     *
     * @since 1.16
     *
     * @returns `this` to allow method chaining.
     */
    close(): this;
    /**
     * Creates a picker popup container where the selection should take place.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The `sap.m.Popover` or `sap.m.Dialog` instance
     */
    createPicker(
      /**
       * The picker type
       */
      sPickerType: string
    ): Control;
    /**
     * Destroys all the items in the aggregation named `items`.
     *
     *
     * @returns `this` to allow method chaining.
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeOpen beforeOpen} event of this `sap.m.Select`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.130
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:change change} event of this `sap.m.Select`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Select$ChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:liveChange liveChange} event of this `sap.m.Select`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.100
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLiveChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Select$LiveChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:beforeOpen beforeOpen} to attached listeners.
     *
     * @since 1.130
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforeOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:change change} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Select$ChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:liveChange liveChange} to attached listeners.
     *
     * @since 1.100
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLiveChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Select$LiveChangeEventParameters
    ): this;
    /**
     * Returns the `sap.m.Select` accessibility information.
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The object contains the accessibility information for `sap.m.Select`
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getAutoAdjustWidth autoAdjustWidth}.
     *
     * Indicates whether the width of the input field is determined by the selected item's content.
     *
     * Default value is `false`.
     *
     * @since 1.16
     *
     * @returns Value of property `autoAdjustWidth`
     */
    getAutoAdjustWidth(): boolean;
    /**
     * Gets current value of property {@link #getColumnRatio columnRatio}.
     *
     * Determines the ratio between the first and the second column when secondary values are displayed.
     *
     * **Note:** This property takes effect only when the `showSecondaryValues` property is set to `true`.
     *
     * Default value is `"3:2"`.
     *
     * @since 1.86
     *
     * @returns Value of property `columnRatio`
     */
    getColumnRatio(): SelectColumnRatio;
    /**
     * Gets current value of property {@link #getEditable editable}.
     *
     * Determines whether the user can modify the selected item. When the property is set to `false`, the control
     * appears as disabled but CAN still be focused.
     *
     * **Note:** When both `enabled` and `editable` properties are set to `false`, `enabled` has priority over
     * `editable`.
     *
     * Default value is `true`.
     *
     * @since 1.66.0
     *
     * @returns Value of property `editable`
     */
    getEditable(): boolean;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Determines whether the user can modify the selected item. When the property is set to `false`, the control
     * appears as disabled and CANNOT be focused.
     *
     * **Note:** When both `enabled` and `editable` properties are set to `false`, `enabled` has priority over
     * `editable`.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets the enabled items from the aggregation named `items`.
     *
     * @since 1.22.0
     *
     * @returns An array containing the enabled items.
     */
    getEnabledItems(
      /**
       * Items to filter.
       */
      aItems?: Item[]
    ): Item[];
    /**
     * Gets the first item from the aggregation named `items`.
     *
     * @since 1.16
     *
     * @returns The first item, or `null` if there are no items.
     */
    getFirstItem(): Item | null;
    /**
     * Returns the DOM Element that should get the focus.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Returns the DOM Element that should get the focus
     */
    getFocusDomRef(): Element;
    /**
     * Gets current value of property {@link #getForceSelection forceSelection}.
     *
     * Indicates whether the selection is restricted to one of the items in the list. **Note:** We strongly
     * recommend that you always set this property to `false` and bind the `selectedKey` property to the desired
     * value for better interoperability with data binding.
     *
     * Default value is `true`.
     *
     * @since 1.34
     *
     * @returns Value of property `forceSelection`
     */
    getForceSelection(): boolean;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * The URI to the icon that will be displayed only when using the `IconOnly` type.
     *
     * Default value is `empty string`.
     *
     * @since 1.16
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets the item from the aggregation named `items` at the given 0-based index.
     *
     * @since 1.16
     *
     * @returns Item at the given index, or `null` if none.
     */
    getItemAt(
      /**
       * Index of the item to return.
       */
      iIndex: int
    ): Item | null;
    /**
     * Gets the item with the given key from the aggregation named `items`.
     *
     * **Note: ** If duplicate keys exist, the first item matching the key is returned.
     *
     * @since 1.16
     *
     * @returns The `sap.ui.core.Item` instance or `null` if there is no such item
     */
    getItemByKey(
      /**
       * An item key that specifies the item to be retrieved.
       */
      sKey: string
    ): Item | null;
    /**
     * Gets aggregation `items`.
     *
     * **Note**: This is the default aggregation.
     *
     *
     * @returns The controls in the `items` aggregation
     */
    getItems(): Item[];
    /**
     * Gets the last item from the aggregation named `items`.
     *
     * @since 1.16
     *
     * @returns The last item, or `null` if there are no items.
     */
    getLastItem(): Item | null;
    /**
     * Gets current value of property {@link #getMaxWidth maxWidth}.
     *
     * Sets the maximum width of the control.
     *
     * **Note:** This property is ignored if the `autoAdjustWidth` property is set to `true`.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Value of property `maxWidth`
     */
    getMaxWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getName name}.
     *
     * The name to be used in the HTML code (for example, for HTML forms that send data to the server via submit).
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `name`
     */
    getName(): string;
    /**
     * Enables the `sap.m.Select` to move inside the sap.m.OverflowToolbar. Required by the {@link sap.m.IOverflowToolbarContent }
     * interface.
     *
     *
     * @returns Configuration information for the `sap.m.IOverflowToolbarContent` interface.
     */
    getOverflowToolbarConfig(): OverflowToolbarConfig;
    /**
     * Gets current value of property {@link #getRequired required}.
     *
     * Indicates that user input is required. This property is only needed for accessibility purposes when a
     * single relationship between the field and a label (see aggregation `labelFor` of `sap.m.Label`) cannot
     * be established (e.g. one label should label multiple fields).
     *
     * Default value is `false`.
     *
     * @since 1.74
     *
     * @returns Value of property `required`
     */
    getRequired(): boolean;
    /**
     * Gets current value of property {@link #getResetOnMissingKey resetOnMissingKey}.
     *
     * Modifies the behavior of the `setSelectedKey` method so that the selected item is cleared when a provided
     * selected key is missing.
     *
     * Default value is `false`.
     *
     * @since 1.77
     *
     * @returns Value of property `resetOnMissingKey`
     */
    getResetOnMissingKey(): boolean;
    /**
     * Gets the selected item object from the aggregation named `items`.
     *
     *
     * @returns The current target of the `selectedItem` association, or null.
     */
    getSelectedItem(): Item | null;
    /**
     * Gets current value of property {@link #getSelectedItemId selectedItemId}.
     *
     * ID of the selected item.
     *
     * Default value is `empty string`.
     *
     * @since 1.12
     *
     * @returns Value of property `selectedItemId`
     */
    getSelectedItemId(): string;
    /**
     * Gets current value of property {@link #getSelectedKey selectedKey}.
     *
     * Key of the selected item.
     *
     * **Notes:**
     * 	 -  If duplicate keys exist, the first item matching the key is used.
     * 	 -  If invalid or none `selectedKey` is used, the first item is being selected.
     * 	 -  Invalid or missing `selectedKey` leads to severe functional issues in `sap.ui.table.Table`, when
     *     the `sap.m.Select` is used inside a `sap.ui.table.Table` column.
     * 	 -  If an item with the default key exists and we try to select it, it happens only if the `forceSelection`
     *     property is set to `true`.
     *
     * Default value is `empty string`.
     *
     * @since 1.11
     *
     * @returns Value of property `selectedKey`
     */
    getSelectedKey(): string;
    /**
     * Gets current value of property {@link #getShowSecondaryValues showSecondaryValues}.
     *
     * Indicates whether the text values of the `additionalText` property of a {@link sap.ui.core.ListItem }
     * are shown.
     *
     * Default value is `false`.
     *
     * @since 1.40
     *
     * @returns Value of property `showSecondaryValues`
     */
    getShowSecondaryValues(): boolean;
    /**
     * Gets current value of property {@link #getTextAlign textAlign}.
     *
     * Sets the horizontal alignment of the text within the input field.
     *
     * Default value is `Initial`.
     *
     * @since 1.28
     *
     * @returns Value of property `textAlign`
     */
    getTextAlign(): TextAlign;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * Specifies the direction of the text within the input field with enumerated options. By default, the control
     * inherits text direction from the DOM.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getType type}.
     *
     * Type of a select. Possible values `Default`, `IconOnly`.
     *
     * Default value is `Default`.
     *
     * @since 1.16
     *
     * @returns Value of property `type`
     */
    getType(): SelectType;
    /**
     * Gets current value of property {@link #getValueState valueState}.
     *
     * Visualizes the validation state of the control, e.g. `Error`, `Warning`, `Success`, `Information`.
     *
     * Default value is `None`.
     *
     * @since 1.40.2
     *
     * @returns Value of property `valueState`
     */
    getValueState(): ValueState;
    /**
     * Gets current value of property {@link #getValueStateText valueStateText}.
     *
     * Defines the text of the value state message popup. If this is not specified, a default text is shown
     * from the resource bundle.
     *
     * Default value is `empty string`.
     *
     * @since 1.40.5
     *
     * @returns Value of property `valueStateText`
     */
    getValueStateText(): string;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Sets the width of the field. By default, the field width is automatically adjusted to the size of its
     * content and the default width of the field is calculated based on the widest list item in the dropdown
     * list. If the width defined is smaller than its content, only the field width is changed whereas the dropdown
     * list keeps the width of its content. If the dropdown list is wider than the visual viewport, it is truncated
     * and an ellipsis is displayed for each item. For phones, the width of the dropdown list is always the
     * same as the viewport.
     *
     * **Note:** This property is ignored if the `autoAdjustWidth` property is set to `true`.
     *
     * Default value is `"auto"`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getWrapItemsText wrapItemsText}.
     *
     * Determines whether the text in the items wraps on multiple lines when the available width is not enough.
     * When the text is truncated (`wrapItemsText` property is set to `false`), the max width of the `SelectList`
     * is 600px. When `wrapItemsText` is set to `true`, `SelectList` takes all of the available width.
     *
     * Default value is `false`.
     *
     * @since 1.69
     *
     * @returns Value of property `wrapItemsText`
     */
    getWrapItemsText(): boolean;
    /**
     * Returns if the control can be bound to a label
     *
     *
     * @returns `true` if the control can be bound to a label
     */
    hasLabelableHTMLElement(): boolean;
    /**
     * Checks for the provided `sap.ui.core.Item` in the aggregation {@link #getItems items}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: Item
    ): int;
    /**
     * Inserts an item into the aggregation named `items`.
     *
     *
     * @returns `this` to allow method chaining.
     */
    insertItem(
      /**
       * The item to be inserted; if empty, nothing is inserted.
       */
      oItem: Item,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position.
       */
      iIndex: int
    ): this;
    /**
     * Indicates whether the control's picker popup is opened.
     *
     * @since 1.16
     *
     * @returns Indicates whether the picker popup is currently open (this includes opening and closing animations).
     */
    isOpen(): boolean;
    /**
     * Open the control's picker popup.
     *
     * @since 1.16
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns `this` to allow method chaining.
     */
    open(): this;
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all the items in the aggregation named `items`. Additionally unregisters them from the hosting
     * UIArea.
     *
     *
     * @returns An array of the removed items (might be empty).
     */
    removeAllItems(): Item[];
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an item from the aggregation named `items`.
     *
     *
     * @returns The removed item or `null`.
     */
    removeItem(
      /**
       * The item to be removed or its index or ID.
       */
      vItem: int | ID | Item
    ): Item | null;
    /**
     * Select next selectable item in the select list
     *
     *
     * @returns item to be selected
     */
    selectNextSelectableItem(): Item;
    /**
     * Sets a new value for property {@link #getAutoAdjustWidth autoAdjustWidth}.
     *
     * Indicates whether the width of the input field is determined by the selected item's content.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAutoAdjustWidth(
      /**
       * New value for property `autoAdjustWidth`
       */
      bAutoAdjustWidth?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getColumnRatio columnRatio}.
     *
     * Determines the ratio between the first and the second column when secondary values are displayed.
     *
     * **Note:** This property takes effect only when the `showSecondaryValues` property is set to `true`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"3:2"`.
     *
     * @since 1.86
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setColumnRatio(
      /**
       * New value for property `columnRatio`
       */
      sColumnRatio?: SelectColumnRatio
    ): this;
    /**
     * Sets a new value for property {@link #getEditable editable}.
     *
     * Determines whether the user can modify the selected item. When the property is set to `false`, the control
     * appears as disabled but CAN still be focused.
     *
     * **Note:** When both `enabled` and `editable` properties are set to `false`, `enabled` has priority over
     * `editable`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.66.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEditable(
      /**
       * New value for property `editable`
       */
      bEditable?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Determines whether the user can modify the selected item. When the property is set to `false`, the control
     * appears as disabled and CANNOT be focused.
     *
     * **Note:** When both `enabled` and `editable` properties are set to `false`, `enabled` has priority over
     * `editable`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getForceSelection forceSelection}.
     *
     * Indicates whether the selection is restricted to one of the items in the list. **Note:** We strongly
     * recommend that you always set this property to `false` and bind the `selectedKey` property to the desired
     * value for better interoperability with data binding.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.34
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setForceSelection(
      /**
       * New value for property `forceSelection`
       */
      bForceSelection?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * The URI to the icon that will be displayed only when using the `IconOnly` type.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getMaxWidth maxWidth}.
     *
     * Sets the maximum width of the control.
     *
     * **Note:** This property is ignored if the `autoAdjustWidth` property is set to `true`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxWidth(
      /**
       * New value for property `maxWidth`
       */
      sMaxWidth?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getName name}.
     *
     * The name to be used in the HTML code (for example, for HTML forms that send data to the server via submit).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setName(
      /**
       * New value for property `name`
       */
      sName?: string
    ): this;
    /**
     * Sets a new value for property {@link #getRequired required}.
     *
     * Indicates that user input is required. This property is only needed for accessibility purposes when a
     * single relationship between the field and a label (see aggregation `labelFor` of `sap.m.Label`) cannot
     * be established (e.g. one label should label multiple fields).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.74
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRequired(
      /**
       * New value for property `required`
       */
      bRequired?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getResetOnMissingKey resetOnMissingKey}.
     *
     * Modifies the behavior of the `setSelectedKey` method so that the selected item is cleared when a provided
     * selected key is missing.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.77
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setResetOnMissingKey(
      /**
       * New value for property `resetOnMissingKey`
       */
      bResetOnMissingKey?: boolean
    ): this;
    /**
     * Sets the `selectedItem` association.
     *
     * Default value is `null`.
     *
     *
     * @returns `this` to allow method chaining.
     */
    setSelectedItem(
      /**
       * New value for the `selectedItem` association. If an ID of a `sap.ui.core.Item` is given, the item with
       * this ID becomes the `selectedItem` association. Alternatively, a `sap.ui.core.Item` instance may be given
       * or `null`. If the value of `null` is provided, the first enabled item will be selected (if any items
       * exist).
       */
      vItem: ID | Item | null
    ): this;
    /**
     * Sets the `selectedItemId` property.
     *
     * Default value is an empty string `""` or `undefined`.
     *
     * @since 1.12
     *
     * @returns `this` to allow method chaining.
     */
    setSelectedItemId(
      /**
       * New value for property `selectedItemId`. If the provided `vItem` has a default value, the first enabled
       * item will be selected (if any items exist).
       */
      vItem?: string
    ): this;
    /**
     * Sets property `selectedKey`.
     *
     * Default value is an empty string `""` or `undefined`.
     *
     * @since 1.11
     *
     * @returns `this` to allow method chaining.
     */
    setSelectedKey(
      /**
       * New value for property `selectedKey`. If the `forceSelection` property is set to `true` and the provided
       * `sKey` is an empty string `""` or `undefined`, the value of `sKey` is changed to match the `key` of the
       * first enabled item and the first enabled item is selected (if any items exist).
       *
       * If an item with the default key exists and we try to select it, it happens only if the `forceSelection`
       * property is set to `true`. If duplicate keys exist, the first item matching the key is selected.
       */
      sKey: string
    ): this;
    /**
     * Sets a new value for property {@link #getShowSecondaryValues showSecondaryValues}.
     *
     * Indicates whether the text values of the `additionalText` property of a {@link sap.ui.core.ListItem }
     * are shown.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.40
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowSecondaryValues(
      /**
       * New value for property `showSecondaryValues`
       */
      bShowSecondaryValues?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getTextAlign textAlign}.
     *
     * Sets the horizontal alignment of the text within the input field.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Initial`.
     *
     * @since 1.28
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextAlign(
      /**
       * New value for property `textAlign`
       */
      sTextAlign?: TextAlign | keyof typeof TextAlign
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * Specifies the direction of the text within the input field with enumerated options. By default, the control
     * inherits text direction from the DOM.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getType type}.
     *
     * Type of a select. Possible values `Default`, `IconOnly`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Default`.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setType(
      /**
       * New value for property `type`
       */
      sType?: SelectType | keyof typeof SelectType
    ): this;
    /**
     * Sets a new value for property {@link #getValueState valueState}.
     *
     * Visualizes the validation state of the control, e.g. `Error`, `Warning`, `Success`, `Information`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     * @since 1.40.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueState(
      /**
       * New value for property `valueState`
       */
      sValueState?: ValueState | keyof typeof ValueState
    ): this;
    /**
     * Sets a new value for property {@link #getValueStateText valueStateText}.
     *
     * Defines the text of the value state message popup. If this is not specified, a default text is shown
     * from the resource bundle.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.40.5
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueStateText(
      /**
       * New value for property `valueStateText`
       */
      sValueStateText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Sets the width of the field. By default, the field width is automatically adjusted to the size of its
     * content and the default width of the field is calculated based on the widest list item in the dropdown
     * list. If the width defined is smaller than its content, only the field width is changed whereas the dropdown
     * list keeps the width of its content. If the dropdown list is wider than the visual viewport, it is truncated
     * and an ellipsis is displayed for each item. For phones, the width of the dropdown list is always the
     * same as the viewport.
     *
     * **Note:** This property is ignored if the `autoAdjustWidth` property is set to `true`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"auto"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Sets the `wrapItemsText` property.
     *
     * @since 1.69
     *
     * @returns `this` to allow method chaining
     */
    setWrapItemsText(bWrap: boolean): this;
    /**
     * Unbinds aggregation {@link #getItems items} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindItems(): this;
  }
  /**
   * Describes the settings that can be provided to the Select constructor.
   */
  export interface $SelectSettings extends $ControlSettings {
    /**
     * The name to be used in the HTML code (for example, for HTML forms that send data to the server via submit).
     */
    name?: string | PropertyBindingInfo;

    /**
     * Determines whether the user can modify the selected item. When the property is set to `false`, the control
     * appears as disabled and CANNOT be focused.
     *
     * **Note:** When both `enabled` and `editable` properties are set to `false`, `enabled` has priority over
     * `editable`.
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the user can modify the selected item. When the property is set to `false`, the control
     * appears as disabled but CAN still be focused.
     *
     * **Note:** When both `enabled` and `editable` properties are set to `false`, `enabled` has priority over
     * `editable`.
     *
     * @since 1.66.0
     */
    editable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the width of the field. By default, the field width is automatically adjusted to the size of its
     * content and the default width of the field is calculated based on the widest list item in the dropdown
     * list. If the width defined is smaller than its content, only the field width is changed whereas the dropdown
     * list keeps the width of its content. If the dropdown list is wider than the visual viewport, it is truncated
     * and an ellipsis is displayed for each item. For phones, the width of the dropdown list is always the
     * same as the viewport.
     *
     * **Note:** This property is ignored if the `autoAdjustWidth` property is set to `true`.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the maximum width of the control.
     *
     * **Note:** This property is ignored if the `autoAdjustWidth` property is set to `true`.
     */
    maxWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Key of the selected item.
     *
     * **Notes:**
     * 	 -  If duplicate keys exist, the first item matching the key is used.
     * 	 -  If invalid or none `selectedKey` is used, the first item is being selected.
     * 	 -  Invalid or missing `selectedKey` leads to severe functional issues in `sap.ui.table.Table`, when
     *     the `sap.m.Select` is used inside a `sap.ui.table.Table` column.
     * 	 -  If an item with the default key exists and we try to select it, it happens only if the `forceSelection`
     *     property is set to `true`.
     *
     * @since 1.11
     */
    selectedKey?: string | PropertyBindingInfo;

    /**
     * ID of the selected item.
     *
     * @since 1.12
     */
    selectedItemId?: string | PropertyBindingInfo;

    /**
     * The URI to the icon that will be displayed only when using the `IconOnly` type.
     *
     * @since 1.16
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Type of a select. Possible values `Default`, `IconOnly`.
     *
     * @since 1.16
     */
    type?:
      | (SelectType | keyof typeof SelectType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Indicates whether the width of the input field is determined by the selected item's content.
     *
     * @since 1.16
     */
    autoAdjustWidth?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the horizontal alignment of the text within the input field.
     *
     * @since 1.28
     */
    textAlign?:
      | (TextAlign | keyof typeof TextAlign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies the direction of the text within the input field with enumerated options. By default, the control
     * inherits text direction from the DOM.
     *
     * @since 1.28
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Visualizes the validation state of the control, e.g. `Error`, `Warning`, `Success`, `Information`.
     *
     * @since 1.40.2
     */
    valueState?:
      | (ValueState | keyof typeof ValueState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the text of the value state message popup. If this is not specified, a default text is shown
     * from the resource bundle.
     *
     * @since 1.40.5
     */
    valueStateText?: string | PropertyBindingInfo;

    /**
     * Indicates whether the text values of the `additionalText` property of a {@link sap.ui.core.ListItem }
     * are shown.
     *
     * @since 1.40
     */
    showSecondaryValues?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Modifies the behavior of the `setSelectedKey` method so that the selected item is cleared when a provided
     * selected key is missing.
     *
     * @since 1.77
     */
    resetOnMissingKey?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether the selection is restricted to one of the items in the list. **Note:** We strongly
     * recommend that you always set this property to `false` and bind the `selectedKey` property to the desired
     * value for better interoperability with data binding.
     *
     * @since 1.34
     */
    forceSelection?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the text in the items wraps on multiple lines when the available width is not enough.
     * When the text is truncated (`wrapItemsText` property is set to `false`), the max width of the `SelectList`
     * is 600px. When `wrapItemsText` is set to `true`, `SelectList` takes all of the available width.
     *
     * @since 1.69
     */
    wrapItemsText?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the ratio between the first and the second column when secondary values are displayed.
     *
     * **Note:** This property takes effect only when the `showSecondaryValues` property is set to `true`.
     *
     * @since 1.86
     */
    columnRatio?: SelectColumnRatio | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates that user input is required. This property is only needed for accessibility purposes when a
     * single relationship between the field and a label (see aggregation `labelFor` of `sap.m.Label`) cannot
     * be established (e.g. one label should label multiple fields).
     *
     * @since 1.74
     */
    required?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the items contained within this control.
     *
     * **Note:** For items with icons you can use {@link sap.ui.core.ListItem}.
     *
     * Example:
     *
     *
     * ```javascript
     *
     * ` <ListItem text="Paper plane" icon="sap-icon://paper-plane"></ListItem> `
     * ```
     */
    items?: Item[] | Item | AggregationBindingInfo | `{${string}}`;

    /**
     * Sets or retrieves the selected item from the aggregation named items.
     */
    selectedItem?: Item | string;

    /**
     * Association to controls / IDs which label this control (see WAI-ARIA attribute `aria-labelledby`).
     *
     * @since 1.27.0
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * This event is fired when the value in the selection field is changed in combination with one of the following
     * actions:
     * 	 - The focus leaves the selection field
     * 	 - The Enter key is pressed
     * 	 - The item is pressed
     */
    change?: (oEvent: Select$ChangeEvent) => void;

    /**
     * Fires when the user navigates through the `Select` items. It's also fired on revert of the currently
     * selected item.
     *
     * **Note:** Revert occurs in some of the following actions:
     * 	 - The user clicks outside of the `Select`
     * 	 - The Escape key is pressed
     *
     * @since 1.100
     */
    liveChange?: (oEvent: Select$LiveChangeEvent) => void;

    /**
     * This event is triggered prior to the opening of the `sap.m.SelectList`.
     *
     * @since 1.130
     */
    beforeOpen?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the Select#beforeOpen event.
   */
  export interface Select$BeforeOpenEventParameters {}

  /**
   * Event object of the Select#beforeOpen event.
   */
  export type Select$BeforeOpenEvent = Event<
    Select$BeforeOpenEventParameters,
    Select
  >;

  /**
   * Parameters of the Select#change event.
   */
  export interface Select$ChangeEventParameters {
    /**
     * The selected item.
     */
    selectedItem?: Item;

    /**
     * The previous selected item.
     */
    previousSelectedItem?: Item;
  }

  /**
   * Event object of the Select#change event.
   */
  export type Select$ChangeEvent = Event<Select$ChangeEventParameters, Select>;

  /**
   * Parameters of the Select#liveChange event.
   */
  export interface Select$LiveChangeEventParameters {
    /**
     * The selected item.
     */
    selectedItem?: Item;
  }

  /**
   * Event object of the Select#liveChange event.
   */
  export type Select$LiveChangeEvent = Event<
    Select$LiveChangeEventParameters,
    Select
  >;
}

declare module "sap/m/SelectDialog" {
  import {
    default as SelectDialogBase,
    $SelectDialogBaseSettings,
  } from "sap/m/SelectDialogBase";

  import ListItemBase from "sap/m/ListItemBase";

  import Event from "sap/ui/base/Event";

  import { CSSSize } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { TitleAlignment } from "sap/m/library";

  import Context from "sap/ui/model/Context";

  import Model from "sap/ui/model/Model";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import StandardListItem from "sap/m/StandardListItem";

  /**
   * Overview: A SelectDialog is a dialog containing a list, search functionality to filter it and a confirmation/cancel
   * button. The list used in the dialog is a growing list and can be filled with any kind of list item. Structure:
   * Dialog structure: The select dialog has the following components:
   * 	 - Header - title of the dialog
   * 	 - Search field - input field to enter search terms
   * 	 - Info toolbar (only in multi-select) - displays the number of currently selected items
   * 	 - Content - {@link sap.m.StandardListItem standard list items}, {@link sap.m.DisplayListItem display list items }
   *     or {@link sap.m.FeedListItem feed list items}
   * 	 - Button toolbar - for confirmation/cancellation buttons   List structure & selection:
   * 	 -  The search field triggers the events `search` and `liveChange` where a filter function can be applied
   *     to the list binding.
   * 	 -  The growing functionality of the list does not support two-way Binding, so if you use this control
   *     with a JSON model make sure the binding mode is set to `OneWay` and that you update the selection model
   *     manually with the items passed in the `confirm` event.
   * 	 -  In the multi-select mode of the select dialog, checkboxes are provided for choosing multiple entries.
   *
   * 	 -  You can set `rememberSelections` to `true` to store the current selection and load this state when
   *     the dialog is opened again.
   * 	 -  When cancelling the selection, the event `change` will be fired and the selection is restored to
   *     the state when the dialog was opened.
   * 	 - The SelectDialog is usually displayed at the center of the screen. Its size and position can be changed
   *     by the user. To enable this you need to set the `resizable` and `draggable` properties. Both properties
   *     are available only in desktop mode.  Usage: When to use::
   * 	 - You need to select one or more entries from a comprehensive list that contains multiple attributes
   *     or values.   When not to use::
   * 	 -  You need to pick one item from a predefined set of options. Use {@link sap.m.Select select} or {@link sap.m.ComboBox combobox }
   *     instead.
   * 	 -  You need to select a range of item. Use {@link sap.ui.comp.valuehelpdialog.ValueHelpDialog value help dialog }
   *     instead.
   * 	 -  You need to be able to add your own values to an existing list. Use a {@link sap.m.Dialog dialog }
   *     instead.   Note:: The property `growing` determines the progressive loading. If it's set to `true`
   *     (the default value), the selected count (if present) and search, will work for currently loaded items
   *     only. To make sure that all items in the list are loaded at once and the above features works properly,
   *     we recommend setting the `growing` property to `false`. **Note: **The default size limit for entries
   *     used for list bindings is set to 100. To change this behavior, you can adjust the size limit by using
   *     `sap.ui.model.Model.prototype.setSizeLimit`; see {@link sap.ui.model.Model#setSizeLimit}. Responsive
   *     Behavior:
   * 	 -  On phones, the select dialog takes up the whole screen.
   * 	 -  On desktop and tablet devices, the select dialog appears as a popover.   When using the `sap.m.SelectDialog`
   *     in SAP Quartz and Horizon themes, the breakpoints and layout paddings could be determined by the dialog's
   *     width. To enable this concept and add responsive paddings to an element of the control, you have to add
   *     the following classes depending on your use case: `sapUiResponsivePadding--header`, `sapUiResponsivePadding--subHeader`,
   *     `sapUiResponsivePadding--content`, `sapUiResponsivePadding--footer`.
   */
  export default class SelectDialog extends SelectDialogBase {
    /**
     * Constructor for a new SelectDialog.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/select-dialog/ Select Dialog}
     */
    constructor(
      /**
       * Initial settings for the new control A dialog that enables users to select one or more items from a comprehensive
       * list.
       */
      mSettings?: $SelectDialogSettings
    );
    /**
     * Constructor for a new SelectDialog.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/select-dialog/ Select Dialog}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control A dialog that enables users to select one or more items from a comprehensive
       * list.
       */
      mSettings?: $SelectDialogSettings
    );

    /**
     * Creates a new subclass of class sap.m.SelectDialog with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.SelectDialogBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SelectDialog>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SelectDialog.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: ListItemBase
    ): this;
    /**
     * Forward method to the inner dialog: addStyleClass
     *
     *
     * @returns `this` pointer for chaining
     */
    addStyleClass(
      /**
       * CSS class name to add
       */
      sStyleClass: string
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cancel cancel} event of this `sap.m.SelectDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectDialog` itself.
     *
     * This event will be fired when the cancel button is clicked or ESC key is pressed
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCancel(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cancel cancel} event of this `sap.m.SelectDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectDialog` itself.
     *
     * This event will be fired when the cancel button is clicked or ESC key is pressed
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCancel(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:confirm confirm} event of this `sap.m.SelectDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectDialog` itself.
     *
     * This event will be fired when the dialog is confirmed by selecting an item in single selection mode or
     * by pressing the confirmation button in multi selection mode . The items being selected are returned as
     * event parameters.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachConfirm(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectDialog$ConfirmEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:confirm confirm} event of this `sap.m.SelectDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectDialog` itself.
     *
     * This event will be fired when the dialog is confirmed by selecting an item in single selection mode or
     * by pressing the confirmation button in multi selection mode . The items being selected are returned as
     * event parameters.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachConfirm(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectDialog$ConfirmEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.SelectDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectDialog` itself.
     *
     * This event will be fired when the value of the search field is changed by a user - e.g. at each key press
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectDialog$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.SelectDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectDialog` itself.
     *
     * This event will be fired when the value of the search field is changed by a user - e.g. at each key press
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectDialog$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:search search} event of this `sap.m.SelectDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectDialog` itself.
     *
     * This event will be fired when the search button has been clicked on the searchfield on the visual control
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSearch(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectDialog$SearchEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:search search} event of this `sap.m.SelectDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectDialog` itself.
     *
     * This event will be fired when the search button has been clicked on the searchfield on the visual control
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSearch(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectDialog$SearchEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Clears the selections in the `sap.m.SelectDialog` and its internally used `sap.m.List` control.
     *
     * Use this method whenever the application logic expects changes in the model providing data for the SelectDialog
     * that will modify the position of the items, or will change the set with completely new items.
     *
     * @since 1.68
     *
     * @returns `this` to allow method chaining.
     */
    clearSelection(): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:cancel cancel} event of this `sap.m.SelectDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachCancel(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:confirm confirm} event of this `sap.m.SelectDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachConfirm(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SelectDialog$ConfirmEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:liveChange liveChange} event of this `sap.m.SelectDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLiveChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SelectDialog$LiveChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:search search} event of this `sap.m.SelectDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSearch(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SelectDialog$SearchEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:cancel cancel} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireCancel(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:confirm confirm} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireConfirm(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SelectDialog$ConfirmEventParameters
    ): this;
    /**
     * Fires event {@link #event:liveChange liveChange} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLiveChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SelectDialog$LiveChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:search search} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSearch(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SelectDialog$SearchEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getConfirmButtonText confirmButtonText}.
     *
     * Overwrites the default text for the confirmation button.
     *
     * @since 1.68
     *
     * @returns Value of property `confirmButtonText`
     */
    getConfirmButtonText(): string;
    /**
     * Get the internal Dialog's contentHeight property {@link sap.m.Dialog}
     *
     *
     * @returns sHeight The content width of the internal dialog
     */
    getContentHeight(): CSSSize;
    /**
     * Get the internal Dialog's contentWidth property {@link sap.m.Dialog}
     *
     *
     * @returns sWidth The content width of the internal dialog
     */
    getContentWidth(): CSSSize;
    /**
     * Forward method to the inner dialog: getDomRef
     *
     *
     * @returns The Element's DOM Element, sub DOM Element or `null`
     */
    getDomRef(): Element | null;
    /**
     * Gets current value of property {@link #getDraggable draggable}.
     *
     * When set to `true`, the SelectDialog is draggable by its header. The default value is `false`. **Note**:
     * The SelectDialog can be draggable only in desktop mode.
     *
     * Default value is `false`.
     *
     * @since 1.70
     *
     * @returns Value of property `draggable`
     */
    getDraggable(): boolean;
    /**
     * Gets current value of property {@link #getGrowing growing}.
     *
     * If set to `true`, enables the growing feature of the control to load more items by requesting from the
     * bound model (progressive loading). **Note:** This feature only works when an `items` aggregation is bound.
     * **Note:** Growing property, must not be used together with two-way binding. **Note:** If the property
     * is set to `true`, selected count (if present) and search, will work for currently loaded items only.
     * To make sure that all items in the list are loaded at once and the above features work properly, we recommend
     * setting the `growing` property to false.
     *
     * Default value is `true`.
     *
     * @since 1.56
     *
     * @returns Value of property `growing`
     */
    getGrowing(): boolean;
    /**
     * Gets current value of property {@link #getGrowingThreshold growingThreshold}.
     *
     * Determines the number of items initially displayed in the list. Also defines the number of items to be
     * requested from the model for each grow. **Note:** This property could take affect only be used if the
     * property `growing` is set to `true`.
     *
     *
     * @returns Value of property `growingThreshold`
     */
    getGrowingThreshold(): int;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * The items of the list shown in the search dialog. It is recommended to use a StandardListItem for the
     * dialog but other combinations are also possible.
     */
    getItems(): ListItemBase[];
    /**
     * Gets current value of property {@link #getMultiSelect multiSelect}.
     *
     * Determines if the user can select several options from the list
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `multiSelect`
     */
    getMultiSelect(): boolean;
    /**
     * Get the internal List's no data text property
     *
     *
     * @returns the current no data text
     */
    getNoDataText(): string;
    /**
     * Gets current value of property {@link #getRememberSelections rememberSelections}.
     *
     * This flag controls whether the dialog clears the selection after the confirm event has been fired. If
     * the dialog needs to be opened multiple times in the same context to allow for corrections of previous
     * user inputs, set this flag to `true`.
     *
     * **Note:** The sap.m.SelectDialog uses {@link sap.m.ListBase#rememberSelections this} property of the
     * ListBase and therefore its behavior and restrictions also apply here.
     *
     * Default value is `false`.
     *
     * @since 1.18
     *
     * @returns Value of property `rememberSelections`
     */
    getRememberSelections(): boolean;
    /**
     * Gets current value of property {@link #getResizable resizable}.
     *
     * When set to `true`, the SelectDialog will have a resize handler in its bottom right corner. The default
     * value is `false`. **Note**: The SelectDialog can be resizable only in desktop mode.
     *
     * Default value is `false`.
     *
     * @since 1.70
     *
     * @returns Value of property `resizable`
     */
    getResizable(): boolean;
    /**
     * Get the internal SearchField's placeholder property
     *
     *
     * @returns the current placeholder text
     */
    getSearchPlaceholder(): string;
    /**
     * Gets current value of property {@link #getShowClearButton showClearButton}.
     *
     * This flag controls whether the Clear button is shown. When set to `true`, it provides a way to clear
     * selection mode in Select Dialog. We recommended enabling of the Clear button in the following cases,
     * where a mechanism to clear the value is needed: In case of single selection mode(default mode) for Select
     * Dialog and `rememberSelections` is set to `true`. Clear button needs to be enabled in order to allow
     * users to clear the selection. In case of using `sap.m.Input` with `valueHelpOnly` set to `true`, the
     * Clear button could be used for clearing selection. In case the application stores a value and uses only
     * Select Dialog to edit/maintain it. **Note:**When used with oData, only the loaded selections will be
     * cleared.
     *
     * Default value is `false`.
     *
     * @since 1.58
     *
     * @returns Value of property `showClearButton`
     */
    getShowClearButton(): boolean;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Determines the title text that appears in the dialog header
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getTitleAlignment titleAlignment}.
     *
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * Default value is `Auto`.
     *
     * @since 1.72
     *
     * @returns Value of property `titleAlignment`
     */
    getTitleAlignment(): TitleAlignment;
    /**
     * Forward method to the inner dialog: hasStyleClass
     *
     *
     * @returns `true` if the class is set, `false` otherwise
     */
    hasStyleClass(): boolean;
    /**
     * Checks for the provided `sap.m.ListItemBase` in the aggregation {@link #getItems items}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: ListItemBase
    ): int;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: ListItemBase,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Invalidates the dialog instead of this control (we don't have a renderer)
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns `this` pointer for chaining
     */
    invalidate(): this;
    /**
     * Is called after renderer is finished to show the busy state
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onAfterRendering(): void;
    /**
     * Opens the internal dialog with a searchfield and a list.
     *
     *
     * @returns `this` pointer for chaining
     */
    open(
      /**
       * A value for the search can be passed to match with the filter applied to the list binding.
       */
      sSearchValue: string
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): ListItemBase[];
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | ListItemBase
    ): ListItemBase | null;
    /**
     * Forward method to the inner dialog: removeStyleClass
     *
     *
     * @returns `this` pointer for chaining
     */
    removeStyleClass(
      /**
       * CSS class name to remove
       */
      sStyleClass: string
    ): this;
    /**
     * Set the binding context for the internal list AND the current control so that both controls can be used
     * with the context
     *
     *
     * @returns `this` pointer for chaining
     */
    setBindingContext(
      /**
       * The new context
       */
      oContext: Context,
      /**
       * The optional model name
       */
      sModelName: string
    ): this;
    /**
     * Sets the busyIndicatorDelay value to the internal list
     *
     *
     * @returns this pointer for chaining
     */
    setBusyIndicatorDelay(
      /**
       * Value for the busyIndicatorDelay.
       */
      iValue: int
    ): this;
    /**
     * Sets the text of the confirmation button.
     *
     *
     * @returns `this` pointer for chaining
     */
    setConfirmButtonText(
      /**
       * The text for the confirm button
       */
      sText: string
    ): this;
    /**
     * Set the internal Dialog's contentHeight property {@link sap.m.Dialog}
     *
     *
     * @returns `this` pointer for chaining
     */
    setContentHeight(
      /**
       * The new content width value for the dialog
       */
      sHeight: CSSSize
    ): this;
    /**
     * Set the internal Dialog's contentWidth property {@link sap.m.Dialog}
     *
     *
     * @returns `this`s pointer for chaining
     */
    setContentWidth(
      /**
       * The new content width value for the dialog
       */
      sWidth: CSSSize
    ): this;
    /**
     * Sets the draggable property.
     *
     *
     * @returns `this` pointer for chaining
     */
    setDraggable(
      /**
       * Value for the draggable property
       */
      bValue: boolean
    ): this;
    /**
     * Sets the growing to the internal list
     *
     *
     * @returns `this` pointer for chaining
     */
    setGrowing(
      /**
       * Value for the list's growing.
       */
      bValue: boolean
    ): this;
    /**
     * Sets the growing threshold to the internal list
     *
     *
     * @returns `this` pointer for chaining
     */
    setGrowingThreshold(
      /**
       * Value for the list's growing threshold.
       */
      iValue: int
    ): this;
    /**
     * Set the model for the internal list AND the current control so that both controls can be used with data
     * binding
     *
     *
     * @returns `this` pointer for chaining
     */
    setModel(
      /**
       * the model that holds the data for the list
       */
      oModel: Model,
      /**
       * the optional model name
       */
      sModelName?: string
    ): this;
    /**
     * Enable/Disable multi selection mode.
     *
     *
     * @returns `this` pointer for chaining
     */
    setMultiSelect(
      /**
       * Flag for multi selection mode
       */
      bMulti: boolean
    ): this;
    /**
     * Set the internal List's no data text property
     *
     *
     * @returns `this` pointer for chaining
     */
    setNoDataText(
      /**
       * The no data text for the list
       */
      sNoDataText: string
    ): this;
    /**
     * Sets a new value for property {@link #getRememberSelections rememberSelections}.
     *
     * This flag controls whether the dialog clears the selection after the confirm event has been fired. If
     * the dialog needs to be opened multiple times in the same context to allow for corrections of previous
     * user inputs, set this flag to `true`.
     *
     * **Note:** The sap.m.SelectDialog uses {@link sap.m.ListBase#rememberSelections this} property of the
     * ListBase and therefore its behavior and restrictions also apply here.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.18
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRememberSelections(
      /**
       * New value for property `rememberSelections`
       */
      bRememberSelections?: boolean
    ): this;
    /**
     * Sets the resizable property.
     *
     *
     * @returns `this` pointer for chaining
     */
    setResizable(
      /**
       * Value for the resizable property
       */
      bValue: boolean
    ): this;
    /**
     * Set the internal SearchField's placeholder property
     *
     *
     * @returns `this` pointer for chaining
     */
    setSearchPlaceholder(
      /**
       * The placeholder text
       */
      sSearchPlaceholder: string
    ): this;
    /**
     * Sets the Clear button visible state
     *
     *
     * @returns `this` pointer for chaining
     */
    setShowClearButton(
      /**
       * Value for the Clear button visible state.
       */
      bVisible: boolean
    ): this;
    /**
     * Set the title of the internal dialog
     *
     *
     * @returns `this` pointer for chaining
     */
    setTitle(
      /**
       * The title text for the dialog
       */
      sTitle: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitleAlignment titleAlignment}.
     *
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     * @since 1.72
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleAlignment(
      /**
       * New value for property `titleAlignment`
       */
      sTitleAlignment?: TitleAlignment | keyof typeof TitleAlignment
    ): this;
    /**
     * Forward method to the inner dialog: toggleStyleClass.
     *
     *
     * @returns `this` pointer for chaining
     */
    toggleStyleClass(
      /**
       * CSS class name to add or remove
       */
      sStyleClass: string,
      /**
       * Whether style class should be added (or removed); when this parameter is not given, the given style class
       * will be toggled (removed, if present, and added if not present)
       */
      bAdd?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the SelectDialog constructor.
   */
  export interface $SelectDialogSettings extends $SelectDialogBaseSettings {
    /**
     * Determines the title text that appears in the dialog header
     */
    title?: string | PropertyBindingInfo;

    /**
     * Determines the text shown when the list has no data
     */
    noDataText?: string | PropertyBindingInfo;

    /**
     * Determines if the user can select several options from the list
     */
    multiSelect?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the number of items initially displayed in the list. Also defines the number of items to be
     * requested from the model for each grow. **Note:** This property could take affect only be used if the
     * property `growing` is set to `true`.
     */
    growingThreshold?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * If set to `true`, enables the growing feature of the control to load more items by requesting from the
     * bound model (progressive loading). **Note:** This feature only works when an `items` aggregation is bound.
     * **Note:** Growing property, must not be used together with two-way binding. **Note:** If the property
     * is set to `true`, selected count (if present) and search, will work for currently loaded items only.
     * To make sure that all items in the list are loaded at once and the above features work properly, we recommend
     * setting the `growing` property to false.
     *
     * @since 1.56
     */
    growing?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the content width of the inner dialog. For more information, see the dialog documentation.
     *
     * @since 1.18
     */
    contentWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * This flag controls whether the dialog clears the selection after the confirm event has been fired. If
     * the dialog needs to be opened multiple times in the same context to allow for corrections of previous
     * user inputs, set this flag to `true`.
     *
     * **Note:** The sap.m.SelectDialog uses {@link sap.m.ListBase#rememberSelections this} property of the
     * ListBase and therefore its behavior and restrictions also apply here.
     *
     * @since 1.18
     */
    rememberSelections?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the content height of the inner dialog. For more information, see the dialog documentation.
     */
    contentHeight?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * This flag controls whether the Clear button is shown. When set to `true`, it provides a way to clear
     * selection mode in Select Dialog. We recommended enabling of the Clear button in the following cases,
     * where a mechanism to clear the value is needed: In case of single selection mode(default mode) for Select
     * Dialog and `rememberSelections` is set to `true`. Clear button needs to be enabled in order to allow
     * users to clear the selection. In case of using `sap.m.Input` with `valueHelpOnly` set to `true`, the
     * Clear button could be used for clearing selection. In case the application stores a value and uses only
     * Select Dialog to edit/maintain it. **Note:**When used with oData, only the loaded selections will be
     * cleared.
     *
     * @since 1.58
     */
    showClearButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Overwrites the default text for the confirmation button.
     *
     * @since 1.68
     */
    confirmButtonText?: string | PropertyBindingInfo;

    /**
     * When set to `true`, the SelectDialog is draggable by its header. The default value is `false`. **Note**:
     * The SelectDialog can be draggable only in desktop mode.
     *
     * @since 1.70
     */
    draggable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * When set to `true`, the SelectDialog will have a resize handler in its bottom right corner. The default
     * value is `false`. **Note**: The SelectDialog can be resizable only in desktop mode.
     *
     * @since 1.70
     */
    resizable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * @since 1.72
     */
    titleAlignment?:
      | (TitleAlignment | keyof typeof TitleAlignment)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Allows overriding the SearchField's default placeholder text. If not set, the word "Search" in the current
     * local language or English will be used as a placeholder.
     *
     * @since 1.110
     */
    searchPlaceholder?: string | PropertyBindingInfo;

    /**
     * The items of the list shown in the search dialog. It is recommended to use a StandardListItem for the
     * dialog but other combinations are also possible.
     */
    items?:
      | ListItemBase[]
      | ListItemBase
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * This event will be fired when the dialog is confirmed by selecting an item in single selection mode or
     * by pressing the confirmation button in multi selection mode . The items being selected are returned as
     * event parameters.
     */
    confirm?: (oEvent: SelectDialog$ConfirmEvent) => void;

    /**
     * This event will be fired when the search button has been clicked on the searchfield on the visual control
     */
    search?: (oEvent: SelectDialog$SearchEvent) => void;

    /**
     * This event will be fired when the value of the search field is changed by a user - e.g. at each key press
     */
    liveChange?: (oEvent: SelectDialog$LiveChangeEvent) => void;

    /**
     * This event will be fired when the cancel button is clicked or ESC key is pressed
     */
    cancel?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the SelectDialog#cancel event.
   */
  export interface SelectDialog$CancelEventParameters {}

  /**
   * Event object of the SelectDialog#cancel event.
   */
  export type SelectDialog$CancelEvent = Event<
    SelectDialog$CancelEventParameters,
    SelectDialog
  >;

  /**
   * Parameters of the SelectDialog#confirm event.
   */
  export interface SelectDialog$ConfirmEventParameters {
    /**
     * Returns the selected list item. When no item is selected, "null" is returned. When multi-selection is
     * enabled and multiple items are selected, only the first selected item is returned.
     */
    selectedItem?: StandardListItem;

    /**
     * Returns an array containing the visible selected list items. If no items are selected, an empty array
     * is returned.
     */
    selectedItems?: StandardListItem[];

    /**
     * Returns the binding contexts of the selected items including the non-visible items, but excluding the
     * not loaded items. See {@link sap.m.ListBase#getSelectedContexts getSelectedContexts} of `sap.m.ListBase`.
     * NOTE: In contrast to the parameter "selectedItems", this parameter will also include the selected but
     * NOT visible items (e.g. due to list filtering). An empty array will be set for this parameter if no data
     * binding is used. NOTE: When the list binding is pre-filtered and there are items in the selection that
     * are not visible upon opening the dialog, these contexts are not loaded. Therefore, these items will not
     * be included in the selectedContexts array unless they are displayed at least once.
     */
    selectedContexts?: object[];
  }

  /**
   * Event object of the SelectDialog#confirm event.
   */
  export type SelectDialog$ConfirmEvent = Event<
    SelectDialog$ConfirmEventParameters,
    SelectDialog
  >;

  /**
   * Parameters of the SelectDialog#liveChange event.
   */
  export interface SelectDialog$LiveChangeEventParameters {
    /**
     * The value to search for, which can change at any keypress
     */
    value?: string;

    /**
     * The Items binding of the Select Dialog. It will only be available if the items aggregation is bound to
     * a model.
     */
    itemsBinding?: any;
  }

  /**
   * Event object of the SelectDialog#liveChange event.
   */
  export type SelectDialog$LiveChangeEvent = Event<
    SelectDialog$LiveChangeEventParameters,
    SelectDialog
  >;

  /**
   * Parameters of the SelectDialog#search event.
   */
  export interface SelectDialog$SearchEventParameters {
    /**
     * The value entered in the search
     */
    value?: string;

    /**
     * The Items binding of the Select Dialog for search purposes. It will only be available if the items aggregation
     * is bound to a model.
     */
    itemsBinding?: any;

    /**
     * Returns if the Clear button is pressed.
     */
    clearButtonPressed?: boolean;
  }

  /**
   * Event object of the SelectDialog#search event.
   */
  export type SelectDialog$SearchEvent = Event<
    SelectDialog$SearchEventParameters,
    SelectDialog
  >;
}

declare module "sap/m/SelectDialogBase" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { SelectDialogInitialFocus } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import ListItemBase from "sap/m/ListItemBase";

  import Event from "sap/ui/base/Event";

  /**
   * The `sap.m.SelectDialogBase` control provides a base functionality of the `sap.m.SelectDialog` and `sap.m.TableSelectDialog`
   * controls.
   *
   * @since 1.93
   */
  export default abstract class SelectDialogBase extends Control {
    /**
     * Constructor for a new SelectDialogBase.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SelectDialogBaseSettings
    );
    /**
     * Constructor for a new SelectDialogBase.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SelectDialogBaseSettings
    );

    /**
     * Creates a new subclass of class sap.m.SelectDialogBase with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SelectDialogBase>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SelectDialogBase.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionChange selectionChange} event of this
     * `sap.m.SelectDialogBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectDialogBase` itself.
     *
     * Fires when selection is changed via user interaction inside the control.
     *
     * @since 1.93
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectDialogBase$SelectionChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectDialogBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionChange selectionChange} event of this
     * `sap.m.SelectDialogBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectDialogBase` itself.
     *
     * Fires when selection is changed via user interaction inside the control.
     *
     * @since 1.93
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectDialogBase$SelectionChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectDialogBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:updateFinished updateFinished} event of this
     * `sap.m.SelectDialogBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectDialogBase` itself.
     *
     * Fires after `items` binding is updated and processed by the control.
     *
     * @since 1.93
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUpdateFinished(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectDialogBase$UpdateFinishedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectDialogBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:updateFinished updateFinished} event of this
     * `sap.m.SelectDialogBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectDialogBase` itself.
     *
     * Fires after `items` binding is updated and processed by the control.
     *
     * @since 1.93
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUpdateFinished(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectDialogBase$UpdateFinishedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectDialogBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:updateStarted updateStarted} event of this `sap.m.SelectDialogBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectDialogBase` itself.
     *
     * Fires before `items` binding is updated (e.g. sorting, filtering)
     *
     * **Note:** Event handler should not invalidate the control.
     *
     * @since 1.93
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUpdateStarted(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectDialogBase$UpdateStartedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectDialogBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:updateStarted updateStarted} event of this `sap.m.SelectDialogBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectDialogBase` itself.
     *
     * Fires before `items` binding is updated (e.g. sorting, filtering)
     *
     * **Note:** Event handler should not invalidate the control.
     *
     * @since 1.93
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUpdateStarted(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectDialogBase$UpdateStartedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectDialogBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:selectionChange selectionChange} event of
     * this `sap.m.SelectDialogBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.93
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelectionChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SelectDialogBase$SelectionChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:updateFinished updateFinished} event of this
     * `sap.m.SelectDialogBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.93
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUpdateFinished(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SelectDialogBase$UpdateFinishedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:updateStarted updateStarted} event of this
     * `sap.m.SelectDialogBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.93
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUpdateStarted(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SelectDialogBase$UpdateStartedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:selectionChange selectionChange} to attached listeners.
     *
     * @since 1.93
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelectionChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SelectDialogBase$SelectionChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:updateFinished updateFinished} to attached listeners.
     *
     * @since 1.93
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUpdateFinished(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SelectDialogBase$UpdateFinishedEventParameters
    ): this;
    /**
     * Fires event {@link #event:updateStarted updateStarted} to attached listeners.
     *
     * @since 1.93
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUpdateStarted(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SelectDialogBase$UpdateStartedEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getInitialFocus initialFocus}.
     *
     * Specifies the control that will receive the initial focus.
     *
     * **Note:** When the `growing` property is set to `true`, you can set the initial focus to `sap.m.SelectDialogInitialFocus.SearchField`.
     * In this way the user can easily search for items that are not currently visible.
     *
     * Default value is `List`.
     *
     * @since 1.117.0
     *
     * @returns Value of property `initialFocus`
     */
    getInitialFocus(): SelectDialogInitialFocus;
    /**
     * Sets a new value for property {@link #getInitialFocus initialFocus}.
     *
     * Specifies the control that will receive the initial focus.
     *
     * **Note:** When the `growing` property is set to `true`, you can set the initial focus to `sap.m.SelectDialogInitialFocus.SearchField`.
     * In this way the user can easily search for items that are not currently visible.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `List`.
     *
     * @since 1.117.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInitialFocus(
      /**
       * New value for property `initialFocus`
       */
      sInitialFocus?:
        | SelectDialogInitialFocus
        | keyof typeof SelectDialogInitialFocus
    ): this;
  }
  /**
   * Describes the settings that can be provided to the SelectDialogBase constructor.
   */
  export interface $SelectDialogBaseSettings extends $ControlSettings {
    /**
     * Specifies the control that will receive the initial focus.
     *
     * **Note:** When the `growing` property is set to `true`, you can set the initial focus to `sap.m.SelectDialogInitialFocus.SearchField`.
     * In this way the user can easily search for items that are not currently visible.
     *
     * @since 1.117.0
     */
    initialFocus?:
      | (SelectDialogInitialFocus | keyof typeof SelectDialogInitialFocus)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Fires before `items` binding is updated (e.g. sorting, filtering)
     *
     * **Note:** Event handler should not invalidate the control.
     *
     * @since 1.93
     */
    updateStarted?: (oEvent: SelectDialogBase$UpdateStartedEvent) => void;

    /**
     * Fires after `items` binding is updated and processed by the control.
     *
     * @since 1.93
     */
    updateFinished?: (oEvent: SelectDialogBase$UpdateFinishedEvent) => void;

    /**
     * Fires when selection is changed via user interaction inside the control.
     *
     * @since 1.93
     */
    selectionChange?: (oEvent: SelectDialogBase$SelectionChangeEvent) => void;
  }

  /**
   * Parameters of the SelectDialogBase#selectionChange event.
   */
  export interface SelectDialogBase$SelectionChangeEventParameters {
    /**
     * The item whose selection has changed. In `MultiSelect` mode, only the up-most selected item is returned.
     * This parameter can be used for single-selection modes.
     */
    listItem?: ListItemBase;

    /**
     * Array of items whose selection has changed. This parameter can be used for `MultiSelect` mode.
     */
    listItems?: ListItemBase[];

    /**
     * Indicates whether the `listItem` parameter is selected or not.
     */
    selected?: boolean;

    /**
     * Indicates whether the select all action is triggered or not.
     */
    selectAll?: boolean;
  }

  /**
   * Event object of the SelectDialogBase#selectionChange event.
   */
  export type SelectDialogBase$SelectionChangeEvent = Event<
    SelectDialogBase$SelectionChangeEventParameters,
    SelectDialogBase
  >;

  /**
   * Parameters of the SelectDialogBase#updateFinished event.
   */
  export interface SelectDialogBase$UpdateFinishedEventParameters {
    /**
     * The reason of the update, e.g. Binding, Filter, Sort, Growing, Change, Refresh, Context.
     */
    reason?: string;

    /**
     * Actual number of items.
     */
    actual?: int;

    /**
     * The total count of bound items. This can be used if the `growing` property is set to `true`.
     */
    total?: int;
  }

  /**
   * Event object of the SelectDialogBase#updateFinished event.
   */
  export type SelectDialogBase$UpdateFinishedEvent = Event<
    SelectDialogBase$UpdateFinishedEventParameters,
    SelectDialogBase
  >;

  /**
   * Parameters of the SelectDialogBase#updateStarted event.
   */
  export interface SelectDialogBase$UpdateStartedEventParameters {
    /**
     * The reason of the update, e.g. Binding, Filter, Sort, Growing, Change, Refresh, Context.
     */
    reason?: string;

    /**
     * Actual number of items.
     */
    actual?: int;

    /**
     * The total count of bound items. This can be used if the `growing` property is set to `true`.
     */
    total?: int;
  }

  /**
   * Event object of the SelectDialogBase#updateStarted event.
   */
  export type SelectDialogBase$UpdateStartedEvent = Event<
    SelectDialogBase$UpdateStartedEventParameters,
    SelectDialogBase
  >;
}

declare module "sap/m/ViewSettingsDialog" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import ViewSettingsCustomTab from "sap/m/ViewSettingsCustomTab";

  import ViewSettingsItem from "sap/m/ViewSettingsItem";

  import Event from "sap/ui/base/Event";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import { StringFilterOperator, TitleAlignment } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { ID } from "sap/ui/core/library";

  import ViewSettingsFilterItem from "sap/m/ViewSettingsFilterItem";

  /**
   * An object with item and sub-item keys
   */
  export type SelectedFilterKeys = Record<string, boolean>;

  /**
   * Helps the user to sort, filter, or group data within a (master) {@link sap.m.List} or a {@link sap.m.Table}.
   * The dialog is triggered by icon buttons in the table toolbar. Each button shows a dropdown list icon.
   *
   * Overview:
   *
   * The `ViewSettingsDialog` is a composite control, consisting of a modal {@link sap.m.Popover} and several
   * internal lists. There are three different tabs (Sort, Group, Filter) in the dialog that can be activated
   * by filling the respective associations. If only one association is filled, the other tabs are automatically
   * hidden. The selected options can be used to create sorters and filters for the table.
   *
   * **Note:** If the app does not offer all three sorting, filtering, and grouping operations, but only one
   * of these (such as sort), we recommend placing the icon button directly in the toolbar. Do not place sort,
   * filter, or group buttons in the footer toolbar if they refer to a table. Place group, sort, and filter
   * buttons in the footer toolbar if they refer to a master list.
   *
   * **Note:** If `ViewSettingsDialog` is used without custom tabs or custom items in any of its aggregations,
   * then Reset button is enabled if the user selects any Filters or presetFilters or changes any of the Sort
   * by, Sort order, Group by, or Group order values. When `ViewSettingsDialog` is used with custom tabs or
   * custom items in any of its aggregations (sortItems, groupItems, filterItems or presetFilterItems), the
   * Reset button is always enabled, because there is no way to determine the initial state of the custom
   * tabs and compare it to their current state in order to determine the enable/disable state of the Reset
   * button.
   *
   * Usage:
   *
   * When to use?
   * 	 - If you need to allow the user to sort line items in a manageable list or table (up to 20 columns)
   *
   * 	 - If you need to offer custom filter settings in a manageable list or table (up to 20 columns)
   * 	 - If you need to allow the user to group line items in a manageable list or table (up to 20 columns)
   *
   * When not to use?
   * 	 - If you have complex tables (more than 20 columns)
   * 	 - If you need to rearrange columns within your table (use the {@link sap.m.TablePersoDialog} instead)
   *
   * 	 - If you need very specific sort, filter, or column sorting options within complex tables (use the
   *     {@link sap.m.P13nDialog} instead)
   *
   * Responsive behavior:
   *
   * The popover dialog appears as a modal window on desktop and tablet screen sizes, but full screen on smartphones.
   *
   * @since 1.16
   */
  export default class ViewSettingsDialog extends Control {
    /**
     * Constructor for a new `ViewSettingsDialog`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/view-settings-dialog/ View Settings Dialog}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ViewSettingsDialogSettings
    );
    /**
     * Constructor for a new `ViewSettingsDialog`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/view-settings-dialog/ View Settings Dialog}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ViewSettingsDialogSettings
    );

    /**
     * Creates a new subclass of class sap.m.ViewSettingsDialog with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ViewSettingsDialog>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ViewSettingsDialog.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Overwrites the aggregation setter in order to have ID validation logic as some strings are reserved for
     * the predefined tabs.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    addCustomTab(
      /**
       * The custom tab to be added
       */
      oCustomTab: ViewSettingsCustomTab
    ): this;
    /**
     * Adds some filterItem to the aggregation {@link #getFilterItems filterItems}.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addFilterItem(
      /**
       * The filterItem to add; if empty, nothing is inserted
       */
      oFilterItem: ViewSettingsItem
    ): this;
    /**
     * Adds a group item and sets the association to reflect the selected state.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    addGroupItem(
      /**
       * The item to be added to the group items
       */
      oItem: ViewSettingsItem
    ): this;
    /**
     * Adds a preset filter item and sets the association to reflect the selected state.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    addPresetFilterItem(
      /**
       * The selected item or a string with the key
       */
      oItem: ViewSettingsItem
    ): this;
    /**
     * Adds a sort item and sets the association to reflect the selected state.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    addSortItem(
      /**
       * The item to be added to the aggregation
       */
      oItem: ViewSettingsItem
    ): this;
    /**
     * Forward method to the inner dialog method: addStyleClass.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    addStyleClass(
      /**
       * CSS class name to add
       */
      sStyleClass: string
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.ViewSettingsDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ViewSettingsDialog` itself.
     *
     * Fired before the dialog is closed. This event can be prevented which effectively prevents the dialog
     * from closing.
     *
     * @since 1.132
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ViewSettingsDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.ViewSettingsDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ViewSettingsDialog` itself.
     *
     * Fired before the dialog is closed. This event can be prevented which effectively prevents the dialog
     * from closing.
     *
     * @since 1.132
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ViewSettingsDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cancel cancel} event of this `sap.m.ViewSettingsDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ViewSettingsDialog` itself.
     *
     * Called when the Cancel button is pressed. It can be used to set the state of custom filter controls.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCancel(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ViewSettingsDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cancel cancel} event of this `sap.m.ViewSettingsDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ViewSettingsDialog` itself.
     *
     * Called when the Cancel button is pressed. It can be used to set the state of custom filter controls.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCancel(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ViewSettingsDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:confirm confirm} event of this `sap.m.ViewSettingsDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ViewSettingsDialog` itself.
     *
     * Indicates that the user has pressed the OK button and the selected sort, group, and filter settings should
     * be applied to the data on this page.
     *
     * **Note:** Custom tabs are not converted to event parameters automatically. For custom tabs, you have
     * to read the state of your controls inside the callback of this event.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachConfirm(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ViewSettingsDialog$ConfirmEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ViewSettingsDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:confirm confirm} event of this `sap.m.ViewSettingsDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ViewSettingsDialog` itself.
     *
     * Indicates that the user has pressed the OK button and the selected sort, group, and filter settings should
     * be applied to the data on this page.
     *
     * **Note:** Custom tabs are not converted to event parameters automatically. For custom tabs, you have
     * to read the state of your controls inside the callback of this event.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachConfirm(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ViewSettingsDialog$ConfirmEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ViewSettingsDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:filterDetailPageOpened filterDetailPageOpened }
     * event of this `sap.m.ViewSettingsDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ViewSettingsDialog` itself.
     *
     * Fired when the filter detail page is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFilterDetailPageOpened(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ViewSettingsDialog$FilterDetailPageOpenedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ViewSettingsDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:filterDetailPageOpened filterDetailPageOpened }
     * event of this `sap.m.ViewSettingsDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ViewSettingsDialog` itself.
     *
     * Fired when the filter detail page is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFilterDetailPageOpened(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ViewSettingsDialog$FilterDetailPageOpenedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ViewSettingsDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:reset reset} event of this `sap.m.ViewSettingsDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ViewSettingsDialog` itself.
     *
     * Called when the Reset button is pressed. It can be used to set the state of custom tabs.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachReset(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ViewSettingsDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:reset reset} event of this `sap.m.ViewSettingsDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ViewSettingsDialog` itself.
     *
     * Called when the Reset button is pressed. It can be used to set the state of custom tabs.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachReset(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ViewSettingsDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:resetFilters resetFilters} event of this `sap.m.ViewSettingsDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ViewSettingsDialog` itself.
     *
     * Called when the filters are being reset.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachResetFilters(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ViewSettingsDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:resetFilters resetFilters} event of this `sap.m.ViewSettingsDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ViewSettingsDialog` itself.
     *
     * Called when the filters are being reset.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachResetFilters(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ViewSettingsDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getCustomTabs customTabs} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     * @since 1.30
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindCustomTabs(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Binds aggregation {@link #getFilterItems filterItems} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindFilterItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Binds aggregation {@link #getGroupItems groupItems} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindGroupItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Binds aggregation {@link #getPresetFilterItems presetFilterItems} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindPresetFilterItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Binds aggregation {@link #getSortItems sortItems} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindSortItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Clears the selected filters and navigates to the filter overview page
     *
     *
     * @returns Reference to `this` for method chaining
     */
    clearFilters(): this;
    /**
     * Destroys all the customTabs in the aggregation {@link #getCustomTabs customTabs}.
     *
     * @since 1.30
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCustomTabs(): this;
    /**
     * Destroys all the filterItems in the aggregation {@link #getFilterItems filterItems}.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyFilterItems(): this;
    /**
     * Destroys all the groupItems in the aggregation {@link #getGroupItems groupItems}.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyGroupItems(): this;
    /**
     * Destroys all the presetFilterItems in the aggregation {@link #getPresetFilterItems presetFilterItems}.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyPresetFilterItems(): this;
    /**
     * Destroys all the sortItems in the aggregation {@link #getSortItems sortItems}.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySortItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeClose beforeClose} event of this `sap.m.ViewSettingsDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.132
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:cancel cancel} event of this `sap.m.ViewSettingsDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachCancel(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:confirm confirm} event of this `sap.m.ViewSettingsDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachConfirm(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ViewSettingsDialog$ConfirmEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:filterDetailPageOpened filterDetailPageOpened }
     * event of this `sap.m.ViewSettingsDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachFilterDetailPageOpened(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ViewSettingsDialog$FilterDetailPageOpenedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:reset reset} event of this `sap.m.ViewSettingsDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachReset(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:resetFilters resetFilters} event of this `sap.m.ViewSettingsDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachResetFilters(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:beforeClose beforeClose} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @since 1.132
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireBeforeClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): boolean;
    /**
     * Fires event {@link #event:cancel cancel} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireCancel(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:confirm confirm} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireConfirm(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ViewSettingsDialog$ConfirmEventParameters
    ): this;
    /**
     * Fires event {@link #event:filterDetailPageOpened filterDetailPageOpened} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireFilterDetailPageOpened(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ViewSettingsDialog$FilterDetailPageOpenedEventParameters
    ): this;
    /**
     * Fires event {@link #event:reset reset} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireReset(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:resetFilters resetFilters} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireResetFilters(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets content of aggregation {@link #getCustomTabs customTabs}.
     *
     * The list of all the custom tabs.
     *
     * @since 1.30
     */
    getCustomTabs(): ViewSettingsCustomTab[];
    /**
     * Forward method to the inner dialog method: getDomRef.
     *
     *
     * @returns The Element's DOM Element, sub DOM Element or `null`
     */
    getDomRef(): Element | null;
    /**
     * Gets content of aggregation {@link #getFilterItems filterItems}.
     *
     * The list of items with key and value that can be filtered on (for example, a list of columns for a table).
     * A filterItem is associated with one or more detail filters.
     *
     * **Note:** It is recommended to use the `sap.m.ViewSettingsFilterItem` as it fits best at the filter page.
     *
     * @since 1.16
     */
    getFilterItems(): ViewSettingsItem[];
    /**
     * Gets current value of property {@link #getFilterSearchOperator filterSearchOperator}.
     *
     * Provides a string filter operator which is used when the user searches items in filter details page.
     * Possible operators are: `AnyWordStartsWith`, `Contains`, `StartsWith`, `Equals`. This property will be
     * ignored if a custom callback is provided through `setFilterSearchCallback` method.
     *
     * Default value is `StartsWith`.
     *
     * @since 1.42
     *
     * @returns Value of property `filterSearchOperator`
     */
    getFilterSearchOperator(): StringFilterOperator;
    /**
     * Gets current value of property {@link #getGroupDescending groupDescending}.
     *
     * Determines whether the group order is descending or ascending (default).
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `groupDescending`
     */
    getGroupDescending(): boolean;
    /**
     * Gets content of aggregation {@link #getGroupItems groupItems}.
     *
     * The list of items with key and value that can be grouped on (for example, a list of columns for a table).
     *
     * @since 1.16
     */
    getGroupItems(): ViewSettingsItem[];
    /**
     * Gets content of aggregation {@link #getPresetFilterItems presetFilterItems}.
     *
     * The list of preset filter items with key and value that allows the selection of more complex or custom
     * filters. These entries are displayed at the top of the filter tab.
     *
     * @since 1.16
     */
    getPresetFilterItems(): ViewSettingsItem[];
    /**
     * Gets the selected filter object in format { parent_key: { key: boolean, key2: boolean, ...}, ... }.
     *
     * @since 1.42
     *
     * @returns An object with item and sub-item keys
     */
    getSelectedFilterCompoundKeys(): Record<string, SelectedFilterKeys>;
    /**
     * Returns the selected filters as an array of ViewSettingsItems.
     *
     * It can be used to create matching sorters and filters to apply the selected settings to the data.
     *
     *
     * @returns An array of selected filter items
     */
    getSelectedFilterItems(): ViewSettingsItem[];
    /**
     * Gets the selected filter object in format {key: boolean}.
     *
     * It can be used to create matching sorters and filters to apply the selected settings to the data.
     *
     * @deprecated As of version 1.42. replaced by `getSelectedFilterCompoundKeys` method
     *
     * @returns An object with item and sub-item keys
     */
    getSelectedFilterKeys(): SelectedFilterKeys;
    /**
     * Gets the filter string in format: "filter name (subfilter1 name, subfilter2 name, ...), ...". For custom
     * and preset filters it will only add the filter name to the resulting string.
     *
     *
     * @returns The selected filter string
     */
    getSelectedFilterString(): string;
    /**
     * ID of the element which is the current target of the association {@link #getSelectedGroupItem selectedGroupItem},
     * or `null`.
     */
    getSelectedGroupItem(): ID | null;
    /**
     * ID of the element which is the current target of the association {@link #getSelectedPresetFilterItem selectedPresetFilterItem},
     * or `null`.
     */
    getSelectedPresetFilterItem(): ID | null;
    /**
     * ID of the element which is the current target of the association {@link #getSelectedSortItem selectedSortItem},
     * or `null`.
     */
    getSelectedSortItem(): ID | null;
    /**
     * Gets current value of property {@link #getSortDescending sortDescending}.
     *
     * Determines whether the sort order is descending or ascending (default).
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `sortDescending`
     */
    getSortDescending(): boolean;
    /**
     * Gets content of aggregation {@link #getSortItems sortItems}.
     *
     * The list of items with key and value that can be sorted over (for example, a list of columns for a table).
     *
     * @since 1.16
     */
    getSortItems(): ViewSettingsItem[];
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Defines the title of the dialog. If not set and there is only one active tab, the dialog uses the default
     * "View" or "Sort", "Group", "Filter" respectively.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getTitleAlignment titleAlignment}.
     *
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.None`, the automatic title
     * alignment depending on the theme settings will be disabled. If set to `TitleAlignment.Auto`, the Title
     * will be aligned as it is set in the theme (if not set, the default value is `center`); Other possible
     * values are `TitleAlignment.Start` (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * Default value is `Auto`.
     *
     * @since 1.72
     *
     * @returns Value of property `titleAlignment`
     */
    getTitleAlignment(): TitleAlignment;
    /**
     * Forward method to the inner dialog method: hasStyleClass.
     *
     *
     * @returns true if the class is set, false otherwise
     */
    hasStyleClass(): boolean;
    /**
     * Checks for the provided `sap.m.ViewSettingsCustomTab` in the aggregation {@link #getCustomTabs customTabs}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.30
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfCustomTab(
      /**
       * The customTab whose index is looked for
       */
      oCustomTab: ViewSettingsCustomTab
    ): int;
    /**
     * Checks for the provided `sap.m.ViewSettingsItem` in the aggregation {@link #getFilterItems filterItems}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.16
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfFilterItem(
      /**
       * The filterItem whose index is looked for
       */
      oFilterItem: ViewSettingsItem
    ): int;
    /**
     * Checks for the provided `sap.m.ViewSettingsItem` in the aggregation {@link #getGroupItems groupItems}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.16
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfGroupItem(
      /**
       * The groupItem whose index is looked for
       */
      oGroupItem: ViewSettingsItem
    ): int;
    /**
     * Checks for the provided `sap.m.ViewSettingsItem` in the aggregation {@link #getPresetFilterItems presetFilterItems}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.16
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfPresetFilterItem(
      /**
       * The presetFilterItem whose index is looked for
       */
      oPresetFilterItem: ViewSettingsItem
    ): int;
    /**
     * Checks for the provided `sap.m.ViewSettingsItem` in the aggregation {@link #getSortItems sortItems}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.16
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfSortItem(
      /**
       * The sortItem whose index is looked for
       */
      oSortItem: ViewSettingsItem
    ): int;
    /**
     * Inserts a customTab into the aggregation {@link #getCustomTabs customTabs}.
     *
     * @since 1.30
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertCustomTab(
      /**
       * The customTab to insert; if empty, nothing is inserted
       */
      oCustomTab: ViewSettingsCustomTab,
      /**
       * The `0`-based index the customTab should be inserted at; for a negative value of `iIndex`, the customTab
       * is inserted at position 0; for a value greater than the current size of the aggregation, the customTab
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a filterItem into the aggregation {@link #getFilterItems filterItems}.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertFilterItem(
      /**
       * The filterItem to insert; if empty, nothing is inserted
       */
      oFilterItem: ViewSettingsItem,
      /**
       * The `0`-based index the filterItem should be inserted at; for a negative value of `iIndex`, the filterItem
       * is inserted at position 0; for a value greater than the current size of the aggregation, the filterItem
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a groupItem into the aggregation {@link #getGroupItems groupItems}.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertGroupItem(
      /**
       * The groupItem to insert; if empty, nothing is inserted
       */
      oGroupItem: ViewSettingsItem,
      /**
       * The `0`-based index the groupItem should be inserted at; for a negative value of `iIndex`, the groupItem
       * is inserted at position 0; for a value greater than the current size of the aggregation, the groupItem
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a presetFilterItem into the aggregation {@link #getPresetFilterItems presetFilterItems}.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertPresetFilterItem(
      /**
       * The presetFilterItem to insert; if empty, nothing is inserted
       */
      oPresetFilterItem: ViewSettingsItem,
      /**
       * The `0`-based index the presetFilterItem should be inserted at; for a negative value of `iIndex`, the
       * presetFilterItem is inserted at position 0; for a value greater than the current size of the aggregation,
       * the presetFilterItem is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a sortItem into the aggregation {@link #getSortItems sortItems}.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertSortItem(
      /**
       * The sortItem to insert; if empty, nothing is inserted
       */
      oSortItem: ViewSettingsItem,
      /**
       * The `0`-based index the sortItem should be inserted at; for a negative value of `iIndex`, the sortItem
       * is inserted at position 0; for a value greater than the current size of the aggregation, the sortItem
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Opens the ViewSettingsDialog relative to the parent control.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    open(
      /**
       * The ID of the initial page to be opened in the dialog. The available values are "sort", "group", "filter"
       * or IDs of custom tabs.
       */
      sPageId?: string
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getCustomTabs customTabs}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.30
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllCustomTabs(): ViewSettingsCustomTab[];
    /**
     * Removes all filter Items and resets the remembered page if it was a filter detail page and all of its
     * filter items are being removed.
     *
     *
     * @returns the removed items
     */
    removeAllFilterItems(): ViewSettingsFilterItem[];
    /**
     * Removes all the controls from the aggregation {@link #getGroupItems groupItems}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.16
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllGroupItems(): ViewSettingsItem[];
    /**
     * Removes all the controls from the aggregation {@link #getPresetFilterItems presetFilterItems}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.16
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllPresetFilterItems(): ViewSettingsItem[];
    /**
     * Removes all the controls from the aggregation {@link #getSortItems sortItems}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.16
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllSortItems(): ViewSettingsItem[];
    /**
     * Removes a customTab from the aggregation {@link #getCustomTabs customTabs}.
     *
     * @since 1.30
     *
     * @returns The removed customTab or `null`
     */
    removeCustomTab(
      /**
       * The customTab to remove or its index or id
       */
      vCustomTab: int | string | ViewSettingsCustomTab
    ): ViewSettingsCustomTab | null;
    /**
     * Removes a filter Item and resets the remembered page if it was the filter detail page of the removed
     * filter.
     *
     *
     * @returns The removed item or `null`
     */
    removeFilterItem(
      /**
       * The filter item's index, or the item itself, or its ID
       */
      vFilterItem: int | ViewSettingsFilterItem | ID
    ): ViewSettingsFilterItem | null;
    /**
     * Removes a groupItem from the aggregation {@link #getGroupItems groupItems}.
     *
     * @since 1.16
     *
     * @returns The removed groupItem or `null`
     */
    removeGroupItem(
      /**
       * The groupItem to remove or its index or id
       */
      vGroupItem: int | string | ViewSettingsItem
    ): ViewSettingsItem | null;
    /**
     * Removes a presetFilterItem from the aggregation {@link #getPresetFilterItems presetFilterItems}.
     *
     * @since 1.16
     *
     * @returns The removed presetFilterItem or `null`
     */
    removePresetFilterItem(
      /**
       * The presetFilterItem to remove or its index or id
       */
      vPresetFilterItem: int | string | ViewSettingsItem
    ): ViewSettingsItem | null;
    /**
     * Removes a sortItem from the aggregation {@link #getSortItems sortItems}.
     *
     * @since 1.16
     *
     * @returns The removed sortItem or `null`
     */
    removeSortItem(
      /**
       * The sortItem to remove or its index or id
       */
      vSortItem: int | string | ViewSettingsItem
    ): ViewSettingsItem | null;
    /**
     * Forward method to the inner dialog method: removeStyleClass.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    removeStyleClass(
      /**
       * CSS class name to remove
       */
      sStyleClass: string
    ): this;
    /**
     * Forward the busy state setting to the internal dialog instance. Needed because of the not-bullet proof
     * implementation of setBusy in sap.ui.core.Control
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setBusy(
      /**
       * The busy state flag
       */
      bBusy: boolean
    ): this;
    /**
     * Sets a callback that will check the ViewSettingsItem's text against the search query. If a callback is
     * set, `filterSearchOperator` property will be ignored, as it serves the same purpose.
     *
     * @since 1.42
     *
     * @returns Reference to `this` for method chaining
     */
    setFilterSearchCallback(
      /**
       * A function that accepts two parameters fnTest({string} query, {string} value) and returns boolean if
       * the value satisfies the query.
       */
      fnTest: (p1: string, p2: string) => boolean
    ): this;
    /**
     * Sets a new value for property {@link #getFilterSearchOperator filterSearchOperator}.
     *
     * Provides a string filter operator which is used when the user searches items in filter details page.
     * Possible operators are: `AnyWordStartsWith`, `Contains`, `StartsWith`, `Equals`. This property will be
     * ignored if a custom callback is provided through `setFilterSearchCallback` method.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `StartsWith`.
     *
     * @since 1.42
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFilterSearchOperator(
      /**
       * New value for property `filterSearchOperator`
       */
      sFilterSearchOperator?:
        | StringFilterOperator
        | keyof typeof StringFilterOperator
    ): this;
    /**
     * Sets a new value for property {@link #getGroupDescending groupDescending}.
     *
     * Determines whether the group order is descending or ascending (default).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGroupDescending(
      /**
       * New value for property `groupDescending`
       */
      bGroupDescending?: boolean
    ): this;
    /**
     * Sets the selected filter object in format { parent_key: { key: boolean, key2: boolean, ...}, ... }.
     *
     * @since 1.42
     *
     * @returns Reference to `this` for method chaining
     */
    setSelectedFilterCompoundKeys(
      /**
       * A configuration object with filter item and sub item keys in the format: { parent_key: { key: boolean,
       * key2: boolean, ...}, ... }. Setting boolean to true will set the filter to true, false or omitting an
       * entry will set the filter to false. It can be used to set the dialog state based on presets.
       */
      oSelectedFilterKeys: Record<string, SelectedFilterKeys>
    ): this;
    /**
     * Sets the selected filter object in format {key: boolean}. **Note:** Do not use duplicated item keys with
     * this method.
     *
     * @deprecated As of version 1.42. replaced by `setSelectedFilterCompoundKeys` method
     *
     * @returns Reference to `this` for method chaining
     */
    setSelectedFilterKeys(
      /**
       * A configuration object with filter item and sub item keys in the format: { key: boolean }. Setting boolean
       * to true will set the filter to true, false or omitting an entry will set the filter to false. It can
       * be used to set the dialog state based on presets.
       */
      oSelectedFilterKeys: SelectedFilterKeys
    ): this;
    /**
     * Sets the selected group item (either by key, item id or item instance).
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setSelectedGroupItem(
      /**
       * The selected item, the item's string key or the item id
       */
      vItemOrKey: ViewSettingsItem | ID | string
    ): this;
    /**
     * Sets the selected preset filter item.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setSelectedPresetFilterItem(
      /**
       * The selected item or the item's key string
       */
      vItemOrKey: ViewSettingsItem | ID | string | null
    ): this;
    /**
     * Sets the selected sort item (either by key, item id or item instance).
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setSelectedSortItem(
      /**
       * The selected item, the item's string key or the item id
       */
      vItemOrKey: ViewSettingsItem | ID | string
    ): this;
    /**
     * Sets a new value for property {@link #getSortDescending sortDescending}.
     *
     * Determines whether the sort order is descending or ascending (default).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSortDescending(
      /**
       * New value for property `sortDescending`
       */
      bSortDescending?: boolean
    ): this;
    /**
     * Sets the title of the internal dialog.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setTitle(
      /**
       * The title text for the dialog
       */
      sTitle: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitleAlignment titleAlignment}.
     *
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.None`, the automatic title
     * alignment depending on the theme settings will be disabled. If set to `TitleAlignment.Auto`, the Title
     * will be aligned as it is set in the theme (if not set, the default value is `center`); Other possible
     * values are `TitleAlignment.Start` (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     * @since 1.72
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleAlignment(
      /**
       * New value for property `titleAlignment`
       */
      sTitleAlignment?: TitleAlignment | keyof typeof TitleAlignment
    ): this;
    /**
     * Forward method to the inner dialog method: toggleStyleClass.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    toggleStyleClass(
      /**
       * CSS class name to add or remove
       */
      sStyleClass: string,
      /**
       * Whether style class should be added (or removed); when this parameter is not given, the given style class
       * will be toggled (removed, if present, and added if not present)
       */
      bAdd?: boolean
    ): this;
    /**
     * Unbinds aggregation {@link #getCustomTabs customTabs} from model data.
     *
     * @since 1.30
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindCustomTabs(): this;
    /**
     * Unbinds aggregation {@link #getFilterItems filterItems} from model data.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindFilterItems(): this;
    /**
     * Unbinds aggregation {@link #getGroupItems groupItems} from model data.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindGroupItems(): this;
    /**
     * Unbinds aggregation {@link #getPresetFilterItems presetFilterItems} from model data.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindPresetFilterItems(): this;
    /**
     * Unbinds aggregation {@link #getSortItems sortItems} from model data.
     *
     * @since 1.16
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindSortItems(): this;
  }
  /**
   * Describes the settings that can be provided to the ViewSettingsDialog constructor.
   */
  export interface $ViewSettingsDialogSettings extends $ControlSettings {
    /**
     * Defines the title of the dialog. If not set and there is only one active tab, the dialog uses the default
     * "View" or "Sort", "Group", "Filter" respectively.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Determines whether the sort order is descending or ascending (default).
     */
    sortDescending?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the group order is descending or ascending (default).
     */
    groupDescending?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Provides a string filter operator which is used when the user searches items in filter details page.
     * Possible operators are: `AnyWordStartsWith`, `Contains`, `StartsWith`, `Equals`. This property will be
     * ignored if a custom callback is provided through `setFilterSearchCallback` method.
     *
     * @since 1.42
     */
    filterSearchOperator?:
      | (StringFilterOperator | keyof typeof StringFilterOperator)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.None`, the automatic title
     * alignment depending on the theme settings will be disabled. If set to `TitleAlignment.Auto`, the Title
     * will be aligned as it is set in the theme (if not set, the default value is `center`); Other possible
     * values are `TitleAlignment.Start` (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * @since 1.72
     */
    titleAlignment?:
      | (TitleAlignment | keyof typeof TitleAlignment)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The list of items with key and value that can be sorted over (for example, a list of columns for a table).
     *
     * @since 1.16
     */
    sortItems?:
      | ViewSettingsItem[]
      | ViewSettingsItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * The list of items with key and value that can be grouped on (for example, a list of columns for a table).
     *
     * @since 1.16
     */
    groupItems?:
      | ViewSettingsItem[]
      | ViewSettingsItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * The list of items with key and value that can be filtered on (for example, a list of columns for a table).
     * A filterItem is associated with one or more detail filters.
     *
     * **Note:** It is recommended to use the `sap.m.ViewSettingsFilterItem` as it fits best at the filter page.
     *
     * @since 1.16
     */
    filterItems?:
      | ViewSettingsItem[]
      | ViewSettingsItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * The list of preset filter items with key and value that allows the selection of more complex or custom
     * filters. These entries are displayed at the top of the filter tab.
     *
     * @since 1.16
     */
    presetFilterItems?:
      | ViewSettingsItem[]
      | ViewSettingsItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * The list of all the custom tabs.
     *
     * @since 1.30
     */
    customTabs?:
      | ViewSettingsCustomTab[]
      | ViewSettingsCustomTab
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * The sort item that is selected. It can be set by either passing a key or the item itself to the function
     * setSelectedSortItem.
     */
    selectedSortItem?: ViewSettingsItem | string;

    /**
     * The group item that is selected. It can be set by either passing a key or the item itself to the function
     * setSelectedGroupItem. By default 'None' is selected. You can restore back to 'None' by setting this association
     * to empty value.
     */
    selectedGroupItem?: ViewSettingsItem | string;

    /**
     * The preset filter item that is selected. It can be set by either passing a key or the item itself to
     * the function setSelectedPresetFilterItem. Note that either a preset filter OR multiple detail filters
     * can be active at the same time.
     */
    selectedPresetFilterItem?: ViewSettingsItem | string;

    /**
     * Indicates that the user has pressed the OK button and the selected sort, group, and filter settings should
     * be applied to the data on this page.
     *
     * **Note:** Custom tabs are not converted to event parameters automatically. For custom tabs, you have
     * to read the state of your controls inside the callback of this event.
     */
    confirm?: (oEvent: ViewSettingsDialog$ConfirmEvent) => void;

    /**
     * Called when the Cancel button is pressed. It can be used to set the state of custom filter controls.
     */
    cancel?: (oEvent: Event) => void;

    /**
     * Called when the filters are being reset.
     */
    resetFilters?: (oEvent: Event) => void;

    /**
     * Called when the Reset button is pressed. It can be used to set the state of custom tabs.
     */
    reset?: (oEvent: Event) => void;

    /**
     * Fired when the filter detail page is opened.
     */
    filterDetailPageOpened?: (
      oEvent: ViewSettingsDialog$FilterDetailPageOpenedEvent
    ) => void;

    /**
     * Fired before the dialog is closed. This event can be prevented which effectively prevents the dialog
     * from closing.
     *
     * @since 1.132
     */
    beforeClose?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the ViewSettingsDialog#beforeClose event.
   */
  export interface ViewSettingsDialog$BeforeCloseEventParameters {}

  /**
   * Event object of the ViewSettingsDialog#beforeClose event.
   */
  export type ViewSettingsDialog$BeforeCloseEvent = Event<
    ViewSettingsDialog$BeforeCloseEventParameters,
    ViewSettingsDialog
  >;

  /**
   * Parameters of the ViewSettingsDialog#cancel event.
   */
  export interface ViewSettingsDialog$CancelEventParameters {}

  /**
   * Event object of the ViewSettingsDialog#cancel event.
   */
  export type ViewSettingsDialog$CancelEvent = Event<
    ViewSettingsDialog$CancelEventParameters,
    ViewSettingsDialog
  >;

  /**
   * Parameters of the ViewSettingsDialog#confirm event.
   */
  export interface ViewSettingsDialog$ConfirmEventParameters {
    /**
     * The selected sort item.
     */
    sortItem?: ViewSettingsItem;

    /**
     * The selected sort order (true = descending, false = ascending).
     */
    sortDescending?: boolean;

    /**
     * The selected group item.
     */
    groupItem?: ViewSettingsItem;

    /**
     * The selected group order (true = descending, false = ascending).
     */
    groupDescending?: boolean;

    /**
     * The selected preset filter item.
     */
    presetFilterItem?: ViewSettingsItem;

    /**
     * The selected filters in an array of ViewSettingsItem.
     */
    filterItems?: ViewSettingsItem[];

    /**
     * The selected filter items in an object notation format: { key: boolean }. If a custom control filter
     * was displayed (for example, the user clicked on the filter item), the value for its key is set to true
     * to indicate that there has been an interaction with the control.
     */
    filterKeys?: object;

    /**
     * The selected filter items in an object notation format: { parentKey: { key: boolean, key2: boolean, ...
     * }, ...}. If a custom control filter was displayed (for example, the user clicked on the filter item),
     * the value for its key is set to true to indicate that there has been an interaction with the control.
     */
    filterCompoundKeys?: object;

    /**
     * The selected filter items in a string format to display in the control's header bar in format "Filtered
     * by: key (subkey1, subkey2, subkey3)".
     */
    filterString?: string;
  }

  /**
   * Event object of the ViewSettingsDialog#confirm event.
   */
  export type ViewSettingsDialog$ConfirmEvent = Event<
    ViewSettingsDialog$ConfirmEventParameters,
    ViewSettingsDialog
  >;

  /**
   * Parameters of the ViewSettingsDialog#filterDetailPageOpened event.
   */
  export interface ViewSettingsDialog$FilterDetailPageOpenedEventParameters {
    /**
     * The filter item for which the details are opened.
     */
    parentFilterItem?: ViewSettingsFilterItem;
  }

  /**
   * Event object of the ViewSettingsDialog#filterDetailPageOpened event.
   */
  export type ViewSettingsDialog$FilterDetailPageOpenedEvent = Event<
    ViewSettingsDialog$FilterDetailPageOpenedEventParameters,
    ViewSettingsDialog
  >;

  /**
   * Parameters of the ViewSettingsDialog#reset event.
   */
  export interface ViewSettingsDialog$ResetEventParameters {}

  /**
   * Event object of the ViewSettingsDialog#reset event.
   */
  export type ViewSettingsDialog$ResetEvent = Event<
    ViewSettingsDialog$ResetEventParameters,
    ViewSettingsDialog
  >;

  /**
   * Parameters of the ViewSettingsDialog#resetFilters event.
   */
  export interface ViewSettingsDialog$ResetFiltersEventParameters {}

  /**
   * Event object of the ViewSettingsDialog#resetFilters event.
   */
  export type ViewSettingsDialog$ResetFiltersEvent = Event<
    ViewSettingsDialog$ResetFiltersEventParameters,
    ViewSettingsDialog
  >;
}

declare module "sap/m/SelectionDetails" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import Item from "sap/ui/core/Item";

  import SelectionDetailsItem from "sap/m/SelectionDetailsItem";

  import Event from "sap/ui/base/Event";

  import { AggregationBindingInfo } from "sap/ui/base/ManagedObject";

  import Interface from "sap/ui/base/Interface";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { SelectionDetailsActionLevel } from "sap/m/library";

  /**
   * The protected control provides a popover that displays the details of the items selected in the chart.
   * This control should only be used in the toolbars of sap.suite.ui.commons.ChartContainer and sap.ui.comp.smartchart.SmartChart
   * controls. Initially, the control is rendered as a button that opens the popup after clicking on it. **Note:**It
   * is protected and should only be used within the framework itself.
   *
   * @since 1.48.0
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export default class SelectionDetails extends Control {
    /**
     * Constructor for a new SelectionDetails.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    protected constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $SelectionDetailsSettings
    );
    /**
     * Constructor for a new SelectionDetails.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    protected constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $SelectionDetailsSettings
    );

    /**
     * Creates a new subclass of class sap.m.SelectionDetails with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SelectionDetails>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SelectionDetails.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some action to the aggregation {@link #getActions actions}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAction(
      /**
       * The action to add; if empty, nothing is inserted
       */
      oAction: Item
    ): this;
    /**
     * Adds some actionGroup to the aggregation {@link #getActionGroups actionGroups}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addActionGroup(
      /**
       * The actionGroup to add; if empty, nothing is inserted
       */
      oActionGroup: Item
    ): this;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: SelectionDetailsItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:actionPress actionPress} event of this `sap.m.SelectionDetails`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectionDetails` itself.
     *
     * Event is triggered when a custom action is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachActionPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectionDetails$ActionPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectionDetails` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:actionPress actionPress} event of this `sap.m.SelectionDetails`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectionDetails` itself.
     *
     * Event is triggered when a custom action is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachActionPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectionDetails$ActionPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectionDetails` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.SelectionDetails`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectionDetails` itself.
     *
     * Event is triggered before the popover is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectionDetails` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.SelectionDetails`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectionDetails` itself.
     *
     * Event is triggered before the popover is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectionDetails` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.SelectionDetails`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectionDetails` itself.
     *
     * Event is triggered before the popover is open.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectionDetails` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.SelectionDetails`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectionDetails` itself.
     *
     * Event is triggered before the popover is open.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectionDetails` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navigate navigate} event of this `sap.m.SelectionDetails`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectionDetails` itself.
     *
     * Event is triggered after a list item of {@link sap.m.SelectionDetailsItem} is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavigate(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectionDetails$NavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectionDetails` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navigate navigate} event of this `sap.m.SelectionDetails`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectionDetails` itself.
     *
     * Event is triggered after a list item of {@link sap.m.SelectionDetailsItem} is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavigate(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectionDetails$NavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectionDetails` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches an event handler to the given listener to react to user selection interaction.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns this to allow method chaining
     */
    attachSelectionHandler(
      /**
       * The identifier of the event to listen for
       */
      eventId: string,
      /**
       * The object which triggers the event to register on
       */
      listener: object
    ): this;
    /**
     * Binds aggregation {@link #getItems items} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the actionGroups in the aggregation {@link #getActionGroups actionGroups}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyActionGroups(): this;
    /**
     * Destroys all the actions in the aggregation {@link #getActions actions}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyActions(): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:actionPress actionPress} event of this `sap.m.SelectionDetails`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachActionPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SelectionDetails$ActionPressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeClose beforeClose} event of this `sap.m.SelectionDetails`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeOpen beforeOpen} event of this `sap.m.SelectionDetails`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:navigate navigate} event of this `sap.m.SelectionDetails`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachNavigate(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SelectionDetails$NavigateEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches the event which was attached by `attachSelectionHandler`.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns this to allow method chaining
     */
    detachSelectionHandler(): this;
    /**
     * Fires event {@link #event:actionPress actionPress} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireActionPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SelectionDetails$ActionPressEventParameters
    ): this;
    /**
     * Fires event {@link #event:beforeClose beforeClose} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforeClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:beforeOpen beforeOpen} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforeOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:navigate navigate} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireNavigate(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SelectionDetails$NavigateEventParameters
    ): this;
    /**
     * Gets content of aggregation {@link #getActionGroups actionGroups}.
     *
     * Contains actions that are rendered as a dedicated {@link sap.m.StandardListItem item}. In case an action
     * group is pressed, a navigation should be triggered via `navTo` method. A maximum of 5 actionGroups is
     * displayed inside the popover, though more can be added to the aggregation.
     */
    getActionGroups(): Item[];
    /**
     * Gets content of aggregation {@link #getActions actions}.
     *
     * Contains custom actions shown in the responsive toolbar below items on the first page.
     */
    getActions(): Item[];
    /**
     * Returns the public facade of the SelectionDetails control for non inner framework usages.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The reduced facade for outer framework usages.
     */
    getFacade(): Interface;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * Contains {@link sap.m.SelectionDetailsItem items} that are displayed on the first page.
     */
    getItems(): SelectionDetailsItem[];
    /**
     * Checks for the provided `sap.ui.core.Item` in the aggregation {@link #getActions actions}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfAction(
      /**
       * The action whose index is looked for
       */
      oAction: Item
    ): int;
    /**
     * Checks for the provided `sap.ui.core.Item` in the aggregation {@link #getActionGroups actionGroups}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfActionGroup(
      /**
       * The actionGroup whose index is looked for
       */
      oActionGroup: Item
    ): int;
    /**
     * Checks for the provided `sap.m.SelectionDetailsItem` in the aggregation {@link #getItems items}. and
     * returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: SelectionDetailsItem
    ): int;
    /**
     * Inserts a action into the aggregation {@link #getActions actions}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertAction(
      /**
       * The action to insert; if empty, nothing is inserted
       */
      oAction: Item,
      /**
       * The `0`-based index the action should be inserted at; for a negative value of `iIndex`, the action is
       * inserted at position 0; for a value greater than the current size of the aggregation, the action is inserted
       * at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a actionGroup into the aggregation {@link #getActionGroups actionGroups}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertActionGroup(
      /**
       * The actionGroup to insert; if empty, nothing is inserted
       */
      oActionGroup: Item,
      /**
       * The `0`-based index the actionGroup should be inserted at; for a negative value of `iIndex`, the actionGroup
       * is inserted at position 0; for a value greater than the current size of the aggregation, the actionGroup
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: SelectionDetailsItem,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Method to register the factory function that creates the SelectionDetailsItems. The factory function
     * is called for every selected entry separately with three parameters. First parameter is the display data
     * array for each item out of the selection. Second parameter is the data array for each item out of the
     * selection. Third parameter is the binding context for each item in the selection. This is undefined if
     * no binding is used. Fourth parameter is `oData`. Can be undefined.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns this to allow method chaining
     */
    registerSelectionDetailsItemFactory(
      /**
       * Data to be passed to the factory function
       */
      data: any,
      /**
       * The item factory function that returns SelectionDetailsItems
       */
      factory: Function
    ): this;
    /**
     * Removes a action from the aggregation {@link #getActions actions}.
     *
     *
     * @returns The removed action or `null`
     */
    removeAction(
      /**
       * The action to remove or its index or id
       */
      vAction: int | string | Item
    ): Item | null;
    /**
     * Removes a actionGroup from the aggregation {@link #getActionGroups actionGroups}.
     *
     *
     * @returns The removed actionGroup or `null`
     */
    removeActionGroup(
      /**
       * The actionGroup to remove or its index or id
       */
      vActionGroup: int | string | Item
    ): Item | null;
    /**
     * Removes all the controls from the aggregation {@link #getActionGroups actionGroups}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllActionGroups(): Item[];
    /**
     * Removes all the controls from the aggregation {@link #getActions actions}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllActions(): Item[];
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): SelectionDetailsItem[];
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | SelectionDetailsItem
    ): SelectionDetailsItem | null;
    /**
     * Sets the popover to modal or non-modal based on the given parameter. This only takes effect on desktop
     * or tablet. Please see the documentation {@link sap.m.ResponsivePopover#modal}.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns To ensure method chaining, return the SelectionDetails.
     */
    setPopoverModal(
      /**
       * New value for property modal of the internally used popover.
       */
      modal: boolean
    ): this;
    /**
     * Unbinds aggregation {@link #getItems items} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindItems(): this;
  }
  /**
   * Describes the settings that can be provided to the SelectionDetails constructor.
   *
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export interface $SelectionDetailsSettings extends $ControlSettings {
    /**
     * Contains {@link sap.m.SelectionDetailsItem items} that are displayed on the first page.
     */
    items?:
      | SelectionDetailsItem[]
      | SelectionDetailsItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Contains custom actions shown in the responsive toolbar below items on the first page.
     */
    actions?: Item[] | Item | AggregationBindingInfo | `{${string}}`;

    /**
     * Contains actions that are rendered as a dedicated {@link sap.m.StandardListItem item}. In case an action
     * group is pressed, a navigation should be triggered via `navTo` method. A maximum of 5 actionGroups is
     * displayed inside the popover, though more can be added to the aggregation.
     */
    actionGroups?: Item[] | Item | AggregationBindingInfo | `{${string}}`;

    /**
     * Event is triggered before the popover is open.
     */
    beforeOpen?: (oEvent: Event) => void;

    /**
     * Event is triggered before the popover is closed.
     */
    beforeClose?: (oEvent: Event) => void;

    /**
     * Event is triggered after a list item of {@link sap.m.SelectionDetailsItem} is pressed.
     */
    navigate?: (oEvent: SelectionDetails$NavigateEvent) => void;

    /**
     * Event is triggered when a custom action is pressed.
     */
    actionPress?: (oEvent: SelectionDetails$ActionPressEvent) => void;
  }

  /**
   * Parameters of the SelectionDetails#actionPress event.
   *
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export interface SelectionDetails$ActionPressEventParameters {
    /**
     * The action that has to be processed once the action has been pressed
     */
    action?: Item;

    /**
     * If the action is pressed on one of the {@link sap.m.SelectionDetailsItem items}, the parameter contains
     * a reference to the pressed {@link sap.m.SelectionDetailsItem item}. If a custom action or action group
     * of the SelectionDetails popover is pressed, this parameter refers to all {@link sap.m.SelectionDetailsItem items}
     */
    items?: SelectionDetailsItem;

    /**
     * The action level of action buttons. The available levels are Item, List and Group
     */
    level?:
      | SelectionDetailsActionLevel
      | keyof typeof SelectionDetailsActionLevel;
  }

  /**
   * Event object of the SelectionDetails#actionPress event.
   *
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export type SelectionDetails$ActionPressEvent = Event<
    SelectionDetails$ActionPressEventParameters,
    SelectionDetails
  >;

  /**
   * Parameters of the SelectionDetails#beforeClose event.
   *
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export interface SelectionDetails$BeforeCloseEventParameters {}

  /**
   * Event object of the SelectionDetails#beforeClose event.
   *
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export type SelectionDetails$BeforeCloseEvent = Event<
    SelectionDetails$BeforeCloseEventParameters,
    SelectionDetails
  >;

  /**
   * Parameters of the SelectionDetails#beforeOpen event.
   *
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export interface SelectionDetails$BeforeOpenEventParameters {}

  /**
   * Event object of the SelectionDetails#beforeOpen event.
   *
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export type SelectionDetails$BeforeOpenEvent = Event<
    SelectionDetails$BeforeOpenEventParameters,
    SelectionDetails
  >;

  /**
   * Parameters of the SelectionDetails#navigate event.
   *
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export interface SelectionDetails$NavigateEventParameters {
    /**
     * The item on which the action has been pressed. Can be null in case a navigation was done without item
     * context, e.g. action press.
     */
    item?: SelectionDetailsItem;

    /**
     * Direction of the triggered navigation, possible values are "to" and "back".
     */
    direction?: string;

    /**
     * The content of the currently viewed page that was previously added via {@link sap.m.SelectionDetailsFacade#navTo}.
     * This contains the content of the page before the navigation was triggered. Can be null in case of first
     * event triggering.
     */
    content?: Control;
  }

  /**
   * Event object of the SelectionDetails#navigate event.
   *
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export type SelectionDetails$NavigateEvent = Event<
    SelectionDetails$NavigateEventParameters,
    SelectionDetails
  >;
}

declare module "sap/m/SelectionDetailsFacade" {
  import Item from "sap/ui/core/Item";

  import Event from "sap/ui/base/Event";

  import Control from "sap/ui/core/Control";

  /**
   * The public facade of the {@link sap.m.SelectionDetails} control.
   *
   * @since 1.48.0
   */
  export default class SelectionDetailsFacade {
    /**
     * Describes the public facade of the {@link sap.m.SelectionDetails} control.
     */
    constructor();

    /**
     * Adds some action to the aggregation {@link #getActions actions}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAction(
      /**
       * The action to add; if empty, nothing is inserted
       */
      oAction: Item
    ): this;
    /**
     * Adds some actionGroup to the aggregation {@link #getActionGroups actionGroups}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addActionGroup(
      /**
       * The actionGroup to add; if empty, nothing is inserted
       */
      oActionGroup: Item
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:actionPress actionPress} event of this `sap.m.SelectionDetails`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectionDetails` itself.
     *
     * Event is triggered when a custom action is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachActionPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectionDetails` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:actionPress actionPress} event of this `sap.m.SelectionDetails`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectionDetails` itself.
     *
     * Event is triggered when a custom action is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachActionPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectionDetails` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.SelectionDetails`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectionDetails` itself.
     *
     * Event is triggered before the popover is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectionDetails` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeClose beforeClose} event of this `sap.m.SelectionDetails`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectionDetails` itself.
     *
     * Event is triggered before the popover is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectionDetails` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.SelectionDetails`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectionDetails` itself.
     *
     * Event is triggered before the popover is open.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectionDetails` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.SelectionDetails`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectionDetails` itself.
     *
     * Event is triggered before the popover is open.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectionDetails` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navigate navigate} event of this `sap.m.SelectionDetails`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectionDetails` itself.
     *
     * Event is triggered after a list item of {@link sap.m.SelectionDetailsItem} is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavigate(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectionDetails` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navigate navigate} event of this `sap.m.SelectionDetails`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectionDetails` itself.
     *
     * Event is triggered after a list item of {@link sap.m.SelectionDetailsItem} is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavigate(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectionDetails` itself
       */
      oListener?: object
    ): this;
    /**
     * Closes SelectionDetails if open.
     *
     *
     * @returns To ensure method chaining, return the SelectionDetails.
     */
    close(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:actionPress actionPress} event of this `sap.m.SelectionDetails`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachActionPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeClose beforeClose} event of this `sap.m.SelectionDetails`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeOpen beforeOpen} event of this `sap.m.SelectionDetails`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:navigate navigate} event of this `sap.m.SelectionDetails`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachNavigate(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Returns `true` if the labels of the {@link sap.m.SelectionDetailsItemLine} elements are wrapped, `false`
     * otherwise.
     *
     *
     * @returns True if the labels of the {@link sap.m.SelectionDetailsItemLine} elements are wrapped, false
     * otherwise.
     */
    getWrapLabels(): boolean;
    /**
     * Returns true if the SelectionDetails is enabled, otherwise false.
     *
     *
     * @returns True if the SelectionDetails contains items, otherwise false.
     */
    isEnabled(): boolean;
    /**
     * Returns true if the SelectionDetails is open, otherwise false.
     *
     *
     * @returns True if the SelectionDetails is open, otherwise false.
     */
    isOpen(): boolean;
    /**
     * Wraps the given content in {@link sap.m.Page page}, adds it to existing {@link sap.m.NavContainer NavContainer }
     * and navigates to this newly created page. Has no effect if the SelectionDetails is closed. Lazily processes
     * dependencies for the navigation event.
     *
     *
     * @returns To ensure method chaining, return the SelectionDetails.
     */
    navTo(
      /**
       * The title property of the {@link sap.m.Page page} control to which the navigation should occur.
       */
      title: string,
      /**
       * The content of the control to which the navigation should occur.
       */
      content: Control
    ): this;
    /**
     * Removes a action from the aggregation {@link #getActions actions}.
     *
     *
     * @returns The removed action or `null`
     */
    removeAction(
      /**
       * The action to remove or its index or id
       */
      vAction: int | string | Item
    ): Item | null;
    /**
     * Removes a actionGroup from the aggregation {@link #getActionGroups actionGroups}.
     *
     *
     * @returns The removed actionGroup or `null`
     */
    removeActionGroup(
      /**
       * The actionGroup to remove or its index or id
       */
      vActionGroup: int | string | Item
    ): Item | null;
    /**
     * Removes all the controls from the aggregation {@link #getActionGroups actionGroups}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllActionGroups(): Item[];
    /**
     * Removes all the controls from the aggregation {@link #getActions actions}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllActions(): Item[];
    /**
     * Enables line wrapping for the labels of the of the {@link sap.m.SelectionDetailsItemLine} elements.
     *
     *
     * @returns To ensure method chaining, returns SelectionDetails.
     */
    setWrapLabels(
      /**
       * True to apply wrapping to the labels of the {@link sap.m.SelectionDetailsItemLine} elements.
       */
      bWrap: boolean
    ): this;
  }
}

declare module "sap/m/SelectionDetailsItem" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import Item from "sap/ui/core/Item";

  import SelectionDetailsItemLine from "sap/m/SelectionDetailsItemLine";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Interface from "sap/ui/base/Interface";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * This protected element provides an item for {@link sap.m.SelectionDetails} that is shown inside a list.
   * The item includes SelectionDetailsItemLine as its lines that are displayed in one block above the optional
   * actions. **Note:**It is protected and should only be used within the framework itself.
   *
   * @since 1.48.0
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export default class SelectionDetailsItem extends UI5Element {
    /**
     * Constructor for a new SelectionDetailsItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    protected constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SelectionDetailsItemSettings
    );
    /**
     * Constructor for a new SelectionDetailsItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    protected constructor(
      /**
       * Id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SelectionDetailsItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.SelectionDetailsItem with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SelectionDetailsItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SelectionDetailsItem.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some action to the aggregation {@link #getActions actions}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAction(
      /**
       * The action to add; if empty, nothing is inserted
       */
      oAction: Item
    ): this;
    /**
     * Adds some line to the aggregation {@link #getLines lines}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addLine(
      /**
       * The line to add; if empty, nothing is inserted
       */
      oLine: SelectionDetailsItemLine
    ): this;
    /**
     * Binds aggregation {@link #getLines lines} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindLines(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the actions in the aggregation {@link #getActions actions}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyActions(): this;
    /**
     * Destroys all the lines in the aggregation {@link #getLines lines}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyLines(): this;
    /**
     * Gets content of aggregation {@link #getActions actions}.
     *
     * Contains custom actions shown below the main content of the item.
     */
    getActions(): Item[];
    /**
     * Gets current value of property {@link #getEnableNav enableNav}.
     *
     * Determines whether or not the item is active and a navigation event is triggered on press.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `enableNav`
     */
    getEnableNav(): boolean;
    /**
     * Returns the public facade of the SelectionDetailsItem for non inner framework usages.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The reduced facade for outer framework usages.
     */
    getFacade(): Interface;
    /**
     * Gets content of aggregation {@link #getLines lines}.
     *
     * Contains a record of information about, for example, measures and dimensions. These entries are usually
     * obtained via selection in chart controls.
     */
    getLines(): SelectionDetailsItemLine[];
    /**
     * Checks for the provided `sap.ui.core.Item` in the aggregation {@link #getActions actions}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfAction(
      /**
       * The action whose index is looked for
       */
      oAction: Item
    ): int;
    /**
     * Checks for the provided `sap.m.SelectionDetailsItemLine` in the aggregation {@link #getLines lines}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfLine(
      /**
       * The line whose index is looked for
       */
      oLine: SelectionDetailsItemLine
    ): int;
    /**
     * Inserts a action into the aggregation {@link #getActions actions}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertAction(
      /**
       * The action to insert; if empty, nothing is inserted
       */
      oAction: Item,
      /**
       * The `0`-based index the action should be inserted at; for a negative value of `iIndex`, the action is
       * inserted at position 0; for a value greater than the current size of the aggregation, the action is inserted
       * at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a line into the aggregation {@link #getLines lines}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertLine(
      /**
       * The line to insert; if empty, nothing is inserted
       */
      oLine: SelectionDetailsItemLine,
      /**
       * The `0`-based index the line should be inserted at; for a negative value of `iIndex`, the line is inserted
       * at position 0; for a value greater than the current size of the aggregation, the line is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes a action from the aggregation {@link #getActions actions}.
     *
     *
     * @returns The removed action or `null`
     */
    removeAction(
      /**
       * The action to remove or its index or id
       */
      vAction: int | string | Item
    ): Item | null;
    /**
     * Removes all the controls from the aggregation {@link #getActions actions}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllActions(): Item[];
    /**
     * Removes all the controls from the aggregation {@link #getLines lines}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllLines(): SelectionDetailsItemLine[];
    /**
     * Removes a line from the aggregation {@link #getLines lines}.
     *
     *
     * @returns The removed line or `null`
     */
    removeLine(
      /**
       * The line to remove or its index or id
       */
      vLine: int | string | SelectionDetailsItemLine
    ): SelectionDetailsItemLine | null;
    /**
     * Sets a new value for property {@link #getEnableNav enableNav}.
     *
     * Determines whether or not the item is active and a navigation event is triggered on press.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableNav(
      /**
       * New value for property `enableNav`
       */
      bEnableNav?: boolean
    ): this;
    /**
     * Unbinds aggregation {@link #getLines lines} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindLines(): this;
  }
  /**
   * Describes the settings that can be provided to the SelectionDetailsItem constructor.
   *
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export interface $SelectionDetailsItemSettings extends $ElementSettings {
    /**
     * Determines whether or not the item is active and a navigation event is triggered on press.
     */
    enableNav?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Contains a record of information about, for example, measures and dimensions. These entries are usually
     * obtained via selection in chart controls.
     */
    lines?:
      | SelectionDetailsItemLine[]
      | SelectionDetailsItemLine
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Contains custom actions shown below the main content of the item.
     */
    actions?: Item[] | Item | AggregationBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/SelectionDetailsItemLine" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * This Element provides a means to fill an {@link sap.m.SelectionDetailsItem} with content. It is used
   * for a form-like display of a label followed by a value with an optional unit. If the unit is used, the
   * value is displayed bold. **Note:**It is protected and should ony be used within the framework
   * itself.
   *
   * @since 1.48.0
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export default class SelectionDetailsItemLine extends UI5Element {
    /**
     * Constructor for a new SelectionDetailsItemLine.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    protected constructor(
      /**
       * Initial settings for the new element
       */
      mSettings?: $SelectionDetailsItemLineSettings
    );
    /**
     * Constructor for a new SelectionDetailsItemLine.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    protected constructor(
      /**
       * ID for the new element, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new element
       */
      mSettings?: $SelectionDetailsItemLineSettings
    );

    /**
     * Creates a new subclass of class sap.m.SelectionDetailsItemLine with name `sClassName` and enriches it
     * with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SelectionDetailsItemLine>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SelectionDetailsItemLine.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getDisplayValue displayValue}.
     *
     * The display value of the line. If this property is set, it overrides the value property and is displayed
     * as is.
     *
     *
     * @returns Value of property `displayValue`
     */
    getDisplayValue(): string;
    /**
     * Gets current value of property {@link #getLabel label}.
     *
     * The label that is shown as the first part of the line. It may contain the name of the currently selected
     * dimension or measure.
     *
     *
     * @returns Value of property `label`
     */
    getLabel(): string;
    /**
     * Gets current value of property {@link #getLineMarker lineMarker}.
     *
     * A string to be rendered by the control as a line marker. This string must be a valid SVG definition.
     * The only valid tags are: svg, path, line.
     *
     *
     * @returns Value of property `lineMarker`
     */
    getLineMarker(): string;
    /**
     * Gets current value of property {@link #getUnit unit}.
     *
     * The unit of the given value. If this unit is given, the line is displayed bold.
     *
     *
     * @returns Value of property `unit`
     */
    getUnit(): string;
    /**
     * Gets current value of property {@link #getValue value}.
     *
     * The value of the line, for example the value of the currently selected measure. Expected type is a string,
     * number or a plain object, including date and time properties of type string.
     *
     *
     * @returns Value of property `value`
     */
    getValue(): any;
    /**
     * Sets a new value for property {@link #getDisplayValue displayValue}.
     *
     * The display value of the line. If this property is set, it overrides the value property and is displayed
     * as is.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisplayValue(
      /**
       * New value for property `displayValue`
       */
      sDisplayValue?: string
    ): this;
    /**
     * Sets a new value for property {@link #getLabel label}.
     *
     * The label that is shown as the first part of the line. It may contain the name of the currently selected
     * dimension or measure.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLabel(
      /**
       * New value for property `label`
       */
      sLabel: string
    ): this;
    /**
     * Sets a new value for property {@link #getLineMarker lineMarker}.
     *
     * A string to be rendered by the control as a line marker. This string must be a valid SVG definition.
     * The only valid tags are: svg, path, line.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLineMarker(
      /**
       * New value for property `lineMarker`
       */
      sLineMarker?: string
    ): this;
    /**
     * Sets a new value for property {@link #getUnit unit}.
     *
     * The unit of the given value. If this unit is given, the line is displayed bold.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUnit(
      /**
       * New value for property `unit`
       */
      sUnit?: string
    ): this;
    /**
     * Sets a new value for property {@link #getValue value}.
     *
     * The value of the line, for example the value of the currently selected measure. Expected type is a string,
     * number or a plain object, including date and time properties of type string.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValue(
      /**
       * New value for property `value`
       */
      oValue: any
    ): this;
  }
  /**
   * Describes the settings that can be provided to the SelectionDetailsItemLine constructor.
   *
   * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
   */
  export interface $SelectionDetailsItemLineSettings extends $ElementSettings {
    /**
     * The label that is shown as the first part of the line. It may contain the name of the currently selected
     * dimension or measure.
     */
    label?: string | PropertyBindingInfo;

    /**
     * The value of the line, for example the value of the currently selected measure. Expected type is a string,
     * number or a plain object, including date and time properties of type string.
     */
    value?: any | PropertyBindingInfo | `{${string}}`;

    /**
     * The display value of the line. If this property is set, it overrides the value property and is displayed
     * as is.
     */
    displayValue?: string | PropertyBindingInfo;

    /**
     * The unit of the given value. If this unit is given, the line is displayed bold.
     */
    unit?: string | PropertyBindingInfo;

    /**
     * A string to be rendered by the control as a line marker. This string must be a valid SVG definition.
     * The only valid tags are: svg, path, line.
     */
    lineMarker?: string | PropertyBindingInfo;
  }
}

declare module "sap/m/SelectList" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { ID, CSSSize } from "sap/ui/core/library";

  import Item from "sap/ui/core/Item";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import { SelectListKeyboardNavigationMode } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Event from "sap/ui/base/Event";

  /**
   * The `sap.m.SelectList` displays a list of items that allows the user to select an item.
   *
   * @since 1.26.0
   */
  export default class SelectList extends Control {
    /**
     * Constructor for a new `sap.m.SelectList`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control.
       */
      mSettings?: $SelectListSettings
    );
    /**
     * Constructor for a new `sap.m.SelectList`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given.
       */
      sId?: string,
      /**
       * Initial settings for the new control.
       */
      mSettings?: $SelectListSettings
    );

    /**
     * Creates a new subclass of class sap.m.SelectList with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SelectList>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SelectList.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: Item
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemPress itemPress} event of this `sap.m.SelectList`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectList` itself.
     *
     * This event is fired when an item is pressed.
     *
     * @since 1.32.4
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectList$ItemPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectList` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemPress itemPress} event of this `sap.m.SelectList`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectList` itself.
     *
     * This event is fired when an item is pressed.
     *
     * @since 1.32.4
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectList$ItemPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectList` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionChange selectionChange} event of this
     * `sap.m.SelectList`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectList` itself.
     *
     * This event is fired when the selection has changed.
     *
     * **Note: ** The selection can be changed by pressing a non-selected item or via keyboard and after the
     * enter or space key is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectList$SelectionChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectList` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionChange selectionChange} event of this
     * `sap.m.SelectList`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SelectList` itself.
     *
     * This event is fired when the selection has changed.
     *
     * **Note: ** The selection can be changed by pressing a non-selected item or via keyboard and after the
     * enter or space key is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SelectList$SelectionChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SelectList` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getItems items} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Clear the selection.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    clearSelection(): void;
    /**
     * Destroys all the items in the aggregation named `items`.
     *
     *
     * @returns `this` to allow method chaining.
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:itemPress itemPress} event of this `sap.m.SelectList`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.32.4
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachItemPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SelectList$ItemPressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:selectionChange selectionChange} event of
     * this `sap.m.SelectList`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelectionChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SelectList$SelectionChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:itemPress itemPress} to attached listeners.
     *
     * @since 1.32.4
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireItemPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SelectList$ItemPressEventParameters
    ): this;
    /**
     * Fires event {@link #event:selectionChange selectionChange} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelectionChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SelectList$SelectionChangeEventParameters
    ): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     */
    getAriaLabelledBy(): ID[];
    /**
     * Retrieves the default selected item from the aggregation named `items`.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    getDefaultSelectedItem(aItems?: Item[]): Item | null;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Indicates whether the user can change the selection.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets the enabled items from the aggregation named `items`.
     *
     *
     * @returns An array containing the enabled items.
     */
    getEnabledItems(
      /**
       * items to filter
       */
      aItems?: Item[]
    ): Item[];
    /**
     * Gets the first item from the aggregation named `items`.
     *
     *
     * @returns The first item, or `null` if there are no items.
     */
    getFirstItem(): Item | null;
    /**
     * Gets the item from the aggregation named `items` at the given 0-based index.
     *
     *
     * @returns Item at the given index, or `null` if none.
     */
    getItemAt(
      /**
       * Index of the item to return.
       */
      iIndex: int
    ): Item | null;
    /**
     * Gets the item with the given key from the aggregation named `items`.
     *
     * **Note: ** If duplicate keys exists, the first item matching the key is returned.
     *
     *
     * @returns The matched item or `null`
     */
    getItemByKey(
      /**
       * An item key that specifies the item to retrieve.
       */
      sKey: string
    ): Item | null;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * Defines the items contained within this control.
     */
    getItems(): Item[];
    /**
     * Gets current value of property {@link #getKeyboardNavigationMode keyboardNavigationMode}.
     *
     * Defines the keyboard navigation mode.
     *
     * **Note:** The `sap.m.SelectListKeyboardNavigationMode.None` enumeration value, is only intended for use
     * in some composite controls that handles keyboard navigation by themselves.
     *
     * Default value is `Delimited`.
     *
     * @since 1.38
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Value of property `keyboardNavigationMode`
     */
    getKeyboardNavigationMode(): SelectListKeyboardNavigationMode;
    /**
     * Gets the enabled items from the aggregation named `items`.
     *
     *
     * @returns The last item, or `null` if there are no items.
     */
    getLastItem(): Item | null;
    /**
     * Gets current value of property {@link #getMaxWidth maxWidth}.
     *
     * Sets the maximum width of the control.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Value of property `maxWidth`
     */
    getMaxWidth(): CSSSize;
    /**
     * Gets the selected item object from the aggregation named `items`.
     *
     *
     * @returns The current target of the `selectedItem` association, or null.
     */
    getSelectedItem(): Item | null;
    /**
     * Gets current value of property {@link #getSelectedItemId selectedItemId}.
     *
     * ID of the selected item.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `selectedItemId`
     */
    getSelectedItemId(): string;
    /**
     * Gets current value of property {@link #getSelectedKey selectedKey}.
     *
     * Key of the selected item.
     *
     * **Note: ** If duplicate keys exist, the first item matching the key is used.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `selectedKey`
     */
    getSelectedKey(): string;
    /**
     * Gets current value of property {@link #getShowSecondaryValues showSecondaryValues}.
     *
     * Indicates whether the text values of the `additionalText` property of a {@link sap.ui.core.ListItem }
     * are shown.
     *
     * Default value is `false`.
     *
     * @since 1.32.3
     *
     * @returns Value of property `showSecondaryValues`
     */
    getShowSecondaryValues(): boolean;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Sets the width of the control.
     *
     * Default value is `"auto"`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Checks for the provided `sap.ui.core.Item` in the aggregation {@link #getItems items}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: Item
    ): int;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: Item,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all the items in the aggregation named `items`. Additionally unregisters them from the hosting
     * UIArea.
     *
     *
     * @returns An array of the removed items (might be empty).
     */
    removeAllItems(): Item[];
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an item from the aggregation named `items`.
     *
     *
     * @returns The removed item or `null`.
     */
    removeItem(
      /**
       * The item to remove or its index or id.
       */
      vItem: int | ID | Item
    ): Item | null;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Indicates whether the user can change the selection.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getKeyboardNavigationMode keyboardNavigationMode}.
     *
     * Defines the keyboard navigation mode.
     *
     * **Note:** The `sap.m.SelectListKeyboardNavigationMode.None` enumeration value, is only intended for use
     * in some composite controls that handles keyboard navigation by themselves.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Delimited`.
     *
     * @since 1.38
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setKeyboardNavigationMode(
      /**
       * New value for property `keyboardNavigationMode`
       */
      sKeyboardNavigationMode?:
        | SelectListKeyboardNavigationMode
        | keyof typeof SelectListKeyboardNavigationMode
    ): this;
    /**
     * Sets a new value for property {@link #getMaxWidth maxWidth}.
     *
     * Sets the maximum width of the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxWidth(
      /**
       * New value for property `maxWidth`
       */
      sMaxWidth?: CSSSize
    ): this;
    /**
     * Sets the `selectedItem` association.
     *
     *
     * @returns `this` to allow method chaining.
     */
    setSelectedItem(
      /**
       * New value for the `selectedItem` association. If an ID of a `sap.ui.core.Item` is given, the item with
       * this ID becomes the `selectedItem` association. Alternatively, a `sap.ui.core.Item` instance may be given
       * or `null` to clear the selection.
       */
      vItem: ID | Item | null
    ): this;
    /**
     * Sets property `selectedItemId`.
     *
     * Default value is an empty string `""` or `undefined`.
     *
     *
     * @returns `this` to allow method chaining.
     */
    setSelectedItemId(
      /**
       * New value for property `selectedItemId`.
       */
      vItem: string | undefined
    ): this;
    /**
     * Sets property `selectedKey`.
     *
     * Default value is an empty string `""` or `undefined`.
     *
     *
     * @returns `this` to allow method chaining.
     */
    setSelectedKey(
      /**
       * New value for property `selectedKey`.
       */
      sKey: string
    ): this;
    /**
     * Updates and synchronizes `selectedItem` association, `selectedItemId` and `selectedKey` properties.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    setSelection(vItem: string | Item | null): void;
    /**
     * Sets a new value for property {@link #getShowSecondaryValues showSecondaryValues}.
     *
     * Indicates whether the text values of the `additionalText` property of a {@link sap.ui.core.ListItem }
     * are shown.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.32.3
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowSecondaryValues(
      /**
       * New value for property `showSecondaryValues`
       */
      bShowSecondaryValues?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Sets the width of the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"auto"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Unbinds aggregation {@link #getItems items} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindItems(): this;
  }
  /**
   * Describes the settings that can be provided to the SelectList constructor.
   */
  export interface $SelectListSettings extends $ControlSettings {
    /**
     * Indicates whether the user can change the selection.
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the width of the control.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the maximum width of the control.
     */
    maxWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Key of the selected item.
     *
     * **Note: ** If duplicate keys exist, the first item matching the key is used.
     */
    selectedKey?: string | PropertyBindingInfo;

    /**
     * ID of the selected item.
     */
    selectedItemId?: string | PropertyBindingInfo;

    /**
     * Indicates whether the text values of the `additionalText` property of a {@link sap.ui.core.ListItem }
     * are shown.
     *
     * @since 1.32.3
     */
    showSecondaryValues?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the keyboard navigation mode.
     *
     * **Note:** The `sap.m.SelectListKeyboardNavigationMode.None` enumeration value, is only intended for use
     * in some composite controls that handles keyboard navigation by themselves.
     *
     * @since 1.38
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    keyboardNavigationMode?:
      | (
          | SelectListKeyboardNavigationMode
          | keyof typeof SelectListKeyboardNavigationMode
        )
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the items contained within this control.
     */
    items?: Item[] | Item | AggregationBindingInfo | `{${string}}`;

    /**
     * Sets or retrieves the selected item from the aggregation named items.
     */
    selectedItem?: Item | string;

    /**
     * Association to controls / IDs which label this control (see WAI-ARIA attribute `aria-labelledby`).
     *
     * @since 1.27.0
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * This event is fired when the selection has changed.
     *
     * **Note: ** The selection can be changed by pressing a non-selected item or via keyboard and after the
     * enter or space key is pressed.
     */
    selectionChange?: (oEvent: SelectList$SelectionChangeEvent) => void;

    /**
     * This event is fired when an item is pressed.
     *
     * @since 1.32.4
     */
    itemPress?: (oEvent: SelectList$ItemPressEvent) => void;
  }

  /**
   * Parameters of the SelectList#itemPress event.
   */
  export interface SelectList$ItemPressEventParameters {
    /**
     * The pressed item.
     */
    item?: Item;
  }

  /**
   * Event object of the SelectList#itemPress event.
   */
  export type SelectList$ItemPressEvent = Event<
    SelectList$ItemPressEventParameters,
    SelectList
  >;

  /**
   * Parameters of the SelectList#selectionChange event.
   */
  export interface SelectList$SelectionChangeEventParameters {
    /**
     * The selected item.
     */
    selectedItem?: Item;
  }

  /**
   * Event object of the SelectList#selectionChange event.
   */
  export type SelectList$SelectionChangeEvent = Event<
    SelectList$SelectionChangeEventParameters,
    SelectList
  >;
}

declare module "sap/m/semantic/AddAction" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * An AddAction button has default semantic-specific properties and is eligible for aggregation content
   * of a {@link sap.m.semantic.SemanticPage}.
   *
   * See {@link sap.m.semantic.MasterPage#addAction}, {@link sap.m.semantic.FullscreenPage#addAction}, {@link sap.m.semantic.DetailPage#addAction}
   *
   * @since 1.30.0
   */
  export default class AddAction extends SemanticButton {
    /**
     * Constructor for a new AddAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $AddActionSettings
    );
    /**
     * Constructor for a new AddAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $AddActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.AddAction with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, AddAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.AddAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the AddAction constructor.
   */
  export interface $AddActionSettings extends $SemanticButtonSettings {}
}

declare module "sap/m/semantic/CancelAction" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A CancelAction button has default semantic-specific properties and is eligible for aggregation content
   * of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default class CancelAction extends SemanticButton {
    /**
     * Constructor for a new CancelAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $CancelActionSettings
    );
    /**
     * Constructor for a new CancelAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $CancelActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.CancelAction with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, CancelAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.CancelAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the CancelAction constructor.
   */
  export interface $CancelActionSettings extends $SemanticButtonSettings {}
}

declare module "sap/m/semantic/DeleteAction" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A DeleteAction button has default semantic-specific properties and is eligible for aggregation content
   * of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.36
   */
  export default class DeleteAction extends SemanticButton {
    /**
     * Constructor for a new DeleteAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $DeleteActionSettings
    );
    /**
     * Constructor for a new DeleteAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $DeleteActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.DeleteAction with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, DeleteAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.DeleteAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the DeleteAction constructor.
   */
  export interface $DeleteActionSettings extends $SemanticButtonSettings {}
}

declare module "sap/m/semantic/DetailPage" {
  import {
    default as ShareMenuPage,
    $ShareMenuPageSettings,
  } from "sap/m/semantic/ShareMenuPage";

  import AddAction from "sap/m/semantic/AddAction";

  import CancelAction from "sap/m/semantic/CancelAction";

  import DeleteAction from "sap/m/semantic/DeleteAction";

  import DiscussInJamAction from "sap/m/semantic/DiscussInJamAction";

  import DraftIndicator from "sap/m/DraftIndicator";

  import EditAction from "sap/m/semantic/EditAction";

  import FavoriteAction from "sap/m/semantic/FavoriteAction";

  import FlagAction from "sap/m/semantic/FlagAction";

  import ForwardAction from "sap/m/semantic/ForwardAction";

  import MainAction from "sap/m/semantic/MainAction";

  import MessagesIndicator from "sap/m/semantic/MessagesIndicator";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import NegativeAction from "sap/m/semantic/NegativeAction";

  import OpenInAction from "sap/m/semantic/OpenInAction";

  import PagingButton from "sap/m/PagingButton";

  import PositiveAction from "sap/m/semantic/PositiveAction";

  import PrintAction from "sap/m/semantic/PrintAction";

  import SaveAction from "sap/m/semantic/SaveAction";

  import Button from "sap/m/Button";

  import SendEmailAction from "sap/m/semantic/SendEmailAction";

  import SendMessageAction from "sap/m/semantic/SendMessageAction";

  import ShareInJamAction from "sap/m/semantic/ShareInJamAction";

  /**
   * A DetailPage is a {@link sap.m.semantic.ShareMenuPage} that supports semantic content of the following
   * types:
   *
   *
   * 	 - {@link sap.m.semantic.AddAction}
   * 	 - {@link sap.m.semantic.MainAction}
   * 	 - {@link sap.m.semantic.PositiveAction}
   * 	 - {@link sap.m.semantic.NegativeAction}
   * 	 - {@link sap.m.semantic.ForwardAction}
   * 	 - {@link sap.m.semantic.EditAction}
   * 	 - {@link sap.m.semantic.SaveAction}
   * 	 - {@link sap.m.semantic.DeleteAction}
   * 	 - {@link sap.m.semantic.CancelAction}
   * 	 - {@link sap.m.semantic.FlagAction}
   * 	 - {@link sap.m.semantic.FavoriteAction}
   * 	 - {@link sap.m.semantic.OpenInAction}
   * 	 - {@link sap.m.semantic.DiscussInJamAction}
   * 	 - {@link sap.m.semantic.ShareInJamAction}
   * 	 - {@link sap.m.semantic.SendEmailAction}
   * 	 - {@link sap.m.semantic.SendMessageAction}
   * 	 - {@link sap.m.semantic.PrintAction}
   * 	 - {@link sap.m.semantic.MessagesIndicator}
   * 	 - {@link sap.m.DraftIndicator}
   *
   * @since 1.30.0
   */
  export default class DetailPage extends ShareMenuPage {
    /**
     * Constructor for a new DetailPage
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $DetailPageSettings
    );
    /**
     * Constructor for a new DetailPage
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $DetailPageSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.DetailPage with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.ShareMenuPage.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, DetailPage>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.DetailPage.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Destroys the addAction in the aggregation {@link #getAddAction addAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyAddAction(): this;
    /**
     * Destroys the cancelAction in the aggregation {@link #getCancelAction cancelAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCancelAction(): this;
    /**
     * Destroys the deleteAction in the aggregation {@link #getDeleteAction deleteAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyDeleteAction(): this;
    /**
     * Destroys the discussInJamAction in the aggregation {@link #getDiscussInJamAction discussInJamAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyDiscussInJamAction(): this;
    /**
     * Destroys the draftIndicator in the aggregation {@link #getDraftIndicator draftIndicator}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyDraftIndicator(): this;
    /**
     * Destroys the editAction in the aggregation {@link #getEditAction editAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyEditAction(): this;
    /**
     * Destroys the favoriteAction in the aggregation {@link #getFavoriteAction favoriteAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyFavoriteAction(): this;
    /**
     * Destroys the flagAction in the aggregation {@link #getFlagAction flagAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyFlagAction(): this;
    /**
     * Destroys the forwardAction in the aggregation {@link #getForwardAction forwardAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyForwardAction(): this;
    /**
     * Destroys the mainAction in the aggregation {@link #getMainAction mainAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyMainAction(): this;
    /**
     * Destroys the messagesIndicator in the aggregation {@link #getMessagesIndicator messagesIndicator}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyMessagesIndicator(): this;
    /**
     * Destroys the negativeAction in the aggregation {@link #getNegativeAction negativeAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyNegativeAction(): this;
    /**
     * Destroys the openInAction in the aggregation {@link #getOpenInAction openInAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyOpenInAction(): this;
    /**
     * Destroys the pagingAction in the aggregation {@link #getPagingAction pagingAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyPagingAction(): this;
    /**
     * Destroys the positiveAction in the aggregation {@link #getPositiveAction positiveAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyPositiveAction(): this;
    /**
     * Destroys the printAction in the aggregation {@link #getPrintAction printAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyPrintAction(): this;
    /**
     * Destroys the saveAction in the aggregation {@link #getSaveAction saveAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySaveAction(): this;
    /**
     * Destroys the saveAsTileAction in the aggregation {@link #getSaveAsTileAction saveAsTileAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySaveAsTileAction(): this;
    /**
     * Destroys the sendEmailAction in the aggregation {@link #getSendEmailAction sendEmailAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySendEmailAction(): this;
    /**
     * Destroys the sendMessageAction in the aggregation {@link #getSendMessageAction sendMessageAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySendMessageAction(): this;
    /**
     * Destroys the shareInJamAction in the aggregation {@link #getShareInJamAction shareInJamAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyShareInJamAction(): this;
    /**
     * Gets content of aggregation {@link #getAddAction addAction}.
     *
     * Add action
     */
    getAddAction(): AddAction;
    /**
     * Gets content of aggregation {@link #getCancelAction cancelAction}.
     *
     * Cancel action
     */
    getCancelAction(): CancelAction;
    /**
     * Gets content of aggregation {@link #getDeleteAction deleteAction}.
     *
     * Delete action
     */
    getDeleteAction(): DeleteAction;
    /**
     * Gets content of aggregation {@link #getDiscussInJamAction discussInJamAction}.
     *
     * DiscussInJam action
     */
    getDiscussInJamAction(): DiscussInJamAction;
    /**
     * Gets content of aggregation {@link #getDraftIndicator draftIndicator}.
     *
     * DraftIndicator
     */
    getDraftIndicator(): DraftIndicator;
    /**
     * Gets content of aggregation {@link #getEditAction editAction}.
     *
     * Edit action
     */
    getEditAction(): EditAction;
    /**
     * Gets content of aggregation {@link #getFavoriteAction favoriteAction}.
     *
     * Favorite action
     */
    getFavoriteAction(): FavoriteAction;
    /**
     * Gets content of aggregation {@link #getFlagAction flagAction}.
     *
     * Flag action
     */
    getFlagAction(): FlagAction;
    /**
     * Gets content of aggregation {@link #getForwardAction forwardAction}.
     *
     * Negative action
     */
    getForwardAction(): ForwardAction;
    /**
     * Gets content of aggregation {@link #getMainAction mainAction}.
     *
     * Main action
     */
    getMainAction(): MainAction;
    /**
     * Gets content of aggregation {@link #getMessagesIndicator messagesIndicator}.
     *
     * MessagesIndicator
     */
    getMessagesIndicator(): MessagesIndicator;
    /**
     * Gets content of aggregation {@link #getNegativeAction negativeAction}.
     *
     * Negative action
     */
    getNegativeAction(): NegativeAction;
    /**
     * Gets content of aggregation {@link #getOpenInAction openInAction}.
     *
     * OpenIn action
     */
    getOpenInAction(): OpenInAction;
    /**
     * Gets content of aggregation {@link #getPagingAction pagingAction}.
     *
     * Paging action
     */
    getPagingAction(): PagingButton;
    /**
     * Gets content of aggregation {@link #getPositiveAction positiveAction}.
     *
     * Positive action
     */
    getPositiveAction(): PositiveAction;
    /**
     * Gets content of aggregation {@link #getPrintAction printAction}.
     *
     * Print action
     */
    getPrintAction(): PrintAction;
    /**
     * Gets content of aggregation {@link #getSaveAction saveAction}.
     *
     * Save action
     */
    getSaveAction(): SaveAction;
    /**
     * Gets content of aggregation {@link #getSaveAsTileAction saveAsTileAction}.
     *
     * SaveAsTile button
     */
    getSaveAsTileAction(): Button;
    /**
     * Gets content of aggregation {@link #getSendEmailAction sendEmailAction}.
     *
     * SendEmail action
     */
    getSendEmailAction(): SendEmailAction;
    /**
     * Gets content of aggregation {@link #getSendMessageAction sendMessageAction}.
     *
     * SendMessage action
     */
    getSendMessageAction(): SendMessageAction;
    /**
     * Gets content of aggregation {@link #getShareInJamAction shareInJamAction}.
     *
     * ShareInJam action
     */
    getShareInJamAction(): ShareInJamAction;
    /**
     * Sets the aggregated {@link #getAddAction addAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAddAction(
      /**
       * The addAction to set
       */
      oAddAction: AddAction
    ): this;
    /**
     * Sets the aggregated {@link #getCancelAction cancelAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCancelAction(
      /**
       * The cancelAction to set
       */
      oCancelAction: CancelAction
    ): this;
    /**
     * Sets the aggregated {@link #getDeleteAction deleteAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDeleteAction(
      /**
       * The deleteAction to set
       */
      oDeleteAction: DeleteAction
    ): this;
    /**
     * Sets the aggregated {@link #getDiscussInJamAction discussInJamAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDiscussInJamAction(
      /**
       * The discussInJamAction to set
       */
      oDiscussInJamAction: DiscussInJamAction
    ): this;
    /**
     * Sets the aggregated {@link #getDraftIndicator draftIndicator}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDraftIndicator(
      /**
       * The draftIndicator to set
       */
      oDraftIndicator: DraftIndicator
    ): this;
    /**
     * Sets the aggregated {@link #getEditAction editAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEditAction(
      /**
       * The editAction to set
       */
      oEditAction: EditAction
    ): this;
    /**
     * Sets the aggregated {@link #getFavoriteAction favoriteAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFavoriteAction(
      /**
       * The favoriteAction to set
       */
      oFavoriteAction: FavoriteAction
    ): this;
    /**
     * Sets the aggregated {@link #getFlagAction flagAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFlagAction(
      /**
       * The flagAction to set
       */
      oFlagAction: FlagAction
    ): this;
    /**
     * Sets the aggregated {@link #getForwardAction forwardAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setForwardAction(
      /**
       * The forwardAction to set
       */
      oForwardAction: ForwardAction
    ): this;
    /**
     * Sets the aggregated {@link #getMainAction mainAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMainAction(
      /**
       * The mainAction to set
       */
      oMainAction: MainAction
    ): this;
    /**
     * Sets the aggregated {@link #getMessagesIndicator messagesIndicator}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMessagesIndicator(
      /**
       * The messagesIndicator to set
       */
      oMessagesIndicator: MessagesIndicator
    ): this;
    /**
     * Sets the aggregated {@link #getNegativeAction negativeAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNegativeAction(
      /**
       * The negativeAction to set
       */
      oNegativeAction: NegativeAction
    ): this;
    /**
     * Sets the aggregated {@link #getOpenInAction openInAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setOpenInAction(
      /**
       * The openInAction to set
       */
      oOpenInAction: OpenInAction
    ): this;
    /**
     * Sets the aggregated {@link #getPagingAction pagingAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPagingAction(
      /**
       * The pagingAction to set
       */
      oPagingAction: PagingButton
    ): this;
    /**
     * Sets the aggregated {@link #getPositiveAction positiveAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPositiveAction(
      /**
       * The positiveAction to set
       */
      oPositiveAction: PositiveAction
    ): this;
    /**
     * Sets the aggregated {@link #getPrintAction printAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPrintAction(
      /**
       * The printAction to set
       */
      oPrintAction: PrintAction
    ): this;
    /**
     * Sets the aggregated {@link #getSaveAction saveAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSaveAction(
      /**
       * The saveAction to set
       */
      oSaveAction: SaveAction
    ): this;
    /**
     * Sets the aggregated {@link #getSaveAsTileAction saveAsTileAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSaveAsTileAction(
      /**
       * The saveAsTileAction to set
       */
      oSaveAsTileAction: Button
    ): this;
    /**
     * Sets the aggregated {@link #getSendEmailAction sendEmailAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSendEmailAction(
      /**
       * The sendEmailAction to set
       */
      oSendEmailAction: SendEmailAction
    ): this;
    /**
     * Sets the aggregated {@link #getSendMessageAction sendMessageAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSendMessageAction(
      /**
       * The sendMessageAction to set
       */
      oSendMessageAction: SendMessageAction
    ): this;
    /**
     * Sets the aggregated {@link #getShareInJamAction shareInJamAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShareInJamAction(
      /**
       * The shareInJamAction to set
       */
      oShareInJamAction: ShareInJamAction
    ): this;
  }
  /**
   * Describes the settings that can be provided to the DetailPage constructor.
   */
  export interface $DetailPageSettings extends $ShareMenuPageSettings {
    /**
     * Add action
     */
    addAction?: AddAction;

    /**
     * Main action
     */
    mainAction?: MainAction;

    /**
     * Positive action
     */
    positiveAction?: PositiveAction;

    /**
     * Negative action
     */
    negativeAction?: NegativeAction;

    /**
     * Negative action
     */
    forwardAction?: ForwardAction;

    /**
     * Edit action
     */
    editAction?: EditAction;

    /**
     * Save action
     */
    saveAction?: SaveAction;

    /**
     * Delete action
     */
    deleteAction?: DeleteAction;

    /**
     * Cancel action
     */
    cancelAction?: CancelAction;

    /**
     * Flag action
     */
    flagAction?: FlagAction;

    /**
     * Favorite action
     */
    favoriteAction?: FavoriteAction;

    /**
     * OpenIn action
     */
    openInAction?: OpenInAction;

    /**
     * DiscussInJam action
     */
    discussInJamAction?: DiscussInJamAction;

    /**
     * ShareInJam action
     */
    shareInJamAction?: ShareInJamAction;

    /**
     * SendEmail action
     */
    sendEmailAction?: SendEmailAction;

    /**
     * SendMessage action
     */
    sendMessageAction?: SendMessageAction;

    /**
     * Print action
     */
    printAction?: PrintAction;

    /**
     * MessagesIndicator
     */
    messagesIndicator?: MessagesIndicator;

    /**
     * SaveAsTile button
     */
    saveAsTileAction?: Button;

    /**
     * Paging action
     */
    pagingAction?: PagingButton;

    /**
     * DraftIndicator
     */
    draftIndicator?: DraftIndicator;
  }
}

declare module "sap/m/semantic/DiscussInJamAction" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A DiscussInJamAction button has default semantic-specific properties and is eligible for aggregation
   * content of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default class DiscussInJamAction extends SemanticButton {
    /**
     * Constructor for a new DiscussInJamAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $DiscussInJamActionSettings
    );
    /**
     * Constructor for a new DiscussInJamAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $DiscussInJamActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.DiscussInJamAction with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, DiscussInJamAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.DiscussInJamAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the DiscussInJamAction constructor.
   */
  export interface $DiscussInJamActionSettings
    extends $SemanticButtonSettings {}
}

declare module "sap/m/semantic/EditAction" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * An EditAction button has default semantic-specific properties and is eligible for aggregation content
   * of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default class EditAction extends SemanticButton {
    /**
     * Constructor for a new EditAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $EditActionSettings
    );
    /**
     * Constructor for a new EditAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $EditActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.EditAction with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, EditAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.EditAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the EditAction constructor.
   */
  export interface $EditActionSettings extends $SemanticButtonSettings {}
}

declare module "sap/m/semantic/FavoriteAction" {
  import {
    default as SemanticToggleButton,
    $SemanticToggleButtonSettings,
  } from "sap/m/semantic/SemanticToggleButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A FavoriteAction button has default semantic-specific properties and is eligible for aggregation content
   * of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default class FavoriteAction extends SemanticToggleButton {
    /**
     * Constructor for a new FavoriteAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticToggleButton#constructor sap.m.semantic.SemanticToggleButton }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $FavoriteActionSettings
    );
    /**
     * Constructor for a new FavoriteAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticToggleButton#constructor sap.m.semantic.SemanticToggleButton }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $FavoriteActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.FavoriteAction with name `sClassName` and enriches it
     * with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticToggleButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, FavoriteAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.FavoriteAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the FavoriteAction constructor.
   */
  export interface $FavoriteActionSettings
    extends $SemanticToggleButtonSettings {}
}

declare module "sap/m/semantic/FilterAction" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import { semantic } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A FilterAction is a {@link sap.m.Button} control enhanced with styling according to the semantics of
   * a common "Filter" action.
   *
   * A FilterAction cannot be used independently but only as aggregation content of a {@link sap.m.semantic.SemanticPage}.
   *
   * Your app should listen to the `press` event of {@link sap.m.semantic.FilterAction} in order to trigger
   * the display of the filtering options.
   *
   * If your filtering options are a simple list of items and require single choice only, then you can consider
   * using a {@link sap.m.semantic.FilterSelect} instead.
   *
   * @since 1.30.0
   */
  export default class FilterAction
    extends SemanticButton
    implements semantic.IFilter
  {
    __implements__sap_m_semantic_IFilter: boolean;
    /**
     * Constructor for a new FilterAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $FilterActionSettings
    );
    /**
     * Constructor for a new FilterAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $FilterActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.FilterAction with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, FilterAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.FilterAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the FilterAction constructor.
   */
  export interface $FilterActionSettings extends $SemanticButtonSettings {}
}

declare module "sap/m/semantic/FilterSelect" {
  import {
    default as SemanticSelect,
    $SemanticSelectSettings,
  } from "sap/m/semantic/SemanticSelect";

  import { semantic } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A FilterSelect is a {@link sap.m.Select} control enhanced with styling according to the semantics of
   * a common "Filter" action.
   *
   * A FilterSelect cannot be used independently but only as aggregation content of a {@link sap.m.semantic.SemanticPage}.
   *
   * The filtering options should be added to the `items` aggregation of {@link sap.m.semantic.FilterSelect }
   * and will be displayed as a pop-up list with support for single-item selection. If this simple popup list
   * is not sufficient for your use case, you can implement your own custom dialog by using {@link sap.m.semantic.FilterAction }
   * to trigger the dialog opening.
   *
   * @since 1.30.0
   */
  export default class FilterSelect
    extends SemanticSelect
    implements semantic.IFilter
  {
    __implements__sap_m_semantic_IFilter: boolean;
    /**
     * Constructor for a new FilterSelect.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticSelect#constructor sap.m.semantic.SemanticSelect }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $FilterSelectSettings
    );
    /**
     * Constructor for a new FilterSelect.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticSelect#constructor sap.m.semantic.SemanticSelect }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $FilterSelectSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.FilterSelect with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticSelect.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, FilterSelect>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.FilterSelect.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the FilterSelect constructor.
   */
  export interface $FilterSelectSettings extends $SemanticSelectSettings {}
}

declare module "sap/m/semantic/FlagAction" {
  import {
    default as SemanticToggleButton,
    $SemanticToggleButtonSettings,
  } from "sap/m/semantic/SemanticToggleButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A FlagAction button has default semantic-specific properties and is eligible for aggregation content
   * of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default class FlagAction extends SemanticToggleButton {
    /**
     * Constructor for a new FlagAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticToggleButton#constructor sap.m.semantic.SemanticToggleButton }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $FlagActionSettings
    );
    /**
     * Constructor for a new FlagAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticToggleButton#constructor sap.m.semantic.SemanticToggleButton }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $FlagActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.FlagAction with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticToggleButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, FlagAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.FlagAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the FlagAction constructor.
   */
  export interface $FlagActionSettings extends $SemanticToggleButtonSettings {}
}

declare module "sap/m/semantic/ForwardAction" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A ForwardAction button has default semantic-specific properties and is eligible for aggregation content
   * of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default class ForwardAction extends SemanticButton {
    /**
     * Constructor for a new ForwardAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $ForwardActionSettings
    );
    /**
     * Constructor for a new ForwardAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $ForwardActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.ForwardAction with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ForwardAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.ForwardAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the ForwardAction constructor.
   */
  export interface $ForwardActionSettings extends $SemanticButtonSettings {}
}

declare module "sap/m/semantic/FullscreenPage" {
  import {
    default as ShareMenuPage,
    $ShareMenuPageSettings,
  } from "sap/m/semantic/ShareMenuPage";

  import AddAction from "sap/m/semantic/AddAction";

  import CancelAction from "sap/m/semantic/CancelAction";

  import DeleteAction from "sap/m/semantic/DeleteAction";

  import DiscussInJamAction from "sap/m/semantic/DiscussInJamAction";

  import DraftIndicator from "sap/m/DraftIndicator";

  import EditAction from "sap/m/semantic/EditAction";

  import FavoriteAction from "sap/m/semantic/FavoriteAction";

  import FlagAction from "sap/m/semantic/FlagAction";

  import ForwardAction from "sap/m/semantic/ForwardAction";

  import MainAction from "sap/m/semantic/MainAction";

  import MessagesIndicator from "sap/m/semantic/MessagesIndicator";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import NegativeAction from "sap/m/semantic/NegativeAction";

  import OpenInAction from "sap/m/semantic/OpenInAction";

  import PagingButton from "sap/m/PagingButton";

  import PositiveAction from "sap/m/semantic/PositiveAction";

  import PrintAction from "sap/m/semantic/PrintAction";

  import SaveAction from "sap/m/semantic/SaveAction";

  import Button from "sap/m/Button";

  import SendEmailAction from "sap/m/semantic/SendEmailAction";

  import SendMessageAction from "sap/m/semantic/SendMessageAction";

  import ShareInJamAction from "sap/m/semantic/ShareInJamAction";

  /**
   * A FullscreenPage is a {@link sap.m.semantic.ShareMenuPage} that supports semantic content of the following
   * types:
   *
   *
   * 	 - {@link sap.m.semantic.AddAction}
   * 	 - {@link sap.m.semantic.MainAction}
   * 	 - {@link sap.m.semantic.PositiveAction}
   * 	 - {@link sap.m.semantic.NegativeAction}
   * 	 - {@link sap.m.semantic.ForwardAction}
   * 	 - {@link sap.m.semantic.EditAction}
   * 	 - {@link sap.m.semantic.SaveAction}
   * 	 - {@link sap.m.semantic.DeleteAction}
   * 	 - {@link sap.m.semantic.CancelAction}
   * 	 - {@link sap.m.semantic.FlagAction}
   * 	 - {@link sap.m.semantic.FavoriteAction}
   * 	 - {@link sap.m.semantic.OpenInAction}
   * 	 - {@link sap.m.semantic.DiscussInJamAction}
   * 	 - {@link sap.m.semantic.ShareInJamAction}
   * 	 - {@link sap.m.semantic.SendEmailAction}
   * 	 - {@link sap.m.semantic.SendMessageAction}
   * 	 - {@link sap.m.semantic.PrintAction}
   * 	 - {@link sap.m.semantic.MessagesIndicator}
   * 	 - {@link sap.m.DraftIndicator}
   *
   * @since 1.30.0
   */
  export default class FullscreenPage extends ShareMenuPage {
    /**
     * Constructor for a new FullscreenPage
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $FullscreenPageSettings
    );
    /**
     * Constructor for a new FullscreenPage
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $FullscreenPageSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.FullscreenPage with name `sClassName` and enriches it
     * with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.ShareMenuPage.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, FullscreenPage>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.FullscreenPage.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Destroys the addAction in the aggregation {@link #getAddAction addAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyAddAction(): this;
    /**
     * Destroys the cancelAction in the aggregation {@link #getCancelAction cancelAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCancelAction(): this;
    /**
     * Destroys the deleteAction in the aggregation {@link #getDeleteAction deleteAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyDeleteAction(): this;
    /**
     * Destroys the discussInJamAction in the aggregation {@link #getDiscussInJamAction discussInJamAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyDiscussInJamAction(): this;
    /**
     * Destroys the draftIndicator in the aggregation {@link #getDraftIndicator draftIndicator}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyDraftIndicator(): this;
    /**
     * Destroys the editAction in the aggregation {@link #getEditAction editAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyEditAction(): this;
    /**
     * Destroys the favoriteAction in the aggregation {@link #getFavoriteAction favoriteAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyFavoriteAction(): this;
    /**
     * Destroys the flagAction in the aggregation {@link #getFlagAction flagAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyFlagAction(): this;
    /**
     * Destroys the forwardAction in the aggregation {@link #getForwardAction forwardAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyForwardAction(): this;
    /**
     * Destroys the mainAction in the aggregation {@link #getMainAction mainAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyMainAction(): this;
    /**
     * Destroys the messagesIndicator in the aggregation {@link #getMessagesIndicator messagesIndicator}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyMessagesIndicator(): this;
    /**
     * Destroys the negativeAction in the aggregation {@link #getNegativeAction negativeAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyNegativeAction(): this;
    /**
     * Destroys the openInAction in the aggregation {@link #getOpenInAction openInAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyOpenInAction(): this;
    /**
     * Destroys the pagingAction in the aggregation {@link #getPagingAction pagingAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyPagingAction(): this;
    /**
     * Destroys the positiveAction in the aggregation {@link #getPositiveAction positiveAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyPositiveAction(): this;
    /**
     * Destroys the printAction in the aggregation {@link #getPrintAction printAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyPrintAction(): this;
    /**
     * Destroys the saveAction in the aggregation {@link #getSaveAction saveAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySaveAction(): this;
    /**
     * Destroys the saveAsTileAction in the aggregation {@link #getSaveAsTileAction saveAsTileAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySaveAsTileAction(): this;
    /**
     * Destroys the sendEmailAction in the aggregation {@link #getSendEmailAction sendEmailAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySendEmailAction(): this;
    /**
     * Destroys the sendMessageAction in the aggregation {@link #getSendMessageAction sendMessageAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySendMessageAction(): this;
    /**
     * Destroys the shareInJamAction in the aggregation {@link #getShareInJamAction shareInJamAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyShareInJamAction(): this;
    /**
     * Gets content of aggregation {@link #getAddAction addAction}.
     *
     * Add action
     */
    getAddAction(): AddAction;
    /**
     * Gets content of aggregation {@link #getCancelAction cancelAction}.
     *
     * Cancel action
     */
    getCancelAction(): CancelAction;
    /**
     * Gets content of aggregation {@link #getDeleteAction deleteAction}.
     *
     * Delete action
     */
    getDeleteAction(): DeleteAction;
    /**
     * Gets content of aggregation {@link #getDiscussInJamAction discussInJamAction}.
     *
     * DiscussInJam action
     */
    getDiscussInJamAction(): DiscussInJamAction;
    /**
     * Gets content of aggregation {@link #getDraftIndicator draftIndicator}.
     *
     * DraftIndicator
     */
    getDraftIndicator(): DraftIndicator;
    /**
     * Gets content of aggregation {@link #getEditAction editAction}.
     *
     * Edit action
     */
    getEditAction(): EditAction;
    /**
     * Gets content of aggregation {@link #getFavoriteAction favoriteAction}.
     *
     * Favorite action
     */
    getFavoriteAction(): FavoriteAction;
    /**
     * Gets content of aggregation {@link #getFlagAction flagAction}.
     *
     * Flag action
     */
    getFlagAction(): FlagAction;
    /**
     * Gets content of aggregation {@link #getForwardAction forwardAction}.
     *
     * Negative action
     */
    getForwardAction(): ForwardAction;
    /**
     * Gets content of aggregation {@link #getMainAction mainAction}.
     *
     * Main action
     */
    getMainAction(): MainAction;
    /**
     * Gets content of aggregation {@link #getMessagesIndicator messagesIndicator}.
     *
     * MessagesIndicator
     */
    getMessagesIndicator(): MessagesIndicator;
    /**
     * Gets content of aggregation {@link #getNegativeAction negativeAction}.
     *
     * Negative action
     */
    getNegativeAction(): NegativeAction;
    /**
     * Gets content of aggregation {@link #getOpenInAction openInAction}.
     *
     * OpenIn action
     */
    getOpenInAction(): OpenInAction;
    /**
     * Gets content of aggregation {@link #getPagingAction pagingAction}.
     *
     * Paging action
     */
    getPagingAction(): PagingButton;
    /**
     * Gets content of aggregation {@link #getPositiveAction positiveAction}.
     *
     * Positive action
     */
    getPositiveAction(): PositiveAction;
    /**
     * Gets content of aggregation {@link #getPrintAction printAction}.
     *
     * Print action
     */
    getPrintAction(): PrintAction;
    /**
     * Gets content of aggregation {@link #getSaveAction saveAction}.
     *
     * Save action
     */
    getSaveAction(): SaveAction;
    /**
     * Gets content of aggregation {@link #getSaveAsTileAction saveAsTileAction}.
     *
     * SaveAsTile button
     */
    getSaveAsTileAction(): Button;
    /**
     * Gets content of aggregation {@link #getSendEmailAction sendEmailAction}.
     *
     * SendEmail action
     */
    getSendEmailAction(): SendEmailAction;
    /**
     * Gets content of aggregation {@link #getSendMessageAction sendMessageAction}.
     *
     * SendMessage action
     */
    getSendMessageAction(): SendMessageAction;
    /**
     * Gets content of aggregation {@link #getShareInJamAction shareInJamAction}.
     *
     * ShareInJam action
     */
    getShareInJamAction(): ShareInJamAction;
    /**
     * Sets the aggregated {@link #getAddAction addAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAddAction(
      /**
       * The addAction to set
       */
      oAddAction: AddAction
    ): this;
    /**
     * Sets the aggregated {@link #getCancelAction cancelAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCancelAction(
      /**
       * The cancelAction to set
       */
      oCancelAction: CancelAction
    ): this;
    /**
     * Sets the aggregated {@link #getDeleteAction deleteAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDeleteAction(
      /**
       * The deleteAction to set
       */
      oDeleteAction: DeleteAction
    ): this;
    /**
     * Sets the aggregated {@link #getDiscussInJamAction discussInJamAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDiscussInJamAction(
      /**
       * The discussInJamAction to set
       */
      oDiscussInJamAction: DiscussInJamAction
    ): this;
    /**
     * Sets the aggregated {@link #getDraftIndicator draftIndicator}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDraftIndicator(
      /**
       * The draftIndicator to set
       */
      oDraftIndicator: DraftIndicator
    ): this;
    /**
     * Sets the aggregated {@link #getEditAction editAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEditAction(
      /**
       * The editAction to set
       */
      oEditAction: EditAction
    ): this;
    /**
     * Sets the aggregated {@link #getFavoriteAction favoriteAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFavoriteAction(
      /**
       * The favoriteAction to set
       */
      oFavoriteAction: FavoriteAction
    ): this;
    /**
     * Sets the aggregated {@link #getFlagAction flagAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFlagAction(
      /**
       * The flagAction to set
       */
      oFlagAction: FlagAction
    ): this;
    /**
     * Sets the aggregated {@link #getForwardAction forwardAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setForwardAction(
      /**
       * The forwardAction to set
       */
      oForwardAction: ForwardAction
    ): this;
    /**
     * Sets the aggregated {@link #getMainAction mainAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMainAction(
      /**
       * The mainAction to set
       */
      oMainAction: MainAction
    ): this;
    /**
     * Sets the aggregated {@link #getMessagesIndicator messagesIndicator}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMessagesIndicator(
      /**
       * The messagesIndicator to set
       */
      oMessagesIndicator: MessagesIndicator
    ): this;
    /**
     * Sets the aggregated {@link #getNegativeAction negativeAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNegativeAction(
      /**
       * The negativeAction to set
       */
      oNegativeAction: NegativeAction
    ): this;
    /**
     * Sets the aggregated {@link #getOpenInAction openInAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setOpenInAction(
      /**
       * The openInAction to set
       */
      oOpenInAction: OpenInAction
    ): this;
    /**
     * Sets the aggregated {@link #getPagingAction pagingAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPagingAction(
      /**
       * The pagingAction to set
       */
      oPagingAction: PagingButton
    ): this;
    /**
     * Sets the aggregated {@link #getPositiveAction positiveAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPositiveAction(
      /**
       * The positiveAction to set
       */
      oPositiveAction: PositiveAction
    ): this;
    /**
     * Sets the aggregated {@link #getPrintAction printAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPrintAction(
      /**
       * The printAction to set
       */
      oPrintAction: PrintAction
    ): this;
    /**
     * Sets the aggregated {@link #getSaveAction saveAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSaveAction(
      /**
       * The saveAction to set
       */
      oSaveAction: SaveAction
    ): this;
    /**
     * Sets the aggregated {@link #getSaveAsTileAction saveAsTileAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSaveAsTileAction(
      /**
       * The saveAsTileAction to set
       */
      oSaveAsTileAction: Button
    ): this;
    /**
     * Sets the aggregated {@link #getSendEmailAction sendEmailAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSendEmailAction(
      /**
       * The sendEmailAction to set
       */
      oSendEmailAction: SendEmailAction
    ): this;
    /**
     * Sets the aggregated {@link #getSendMessageAction sendMessageAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSendMessageAction(
      /**
       * The sendMessageAction to set
       */
      oSendMessageAction: SendMessageAction
    ): this;
    /**
     * Sets the aggregated {@link #getShareInJamAction shareInJamAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShareInJamAction(
      /**
       * The shareInJamAction to set
       */
      oShareInJamAction: ShareInJamAction
    ): this;
  }
  /**
   * Describes the settings that can be provided to the FullscreenPage constructor.
   */
  export interface $FullscreenPageSettings extends $ShareMenuPageSettings {
    /**
     * Add action
     */
    addAction?: AddAction;

    /**
     * Main action
     */
    mainAction?: MainAction;

    /**
     * Positive action
     */
    positiveAction?: PositiveAction;

    /**
     * Negative action
     */
    negativeAction?: NegativeAction;

    /**
     * Negative action
     */
    forwardAction?: ForwardAction;

    /**
     * Edit action
     */
    editAction?: EditAction;

    /**
     * Save action
     */
    saveAction?: SaveAction;

    /**
     * Delete action
     */
    deleteAction?: DeleteAction;

    /**
     * Cancel action
     */
    cancelAction?: CancelAction;

    /**
     * Flag action
     */
    flagAction?: FlagAction;

    /**
     * Favorite action
     */
    favoriteAction?: FavoriteAction;

    /**
     * OpenIn action
     */
    openInAction?: OpenInAction;

    /**
     * DiscussInJam action
     */
    discussInJamAction?: DiscussInJamAction;

    /**
     * ShareInJam action
     */
    shareInJamAction?: ShareInJamAction;

    /**
     * SendEmail action
     */
    sendEmailAction?: SendEmailAction;

    /**
     * SendMessage action
     */
    sendMessageAction?: SendMessageAction;

    /**
     * Print action
     */
    printAction?: PrintAction;

    /**
     * MessagesIndicator
     */
    messagesIndicator?: MessagesIndicator;

    /**
     * SaveAsTile button
     */
    saveAsTileAction?: Button;

    /**
     * Paging action
     */
    pagingAction?: PagingButton;

    /**
     * DraftIndicator
     */
    draftIndicator?: DraftIndicator;
  }
}

declare module "sap/m/semantic/GroupAction" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import { semantic } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A GroupAction is a {@link sap.m.Button} control enhanced with styling according to the semantics of a
   * common "Group" action.
   *
   * A GroupAction cannot be used independently but only as aggregation content of a {@link sap.m.semantic.SemanticPage}.
   *
   * Your app should listen to the `press` event of {@link sap.m.semantic.GroupAction} in order to trigger
   * the display of the grouping options.
   *
   * If your grouping options are a simple list of items and require single choice only, then you can consider
   * using a {@link sap.m.semantic.GroupSelect} instead.
   *
   * @since 1.30.0
   */
  export default class GroupAction
    extends SemanticButton
    implements semantic.IGroup
  {
    __implements__sap_m_semantic_IGroup: boolean;
    /**
     * Constructor for a new GroupAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $GroupActionSettings
    );
    /**
     * Constructor for a new GroupAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $GroupActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.GroupAction with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, GroupAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.GroupAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the GroupAction constructor.
   */
  export interface $GroupActionSettings extends $SemanticButtonSettings {}
}

declare module "sap/m/semantic/GroupSelect" {
  import {
    default as SemanticSelect,
    $SemanticSelectSettings,
  } from "sap/m/semantic/SemanticSelect";

  import { semantic } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A GroupSelect is a {@link sap.m.Select} control enhanced with styling according to the semantics of a
   * common "Group" acton.
   *
   * A GroupSelect cannot be used independently but only as aggregation content of a {@link sap.m.semantic.SemanticPage}.
   *
   * The grouping options should be added to the `items` aggregation of {@link sap.m.semantic.GroupSelect }
   * and will be displayed as a pop-up list with support for single-item selection. If this simple popup list
   * is not sufficient for your use case, you can implement your own custom dialog by using {@link sap.m.semantic.GroupAction }
   * to trigger the dialog opening.
   *
   * @since 1.30.0
   */
  export default class GroupSelect
    extends SemanticSelect
    implements semantic.IGroup
  {
    __implements__sap_m_semantic_IGroup: boolean;
    /**
     * Constructor for a new GroupSelect.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticSelect#constructor sap.m.semantic.SemanticSelect }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $GroupSelectSettings
    );
    /**
     * Constructor for a new GroupSelect.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticSelect#constructor sap.m.semantic.SemanticSelect }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $GroupSelectSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.GroupSelect with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticSelect.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, GroupSelect>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.GroupSelect.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the GroupSelect constructor.
   */
  export interface $GroupSelectSettings extends $SemanticSelectSettings {}
}

declare module "sap/m/semantic/MainAction" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * A MainAction button has default semantic-specific properties and is eligible for aggregation content
   * of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default class MainAction extends SemanticButton {
    /**
     * Constructor for a new MainAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $MainActionSettings
    );
    /**
     * Constructor for a new MainAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $MainActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.MainAction with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, MainAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.MainAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Button text
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Button text
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the MainAction constructor.
   */
  export interface $MainActionSettings extends $SemanticButtonSettings {
    /**
     * Button text
     */
    text?: string | PropertyBindingInfo;
  }
}

declare module "sap/m/semantic/MasterPage" {
  import {
    default as SemanticPage,
    $SemanticPageSettings,
  } from "sap/m/semantic/SemanticPage";

  import AddAction from "sap/m/semantic/AddAction";

  import CancelAction from "sap/m/semantic/CancelAction";

  import DeleteAction from "sap/m/semantic/DeleteAction";

  import EditAction from "sap/m/semantic/EditAction";

  import { semantic } from "sap/m/library";

  import ForwardAction from "sap/m/semantic/ForwardAction";

  import MainAction from "sap/m/semantic/MainAction";

  import MessagesIndicator from "sap/m/semantic/MessagesIndicator";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import MultiSelectAction from "sap/m/semantic/MultiSelectAction";

  import NegativeAction from "sap/m/semantic/NegativeAction";

  import PositiveAction from "sap/m/semantic/PositiveAction";

  import SaveAction from "sap/m/semantic/SaveAction";

  /**
   * A MasterPage is a {@link sap.m.semantic.SemanticPage} that supports semantic content of the following
   * types:
   *
   *
   * 	 - {@link sap.m.semantic.AddAction}
   * 	 - {@link sap.m.semantic.MainAction}
   * 	 - {@link sap.m.semantic.PositiveAction}
   * 	 - {@link sap.m.semantic.NegativeAction}
   * 	 - {@link sap.m.semantic.ForwardAction}
   * 	 - {@link sap.m.semantic.EditAction}
   * 	 - {@link sap.m.semantic.SaveAction}
   * 	 - {@link sap.m.semantic.DeleteAction}
   * 	 - {@link sap.m.semantic.CancelAction}
   * 	 - {@link sap.m.semantic.MultiSelectAction}
   * 	 - {@link sap.m.semantic.FlagAction}
   * 	 - {@link sap.m.semantic.FavoriteAction}
   * 	 - {@link sap.m.semantic.SortAction}
   * 	 - {@link sap.m.semantic.SortSelect}
   * 	 - {@link sap.m.semantic.FilterAction}
   * 	 - {@link sap.m.semantic.FilterSelect}
   * 	 - {@link sap.m.semantic.GroupAction}
   * 	 - {@link sap.m.semantic.GroupSelect}
   * 	 - {@link sap.m.semantic.MessagesIndicator}
   *
   * @since 1.30.0
   */
  export default class MasterPage extends SemanticPage {
    /**
     * Constructor for a new MasterPage
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $MasterPageSettings
    );
    /**
     * Constructor for a new MasterPage
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $MasterPageSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.MasterPage with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticPage.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, MasterPage>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.MasterPage.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Destroys the addAction in the aggregation {@link #getAddAction addAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyAddAction(): this;
    /**
     * Destroys the cancelAction in the aggregation {@link #getCancelAction cancelAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCancelAction(): this;
    /**
     * Destroys the deleteAction in the aggregation {@link #getDeleteAction deleteAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyDeleteAction(): this;
    /**
     * Destroys the editAction in the aggregation {@link #getEditAction editAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyEditAction(): this;
    /**
     * Destroys the filter in the aggregation {@link #getFilter filter}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyFilter(): this;
    /**
     * Destroys the forwardAction in the aggregation {@link #getForwardAction forwardAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyForwardAction(): this;
    /**
     * Destroys the group in the aggregation {@link #getGroup group}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyGroup(): this;
    /**
     * Destroys the mainAction in the aggregation {@link #getMainAction mainAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyMainAction(): this;
    /**
     * Destroys the messagesIndicator in the aggregation {@link #getMessagesIndicator messagesIndicator}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyMessagesIndicator(): this;
    /**
     * Destroys the multiSelectAction in the aggregation {@link #getMultiSelectAction multiSelectAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyMultiSelectAction(): this;
    /**
     * Destroys the negativeAction in the aggregation {@link #getNegativeAction negativeAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyNegativeAction(): this;
    /**
     * Destroys the positiveAction in the aggregation {@link #getPositiveAction positiveAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyPositiveAction(): this;
    /**
     * Destroys the saveAction in the aggregation {@link #getSaveAction saveAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySaveAction(): this;
    /**
     * Destroys the sort in the aggregation {@link #getSort sort}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySort(): this;
    /**
     * Gets content of aggregation {@link #getAddAction addAction}.
     *
     * Add action
     */
    getAddAction(): AddAction;
    /**
     * Gets content of aggregation {@link #getCancelAction cancelAction}.
     *
     * Cancel action
     */
    getCancelAction(): CancelAction;
    /**
     * Gets content of aggregation {@link #getDeleteAction deleteAction}.
     *
     * Delete action
     */
    getDeleteAction(): DeleteAction;
    /**
     * Gets content of aggregation {@link #getEditAction editAction}.
     *
     * Edit action
     */
    getEditAction(): EditAction;
    /**
     * Gets content of aggregation {@link #getFilter filter}.
     *
     * Filter action
     */
    getFilter(): semantic.IFilter;
    /**
     * Gets content of aggregation {@link #getForwardAction forwardAction}.
     *
     * Forward action
     */
    getForwardAction(): ForwardAction;
    /**
     * Gets content of aggregation {@link #getGroup group}.
     *
     * Group action
     */
    getGroup(): semantic.IGroup;
    /**
     * Gets content of aggregation {@link #getMainAction mainAction}.
     *
     * Main action
     */
    getMainAction(): MainAction;
    /**
     * Gets content of aggregation {@link #getMessagesIndicator messagesIndicator}.
     *
     * MessagesIndicator
     */
    getMessagesIndicator(): MessagesIndicator;
    /**
     * Gets content of aggregation {@link #getMultiSelectAction multiSelectAction}.
     *
     * MultiSelect action
     */
    getMultiSelectAction(): MultiSelectAction;
    /**
     * Gets content of aggregation {@link #getNegativeAction negativeAction}.
     *
     * Negative action
     */
    getNegativeAction(): NegativeAction;
    /**
     * Gets content of aggregation {@link #getPositiveAction positiveAction}.
     *
     * Positive action
     */
    getPositiveAction(): PositiveAction;
    /**
     * Gets content of aggregation {@link #getSaveAction saveAction}.
     *
     * Save action
     */
    getSaveAction(): SaveAction;
    /**
     * Gets content of aggregation {@link #getSort sort}.
     *
     * Sort action
     */
    getSort(): semantic.ISort;
    /**
     * Sets the aggregated {@link #getAddAction addAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAddAction(
      /**
       * The addAction to set
       */
      oAddAction: AddAction
    ): this;
    /**
     * Sets the aggregated {@link #getCancelAction cancelAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCancelAction(
      /**
       * The cancelAction to set
       */
      oCancelAction: CancelAction
    ): this;
    /**
     * Sets the aggregated {@link #getDeleteAction deleteAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDeleteAction(
      /**
       * The deleteAction to set
       */
      oDeleteAction: DeleteAction
    ): this;
    /**
     * Sets the aggregated {@link #getEditAction editAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEditAction(
      /**
       * The editAction to set
       */
      oEditAction: EditAction
    ): this;
    /**
     * Sets the aggregated {@link #getFilter filter}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFilter(
      /**
       * The filter to set
       */
      oFilter: semantic.IFilter
    ): this;
    /**
     * Sets the aggregated {@link #getForwardAction forwardAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setForwardAction(
      /**
       * The forwardAction to set
       */
      oForwardAction: ForwardAction
    ): this;
    /**
     * Sets the aggregated {@link #getGroup group}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGroup(
      /**
       * The group to set
       */
      oGroup: semantic.IGroup
    ): this;
    /**
     * Sets the aggregated {@link #getMainAction mainAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMainAction(
      /**
       * The mainAction to set
       */
      oMainAction: MainAction
    ): this;
    /**
     * Sets the aggregated {@link #getMessagesIndicator messagesIndicator}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMessagesIndicator(
      /**
       * The messagesIndicator to set
       */
      oMessagesIndicator: MessagesIndicator
    ): this;
    /**
     * Sets the aggregated {@link #getMultiSelectAction multiSelectAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMultiSelectAction(
      /**
       * The multiSelectAction to set
       */
      oMultiSelectAction: MultiSelectAction
    ): this;
    /**
     * Sets the aggregated {@link #getNegativeAction negativeAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNegativeAction(
      /**
       * The negativeAction to set
       */
      oNegativeAction: NegativeAction
    ): this;
    /**
     * Sets the aggregated {@link #getPositiveAction positiveAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPositiveAction(
      /**
       * The positiveAction to set
       */
      oPositiveAction: PositiveAction
    ): this;
    /**
     * Sets the aggregated {@link #getSaveAction saveAction}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSaveAction(
      /**
       * The saveAction to set
       */
      oSaveAction: SaveAction
    ): this;
    /**
     * Sets the aggregated {@link #getSort sort}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSort(
      /**
       * The sort to set
       */
      oSort: semantic.ISort
    ): this;
  }
  /**
   * Describes the settings that can be provided to the MasterPage constructor.
   */
  export interface $MasterPageSettings extends $SemanticPageSettings {
    /**
     * Add action
     */
    addAction?: AddAction;

    /**
     * Main action
     */
    mainAction?: MainAction;

    /**
     * Positive action
     */
    positiveAction?: PositiveAction;

    /**
     * Negative action
     */
    negativeAction?: NegativeAction;

    /**
     * MultiSelect action
     */
    multiSelectAction?: MultiSelectAction;

    /**
     * Forward action
     */
    forwardAction?: ForwardAction;

    /**
     * Edit action
     */
    editAction?: EditAction;

    /**
     * Save action
     */
    saveAction?: SaveAction;

    /**
     * Delete action
     */
    deleteAction?: DeleteAction;

    /**
     * Cancel action
     */
    cancelAction?: CancelAction;

    /**
     * Sort action
     */
    sort?: semantic.ISort;

    /**
     * Filter action
     */
    filter?: semantic.IFilter;

    /**
     * Group action
     */
    group?: semantic.IGroup;

    /**
     * MessagesIndicator
     */
    messagesIndicator?: MessagesIndicator;
  }
}

declare module "sap/m/semantic/MessagesIndicator" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A MessagesIndicator button has default semantic-specific properties and is eligible for aggregation content
   * of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default class MessagesIndicator extends SemanticButton {
    /**
     * Constructor for a new MessagesIndicator.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $MessagesIndicatorSettings
    );
    /**
     * Constructor for a new MessagesIndicator.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $MessagesIndicatorSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.MessagesIndicator with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, MessagesIndicator>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.MessagesIndicator.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the MessagesIndicator constructor.
   */
  export interface $MessagesIndicatorSettings extends $SemanticButtonSettings {}
}

declare module "sap/m/semantic/MultiSelectAction" {
  import {
    default as SemanticToggleButton,
    $SemanticToggleButtonSettings,
  } from "sap/m/semantic/SemanticToggleButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A MultiSelectAction button has default semantic-specific properties and is eligible for aggregation content
   * of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default class MultiSelectAction extends SemanticToggleButton {
    /**
     * Constructor for a new MultiSelectAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticToggleButton#constructor sap.m.semantic.SemanticToggleButton }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $MultiSelectActionSettings
    );
    /**
     * Constructor for a new MultiSelectAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticToggleButton#constructor sap.m.semantic.SemanticToggleButton }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $MultiSelectActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.MultiSelectAction with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticToggleButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, MultiSelectAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.MultiSelectAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the MultiSelectAction constructor.
   */
  export interface $MultiSelectActionSettings
    extends $SemanticToggleButtonSettings {}
}

declare module "sap/m/semantic/NegativeAction" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * A NegativeAction button has default semantic-specific properties and is eligible for aggregation content
   * of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default class NegativeAction extends SemanticButton {
    /**
     * Constructor for a new NegativeAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $NegativeActionSettings
    );
    /**
     * Constructor for a new NegativeAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $NegativeActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.NegativeAction with name `sClassName` and enriches it
     * with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, NegativeAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.NegativeAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Button text
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Button text
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the NegativeAction constructor.
   */
  export interface $NegativeActionSettings extends $SemanticButtonSettings {
    /**
     * Button text
     */
    text?: string | PropertyBindingInfo;
  }
}

declare module "sap/m/semantic/OpenInAction" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * An OpenInAction button has default semantic-specific properties and is eligible for aggregation content
   * of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default class OpenInAction extends SemanticButton {
    /**
     * Constructor for a new OpenInAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $OpenInActionSettings
    );
    /**
     * Constructor for a new OpenInAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $OpenInActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.OpenInAction with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, OpenInAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.OpenInAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the OpenInAction constructor.
   */
  export interface $OpenInActionSettings extends $SemanticButtonSettings {}
}

declare module "sap/m/semantic/PositiveAction" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * A PositiveAction button has default semantic-specific properties and is eligible for aggregation content
   * of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default class PositiveAction extends SemanticButton {
    /**
     * Constructor for a new PositiveAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $PositiveActionSettings
    );
    /**
     * Constructor for a new PositiveAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $PositiveActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.PositiveAction with name `sClassName` and enriches it
     * with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, PositiveAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.PositiveAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Button text
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Button text
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the PositiveAction constructor.
   */
  export interface $PositiveActionSettings extends $SemanticButtonSettings {
    /**
     * Button text
     */
    text?: string | PropertyBindingInfo;
  }
}

declare module "sap/m/semantic/PrintAction" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A PrintAction button has default semantic-specific properties and is eligible for aggregation content
   * of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default class PrintAction extends SemanticButton {
    /**
     * Constructor for a new PrintAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $PrintActionSettings
    );
    /**
     * Constructor for a new PrintAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $PrintActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.PrintAction with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, PrintAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.PrintAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the PrintAction constructor.
   */
  export interface $PrintActionSettings extends $SemanticButtonSettings {}
}

declare module "sap/m/semantic/SaveAction" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A SaveAction button has default semantic-specific properties and is eligible for aggregation content
   * of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default class SaveAction extends SemanticButton {
    /**
     * Constructor for a new SaveAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $SaveActionSettings
    );
    /**
     * Constructor for a new SaveAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $SaveActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.SaveAction with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SaveAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.SaveAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the SaveAction constructor.
   */
  export interface $SaveActionSettings extends $SemanticButtonSettings {}
}

declare module "sap/m/semantic/SemanticButton" {
  import {
    default as SemanticControl,
    $SemanticControlSettings,
  } from "sap/m/semantic/SemanticControl";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * A semantic button is either a {@link sap.m.Button} or {@link sap.m.semantic.SemanticOverflowToolbarButton }
   * , eligible for aggregation content of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default abstract class SemanticButton extends SemanticControl {
    /**
     * Constructor for a new SemanticButton.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SemanticButtonSettings
    );
    /**
     * Constructor for a new SemanticButton.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SemanticButtonSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.SemanticButton with name `sClassName` and enriches it
     * with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticControl.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SemanticButton>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.SemanticButton.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.semantic.SemanticButton`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.semantic.SemanticButton` itself.
     *
     * See {@link sap.m.Button#event:press}
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.semantic.SemanticButton` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.semantic.SemanticButton`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.semantic.SemanticButton` itself.
     *
     * See {@link sap.m.Button#event:press}
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.semantic.SemanticButton` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.semantic.SemanticButton`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * See {@link sap.m.Button#enabled}
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * See {@link sap.m.Button#enabled}
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the SemanticButton constructor.
   */
  export interface $SemanticButtonSettings extends $SemanticControlSettings {
    /**
     * See {@link sap.m.Button#enabled}
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * See {@link sap.m.Button#event:press}
     */
    press?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the SemanticButton#press event.
   */
  export interface SemanticButton$PressEventParameters {}

  /**
   * Event object of the SemanticButton#press event.
   */
  export type SemanticButton$PressEvent = Event<
    SemanticButton$PressEventParameters,
    SemanticButton
  >;
}

declare module "sap/m/semantic/SemanticControl" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * A semantic control is an abstraction for either a {@link sap.m.semantic.SemanticButton} or {@link sap.m.semantic.SemanticSelect }
   * , eligible for aggregation content of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default abstract class SemanticControl extends UI5Element {
    /**
     * Constructor for a new SemanticControl.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $SemanticControlSettings
    );
    /**
     * Constructor for a new SemanticControl.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $SemanticControlSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.SemanticControl with name `sClassName` and enriches it
     * with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SemanticControl>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.SemanticControl.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Implementation of a commonly used function that adapts `sap.ui.core.Element` to provide DOM reference
     * for opening popovers.
     *
     *
     * @returns The DOM reference of the actual wrapped control
     */
    getPopupAnchorDomRef(): Element;
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * See {@link sap.ui.core.Control#visible}
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * See {@link sap.ui.core.Control#visible}
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the SemanticControl constructor.
   */
  export interface $SemanticControlSettings extends $ElementSettings {
    /**
     * See {@link sap.ui.core.Control#visible}
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/semantic/SemanticPage" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import Button from "sap/m/Button";

  import Event from "sap/ui/base/Event";

  import { PageBackgroundDesign, semantic, IBar } from "sap/m/library";

  import PageAccessibleLandmarkInfo from "sap/m/PageAccessibleLandmarkInfo";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { TitleLevel } from "sap/ui/core/library";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * An enhanced {@link sap.m.Page}, that can contain controls with semantic meaning, see {@link sap.m.semantic.SemanticControl}.
   *
   * **Note:** This control implements the SAP Fiori 1.0 design guidelines. For SAP Fiori 2.0, see the {@link sap.f.semantic.SemanticPage}.
   *
   * Overview:
   *
   * The main functionality of the `SemanticPage` is to predefine the placement, behavior and styles of the
   * page elements.
   *
   * Content specified in the semantic aggregations will be automatically positioned in dedicated sections
   * of the footer or the header of the page.
   *
   * Structure:
   *
   * The semantics of the content are the following:
   * 	 - Visual properties (for example, `AddAction` will be styled as an icon button)
   * 	 - Position in the page (UX guidelines specify that some buttons should be in the header only, while
   *     others are in the footer or the "share" menu, so we do the correct positioning)
   * 	 - Sequence order (UX guidelines define a specific sequence order of semantic controls with respect
   *     to each other)
   * 	 - Default localized tooltip for icon-only buttons
   * 	 - Overflow behavior (UX guidelines define which buttons are allowed to go to the overflow of the toolbar
   *     when the screen gets narrower). For icon buttons, we ensure that the text label of the button appears
   *     when the button is in overflow, as specified by UX.
   * 	 - Screen reader support (invisible text for reading the semantic type)
   *
   * In addition to the predefined semantic controls, the `SemanticPage` can host also custom app controls.
   * It preserves most of the API of the {@link sap.m.Page} for specifying page content.
   *
   * Usage:
   *
   * The app developer only has to specify the action type, and the required styling and positioning are automatically
   * added.
   *
   * @since 1.30.0
   */
  export default abstract class SemanticPage extends Control {
    /**
     * Constructor for a new `SemanticPage`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/4a97a07ec8f5441d901994d82eaab1f5 Semantic Page}
     * 	{@link https://ui5.sap.com/#/topic/84f3d52f492648d5b594e4f45dca7727 Semantic Pages}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SemanticPageSettings
    );
    /**
     * Constructor for a new `SemanticPage`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/4a97a07ec8f5441d901994d82eaab1f5 Semantic Page}
     * 	{@link https://ui5.sap.com/#/topic/84f3d52f492648d5b594e4f45dca7727 Semantic Pages}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SemanticPageSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.SemanticPage with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SemanticPage>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.SemanticPage.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some content to the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContent(
      /**
       * The content to add; if empty, nothing is inserted
       */
      oContent: Control
    ): this;
    /**
     * Adds some customFooterContent to the aggregation {@link #getCustomFooterContent customFooterContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addCustomFooterContent(
      /**
       * The customFooterContent to add; if empty, nothing is inserted
       */
      oCustomFooterContent: Button
    ): this;
    /**
     * Adds some customHeaderContent to the aggregation {@link #getCustomHeaderContent customHeaderContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addCustomHeaderContent(
      /**
       * The customHeaderContent to add; if empty, nothing is inserted
       */
      oCustomHeaderContent: Button
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navButtonPress navButtonPress} event of this
     * `sap.m.semantic.SemanticPage`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.semantic.SemanticPage` itself.
     *
     * See {@link sap.m.Page#navButtonPress}
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavButtonPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.semantic.SemanticPage` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navButtonPress navButtonPress} event of this
     * `sap.m.semantic.SemanticPage`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.semantic.SemanticPage` itself.
     *
     * See {@link sap.m.Page#navButtonPress}
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavButtonPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.semantic.SemanticPage` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Destroys all the customFooterContent in the aggregation {@link #getCustomFooterContent customFooterContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCustomFooterContent(): this;
    /**
     * Destroys all the customHeaderContent in the aggregation {@link #getCustomHeaderContent customHeaderContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCustomHeaderContent(): this;
    /**
     * Destroys the landmarkInfo in the aggregation {@link #getLandmarkInfo landmarkInfo}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyLandmarkInfo(): this;
    /**
     * Destroys the subHeader in the aggregation {@link #getSubHeader subHeader}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySubHeader(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:navButtonPress navButtonPress} event of this
     * `sap.m.semantic.SemanticPage`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachNavButtonPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:navButtonPress navButtonPress} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireNavButtonPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Determines the backgound color of the page. For more information, see {@link sap.m.Page#backgroundDesign}.
     *
     * Default value is `Standard`.
     *
     * @since 1.52
     *
     * @returns Value of property `backgroundDesign`
     */
    getBackgroundDesign(): PageBackgroundDesign;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * See {@link sap.m.Page#content}
     */
    getContent(): Control[];
    /**
     * Gets content of aggregation {@link #getCustomFooterContent customFooterContent}.
     *
     * Custom footer buttons
     */
    getCustomFooterContent(): Button[];
    /**
     * Gets content of aggregation {@link #getCustomHeaderContent customHeaderContent}.
     *
     * Custom header buttons
     */
    getCustomHeaderContent(): Button[];
    /**
     * Gets current value of property {@link #getEnableScrolling enableScrolling}.
     *
     * See {@link sap.m.Page#enableScrolling}
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enableScrolling`
     */
    getEnableScrolling(): boolean;
    /**
     * Gets current value of property {@link #getFloatingFooter floatingFooter}.
     *
     * Determines whether the floating footer behavior is enabled. If set to `true`, the content is visible
     * when it's underneath the footer.
     *
     * Default value is `false`.
     *
     * @since 1.40.1
     *
     * @returns Value of property `floatingFooter`
     */
    getFloatingFooter(): boolean;
    /**
     * Gets content of aggregation {@link #getLandmarkInfo landmarkInfo}.
     *
     * Accessible landmark settings to be applied to the containers of the `sap.m.Page` control.
     *
     * If not set, no landmarks will be written.
     */
    getLandmarkInfo(): PageAccessibleLandmarkInfo;
    /**
     * Gets current value of property {@link #getSemanticRuleSet semanticRuleSet}.
     *
     * Declares the type of semantic ruleset that will govern the styling and positioning of semantic content.
     *
     * Default value is `Classic`.
     *
     * @since 1.44
     *
     * @returns Value of property `semanticRuleSet`
     */
    getSemanticRuleSet(): semantic.SemanticRuleSetType;
    /**
     * Gets current value of property {@link #getShowFooter showFooter}.
     *
     * Hides or shows the page footer
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showFooter`
     */
    getShowFooter(): boolean;
    /**
     * Gets current value of property {@link #getShowNavButton showNavButton}.
     *
     * See {@link sap.m.Page#showNavButton}
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showNavButton`
     */
    getShowNavButton(): boolean;
    /**
     * Gets current value of property {@link #getShowSubHeader showSubHeader}.
     *
     * See {@link sap.m.Page#showSubHeader}
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showSubHeader`
     */
    getShowSubHeader(): boolean;
    /**
     * Gets content of aggregation {@link #getSubHeader subHeader}.
     *
     * See {@link sap.m.Page#subHeader}
     */
    getSubHeader(): IBar;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * See {@link sap.m.Page#title}
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getTitleLevel titleLevel}.
     *
     * See {@link sap.m.Page#titleLevel}
     *
     * Default value is `Auto`.
     *
     *
     * @returns Value of property `titleLevel`
     */
    getTitleLevel(): TitleLevel;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContent content}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContent(
      /**
       * The content whose index is looked for
       */
      oContent: Control
    ): int;
    /**
     * Checks for the provided `sap.m.Button` in the aggregation {@link #getCustomFooterContent customFooterContent}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfCustomFooterContent(
      /**
       * The customFooterContent whose index is looked for
       */
      oCustomFooterContent: Button
    ): int;
    /**
     * Checks for the provided `sap.m.Button` in the aggregation {@link #getCustomHeaderContent customHeaderContent}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfCustomHeaderContent(
      /**
       * The customHeaderContent whose index is looked for
       */
      oCustomHeaderContent: Button
    ): int;
    /**
     * Inserts a content into the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContent(
      /**
       * The content to insert; if empty, nothing is inserted
       */
      oContent: Control,
      /**
       * The `0`-based index the content should be inserted at; for a negative value of `iIndex`, the content
       * is inserted at position 0; for a value greater than the current size of the aggregation, the content
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a customFooterContent into the aggregation {@link #getCustomFooterContent customFooterContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertCustomFooterContent(
      /**
       * The customFooterContent to insert; if empty, nothing is inserted
       */
      oCustomFooterContent: Button,
      /**
       * The `0`-based index the customFooterContent should be inserted at; for a negative value of `iIndex`,
       * the customFooterContent is inserted at position 0; for a value greater than the current size of the aggregation,
       * the customFooterContent is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a customHeaderContent into the aggregation {@link #getCustomHeaderContent customHeaderContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertCustomHeaderContent(
      /**
       * The customHeaderContent to insert; if empty, nothing is inserted
       */
      oCustomHeaderContent: Button,
      /**
       * The `0`-based index the customHeaderContent should be inserted at; for a negative value of `iIndex`,
       * the customHeaderContent is inserted at position 0; for a value greater than the current size of the aggregation,
       * the customHeaderContent is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getContent content}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContent(): Control[];
    /**
     * Removes all the controls from the aggregation {@link #getCustomFooterContent customFooterContent}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllCustomFooterContent(): Button[];
    /**
     * Removes all the controls from the aggregation {@link #getCustomHeaderContent customHeaderContent}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllCustomHeaderContent(): Button[];
    /**
     * Removes a content from the aggregation {@link #getContent content}.
     *
     *
     * @returns The removed content or `null`
     */
    removeContent(
      /**
       * The content to remove or its index or id
       */
      vContent: int | string | Control
    ): Control | null;
    /**
     * Removes a customFooterContent from the aggregation {@link #getCustomFooterContent customFooterContent}.
     *
     *
     * @returns The removed customFooterContent or `null`
     */
    removeCustomFooterContent(
      /**
       * The customFooterContent to remove or its index or id
       */
      vCustomFooterContent: int | string | Button
    ): Button | null;
    /**
     * Removes a customHeaderContent from the aggregation {@link #getCustomHeaderContent customHeaderContent}.
     *
     *
     * @returns The removed customHeaderContent or `null`
     */
    removeCustomHeaderContent(
      /**
       * The customHeaderContent to remove or its index or id
       */
      vCustomHeaderContent: int | string | Button
    ): Button | null;
    /**
     * Sets a new value for property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Determines the backgound color of the page. For more information, see {@link sap.m.Page#backgroundDesign}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Standard`.
     *
     * @since 1.52
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundDesign(
      /**
       * New value for property `backgroundDesign`
       */
      sBackgroundDesign?:
        | PageBackgroundDesign
        | keyof typeof PageBackgroundDesign
    ): this;
    /**
     * Sets a new value for property {@link #getEnableScrolling enableScrolling}.
     *
     * See {@link sap.m.Page#enableScrolling}
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableScrolling(
      /**
       * New value for property `enableScrolling`
       */
      bEnableScrolling?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getFloatingFooter floatingFooter}.
     *
     * Determines whether the floating footer behavior is enabled. If set to `true`, the content is visible
     * when it's underneath the footer.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.40.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFloatingFooter(
      /**
       * New value for property `floatingFooter`
       */
      bFloatingFooter?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getLandmarkInfo landmarkInfo}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLandmarkInfo(
      /**
       * The landmarkInfo to set
       */
      oLandmarkInfo: PageAccessibleLandmarkInfo
    ): this;
    /**
     * Sets a new value for property {@link #getSemanticRuleSet semanticRuleSet}.
     *
     * Declares the type of semantic ruleset that will govern the styling and positioning of semantic content.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Classic`.
     *
     * @since 1.44
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSemanticRuleSet(
      /**
       * New value for property `semanticRuleSet`
       */
      sSemanticRuleSet?:
        | semantic.SemanticRuleSetType
        | keyof typeof semantic.SemanticRuleSetType
    ): this;
    /**
     * Sets a new value for property {@link #getShowFooter showFooter}.
     *
     * Hides or shows the page footer
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowFooter(
      /**
       * New value for property `showFooter`
       */
      bShowFooter?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowNavButton showNavButton}.
     *
     * See {@link sap.m.Page#showNavButton}
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowNavButton(
      /**
       * New value for property `showNavButton`
       */
      bShowNavButton?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowSubHeader showSubHeader}.
     *
     * See {@link sap.m.Page#showSubHeader}
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowSubHeader(
      /**
       * New value for property `showSubHeader`
       */
      bShowSubHeader?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getSubHeader subHeader}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSubHeader(
      /**
       * The subHeader to set
       */
      oSubHeader: IBar
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * See {@link sap.m.Page#title}
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitleLevel titleLevel}.
     *
     * See {@link sap.m.Page#titleLevel}
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleLevel(
      /**
       * New value for property `titleLevel`
       */
      sTitleLevel?: TitleLevel | keyof typeof TitleLevel
    ): this;
  }
  /**
   * Describes the settings that can be provided to the SemanticPage constructor.
   */
  export interface $SemanticPageSettings extends $ControlSettings {
    /**
     * See {@link sap.m.Page#title}
     */
    title?: string | PropertyBindingInfo;

    /**
     * See {@link sap.m.Page#titleLevel}
     */
    titleLevel?:
      | (TitleLevel | keyof typeof TitleLevel)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * See {@link sap.m.Page#showNavButton}
     */
    showNavButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * See {@link sap.m.Page#showSubHeader}
     */
    showSubHeader?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * See {@link sap.m.Page#enableScrolling}
     */
    enableScrolling?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Hides or shows the page footer
     */
    showFooter?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the floating footer behavior is enabled. If set to `true`, the content is visible
     * when it's underneath the footer.
     *
     * @since 1.40.1
     */
    floatingFooter?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Declares the type of semantic ruleset that will govern the styling and positioning of semantic content.
     *
     * @since 1.44
     */
    semanticRuleSet?:
      | (
          | semantic.SemanticRuleSetType
          | keyof typeof semantic.SemanticRuleSetType
        )
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the backgound color of the page. For more information, see {@link sap.m.Page#backgroundDesign}.
     *
     * @since 1.52
     */
    backgroundDesign?:
      | (PageBackgroundDesign | keyof typeof PageBackgroundDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * See {@link sap.m.Page#subHeader}
     */
    subHeader?: IBar;

    /**
     * See {@link sap.m.Page#content}
     */
    content?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * Custom header buttons
     */
    customHeaderContent?:
      | Button[]
      | Button
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Custom footer buttons
     */
    customFooterContent?:
      | Button[]
      | Button
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Accessible landmark settings to be applied to the containers of the `sap.m.Page` control.
     *
     * If not set, no landmarks will be written.
     */
    landmarkInfo?: PageAccessibleLandmarkInfo;

    /**
     * See {@link sap.m.Page#navButtonPress}
     */
    navButtonPress?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the SemanticPage#navButtonPress event.
   */
  export interface SemanticPage$NavButtonPressEventParameters {}

  /**
   * Event object of the SemanticPage#navButtonPress event.
   */
  export type SemanticPage$NavButtonPressEvent = Event<
    SemanticPage$NavButtonPressEventParameters,
    SemanticPage
  >;
}

declare module "sap/m/semantic/SemanticSelect" {
  import {
    default as SemanticControl,
    $SemanticControlSettings,
  } from "sap/m/semantic/SemanticControl";

  import Item from "sap/ui/core/Item";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { ID } from "sap/ui/core/library";

  import Event from "sap/ui/base/Event";

  /**
   * A semantic select is a {@link sap.m.Select} eligible for aggregation content of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30
   */
  export default abstract class SemanticSelect extends SemanticControl {
    /**
     * Constructor for a new SemanticSelect.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SemanticSelectSettings
    );
    /**
     * Constructor for a new SemanticSelect.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SemanticSelectSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.SemanticSelect with name `sClassName` and enriches it
     * with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticControl.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SemanticSelect>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.SemanticSelect.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: Item
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.semantic.SemanticSelect`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.semantic.SemanticSelect` itself.
     *
     * See {@link sap.m.Select#event:change}
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SemanticSelect$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.semantic.SemanticSelect` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.semantic.SemanticSelect`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.semantic.SemanticSelect` itself.
     *
     * See {@link sap.m.Select#event:change}
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SemanticSelect$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.semantic.SemanticSelect` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getItems items} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:change change} event of this `sap.m.semantic.SemanticSelect`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SemanticSelect$ChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:change change} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SemanticSelect$ChangeEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * See {@link sap.m.Select#getEnabled}
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * See {@link sap.m.Select#getItems}
     */
    getItems(): Item[];
    /**
     * ID of the element which is the current target of the association {@link #getSelectedItem selectedItem},
     * or `null`.
     */
    getSelectedItem(): ID | null;
    /**
     * Gets current value of property {@link #getSelectedKey selectedKey}.
     *
     * See {@link sap.m.Select#getSelectedKey}
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `selectedKey`
     */
    getSelectedKey(): string;
    /**
     * Checks for the provided `sap.ui.core.Item` in the aggregation {@link #getItems items}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: Item
    ): int;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: Item,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): Item[];
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | Item
    ): Item | null;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * See {@link sap.m.Select#getEnabled}
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets the associated {@link #getSelectedItem selectedItem}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSelectedItem(
      /**
       * ID of an element which becomes the new target of this selectedItem association; alternatively, an element
       * instance may be given
       */
      oSelectedItem: ID | Item
    ): this;
    /**
     * Sets a new value for property {@link #getSelectedKey selectedKey}.
     *
     * See {@link sap.m.Select#getSelectedKey}
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSelectedKey(
      /**
       * New value for property `selectedKey`
       */
      sSelectedKey?: string
    ): this;
    /**
     * Unbinds aggregation {@link #getItems items} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindItems(): this;
  }
  /**
   * Describes the settings that can be provided to the SemanticSelect constructor.
   */
  export interface $SemanticSelectSettings extends $SemanticControlSettings {
    /**
     * See {@link sap.m.Select#getEnabled}
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * See {@link sap.m.Select#getSelectedKey}
     */
    selectedKey?: string | PropertyBindingInfo;

    /**
     * See {@link sap.m.Select#getItems}
     */
    items?: Item[] | Item | AggregationBindingInfo | `{${string}}`;

    /**
     * See {@link sap.m.Select#getSelectedItem}
     */
    selectedItem?: Item | string;

    /**
     * See {@link sap.m.Select#event:change}
     */
    change?: (oEvent: SemanticSelect$ChangeEvent) => void;
  }

  /**
   * Parameters of the SemanticSelect#change event.
   */
  export interface SemanticSelect$ChangeEventParameters {
    /**
     * The selected item.
     */
    selectedItem?: Item;
  }

  /**
   * Event object of the SemanticSelect#change event.
   */
  export type SemanticSelect$ChangeEvent = Event<
    SemanticSelect$ChangeEventParameters,
    SemanticSelect
  >;
}

declare module "sap/m/semantic/SemanticToggleButton" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * A SemanticToggleButton is eligible for aggregation content of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default abstract class SemanticToggleButton extends SemanticButton {
    /**
     * Constructor for a new SemanticToggleButton.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SemanticToggleButtonSettings
    );
    /**
     * Constructor for a new SemanticToggleButton.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SemanticToggleButtonSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.SemanticToggleButton with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SemanticToggleButton>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.SemanticToggleButton.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getPressed pressed}.
     *
     * The property is “true” when the control is toggled. The default state of this property is "false".
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `pressed`
     */
    getPressed(): boolean;
    /**
     * Sets a new value for property {@link #getPressed pressed}.
     *
     * The property is “true” when the control is toggled. The default state of this property is "false".
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPressed(
      /**
       * New value for property `pressed`
       */
      bPressed?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the SemanticToggleButton constructor.
   */
  export interface $SemanticToggleButtonSettings
    extends $SemanticButtonSettings {
    /**
     * The property is “true” when the control is toggled. The default state of this property is "false".
     */
    pressed?: boolean | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/semantic/SendEmailAction" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A SendEmailAction button has default semantic-specific properties and is eligible for aggregation content
   * of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default class SendEmailAction extends SemanticButton {
    /**
     * Constructor for a new SendEmailAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $SendEmailActionSettings
    );
    /**
     * Constructor for a new SendEmailAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $SendEmailActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.SendEmailAction with name `sClassName` and enriches it
     * with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SendEmailAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.SendEmailAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the SendEmailAction constructor.
   */
  export interface $SendEmailActionSettings extends $SemanticButtonSettings {}
}

declare module "sap/m/semantic/SendMessageAction" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A SendMessageAction button has default semantic-specific properties and is eligible for aggregation content
   * of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default class SendMessageAction extends SemanticButton {
    /**
     * Constructor for a new SendMessageAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $SendMessageActionSettings
    );
    /**
     * Constructor for a new SendMessageAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $SendMessageActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.SendMessageAction with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SendMessageAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.SendMessageAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the SendMessageAction constructor.
   */
  export interface $SendMessageActionSettings extends $SemanticButtonSettings {}
}

declare module "sap/m/semantic/ShareInJamAction" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A ShareInJamAction button has default semantic-specific properties and is eligible for aggregation content
   * of a {@link sap.m.semantic.SemanticPage}.
   *
   * @since 1.30.0
   */
  export default class ShareInJamAction extends SemanticButton {
    /**
     * Constructor for a new ShareInJamAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $ShareInJamActionSettings
    );
    /**
     * Constructor for a new ShareInJamAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $ShareInJamActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.ShareInJamAction with name `sClassName` and enriches it
     * with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ShareInJamAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.ShareInJamAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the ShareInJamAction constructor.
   */
  export interface $ShareInJamActionSettings extends $SemanticButtonSettings {}
}

declare module "sap/m/semantic/ShareMenuPage" {
  import {
    default as SemanticPage,
    $SemanticPageSettings,
  } from "sap/m/semantic/SemanticPage";

  import Button from "sap/m/Button";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { AggregationBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * A ShareMenuPage is a {@link sap.m.semantic.SemanticPage} with support for "share" menu in the footer.
   *
   * @since 1.30.0
   */
  export default class ShareMenuPage extends SemanticPage {
    /**
     * Constructor for a new ShareMenuPage
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $ShareMenuPageSettings
    );
    /**
     * Constructor for a new ShareMenuPage
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $ShareMenuPageSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.ShareMenuPage with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticPage.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ShareMenuPage>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.ShareMenuPage.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some customShareMenuContent to the aggregation {@link #getCustomShareMenuContent customShareMenuContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addCustomShareMenuContent(
      /**
       * The customShareMenuContent to add; if empty, nothing is inserted
       */
      oCustomShareMenuContent: Button
    ): this;
    /**
     * Destroys all the customShareMenuContent in the aggregation {@link #getCustomShareMenuContent customShareMenuContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCustomShareMenuContent(): this;
    /**
     * Gets content of aggregation {@link #getCustomShareMenuContent customShareMenuContent}.
     *
     * Custom share menu buttons
     */
    getCustomShareMenuContent(): Button[];
    /**
     * Checks for the provided `sap.m.Button` in the aggregation {@link #getCustomShareMenuContent customShareMenuContent}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfCustomShareMenuContent(
      /**
       * The customShareMenuContent whose index is looked for
       */
      oCustomShareMenuContent: Button
    ): int;
    /**
     * Inserts a customShareMenuContent into the aggregation {@link #getCustomShareMenuContent customShareMenuContent}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertCustomShareMenuContent(
      /**
       * The customShareMenuContent to insert; if empty, nothing is inserted
       */
      oCustomShareMenuContent: Button,
      /**
       * The `0`-based index the customShareMenuContent should be inserted at; for a negative value of `iIndex`,
       * the customShareMenuContent is inserted at position 0; for a value greater than the current size of the
       * aggregation, the customShareMenuContent is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getCustomShareMenuContent customShareMenuContent}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllCustomShareMenuContent(): Button[];
    /**
     * Removes a customShareMenuContent from the aggregation {@link #getCustomShareMenuContent customShareMenuContent}.
     *
     *
     * @returns The removed customShareMenuContent or `null`
     */
    removeCustomShareMenuContent(
      /**
       * The customShareMenuContent to remove or its index or id
       */
      vCustomShareMenuContent: int | string | Button
    ): Button | null;
  }
  /**
   * Describes the settings that can be provided to the ShareMenuPage constructor.
   */
  export interface $ShareMenuPageSettings extends $SemanticPageSettings {
    /**
     * Custom share menu buttons
     */
    customShareMenuContent?:
      | Button[]
      | Button
      | AggregationBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/semantic/SortAction" {
  import {
    default as SemanticButton,
    $SemanticButtonSettings,
  } from "sap/m/semantic/SemanticButton";

  import { semantic } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A SortAction is a {@link sap.m.Button} control enhanced with styling according to the semantics of a
   * common "Sort" action.
   *
   * A SortAction cannot be used independently but only as aggregation content of a {@link sap.m.semantic.SemanticPage}.
   *
   * Your app should listen to the `press` event of {@link sap.m.semantic.SortAction} in order to trigger
   * the display of the sorting options.
   *
   * If your sorting options are a simple list of items and require single choice only, then you can consider
   * using a {@link sap.m.semantic.SortSelect} instead.
   *
   * @since 1.30.0
   */
  export default class SortAction
    extends SemanticButton
    implements semantic.ISort
  {
    __implements__sap_m_semantic_ISort: boolean;
    /**
     * Constructor for a new SortAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $SortActionSettings
    );
    /**
     * Constructor for a new SortAction.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticButton#constructor sap.m.semantic.SemanticButton }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $SortActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.SortAction with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticButton.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SortAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.SortAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the SortAction constructor.
   */
  export interface $SortActionSettings extends $SemanticButtonSettings {}
}

declare module "sap/m/semantic/SortSelect" {
  import {
    default as SemanticSelect,
    $SemanticSelectSettings,
  } from "sap/m/semantic/SemanticSelect";

  import { semantic } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A SortSelect is a {@link sap.m.Select} control enhanced with styling according to the semantics of a
   * common "Sort" acton.
   *
   * A SortSelect cannot be used independently but only as aggregation content of a {@link sap.m.semantic.SemanticPage}.
   *
   * The sorting options should be added to the `items` aggregation of {@link sap.m.semantic.SortSelect} and
   * will be displayed as a pop-up list with support for single-item selection. If this simple popup list
   * is not sufficient for your use case, you can implement your own custom dialog by using {@link sap.m.semantic.SortAction }
   * to trigger the dialog opening.
   *
   * @since 1.30.0
   */
  export default class SortSelect
    extends SemanticSelect
    implements semantic.ISort
  {
    __implements__sap_m_semantic_ISort: boolean;
    /**
     * Constructor for a new SortSelect.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticSelect#constructor sap.m.semantic.SemanticSelect }
     * can be used.
     */
    constructor(
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $SortSelectSettings
    );
    /**
     * Constructor for a new SortSelect.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.semantic.SemanticSelect#constructor sap.m.semantic.SemanticSelect }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Optional initial settings for the new control: a map/JSON-object with initial property values, event
       * listeners etc. for the new object
       */
      mSettings?: $SortSelectSettings
    );

    /**
     * Creates a new subclass of class sap.m.semantic.SortSelect with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.semantic.SemanticSelect.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SortSelect>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.semantic.SortSelect.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the SortSelect constructor.
   */
  export interface $SortSelectSettings extends $SemanticSelectSettings {}
}

declare module "sap/m/Shell" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import Event from "sap/ui/base/Event";

  import { CSSColor, URI, TitleLevel } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The Shell control can be used as root element of applications. It can contain an App or a `SplitApp`
   * control. The Shell provides some overarching functionality for the overall application and takes care
   * of visual adaptation, such as a frame around the App, on desktop browser platforms.
   *
   * @since 1.12
   */
  export default class Shell extends Control {
    /**
     * Constructor for a new Shell.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ShellSettings
    );
    /**
     * Constructor for a new Shell.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ShellSettings
    );

    /**
     * Creates a new subclass of class sap.m.Shell with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Shell>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Shell.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:logout logout} event of this `sap.m.Shell`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Shell` itself.
     *
     * Fires when the user presses the logout button/link.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLogout(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Shell` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:logout logout} event of this `sap.m.Shell`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Shell` itself.
     *
     * Fires when the user presses the logout button/link.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLogout(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Shell` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys the app in the aggregation {@link #getApp app}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyApp(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:logout logout} event of this `sap.m.Shell`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLogout(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:logout logout} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLogout(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets content of aggregation {@link #getApp app}.
     *
     * A Shell contains an App or a SplitApp (they may be wrapped in a View). Other control types are not allowed.
     */
    getApp(): Control;
    /**
     * Gets current value of property {@link #getAppWidthLimited appWidthLimited}.
     *
     * Determines whether the width of the content (the aggregated App) should be limited or extended to the
     * full screen width.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `appWidthLimited`
     */
    getAppWidthLimited(): boolean;
    /**
     * Gets current value of property {@link #getBackgroundColor backgroundColor}.
     *
     * Defines the background color of the Shell. If set, this color will override the default background defined
     * by the theme. This should only be set when really required. Any configured background image will be placed
     * above this colored background. Use the backgroundRepeat property to define whether this image should
     * be stretched to cover the complete Shell or whether it should be tiled.
     *
     * @since 1.11.2
     *
     * @returns Value of property `backgroundColor`
     */
    getBackgroundColor(): CSSColor;
    /**
     * Gets current value of property {@link #getBackgroundImage backgroundImage}.
     *
     * Defines the background image of the Shell. If set, this image will override the default background defined
     * by the theme. This should only be set when really required. This background image will be placed above
     * any color set for the background. Use the backgroundRepeat property to define whether this image should
     * be stretched to cover the complete Shell or whether it should be tiled.
     *
     * @since 1.11.2
     *
     * @returns Value of property `backgroundImage`
     */
    getBackgroundImage(): URI;
    /**
     * Gets current value of property {@link #getBackgroundOpacity backgroundOpacity}.
     *
     * Defines the opacity of the background image. The opacity can be set between 0 (fully transparent) and
     * 1 (fully opaque). This can be used to improve readability of the Shell content by making the background
     * image partly transparent.
     *
     * Default value is `1`.
     *
     * @since 1.11.2
     *
     * @returns Value of property `backgroundOpacity`
     */
    getBackgroundOpacity(): float;
    /**
     * Gets current value of property {@link #getBackgroundRepeat backgroundRepeat}.
     *
     * Determines whether the background image (if configured) should be proportionally stretched to cover the
     * whole Shell (false, default) or whether it should be tiled (true). Note: the image will not be displayed
     * when the `sap.m.Shell` content is fully overlapping the `sap.m.Shell` background (e.g. when "appWidthLimited"
     * is set to "false").
     *
     * Default value is `false`.
     *
     * @since 1.11.2
     *
     * @returns Value of property `backgroundRepeat`
     */
    getBackgroundRepeat(): boolean;
    /**
     * Gets current value of property {@link #getHeaderRightText headerRightText}.
     *
     * Defines texts, such as the name of the logged-in user, which should be displayed on the right side of
     * the header (if there is enough space to display the header at all - this only happens on very tall screens
     * (1568px height), otherwise, it is always hidden).
     *
     *
     * @returns Value of property `headerRightText`
     */
    getHeaderRightText(): string;
    /**
     * Gets current value of property {@link #getHomeIcon homeIcon}.
     *
     * The icon used for the mobile device home screen and the icon to be used for bookmarks by desktop browsers.
     *
     * This property should be only set once, and as early as possible. Subsequent calls replace the previous
     * icon settings and may lead to different behavior depending on the browser.
     *
     * Different image sizes for device home screen need to be given as PNG images, an ICO file needs to be
     * given as desktop browser bookmark icon (other file formats may not work in all browsers). The `precomposed`
     * flag defines whether there is already a glow effect contained in the home screen images (or whether iOS
     * should add such an effect). The given structure could look like this: { 'phone':'phone-icon_57x57.png',
     * 'phone@2':'phone-retina_114x114.png', 'tablet':'tablet-icon_72x72.png', 'tablet@2':'tablet-retina_144x144.png',
     * 'precomposed':true, 'favicon':'favicon.ico' }
     *
     * See {@link module:sap/ui/util/Mobile.setIcons} for full documentation.
     *
     *
     * @returns Value of property `homeIcon`
     */
    getHomeIcon(): object;
    /**
     * Gets current value of property {@link #getLogo logo}.
     *
     * Defines the logo to be displayed next to the App when the screen is sufficiently large.
     *
     * Note: If property value isn't set, then the logo address is taken from the theme parameters. For reference
     * please see: {@link sap.ui.core.theming.Parameters}
     *
     *
     * @returns Value of property `logo`
     */
    getLogo(): URI;
    /**
     * Gets current value of property {@link #getShowLogout showLogout}.
     *
     * Determines whether the Logout button should be displayed. Currently, this only happens on very tall screens
     * (1568px height), otherwise, it is always hidden.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showLogout`
     */
    getShowLogout(): boolean;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Defines the application title, which may or may not be displayed outside the actual application, depending
     * on the available screen size.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getTitleLevel titleLevel}.
     *
     * Defines the semantic level of the title.
     *
     * This information is used by assistive technologies, such as screen readers to create a hierarchical site
     * map for faster navigation. Depending on this setting an HTML h1-h6 element is used.
     *
     * Default value is `H1`.
     *
     *
     * @returns Value of property `titleLevel`
     */
    getTitleLevel(): TitleLevel;
    /**
     * Sets the aggregated {@link #getApp app}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setApp(
      /**
       * The app to set
       */
      oApp: Control
    ): this;
    /**
     * Sets a new value for property {@link #getAppWidthLimited appWidthLimited}.
     *
     * Determines whether the width of the content (the aggregated App) should be limited or extended to the
     * full screen width.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAppWidthLimited(
      /**
       * New value for property `appWidthLimited`
       */
      bAppWidthLimited?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundColor backgroundColor}.
     *
     * Defines the background color of the Shell. If set, this color will override the default background defined
     * by the theme. This should only be set when really required. Any configured background image will be placed
     * above this colored background. Use the backgroundRepeat property to define whether this image should
     * be stretched to cover the complete Shell or whether it should be tiled.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.11.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundColor(
      /**
       * New value for property `backgroundColor`
       */
      sBackgroundColor?: CSSColor
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundImage backgroundImage}.
     *
     * Defines the background image of the Shell. If set, this image will override the default background defined
     * by the theme. This should only be set when really required. This background image will be placed above
     * any color set for the background. Use the backgroundRepeat property to define whether this image should
     * be stretched to cover the complete Shell or whether it should be tiled.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.11.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundImage(
      /**
       * New value for property `backgroundImage`
       */
      sBackgroundImage?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundOpacity backgroundOpacity}.
     *
     * Defines the opacity of the background image. The opacity can be set between 0 (fully transparent) and
     * 1 (fully opaque). This can be used to improve readability of the Shell content by making the background
     * image partly transparent.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `1`.
     *
     * @since 1.11.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundOpacity(
      /**
       * New value for property `backgroundOpacity`
       */
      fBackgroundOpacity?: float
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundRepeat backgroundRepeat}.
     *
     * Determines whether the background image (if configured) should be proportionally stretched to cover the
     * whole Shell (false, default) or whether it should be tiled (true). Note: the image will not be displayed
     * when the `sap.m.Shell` content is fully overlapping the `sap.m.Shell` background (e.g. when "appWidthLimited"
     * is set to "false").
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.11.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundRepeat(
      /**
       * New value for property `backgroundRepeat`
       */
      bBackgroundRepeat?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getHeaderRightText headerRightText}.
     *
     * Defines texts, such as the name of the logged-in user, which should be displayed on the right side of
     * the header (if there is enough space to display the header at all - this only happens on very tall screens
     * (1568px height), otherwise, it is always hidden).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeaderRightText(
      /**
       * New value for property `headerRightText`
       */
      sHeaderRightText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getLogo logo}.
     *
     * Defines the logo to be displayed next to the App when the screen is sufficiently large.
     *
     * Note: If property value isn't set, then the logo address is taken from the theme parameters. For reference
     * please see: {@link sap.ui.core.theming.Parameters}
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLogo(
      /**
       * New value for property `logo`
       */
      sLogo?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getShowLogout showLogout}.
     *
     * Determines whether the Logout button should be displayed. Currently, this only happens on very tall screens
     * (1568px height), otherwise, it is always hidden.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowLogout(
      /**
       * New value for property `showLogout`
       */
      bShowLogout?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Defines the application title, which may or may not be displayed outside the actual application, depending
     * on the available screen size.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitleLevel titleLevel}.
     *
     * Defines the semantic level of the title.
     *
     * This information is used by assistive technologies, such as screen readers to create a hierarchical site
     * map for faster navigation. Depending on this setting an HTML h1-h6 element is used.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `H1`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleLevel(
      /**
       * New value for property `titleLevel`
       */
      sTitleLevel?: TitleLevel | keyof typeof TitleLevel
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Shell constructor.
   */
  export interface $ShellSettings extends $ControlSettings {
    /**
     * Defines the application title, which may or may not be displayed outside the actual application, depending
     * on the available screen size.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Defines the logo to be displayed next to the App when the screen is sufficiently large.
     *
     * Note: If property value isn't set, then the logo address is taken from the theme parameters. For reference
     * please see: {@link sap.ui.core.theming.Parameters}
     */
    logo?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the Logout button should be displayed. Currently, this only happens on very tall screens
     * (1568px height), otherwise, it is always hidden.
     */
    showLogout?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines texts, such as the name of the logged-in user, which should be displayed on the right side of
     * the header (if there is enough space to display the header at all - this only happens on very tall screens
     * (1568px height), otherwise, it is always hidden).
     */
    headerRightText?: string | PropertyBindingInfo;

    /**
     * Determines whether the width of the content (the aggregated App) should be limited or extended to the
     * full screen width.
     */
    appWidthLimited?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the background color of the Shell. If set, this color will override the default background defined
     * by the theme. This should only be set when really required. Any configured background image will be placed
     * above this colored background. Use the backgroundRepeat property to define whether this image should
     * be stretched to cover the complete Shell or whether it should be tiled.
     *
     * @since 1.11.2
     */
    backgroundColor?: CSSColor | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the background image of the Shell. If set, this image will override the default background defined
     * by the theme. This should only be set when really required. This background image will be placed above
     * any color set for the background. Use the backgroundRepeat property to define whether this image should
     * be stretched to cover the complete Shell or whether it should be tiled.
     *
     * @since 1.11.2
     */
    backgroundImage?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the background image (if configured) should be proportionally stretched to cover the
     * whole Shell (false, default) or whether it should be tiled (true). Note: the image will not be displayed
     * when the `sap.m.Shell` content is fully overlapping the `sap.m.Shell` background (e.g. when "appWidthLimited"
     * is set to "false").
     *
     * @since 1.11.2
     */
    backgroundRepeat?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the opacity of the background image. The opacity can be set between 0 (fully transparent) and
     * 1 (fully opaque). This can be used to improve readability of the Shell content by making the background
     * image partly transparent.
     *
     * @since 1.11.2
     */
    backgroundOpacity?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * The icon used for the mobile device home screen and the icon to be used for bookmarks by desktop browsers.
     *
     * This property should be only set once, and as early as possible. Subsequent calls replace the previous
     * icon settings and may lead to different behavior depending on the browser.
     *
     * Different image sizes for device home screen need to be given as PNG images, an ICO file needs to be
     * given as desktop browser bookmark icon (other file formats may not work in all browsers). The `precomposed`
     * flag defines whether there is already a glow effect contained in the home screen images (or whether iOS
     * should add such an effect). The given structure could look like this: { 'phone':'phone-icon_57x57.png',
     * 'phone@2':'phone-retina_114x114.png', 'tablet':'tablet-icon_72x72.png', 'tablet@2':'tablet-retina_144x144.png',
     * 'precomposed':true, 'favicon':'favicon.ico' }
     *
     * See {@link module:sap/ui/util/Mobile.setIcons} for full documentation.
     */
    homeIcon?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the semantic level of the title.
     *
     * This information is used by assistive technologies, such as screen readers to create a hierarchical site
     * map for faster navigation. Depending on this setting an HTML h1-h6 element is used.
     */
    titleLevel?:
      | (TitleLevel | keyof typeof TitleLevel)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * A Shell contains an App or a SplitApp (they may be wrapped in a View). Other control types are not allowed.
     */
    app?: Control;

    /**
     * Fires when the user presses the logout button/link.
     */
    logout?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the Shell#logout event.
   */
  export interface Shell$LogoutEventParameters {}

  /**
   * Event object of the Shell#logout event.
   */
  export type Shell$LogoutEvent = Event<Shell$LogoutEventParameters, Shell>;
}

declare module "sap/m/SinglePlanningCalendar" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import CalendarAppointment from "sap/ui/unified/CalendarAppointment";

  import NonWorkingPeriod from "sap/ui/unified/NonWorkingPeriod";

  import DateRange from "sap/ui/unified/DateRange";

  import DateTypeRange from "sap/ui/unified/DateTypeRange";

  import SinglePlanningCalendarView from "sap/m/SinglePlanningCalendarView";

  import Event from "sap/ui/base/Event";

  import CalendarWeekNumbering from "sap/base/i18n/date/CalendarWeekNumbering";

  import {
    SinglePlanningCalendarSelectionMode,
    PlanningCalendarStickyMode,
  } from "sap/m/library";

  import { ID } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import UI5Date from "sap/ui/core/date/UI5Date";

  import PlanningCalendarLegend from "sap/m/PlanningCalendarLegend";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Link from "sap/m/Link";

  /**
   * Displays a calendar of a single entity (such as person, resource) for the selected time interval.
   *
   * Overview:
   *
   * **Note:** The application developer should add dependency to `sap.ui.unified` library on application
   * level to ensure that the library is loaded before the module dependencies will be required. The `SinglePlanningCalendar`
   * uses parts of the `sap.ui.unified` library. This library will be loaded after the `SinglePlanningCalendar`,
   * if it wasn't previously loaded. This could lead to CSP compliance issues and adds an additional waiting
   * time when a `SinglePlanningCalendar` is used for the first time. To prevent this, apps using the `SinglePlanningCalendar`
   * must also load the `sap.ui.unified` library in advance.
   *
   * The `SinglePlanningCalendar` has the following structure:
   *
   *
   * 	A `PlanningCalendarHeader` at the top. It contains the `title` set from the corresponding property,
   * the `SegmentedButton`, which facilitates navigation through the views, controls, passed to the `actions`
   * aggregation and the navigation, assisting the user in choosing the desired time period. The views, either
   * custom or not, can be configured and passed through the `views` aggregation.
   *
   * To create custom views, extend the `SinglePlanningCalendarView` basic view class. It defines three methods
   * that should be overwritten: `getEntityCount`, `getScrollEntityCount` and `calculateStartDate`
   * 	 - `getEntityCount` - returns number of columns to be displayed
   * 	 - `getScrollEntityCount` - used when next and previous arrows in the calendar are used. For example,
   *     in work week view, the `getEntityCount` returns 5 (5 columns from Monday to Friday), but when next arrow
   *     is selected, the control navigates 7 days ahead and `getScrollEntityCount` returns 7.
   * 	 - `calculateStartDate` - calculates the first day displayed in the calendar based on the `startDate`
   *     property of the `SinglePlanningCalendar`. For example, it returns the first date of a month or a week
   *     to display the first 10 days of the month.
   *
   * A `SinglePlanningCalendarGrid` or `SinglePlanningCalendarMonthGrid`, which displays the appointments,
   * set to the visual time range. An all-day appointment is an appointment which starts at 00:00 and ends
   * in 00:00 on any day in the future.
   *
   * @since 1.61
   */
  export default class SinglePlanningCalendar extends Control {
    /**
     * Constructor for a new `SinglePlanningCalendar`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $SinglePlanningCalendarSettings
    );
    /**
     * Constructor for a new `SinglePlanningCalendar`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $SinglePlanningCalendarSettings
    );

    /**
     * Creates a new subclass of class sap.m.SinglePlanningCalendar with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SinglePlanningCalendar>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SinglePlanningCalendar.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some action to the aggregation {@link #getActions actions}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAction(
      /**
       * The action to add; if empty, nothing is inserted
       */
      oAction: Control
    ): this;
    /**
     * Adds some appointment to the aggregation {@link #getAppointments appointments}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAppointment(
      /**
       * The appointment to add; if empty, nothing is inserted
       */
      oAppointment: CalendarAppointment
    ): this;
    /**
     * Adds some nonWorkingPeriod to the aggregation {@link #getNonWorkingPeriods nonWorkingPeriods}.
     *
     * @since 1.128
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addNonWorkingPeriod(
      /**
       * The nonWorkingPeriod to add; if empty, nothing is inserted
       */
      oNonWorkingPeriod: NonWorkingPeriod
    ): this;
    /**
     * Adds a selected date to the grid.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    addSelectedDate(
      /**
       * A DateRange object
       */
      oSelectedDate: DateRange
    ): this;
    /**
     * Adds some specialDate to the aggregation {@link #getSpecialDates specialDates}.
     *
     * @since 1.66
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addSpecialDate(
      /**
       * The specialDate to add; if empty, nothing is inserted
       */
      oSpecialDate: DateTypeRange
    ): this;
    /**
     * Adds some view to the aggregation {@link #getViews views}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addView(
      /**
       * The view to add; if empty, nothing is inserted
       */
      oView: SinglePlanningCalendarView
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:appointmentCreate appointmentCreate} event of
     * this `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * Fired if an appointment is created.
     *
     * @since 1.65
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAppointmentCreate(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$AppointmentCreateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:appointmentCreate appointmentCreate} event of
     * this `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * Fired if an appointment is created.
     *
     * @since 1.65
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAppointmentCreate(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$AppointmentCreateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:appointmentDrop appointmentDrop} event of this
     * `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * Fired if an appointment is dropped.
     *
     * @since 1.64
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAppointmentDrop(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$AppointmentDropEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:appointmentDrop appointmentDrop} event of this
     * `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * Fired if an appointment is dropped.
     *
     * @since 1.64
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAppointmentDrop(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$AppointmentDropEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:appointmentResize appointmentResize} event of
     * this `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * Fired when an appointment is resized.
     *
     * @since 1.65
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAppointmentResize(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$AppointmentResizeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:appointmentResize appointmentResize} event of
     * this `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * Fired when an appointment is resized.
     *
     * @since 1.65
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAppointmentResize(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$AppointmentResizeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:appointmentSelect appointmentSelect} event of
     * this `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * Fired when the selected state of an appointment is changed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAppointmentSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$AppointmentSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:appointmentSelect appointmentSelect} event of
     * this `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * Fired when the selected state of an appointment is changed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAppointmentSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$AppointmentSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cellPress cellPress} event of this `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * Fired when a grid cell is pressed.
     *
     * @since 1.65
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCellPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$CellPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cellPress cellPress} event of this `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * Fired when a grid cell is pressed.
     *
     * @since 1.65
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCellPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$CellPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:headerDateSelect headerDateSelect} event of
     * this `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * Fired if a date is selected in the calendar header.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachHeaderDateSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$HeaderDateSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:headerDateSelect headerDateSelect} event of
     * this `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * Fired if a date is selected in the calendar header.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachHeaderDateSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$HeaderDateSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:moreLinkPress moreLinkPress} event of this `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * Fired when a 'more' button is pressed. **Note:** The 'more' button appears in a month view cell when
     * multiple appointments exist and the available space is not sufficient to display all of them.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachMoreLinkPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$MoreLinkPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:moreLinkPress moreLinkPress} event of this `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * Fired when a 'more' button is pressed. **Note:** The 'more' button appears in a month view cell when
     * multiple appointments exist and the available space is not sufficient to display all of them.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachMoreLinkPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$MoreLinkPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectedDatesChange selectedDatesChange} event
     * of this `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * Fired when the selected dates change. The default behavior can be prevented using the `preventDefault`
     * method.
     *
     * **Note:** If the event is prevented, the changes in the aggregation `selectedDates` will be canceled
     * and it will revert to its previous state.
     *
     * @since 1.123
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectedDatesChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$SelectedDatesChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectedDatesChange selectedDatesChange} event
     * of this `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * Fired when the selected dates change. The default behavior can be prevented using the `preventDefault`
     * method.
     *
     * **Note:** If the event is prevented, the changes in the aggregation `selectedDates` will be canceled
     * and it will revert to its previous state.
     *
     * @since 1.123
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectedDatesChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$SelectedDatesChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:startDateChange startDateChange} event of this
     * `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * `startDate` is changed while navigating in the `SinglePlanningCalendar`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachStartDateChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$StartDateChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:startDateChange startDateChange} event of this
     * `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * `startDate` is changed while navigating in the `SinglePlanningCalendar`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachStartDateChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$StartDateChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:viewChange viewChange} event of this `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * The view was changed by user interaction.
     *
     * @since 1.71.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachViewChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:viewChange viewChange} event of this `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * The view was changed by user interaction.
     *
     * @since 1.71.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachViewChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:weekNumberPress weekNumberPress} event of this
     * `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * Fired when the week number selection changes. If `dateSelectionMode` is `SinglePlanningCalendarSelectionMode.Multiselect`,
     * clicking on the week number will select the corresponding week. If the week has already been selected,
     * clicking the week number will deselect it.
     *
     * @since 1.123
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachWeekNumberPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$WeekNumberPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:weekNumberPress weekNumberPress} event of this
     * `sap.m.SinglePlanningCalendar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SinglePlanningCalendar` itself.
     *
     * Fired when the week number selection changes. If `dateSelectionMode` is `SinglePlanningCalendarSelectionMode.Multiselect`,
     * clicking on the week number will select the corresponding week. If the week has already been selected,
     * clicking the week number will deselect it.
     *
     * @since 1.123
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachWeekNumberPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$WeekNumberPressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SinglePlanningCalendar` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the actions in the aggregation {@link #getActions actions}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyActions(): this;
    /**
     * Destroys all the appointments in the aggregation {@link #getAppointments appointments}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyAppointments(): this;
    /**
     * Destroys all the nonWorkingPeriods in the aggregation {@link #getNonWorkingPeriods nonWorkingPeriods}.
     *
     * @since 1.128
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyNonWorkingPeriods(): this;
    /**
     * Destroys all the selectedDates in the aggregation {@link #getSelectedDates selectedDates}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySelectedDates(): this;
    /**
     * Destroys all the specialDates in the aggregation {@link #getSpecialDates specialDates}.
     *
     * @since 1.66
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySpecialDates(): this;
    /**
     * Destroys all the views in the aggregation {@link #getViews views}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyViews(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:appointmentCreate appointmentCreate} event
     * of this `sap.m.SinglePlanningCalendar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.65
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAppointmentCreate(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$AppointmentCreateEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:appointmentDrop appointmentDrop} event of
     * this `sap.m.SinglePlanningCalendar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.64
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAppointmentDrop(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$AppointmentDropEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:appointmentResize appointmentResize} event
     * of this `sap.m.SinglePlanningCalendar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.65
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAppointmentResize(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$AppointmentResizeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:appointmentSelect appointmentSelect} event
     * of this `sap.m.SinglePlanningCalendar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAppointmentSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$AppointmentSelectEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:cellPress cellPress} event of this `sap.m.SinglePlanningCalendar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.65
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachCellPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$CellPressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:headerDateSelect headerDateSelect} event of
     * this `sap.m.SinglePlanningCalendar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachHeaderDateSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$HeaderDateSelectEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:moreLinkPress moreLinkPress} event of this
     * `sap.m.SinglePlanningCalendar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachMoreLinkPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$MoreLinkPressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:selectedDatesChange selectedDatesChange} event
     * of this `sap.m.SinglePlanningCalendar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.123
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelectedDatesChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$SelectedDatesChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:startDateChange startDateChange} event of
     * this `sap.m.SinglePlanningCalendar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachStartDateChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$StartDateChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:viewChange viewChange} event of this `sap.m.SinglePlanningCalendar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.71.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachViewChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:weekNumberPress weekNumberPress} event of
     * this `sap.m.SinglePlanningCalendar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.123
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachWeekNumberPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SinglePlanningCalendar$WeekNumberPressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:appointmentCreate appointmentCreate} to attached listeners.
     *
     * @since 1.65
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAppointmentCreate(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SinglePlanningCalendar$AppointmentCreateEventParameters
    ): this;
    /**
     * Fires event {@link #event:appointmentDrop appointmentDrop} to attached listeners.
     *
     * @since 1.64
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAppointmentDrop(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SinglePlanningCalendar$AppointmentDropEventParameters
    ): this;
    /**
     * Fires event {@link #event:appointmentResize appointmentResize} to attached listeners.
     *
     * @since 1.65
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAppointmentResize(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SinglePlanningCalendar$AppointmentResizeEventParameters
    ): this;
    /**
     * Fires event {@link #event:appointmentSelect appointmentSelect} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAppointmentSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SinglePlanningCalendar$AppointmentSelectEventParameters
    ): this;
    /**
     * Fires event {@link #event:cellPress cellPress} to attached listeners.
     *
     * @since 1.65
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireCellPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SinglePlanningCalendar$CellPressEventParameters
    ): this;
    /**
     * Fires event {@link #event:headerDateSelect headerDateSelect} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireHeaderDateSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SinglePlanningCalendar$HeaderDateSelectEventParameters
    ): this;
    /**
     * Fires event {@link #event:moreLinkPress moreLinkPress} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireMoreLinkPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SinglePlanningCalendar$MoreLinkPressEventParameters
    ): this;
    /**
     * Fires event {@link #event:selectedDatesChange selectedDatesChange} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @since 1.123
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireSelectedDatesChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SinglePlanningCalendar$SelectedDatesChangeEventParameters
    ): boolean;
    /**
     * Fires event {@link #event:startDateChange startDateChange} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireStartDateChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SinglePlanningCalendar$StartDateChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:viewChange viewChange} to attached listeners.
     *
     * @since 1.71.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireViewChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:weekNumberPress weekNumberPress} to attached listeners.
     *
     * @since 1.123
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireWeekNumberPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SinglePlanningCalendar$WeekNumberPressEventParameters
    ): this;
    /**
     * Gets content of aggregation {@link #getActions actions}.
     *
     * The controls to be passed to the toolbar.
     */
    getActions(): Control[];
    /**
     * Gets content of aggregation {@link #getAppointments appointments}.
     *
     * The appointments to be displayed in the grid. Appointments outside the visible time frame are not rendered.
     * Appointments, longer than a day, will be displayed in all of the affected days. To display an all-day
     * appointment, the appointment must start at 00:00 and end on any day in the future in 00:00h.
     */
    getAppointments(): CalendarAppointment[];
    /**
     * Gets current value of property {@link #getCalendarWeekNumbering calendarWeekNumbering}.
     *
     * If set, the calendar week numbering is used for display. If not set, the calendar week numbering of the
     * global configuration is used. Note: This property should not be used with firstDayOfWeek property.
     *
     * @since 1.110.0
     *
     * @returns Value of property `calendarWeekNumbering`
     */
    getCalendarWeekNumbering(): CalendarWeekNumbering;
    /**
     * Gets current value of property {@link #getDateSelectionMode dateSelectionMode}.
     *
     * Determines whether more than one day will be selectable. **Note:** selecting more than one day is possible
     * with a combination of `Ctrl + mouse click`
     *
     * Default value is `SingleSelect`.
     *
     *
     * @returns Value of property `dateSelectionMode`
     */
    getDateSelectionMode(): SinglePlanningCalendarSelectionMode;
    /**
     * Gets current value of property {@link #getEnableAppointmentsCreate enableAppointmentsCreate}.
     *
     * Determines whether the appointments can be created by dragging on empty cells.
     *
     * See `enableAppointmentsResize` property documentation for the specific points for events snapping.
     *
     * Default value is `false`.
     *
     * @since 1.65
     *
     * @returns Value of property `enableAppointmentsCreate`
     */
    getEnableAppointmentsCreate(): boolean;
    /**
     * Gets current value of property {@link #getEnableAppointmentsDragAndDrop enableAppointmentsDragAndDrop}.
     *
     * Determines whether the appointments in the grid are draggable.
     *
     * The drag and drop interaction is visualized by a placeholder highlighting the area where the appointment
     * can be dropped by the user.
     *
     * **Note:** Additional application-level code will be needed to provide a keyboard alternative to drag
     * and drop mouse interactions. One possible option is by handling {@link sap.m.SinglePlanningCalendar#event:appointmentSelect appointmentSelect }
     * event of the `sap.m.SinglePlanningCalendar`, as shown in the following simplified example:
     *
     *
     * ```javascript
     *
     * 	new sap.m.SinglePlanningCalendar({
     * 		...
     * 		enableAppointmentsDragAndDrop: true,
     * 		...
     * 		appointmentSelect: function(event) {
     * 			// Open edit {@link sap.m.Dialog Dialog} to modify the appointment properties
     * 			new sap.m.Dialog({ ... }).openBy(event.getParameter("appointment"));
     * 		}
     * 	});
     * ```
     *
     *
     * For a complete example, you can check out the following Demokit sample: {@link https://ui5.sap.com/#/entity/sap.m.SinglePlanningCalendar/sample/sap.m.sample.SinglePlanningCalendarCreateApp Single Planning Calendar - Create and Modify Appointments}
     *
     * Default value is `false`.
     *
     * @since 1.64
     *
     * @returns Value of property `enableAppointmentsDragAndDrop`
     */
    getEnableAppointmentsDragAndDrop(): boolean;
    /**
     * Gets current value of property {@link #getEnableAppointmentsResize enableAppointmentsResize}.
     *
     * Determines whether the appointments are resizable.
     *
     * The resize interaction is visualized by making the appointment transparent.
     *
     * The appointment snaps on every interval of 30 minutes. After the resize is finished, the {@link #event:appointmentResize appointmentResize }
     * event is fired, containing the new start and end UI5Date or JavaScript Date objects.
     *
     * **Note:** Additional application-level code will be needed to provide a keyboard alternative to appointments
     * resizing interactions with mouse. It can be done in a similar way as described in the `enableAppointmentsDragAndDrop`
     * property documentation.
     *
     * Default value is `false`.
     *
     * @since 1.65
     *
     * @returns Value of property `enableAppointmentsResize`
     */
    getEnableAppointmentsResize(): boolean;
    /**
     * Gets current value of property {@link #getEndHour endHour}.
     *
     * Determines the end hour of the grid to be shown if the `fullDay` property is set to `false`. Otherwise
     * the next hours are displayed as non-working. The passed hour is considered as 24-hour based.
     *
     * Default value is `24`.
     *
     *
     * @returns Value of property `endHour`
     */
    getEndHour(): int;
    /**
     * Finds the start and end dates in the visible range.
     *
     * @since 1.133
     *
     * @returns returns an object that stores both the start and end date within the currently visible range.
     */
    getFirstAndLastVisibleDates(): Object;
    /**
     * Gets current value of property {@link #getFirstDayOfWeek firstDayOfWeek}.
     *
     * If set, the first day of the displayed week is this day. Valid values are 0 to 6 starting on Sunday.
     * If there is no valid value set, the default of the used locale is used.
     *
     * Note: This property will only have effect in Week view and Month view of the SinglePlanningCalendar,
     * but it wouldn't have effect in WorkWeek view. This property should not be used with the calendarWeekNumbering
     * property.
     *
     * Default value is `-1`.
     *
     * @since 1.98
     *
     * @returns Value of property `firstDayOfWeek`
     */
    getFirstDayOfWeek(): int;
    /**
     * Gets current value of property {@link #getFullDay fullDay}.
     *
     * Determines if all of the hours in a day are displayed. If set to `false`, the hours shown are between
     * the `startHour` and `endHour`.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `fullDay`
     */
    getFullDay(): boolean;
    /**
     * ID of the element which is the current target of the association {@link #getLegend legend}, or `null`.
     *
     * @since 1.65.0
     */
    getLegend(): ID | null;
    /**
     * Gets content of aggregation {@link #getNonWorkingPeriods nonWorkingPeriods}.
     *
     * Sets the provided period to be displayed as a non-working.
     *
     * **Note:** The visualization of non-working periods is present in all views that include hours representation.
     *
     * @since 1.128
     */
    getNonWorkingPeriods(): NonWorkingPeriod[];
    /**
     * Gets current value of property {@link #getScaleFactor scaleFactor}.
     *
     * Determines scale factor for the appointments.
     *
     * Acceptable range is from 1 to 6.
     *
     * Default value is `1`.
     *
     * @since 1.99
     *
     * @returns Value of property `scaleFactor`
     */
    getScaleFactor(): float;
    /**
     * Holds the selected appointments. If no appointments are selected, an empty array is returned.
     *
     * @since 1.62
     *
     * @returns All selected appointments
     */
    getSelectedAppointments(): CalendarAppointment[];
    /**
     * Gets the selected dates of the grid.
     *
     *
     * @returns An array of DateRange objects
     */
    getSelectedDates(): DateRange[];
    /**
     * ID of the element which is the current target of the association {@link #getSelectedView selectedView},
     * or `null`.
     */
    getSelectedView(): ID | null;
    /**
     * Gets content of aggregation {@link #getSpecialDates specialDates}.
     *
     * Special days in the header visualized as a date range with type.
     *
     * **Note:** In case there are multiple `sap.ui.unified.DateTypeRange` instances given for a single date,
     * only the first `sap.ui.unified.DateTypeRange` instance will be used. For example, using the following
     * sample, the 1st of November will be displayed as a working day of type "Type10":
     *
     *
     * ```javascript
     *
     * 	new DateTypeRange({
     * 		startDate: UI5Date.getInstance(2023, 10, 1),
     * 		type: CalendarDayType.Type10,
     * 	}),
     * 	new DateTypeRange({
     * 		startDate: UI5Date.getInstance(2023, 10, 1),
     * 		type: CalendarDayType.NonWorking
     * 	})
     * 	```
     *
     *
     * If you want the first of November to be displayed as a non-working day and also as "Type10," the following
     * should be done:
     * ```javascript
     *
     * 	new DateTypeRange({
     * 		startDate: UI5Date.getInstance(2023, 10, 1),
     * 		type: CalendarDayType.Type10,
     * 		secondaryType: CalendarDayType.NonWorking
     * 	})
     * 	```
     *
     *
     * You can use only one of the following types for a given date: `sap.ui.unified.CalendarDayType.NonWorking`,
     * `sap.ui.unified.CalendarDayType.Working` or `sap.ui.unified.CalendarDayType.None`. Assigning more than
     * one of these values in combination for the same date will lead to unpredictable results.
     *
     * @since 1.66
     */
    getSpecialDates(): DateTypeRange[];
    /**
     * Gets current value of property `startDate`.
     *
     *
     * @returns The startDate as a UI5Date or JavaScript Date object
     */
    getStartDate(): Date | UI5Date;
    /**
     * Gets current value of property {@link #getStartHour startHour}.
     *
     * Determines the start hour of the grid to be shown if the `fullDay` property is set to `false`. Otherwise
     * the previous hours are displayed as non-working. The passed hour is considered as 24-hour based.
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `startHour`
     */
    getStartHour(): int;
    /**
     * Gets current value of property {@link #getStickyMode stickyMode}.
     *
     * Determines which part of the control will remain fixed at the top of the page during vertical scrolling
     * as long as the control is in the viewport.
     *
     * **Note:** Limited browser support. Browsers which do not support this feature:
     * 	 - Microsoft Internet Explorer
     * 	 - Microsoft Edge lower than version 41 (EdgeHTML 16)
     * 	 - Mozilla Firefox lower than version 59
     *
     * Default value is `None`.
     *
     * @since 1.62
     *
     * @returns Value of property `stickyMode`
     */
    getStickyMode(): PlanningCalendarStickyMode;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Determines the title of the `SinglePlanningCalendar`.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Finds the view object by given key.
     *
     * @since 1.75
     *
     * @returns the view object which matched the given `sKey`, or `null` if there is no such view
     */
    getViewByKey(
      /**
       * The key of the view
       */
      sKey: string
    ): SinglePlanningCalendarView | null;
    /**
     * Gets content of aggregation {@link #getViews views}.
     *
     * Views of the `SinglePlanningCalendar`.
     *
     * **Note:** If not set, the Week view is available.
     */
    getViews(): SinglePlanningCalendarView[];
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getActions actions}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfAction(
      /**
       * The action whose index is looked for
       */
      oAction: Control
    ): int;
    /**
     * Checks for the provided `sap.ui.unified.CalendarAppointment` in the aggregation {@link #getAppointments appointments}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfAppointment(
      /**
       * The appointment whose index is looked for
       */
      oAppointment: CalendarAppointment
    ): int;
    /**
     * Checks for the provided `sap.ui.unified.NonWorkingPeriod` in the aggregation {@link #getNonWorkingPeriods nonWorkingPeriods}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.128
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfNonWorkingPeriod(
      /**
       * The nonWorkingPeriod whose index is looked for
       */
      oNonWorkingPeriod: NonWorkingPeriod
    ): int;
    /**
     * Checks for the provided `sap.ui.unified.DateRange` in the aggregation {@link #getSelectedDates selectedDates}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfSelectedDate(
      /**
       * The selectedDate whose index is looked for
       */
      oSelectedDate: DateRange
    ): int;
    /**
     * Checks for the provided `sap.ui.unified.DateTypeRange` in the aggregation {@link #getSpecialDates specialDates}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.66
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfSpecialDate(
      /**
       * The specialDate whose index is looked for
       */
      oSpecialDate: DateTypeRange
    ): int;
    /**
     * Checks for the provided `sap.m.SinglePlanningCalendarView` in the aggregation {@link #getViews views}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfView(
      /**
       * The view whose index is looked for
       */
      oView: SinglePlanningCalendarView
    ): int;
    /**
     * Inserts a action into the aggregation {@link #getActions actions}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertAction(
      /**
       * The action to insert; if empty, nothing is inserted
       */
      oAction: Control,
      /**
       * The `0`-based index the action should be inserted at; for a negative value of `iIndex`, the action is
       * inserted at position 0; for a value greater than the current size of the aggregation, the action is inserted
       * at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a appointment into the aggregation {@link #getAppointments appointments}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertAppointment(
      /**
       * The appointment to insert; if empty, nothing is inserted
       */
      oAppointment: CalendarAppointment,
      /**
       * The `0`-based index the appointment should be inserted at; for a negative value of `iIndex`, the appointment
       * is inserted at position 0; for a value greater than the current size of the aggregation, the appointment
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a nonWorkingPeriod into the aggregation {@link #getNonWorkingPeriods nonWorkingPeriods}.
     *
     * @since 1.128
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertNonWorkingPeriod(
      /**
       * The nonWorkingPeriod to insert; if empty, nothing is inserted
       */
      oNonWorkingPeriod: NonWorkingPeriod,
      /**
       * The `0`-based index the nonWorkingPeriod should be inserted at; for a negative value of `iIndex`, the
       * nonWorkingPeriod is inserted at position 0; for a value greater than the current size of the aggregation,
       * the nonWorkingPeriod is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a selectedDate into the aggregation {@link #getSelectedDates selectedDates}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertSelectedDate(
      /**
       * The selectedDate to insert; if empty, nothing is inserted
       */
      oSelectedDate: DateRange,
      /**
       * The `0`-based index the selectedDate should be inserted at; for a negative value of `iIndex`, the selectedDate
       * is inserted at position 0; for a value greater than the current size of the aggregation, the selectedDate
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a specialDate into the aggregation {@link #getSpecialDates specialDates}.
     *
     * @since 1.66
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertSpecialDate(
      /**
       * The specialDate to insert; if empty, nothing is inserted
       */
      oSpecialDate: DateTypeRange,
      /**
       * The `0`-based index the specialDate should be inserted at; for a negative value of `iIndex`, the specialDate
       * is inserted at position 0; for a value greater than the current size of the aggregation, the specialDate
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a view into the aggregation {@link #getViews views}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertView(
      /**
       * The view to insert; if empty, nothing is inserted
       */
      oView: SinglePlanningCalendarView,
      /**
       * The `0`-based index the view should be inserted at; for a negative value of `iIndex`, the view is inserted
       * at position 0; for a value greater than the current size of the aggregation, the view is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes a action from the aggregation {@link #getActions actions}.
     *
     *
     * @returns The removed action or `null`
     */
    removeAction(
      /**
       * The action to remove or its index or id
       */
      vAction: int | string | Control
    ): Control | null;
    /**
     * Removes all the controls from the aggregation {@link #getActions actions}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllActions(): Control[];
    /**
     * Removes all the controls from the aggregation {@link #getAppointments appointments}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAppointments(): CalendarAppointment[];
    /**
     * Removes all the controls from the aggregation {@link #getNonWorkingPeriods nonWorkingPeriods}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.128
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllNonWorkingPeriods(): NonWorkingPeriod[];
    /**
     * Removes the selected dates of the grid.
     *
     *
     * @returns An array of the removed DateRange objects
     */
    removeAllSelectedDates(): DateRange[];
    /**
     * Removes all the controls from the aggregation {@link #getSpecialDates specialDates}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.66
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllSpecialDates(): DateTypeRange[];
    /**
     * Removes all the controls from the aggregation {@link #getViews views}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllViews(): SinglePlanningCalendarView[];
    /**
     * Removes a appointment from the aggregation {@link #getAppointments appointments}.
     *
     *
     * @returns The removed appointment or `null`
     */
    removeAppointment(
      /**
       * The appointment to remove or its index or id
       */
      vAppointment: int | string | CalendarAppointment
    ): CalendarAppointment | null;
    /**
     * Removes a nonWorkingPeriod from the aggregation {@link #getNonWorkingPeriods nonWorkingPeriods}.
     *
     * @since 1.128
     *
     * @returns The removed nonWorkingPeriod or `null`
     */
    removeNonWorkingPeriod(
      /**
       * The nonWorkingPeriod to remove or its index or id
       */
      vNonWorkingPeriod: int | string | NonWorkingPeriod
    ): NonWorkingPeriod | null;
    /**
     * Removes a selectedDate from the aggregation {@link #getSelectedDates selectedDates}.
     *
     *
     * @returns The removed selectedDate or `null`
     */
    removeSelectedDate(
      /**
       * The selectedDate to remove or its index or id
       */
      vSelectedDate: int | string | DateRange
    ): DateRange | null;
    /**
     * Removes a specialDate from the aggregation {@link #getSpecialDates specialDates}.
     *
     * @since 1.66
     *
     * @returns The removed specialDate or `null`
     */
    removeSpecialDate(
      /**
       * The specialDate to remove or its index or id
       */
      vSpecialDate: int | string | DateTypeRange
    ): DateTypeRange | null;
    /**
     * Removes a view from the aggregation {@link #getViews views}.
     *
     *
     * @returns The removed view or `null`
     */
    removeView(
      /**
       * The view to remove or its index or id
       */
      vView: int | string | SinglePlanningCalendarView
    ): SinglePlanningCalendarView | null;
    /**
     * Sets a new value for property {@link #getCalendarWeekNumbering calendarWeekNumbering}.
     *
     * If set, the calendar week numbering is used for display. If not set, the calendar week numbering of the
     * global configuration is used. Note: This property should not be used with firstDayOfWeek property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.110.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCalendarWeekNumbering(
      /**
       * New value for property `calendarWeekNumbering`
       */
      sCalendarWeekNumbering?:
        | CalendarWeekNumbering
        | keyof typeof CalendarWeekNumbering
    ): this;
    /**
     * Sets a new value for property {@link #getDateSelectionMode dateSelectionMode}.
     *
     * Determines whether more than one day will be selectable. **Note:** selecting more than one day is possible
     * with a combination of `Ctrl + mouse click`
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `SingleSelect`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDateSelectionMode(
      /**
       * New value for property `dateSelectionMode`
       */
      sDateSelectionMode?:
        | SinglePlanningCalendarSelectionMode
        | keyof typeof SinglePlanningCalendarSelectionMode
    ): this;
    /**
     * Sets a new value for property {@link #getEnableAppointmentsCreate enableAppointmentsCreate}.
     *
     * Determines whether the appointments can be created by dragging on empty cells.
     *
     * See `enableAppointmentsResize` property documentation for the specific points for events snapping.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.65
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableAppointmentsCreate(
      /**
       * New value for property `enableAppointmentsCreate`
       */
      bEnableAppointmentsCreate?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnableAppointmentsDragAndDrop enableAppointmentsDragAndDrop}.
     *
     * Determines whether the appointments in the grid are draggable.
     *
     * The drag and drop interaction is visualized by a placeholder highlighting the area where the appointment
     * can be dropped by the user.
     *
     * **Note:** Additional application-level code will be needed to provide a keyboard alternative to drag
     * and drop mouse interactions. One possible option is by handling {@link sap.m.SinglePlanningCalendar#event:appointmentSelect appointmentSelect }
     * event of the `sap.m.SinglePlanningCalendar`, as shown in the following simplified example:
     *
     *
     * ```javascript
     *
     * 	new sap.m.SinglePlanningCalendar({
     * 		...
     * 		enableAppointmentsDragAndDrop: true,
     * 		...
     * 		appointmentSelect: function(event) {
     * 			// Open edit {@link sap.m.Dialog Dialog} to modify the appointment properties
     * 			new sap.m.Dialog({ ... }).openBy(event.getParameter("appointment"));
     * 		}
     * 	});
     * ```
     *
     *
     * For a complete example, you can check out the following Demokit sample: {@link https://ui5.sap.com/#/entity/sap.m.SinglePlanningCalendar/sample/sap.m.sample.SinglePlanningCalendarCreateApp Single Planning Calendar - Create and Modify Appointments}
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.64
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableAppointmentsDragAndDrop(
      /**
       * New value for property `enableAppointmentsDragAndDrop`
       */
      bEnableAppointmentsDragAndDrop?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnableAppointmentsResize enableAppointmentsResize}.
     *
     * Determines whether the appointments are resizable.
     *
     * The resize interaction is visualized by making the appointment transparent.
     *
     * The appointment snaps on every interval of 30 minutes. After the resize is finished, the {@link #event:appointmentResize appointmentResize }
     * event is fired, containing the new start and end UI5Date or JavaScript Date objects.
     *
     * **Note:** Additional application-level code will be needed to provide a keyboard alternative to appointments
     * resizing interactions with mouse. It can be done in a similar way as described in the `enableAppointmentsDragAndDrop`
     * property documentation.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.65
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableAppointmentsResize(
      /**
       * New value for property `enableAppointmentsResize`
       */
      bEnableAppointmentsResize?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEndHour endHour}.
     *
     * Determines the end hour of the grid to be shown if the `fullDay` property is set to `false`. Otherwise
     * the next hours are displayed as non-working. The passed hour is considered as 24-hour based.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `24`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEndHour(
      /**
       * New value for property `endHour`
       */
      iEndHour?: int
    ): this;
    /**
     * Sets a new value for property {@link #getFirstDayOfWeek firstDayOfWeek}.
     *
     * If set, the first day of the displayed week is this day. Valid values are 0 to 6 starting on Sunday.
     * If there is no valid value set, the default of the used locale is used.
     *
     * Note: This property will only have effect in Week view and Month view of the SinglePlanningCalendar,
     * but it wouldn't have effect in WorkWeek view. This property should not be used with the calendarWeekNumbering
     * property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `-1`.
     *
     * @since 1.98
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFirstDayOfWeek(
      /**
       * New value for property `firstDayOfWeek`
       */
      iFirstDayOfWeek?: int
    ): this;
    /**
     * Sets a new value for property {@link #getFullDay fullDay}.
     *
     * Determines if all of the hours in a day are displayed. If set to `false`, the hours shown are between
     * the `startHour` and `endHour`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFullDay(
      /**
       * New value for property `fullDay`
       */
      bFullDay?: boolean
    ): this;
    /**
     * Sets the associated {@link #getLegend legend}.
     *
     * @since 1.65.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLegend(
      /**
       * ID of an element which becomes the new target of this legend association; alternatively, an element instance
       * may be given
       */
      oLegend: ID | PlanningCalendarLegend
    ): this;
    /**
     * Sets a new value for property {@link #getScaleFactor scaleFactor}.
     *
     * Determines scale factor for the appointments.
     *
     * Acceptable range is from 1 to 6.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `1`.
     *
     * @since 1.99
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setScaleFactor(
      /**
       * New value for property `scaleFactor`
       */
      fScaleFactor?: float
    ): this;
    /**
     * Sets the associated {@link #getSelectedView selectedView}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSelectedView(
      /**
       * ID of an element which becomes the new target of this selectedView association; alternatively, an element
       * instance may be given
       */
      oSelectedView: ID | SinglePlanningCalendarView
    ): this;
    /**
     * Sets the start date of the grid.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setStartDate(
      /**
       * A date instance
       */
      oDate: Date | UI5Date
    ): this;
    /**
     * Sets a new value for property {@link #getStartHour startHour}.
     *
     * Determines the start hour of the grid to be shown if the `fullDay` property is set to `false`. Otherwise
     * the previous hours are displayed as non-working. The passed hour is considered as 24-hour based.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setStartHour(
      /**
       * New value for property `startHour`
       */
      iStartHour?: int
    ): this;
    /**
     * Sets a new value for property {@link #getStickyMode stickyMode}.
     *
     * Determines which part of the control will remain fixed at the top of the page during vertical scrolling
     * as long as the control is in the viewport.
     *
     * **Note:** Limited browser support. Browsers which do not support this feature:
     * 	 - Microsoft Internet Explorer
     * 	 - Microsoft Edge lower than version 41 (EdgeHTML 16)
     * 	 - Mozilla Firefox lower than version 59
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     * @since 1.62
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setStickyMode(
      /**
       * New value for property `stickyMode`
       */
      sStickyMode?:
        | PlanningCalendarStickyMode
        | keyof typeof PlanningCalendarStickyMode
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Determines the title of the `SinglePlanningCalendar`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the SinglePlanningCalendar constructor.
   */
  export interface $SinglePlanningCalendarSettings extends $ControlSettings {
    /**
     * Determines the title of the `SinglePlanningCalendar`.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Determines the start date of the grid, as a UI5Date or JavaScript Date object. It is considered as a
     * local date. The time part will be ignored. The current date is used as default.
     */
    startDate?: object | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the start hour of the grid to be shown if the `fullDay` property is set to `false`. Otherwise
     * the previous hours are displayed as non-working. The passed hour is considered as 24-hour based.
     */
    startHour?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the end hour of the grid to be shown if the `fullDay` property is set to `false`. Otherwise
     * the next hours are displayed as non-working. The passed hour is considered as 24-hour based.
     */
    endHour?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines if all of the hours in a day are displayed. If set to `false`, the hours shown are between
     * the `startHour` and `endHour`.
     */
    fullDay?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines which part of the control will remain fixed at the top of the page during vertical scrolling
     * as long as the control is in the viewport.
     *
     * **Note:** Limited browser support. Browsers which do not support this feature:
     * 	 - Microsoft Internet Explorer
     * 	 - Microsoft Edge lower than version 41 (EdgeHTML 16)
     * 	 - Mozilla Firefox lower than version 59
     *
     * @since 1.62
     */
    stickyMode?:
      | (PlanningCalendarStickyMode | keyof typeof PlanningCalendarStickyMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines scale factor for the appointments.
     *
     * Acceptable range is from 1 to 6.
     *
     * @since 1.99
     */
    scaleFactor?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the appointments in the grid are draggable.
     *
     * The drag and drop interaction is visualized by a placeholder highlighting the area where the appointment
     * can be dropped by the user.
     *
     * **Note:** Additional application-level code will be needed to provide a keyboard alternative to drag
     * and drop mouse interactions. One possible option is by handling {@link sap.m.SinglePlanningCalendar#event:appointmentSelect appointmentSelect }
     * event of the `sap.m.SinglePlanningCalendar`, as shown in the following simplified example:
     *
     *
     * ```javascript
     *
     * 	new sap.m.SinglePlanningCalendar({
     * 		...
     * 		enableAppointmentsDragAndDrop: true,
     * 		...
     * 		appointmentSelect: function(event) {
     * 			// Open edit {@link sap.m.Dialog Dialog} to modify the appointment properties
     * 			new sap.m.Dialog({ ... }).openBy(event.getParameter("appointment"));
     * 		}
     * 	});
     * ```
     *
     *
     * For a complete example, you can check out the following Demokit sample: {@link https://ui5.sap.com/#/entity/sap.m.SinglePlanningCalendar/sample/sap.m.sample.SinglePlanningCalendarCreateApp Single Planning Calendar - Create and Modify Appointments}
     *
     * @since 1.64
     */
    enableAppointmentsDragAndDrop?:
      | boolean
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines whether the appointments are resizable.
     *
     * The resize interaction is visualized by making the appointment transparent.
     *
     * The appointment snaps on every interval of 30 minutes. After the resize is finished, the {@link #event:appointmentResize appointmentResize }
     * event is fired, containing the new start and end UI5Date or JavaScript Date objects.
     *
     * **Note:** Additional application-level code will be needed to provide a keyboard alternative to appointments
     * resizing interactions with mouse. It can be done in a similar way as described in the `enableAppointmentsDragAndDrop`
     * property documentation.
     *
     * @since 1.65
     */
    enableAppointmentsResize?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the appointments can be created by dragging on empty cells.
     *
     * See `enableAppointmentsResize` property documentation for the specific points for events snapping.
     *
     * @since 1.65
     */
    enableAppointmentsCreate?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * If set, the first day of the displayed week is this day. Valid values are 0 to 6 starting on Sunday.
     * If there is no valid value set, the default of the used locale is used.
     *
     * Note: This property will only have effect in Week view and Month view of the SinglePlanningCalendar,
     * but it wouldn't have effect in WorkWeek view. This property should not be used with the calendarWeekNumbering
     * property.
     *
     * @since 1.98
     */
    firstDayOfWeek?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * If set, the calendar week numbering is used for display. If not set, the calendar week numbering of the
     * global configuration is used. Note: This property should not be used with firstDayOfWeek property.
     *
     * @since 1.110.0
     */
    calendarWeekNumbering?:
      | (CalendarWeekNumbering | keyof typeof CalendarWeekNumbering)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines whether more than one day will be selectable. **Note:** selecting more than one day is possible
     * with a combination of `Ctrl + mouse click`
     */
    dateSelectionMode?:
      | (
          | SinglePlanningCalendarSelectionMode
          | keyof typeof SinglePlanningCalendarSelectionMode
        )
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The controls to be passed to the toolbar.
     */
    actions?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * The appointments to be displayed in the grid. Appointments outside the visible time frame are not rendered.
     * Appointments, longer than a day, will be displayed in all of the affected days. To display an all-day
     * appointment, the appointment must start at 00:00 and end on any day in the future in 00:00h.
     */
    appointments?:
      | CalendarAppointment[]
      | CalendarAppointment
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Sets the provided period to be displayed as a non-working.
     *
     * **Note:** The visualization of non-working periods is present in all views that include hours representation.
     *
     * @since 1.128
     */
    nonWorkingPeriods?:
      | NonWorkingPeriod[]
      | NonWorkingPeriod
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Views of the `SinglePlanningCalendar`.
     *
     * **Note:** If not set, the Week view is available.
     */
    views?:
      | SinglePlanningCalendarView[]
      | SinglePlanningCalendarView
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Special days in the header visualized as a date range with type.
     *
     * **Note:** In case there are multiple `sap.ui.unified.DateTypeRange` instances given for a single date,
     * only the first `sap.ui.unified.DateTypeRange` instance will be used. For example, using the following
     * sample, the 1st of November will be displayed as a working day of type "Type10":
     *
     *
     * ```javascript
     *
     * 	new DateTypeRange({
     * 		startDate: UI5Date.getInstance(2023, 10, 1),
     * 		type: CalendarDayType.Type10,
     * 	}),
     * 	new DateTypeRange({
     * 		startDate: UI5Date.getInstance(2023, 10, 1),
     * 		type: CalendarDayType.NonWorking
     * 	})
     * 	```
     *
     *
     * If you want the first of November to be displayed as a non-working day and also as "Type10," the following
     * should be done:
     * ```javascript
     *
     * 	new DateTypeRange({
     * 		startDate: UI5Date.getInstance(2023, 10, 1),
     * 		type: CalendarDayType.Type10,
     * 		secondaryType: CalendarDayType.NonWorking
     * 	})
     * 	```
     *
     *
     * You can use only one of the following types for a given date: `sap.ui.unified.CalendarDayType.NonWorking`,
     * `sap.ui.unified.CalendarDayType.Working` or `sap.ui.unified.CalendarDayType.None`. Assigning more than
     * one of these values in combination for the same date will lead to unpredictable results.
     *
     * @since 1.66
     */
    specialDates?:
      | DateTypeRange[]
      | DateTypeRange
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Dates or date ranges for selected dates.
     *
     * To set a single date (instead of a range), set only the `startDate` property of the {@link sap.ui.unified.DateRange }
     * class.
     */
    selectedDates?:
      | DateRange[]
      | DateRange
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Corresponds to the currently selected view.
     */
    selectedView?: SinglePlanningCalendarView | string;

    /**
     * Association to the `PlanningCalendarLegend` explaining the colors of the `Appointments`.
     *
     * **Note:** The legend does not have to be rendered but must exist and all required types must be assigned.
     *
     * @since 1.65.0
     */
    legend?: PlanningCalendarLegend | string;

    /**
     * Fired when the selected state of an appointment is changed.
     */
    appointmentSelect?: (
      oEvent: SinglePlanningCalendar$AppointmentSelectEvent
    ) => void;

    /**
     * Fired if an appointment is dropped.
     *
     * @since 1.64
     */
    appointmentDrop?: (
      oEvent: SinglePlanningCalendar$AppointmentDropEvent
    ) => void;

    /**
     * Fired when an appointment is resized.
     *
     * @since 1.65
     */
    appointmentResize?: (
      oEvent: SinglePlanningCalendar$AppointmentResizeEvent
    ) => void;

    /**
     * Fired if an appointment is created.
     *
     * @since 1.65
     */
    appointmentCreate?: (
      oEvent: SinglePlanningCalendar$AppointmentCreateEvent
    ) => void;

    /**
     * Fired if a date is selected in the calendar header.
     */
    headerDateSelect?: (
      oEvent: SinglePlanningCalendar$HeaderDateSelectEvent
    ) => void;

    /**
     * `startDate` is changed while navigating in the `SinglePlanningCalendar`.
     */
    startDateChange?: (
      oEvent: SinglePlanningCalendar$StartDateChangeEvent
    ) => void;

    /**
     * Fired when a grid cell is pressed.
     *
     * @since 1.65
     */
    cellPress?: (oEvent: SinglePlanningCalendar$CellPressEvent) => void;

    /**
     * Fired when a 'more' button is pressed. **Note:** The 'more' button appears in a month view cell when
     * multiple appointments exist and the available space is not sufficient to display all of them.
     */
    moreLinkPress?: (oEvent: SinglePlanningCalendar$MoreLinkPressEvent) => void;

    /**
     * The view was changed by user interaction.
     *
     * @since 1.71.0
     */
    viewChange?: (oEvent: Event) => void;

    /**
     * Fired when the week number selection changes. If `dateSelectionMode` is `SinglePlanningCalendarSelectionMode.Multiselect`,
     * clicking on the week number will select the corresponding week. If the week has already been selected,
     * clicking the week number will deselect it.
     *
     * @since 1.123
     */
    weekNumberPress?: (
      oEvent: SinglePlanningCalendar$WeekNumberPressEvent
    ) => void;

    /**
     * Fired when the selected dates change. The default behavior can be prevented using the `preventDefault`
     * method.
     *
     * **Note:** If the event is prevented, the changes in the aggregation `selectedDates` will be canceled
     * and it will revert to its previous state.
     *
     * @since 1.123
     */
    selectedDatesChange?: (
      oEvent: SinglePlanningCalendar$SelectedDatesChangeEvent
    ) => void;
  }

  /**
   * Parameters of the SinglePlanningCalendar#appointmentCreate event.
   */
  export interface SinglePlanningCalendar$AppointmentCreateEventParameters {
    /**
     * Start date of the created appointment, as a UI5Date or JavaScript Date object.
     */
    startDate?: object;

    /**
     * End date of the created appointment, as a UI5Date or JavaScript Date object.
     */
    endDate?: object;
  }

  /**
   * Event object of the SinglePlanningCalendar#appointmentCreate event.
   */
  export type SinglePlanningCalendar$AppointmentCreateEvent = Event<
    SinglePlanningCalendar$AppointmentCreateEventParameters,
    SinglePlanningCalendar
  >;

  /**
   * Parameters of the SinglePlanningCalendar#appointmentDrop event.
   */
  export interface SinglePlanningCalendar$AppointmentDropEventParameters {
    /**
     * The dropped appointment.
     */
    appointment?: CalendarAppointment;

    /**
     * Start date of the dropped appointment, as a UI5Date or JavaScript Date object.
     */
    startDate?: object;

    /**
     * Dropped appointment end date as a UI5Date or JavaScript Date object.
     */
    endDate?: object;

    /**
     * The drop type. If true - it's "Copy", if false - it's "Move".
     */
    copy?: boolean;
  }

  /**
   * Event object of the SinglePlanningCalendar#appointmentDrop event.
   */
  export type SinglePlanningCalendar$AppointmentDropEvent = Event<
    SinglePlanningCalendar$AppointmentDropEventParameters,
    SinglePlanningCalendar
  >;

  /**
   * Parameters of the SinglePlanningCalendar#appointmentResize event.
   */
  export interface SinglePlanningCalendar$AppointmentResizeEventParameters {
    /**
     * The resized appointment.
     */
    appointment?: CalendarAppointment;

    /**
     * Start date of the resized appointment, as a UI5Date or JavaScript Date object.
     */
    startDate?: object;

    /**
     * End date of the resized appointment, as a UI5Date or JavaScript Date object.
     */
    endDate?: object;
  }

  /**
   * Event object of the SinglePlanningCalendar#appointmentResize event.
   */
  export type SinglePlanningCalendar$AppointmentResizeEvent = Event<
    SinglePlanningCalendar$AppointmentResizeEventParameters,
    SinglePlanningCalendar
  >;

  /**
   * Parameters of the SinglePlanningCalendar#appointmentSelect event.
   */
  export interface SinglePlanningCalendar$AppointmentSelectEventParameters {
    /**
     * The appointment on which the event was triggered.
     */
    appointment?: CalendarAppointment;

    /**
     * All appointments with changed selected state.
     */
    appointments?: CalendarAppointment[];
  }

  /**
   * Event object of the SinglePlanningCalendar#appointmentSelect event.
   */
  export type SinglePlanningCalendar$AppointmentSelectEvent = Event<
    SinglePlanningCalendar$AppointmentSelectEventParameters,
    SinglePlanningCalendar
  >;

  /**
   * Parameters of the SinglePlanningCalendar#cellPress event.
   */
  export interface SinglePlanningCalendar$CellPressEventParameters {
    /**
     * The start date as a UI5Date or JavaScript Date object of the focused grid cell.
     */
    startDate?: object;

    /**
     * The end date as a UI5Date or JavaScript Date object of the focused grid cell.
     */
    endDate?: object;
  }

  /**
   * Event object of the SinglePlanningCalendar#cellPress event.
   */
  export type SinglePlanningCalendar$CellPressEvent = Event<
    SinglePlanningCalendar$CellPressEventParameters,
    SinglePlanningCalendar
  >;

  /**
   * Parameters of the SinglePlanningCalendar#headerDateSelect event.
   */
  export interface SinglePlanningCalendar$HeaderDateSelectEventParameters {
    /**
     * Date of the selected header, as a UI5Date or JavaScript Date object. It is considered as a local date.
     */
    date?: object;
  }

  /**
   * Event object of the SinglePlanningCalendar#headerDateSelect event.
   */
  export type SinglePlanningCalendar$HeaderDateSelectEvent = Event<
    SinglePlanningCalendar$HeaderDateSelectEventParameters,
    SinglePlanningCalendar
  >;

  /**
   * Parameters of the SinglePlanningCalendar#moreLinkPress event.
   */
  export interface SinglePlanningCalendar$MoreLinkPressEventParameters {
    /**
     * The date as a UI5Date or JavaScript Date object of the cell with the pressed more link.
     */
    date?: object;

    /**
     * The link that has been triggered
     */
    sourceLink?: Link;
  }

  /**
   * Event object of the SinglePlanningCalendar#moreLinkPress event.
   */
  export type SinglePlanningCalendar$MoreLinkPressEvent = Event<
    SinglePlanningCalendar$MoreLinkPressEventParameters,
    SinglePlanningCalendar
  >;

  /**
   * Parameters of the SinglePlanningCalendar#selectedDatesChange event.
   */
  export interface SinglePlanningCalendar$SelectedDatesChangeEventParameters {
    /**
     * The array of all selected days.
     */
    selectedDates?: DateRange[];
  }

  /**
   * Event object of the SinglePlanningCalendar#selectedDatesChange event.
   */
  export type SinglePlanningCalendar$SelectedDatesChangeEvent = Event<
    SinglePlanningCalendar$SelectedDatesChangeEventParameters,
    SinglePlanningCalendar
  >;

  /**
   * Parameters of the SinglePlanningCalendar#startDateChange event.
   */
  export interface SinglePlanningCalendar$StartDateChangeEventParameters {
    /**
     * The new start date, as a UI5Date or JavaScript Date object. It is considered as a local date.
     */
    date?: object;
  }

  /**
   * Event object of the SinglePlanningCalendar#startDateChange event.
   */
  export type SinglePlanningCalendar$StartDateChangeEvent = Event<
    SinglePlanningCalendar$StartDateChangeEventParameters,
    SinglePlanningCalendar
  >;

  /**
   * Parameters of the SinglePlanningCalendar#viewChange event.
   */
  export interface SinglePlanningCalendar$ViewChangeEventParameters {}

  /**
   * Event object of the SinglePlanningCalendar#viewChange event.
   */
  export type SinglePlanningCalendar$ViewChangeEvent = Event<
    SinglePlanningCalendar$ViewChangeEventParameters,
    SinglePlanningCalendar
  >;

  /**
   * Parameters of the SinglePlanningCalendar#weekNumberPress event.
   */
  export interface SinglePlanningCalendar$WeekNumberPressEventParameters {
    /**
     * Тhe number of the pressed calendar week.
     */
    weekNumber?: int;
  }

  /**
   * Event object of the SinglePlanningCalendar#weekNumberPress event.
   */
  export type SinglePlanningCalendar$WeekNumberPressEvent = Event<
    SinglePlanningCalendar$WeekNumberPressEventParameters,
    SinglePlanningCalendar
  >;
}

declare module "sap/m/SinglePlanningCalendarDayView" {
  import {
    default as SinglePlanningCalendarView,
    $SinglePlanningCalendarViewSettings,
  } from "sap/m/SinglePlanningCalendarView";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * Represents a day view of the {@link sap.m.SinglePlanningCalendar}. The purpose of the element is to decouple
   * the view logic from parent control `SinglePlanningCalendar`.
   *
   * @since 1.61
   */
  export default class SinglePlanningCalendarDayView extends SinglePlanningCalendarView {
    /**
     * Constructor for a new `SinglePlanningCalendarDayView`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.SinglePlanningCalendarView#constructor sap.m.SinglePlanningCalendarView }
     * can be used.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SinglePlanningCalendarDayViewSettings
    );
    /**
     * Constructor for a new `SinglePlanningCalendarDayView`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.SinglePlanningCalendarView#constructor sap.m.SinglePlanningCalendarView }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SinglePlanningCalendarDayViewSettings
    );

    /**
     * Creates a new subclass of class sap.m.SinglePlanningCalendarDayView with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.SinglePlanningCalendarView.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SinglePlanningCalendarDayView>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SinglePlanningCalendarDayView.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the SinglePlanningCalendarDayView constructor.
   */
  export interface $SinglePlanningCalendarDayViewSettings
    extends $SinglePlanningCalendarViewSettings {}
}

declare module "sap/m/SinglePlanningCalendarMonthView" {
  import {
    default as SinglePlanningCalendarView,
    $SinglePlanningCalendarViewSettings,
  } from "sap/m/SinglePlanningCalendarView";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * Represents a one month view of the `SinglePlanningCalendar`. The purpose of the element is to decouple
   * the view logic from parent control `SinglePlanningCalendar`.
   *
   * @since 1.69
   */
  export default class SinglePlanningCalendarMonthView extends SinglePlanningCalendarView {
    /**
     * Constructor for a new `SinglePlanningCalendarMonthView`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.SinglePlanningCalendarView#constructor sap.m.SinglePlanningCalendarView }
     * can be used.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SinglePlanningCalendarMonthViewSettings
    );
    /**
     * Constructor for a new `SinglePlanningCalendarMonthView`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.SinglePlanningCalendarView#constructor sap.m.SinglePlanningCalendarView }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SinglePlanningCalendarMonthViewSettings
    );

    /**
     * Creates a new subclass of class sap.m.SinglePlanningCalendarMonthView with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.SinglePlanningCalendarView.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SinglePlanningCalendarMonthView>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SinglePlanningCalendarMonthView.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the SinglePlanningCalendarMonthView constructor.
   */
  export interface $SinglePlanningCalendarMonthViewSettings
    extends $SinglePlanningCalendarViewSettings {}
}

declare module "sap/m/SinglePlanningCalendarView" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import UI5Date from "sap/ui/core/date/UI5Date";

  import CalendarWeekNumbering from "sap/base/i18n/date/CalendarWeekNumbering";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Represents a day view of the {@link sap.m.SinglePlanningCalendar}. The purpose of the element is to decouple
   * the view logic from parent control `SinglePlanningCalendar`.
   *
   * @since 1.61
   */
  export default class SinglePlanningCalendarView extends UI5Element {
    /**
     * Constructor for a new `SinglePlanningCalendarView`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SinglePlanningCalendarViewSettings
    );
    /**
     * Constructor for a new `SinglePlanningCalendarView`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SinglePlanningCalendarViewSettings
    );

    /**
     * Creates a new subclass of class sap.m.SinglePlanningCalendarView with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SinglePlanningCalendarView>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SinglePlanningCalendarView.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Should calculate the startDate which will be displayed in the `sap.m.SinglePlanningCalendar` based on
     * a given date.
     *
     *
     * @returns The startDate of the view
     */
    calculateStartDate(
      /**
       * The given date
       */
      oDate: Date | UI5Date
    ): Date | UI5Date;
    /**
     * Gets current value of property {@link #getCalendarWeekNumbering calendarWeekNumbering}.
     *
     * If set, the calendar week numbering is used for display. If not set, the calendar week numbering of the
     * global configuration is used. Note: This property should not be used with firstDayOfWeek property.
     *
     * @since 1.110.0
     *
     * @returns Value of property `calendarWeekNumbering`
     */
    getCalendarWeekNumbering(): CalendarWeekNumbering;
    /**
     * Should return the number of columns to be displayed in the grid of the `sap.m.SinglePlanningCalendar`.
     *
     *
     * @returns the number of columns to be displayed
     */
    getEntityCount(): int;
    /**
     * Gets current value of property {@link #getFirstDayOfWeek firstDayOfWeek}.
     *
     * If set, the first day of the displayed week is this day. Valid values are 0 to 6 starting on Sunday.
     * If there is no valid value set, the default of the used locale is used.
     *
     * Note: This property will only have effect in Week view and Month view of the SinglePlanningCalendar,
     * but it wouldn't have effect in WorkWeek view.
     *
     * Default value is `-1`.
     *
     * @since 1.98
     *
     * @returns Value of property `firstDayOfWeek`
     */
    getFirstDayOfWeek(): int;
    /**
     * Gets current value of property {@link #getKey key}.
     *
     * Indicates a unique key for the view
     *
     *
     * @returns Value of property `key`
     */
    getKey(): string;
    /**
     * Should return a number of entities until the next/previous startDate of the `sap.m.SinglePlanningCalendar`
     * after navigating forward/backward with the arrows. For example, by pressing the forward button inside
     * the work week view, the next startDate of a work week will be 7 entities (days) away from the current
     * one.
     *
     *
     * @returns the number of entities to be skipped by scrolling
     */
    getScrollEntityCount(): int;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Adds a title for the view
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Sets a new value for property {@link #getCalendarWeekNumbering calendarWeekNumbering}.
     *
     * If set, the calendar week numbering is used for display. If not set, the calendar week numbering of the
     * global configuration is used. Note: This property should not be used with firstDayOfWeek property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.110.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCalendarWeekNumbering(
      /**
       * New value for property `calendarWeekNumbering`
       */
      sCalendarWeekNumbering?:
        | CalendarWeekNumbering
        | keyof typeof CalendarWeekNumbering
    ): this;
    /**
     * Sets a new value for property {@link #getFirstDayOfWeek firstDayOfWeek}.
     *
     * If set, the first day of the displayed week is this day. Valid values are 0 to 6 starting on Sunday.
     * If there is no valid value set, the default of the used locale is used.
     *
     * Note: This property will only have effect in Week view and Month view of the SinglePlanningCalendar,
     * but it wouldn't have effect in WorkWeek view.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `-1`.
     *
     * @since 1.98
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFirstDayOfWeek(
      /**
       * New value for property `firstDayOfWeek`
       */
      iFirstDayOfWeek?: int
    ): this;
    /**
     * Sets a new value for property {@link #getKey key}.
     *
     * Indicates a unique key for the view
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setKey(
      /**
       * New value for property `key`
       */
      sKey: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Adds a title for the view
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the SinglePlanningCalendarView constructor.
   */
  export interface $SinglePlanningCalendarViewSettings
    extends $ElementSettings {
    /**
     * Indicates a unique key for the view
     */
    key?: string | PropertyBindingInfo;

    /**
     * Adds a title for the view
     */
    title?: string | PropertyBindingInfo;

    /**
     * If set, the first day of the displayed week is this day. Valid values are 0 to 6 starting on Sunday.
     * If there is no valid value set, the default of the used locale is used.
     *
     * Note: This property will only have effect in Week view and Month view of the SinglePlanningCalendar,
     * but it wouldn't have effect in WorkWeek view.
     *
     * @since 1.98
     */
    firstDayOfWeek?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * If set, the calendar week numbering is used for display. If not set, the calendar week numbering of the
     * global configuration is used. Note: This property should not be used with firstDayOfWeek property.
     *
     * @since 1.110.0
     */
    calendarWeekNumbering?:
      | (CalendarWeekNumbering | keyof typeof CalendarWeekNumbering)
      | PropertyBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/SinglePlanningCalendarWeekView" {
  import {
    default as SinglePlanningCalendarView,
    $SinglePlanningCalendarViewSettings,
  } from "sap/m/SinglePlanningCalendarView";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * Represents a week view of the {@link sap.m.SinglePlanningCalendar}. The purpose of the element is to
   * decouple the view logic from parent control `SinglePlanningCalendar`.
   *
   * @since 1.61
   */
  export default class SinglePlanningCalendarWeekView extends SinglePlanningCalendarView {
    /**
     * Constructor for a new `SinglePlanningCalendarWeekView`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.SinglePlanningCalendarView#constructor sap.m.SinglePlanningCalendarView }
     * can be used.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SinglePlanningCalendarWeekViewSettings
    );
    /**
     * Constructor for a new `SinglePlanningCalendarWeekView`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.SinglePlanningCalendarView#constructor sap.m.SinglePlanningCalendarView }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SinglePlanningCalendarWeekViewSettings
    );

    /**
     * Creates a new subclass of class sap.m.SinglePlanningCalendarWeekView with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.SinglePlanningCalendarView.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SinglePlanningCalendarWeekView>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SinglePlanningCalendarWeekView.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the SinglePlanningCalendarWeekView constructor.
   */
  export interface $SinglePlanningCalendarWeekViewSettings
    extends $SinglePlanningCalendarViewSettings {}
}

declare module "sap/m/SinglePlanningCalendarWorkWeekView" {
  import {
    default as SinglePlanningCalendarView,
    $SinglePlanningCalendarViewSettings,
  } from "sap/m/SinglePlanningCalendarView";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * Represents a week view of the {@link sap.m.SinglePlanningCalendar}. The purpose of the element is to
   * decouple the view logic from parent control `SinglePlanningCalendar`.
   *
   * @since 1.61
   */
  export default class SinglePlanningCalendarWorkWeekView extends SinglePlanningCalendarView {
    /**
     * Constructor for a new `SinglePlanningCalendarWorkWeekView`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.SinglePlanningCalendarView#constructor sap.m.SinglePlanningCalendarView }
     * can be used.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SinglePlanningCalendarWorkWeekViewSettings
    );
    /**
     * Constructor for a new `SinglePlanningCalendarWorkWeekView`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.SinglePlanningCalendarView#constructor sap.m.SinglePlanningCalendarView }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SinglePlanningCalendarWorkWeekViewSettings
    );

    /**
     * Creates a new subclass of class sap.m.SinglePlanningCalendarWorkWeekView with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.SinglePlanningCalendarView.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SinglePlanningCalendarWorkWeekView>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SinglePlanningCalendarWorkWeekView.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the SinglePlanningCalendarWorkWeekView constructor.
   */
  export interface $SinglePlanningCalendarWorkWeekViewSettings
    extends $SinglePlanningCalendarViewSettings {}
}

declare module "sap/m/Slider" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IFormContent,
    ISemanticFormContent,
    ID,
    CSSSize,
  } from "sap/ui/core/library";

  import { IToolbarInteractiveControl, IScale } from "sap/m/library";

  import SliderTooltipBase from "sap/m/SliderTooltipBase";

  import UI5Element from "sap/ui/core/Element";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * Overview:
   *
   * A {@link sap.m.Slider} control represents a numerical range and a handle. The purpose of the control
   * is to enable visual selection of a value in a continuous numerical range by moving an adjustable handle.
   *
   * **Notes:**
   * 	 - Only horizontal sliders are possible.
   * 	 - The handle can be moved in steps of predefined size. This is done with the `step` property.
   * 	 - Setting the property `showAdvancedTooltip` shows an input field above the handle
   * 	 - Setting the property `inputsAsTooltips` enables the user to enter a specific value in the handle's
   *     tooltip.
   *
   * Structure:
   *
   * The most important properties of the Slider are:
   * 	 -  min - The minimum value of the slider range
   * 	 -  max - The maximum value of the slider range
   * 	 -  value - The current value of the slider
   * 	 -  progress - Determines if a progress bar will be shown on the slider range
   * 	 -  step - Determines the increments in which the slider will move  These properties determine
   *     the visualization of the tooltips:
   * 	 -  `showAdvancedTooltip` - Determines if a tooltip should be displayed above the handle
   * 	 -  `inputsAsTooltips` - Determines if the tooltip displayed above the slider's handle should include
   *     an input field
   *
   * Usage:
   *
   * The most common usecase is to select values on a continuous numerical scale (e.g. temperature, volume,
   * etc. ).
   *
   * Responsive Behavior:
   *
   * The `sap.m.Slider` control adjusts to the size of its parent container by recalculating and resizing
   * the width of the control. You can move the slider handle in several different ways:
   * 	 -  Drag and drop to the desired value
   * 	 -  Click/tap on the range bar to move the handle to that location
   * 	 -  Enter the desired value in the input field (if available)
   * 	 -  Keyboard (Arrow keys, "+" and "-")
   */
  export default class Slider
    extends Control
    implements IFormContent, ISemanticFormContent, IToolbarInteractiveControl
  {
    __implements__sap_ui_core_IFormContent: boolean;
    __implements__sap_ui_core_ISemanticFormContent: boolean;
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new `Slider`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/slider/ Slider}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SliderSettings
    );
    /**
     * Constructor for a new `Slider`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/slider/ Slider}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SliderSettings
    );

    /**
     * Creates a new subclass of class sap.m.Slider with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Slider>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Slider.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds some customTooltip to the aggregation {@link #getCustomTooltips customTooltips}.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addCustomTooltip(
      /**
       * The customTooltip to add; if empty, nothing is inserted
       */
      oCustomTooltip: SliderTooltipBase
    ): this;
    /**
     * Creates default tooltips, if needed, and forwards properties to them
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    assignDefaultTooltips(
      /**
       * Array of strings for ID generation
       */
      aTooltipIds?: any[]
    ): void;
    /**
     * Creates custom tooltips, if needed, and forwards properties to them
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    associateCustomTooltips(
      /**
       * Count of the tooltips
       */
      iTooltipCount?: number
    ): void;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.Slider`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Slider` itself.
     *
     * This event is triggered after the end user finishes interacting, if there is any change.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Slider$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Slider` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.Slider`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Slider` itself.
     *
     * This event is triggered after the end user finishes interacting, if there is any change.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Slider$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Slider` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.Slider`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Slider` itself.
     *
     * This event is triggered during the dragging period, each time the slider value changes.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Slider$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Slider` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.Slider`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Slider` itself.
     *
     * This event is triggered during the dragging period, each time the slider value changes.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Slider$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Slider` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the customTooltips in the aggregation {@link #getCustomTooltips customTooltips}.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCustomTooltips(): this;
    /**
     * Destroys the scale in the aggregation {@link #getScale scale}.
     *
     * @since 1.46
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyScale(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:change change} event of this `sap.m.Slider`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Slider$ChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:liveChange liveChange} event of this `sap.m.Slider`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLiveChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Slider$LiveChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:change change} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Slider$ChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:liveChange liveChange} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLiveChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Slider$LiveChangeEventParameters
    ): this;
    /**
     * Forwards properties to a given control
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    forwardProperties(
      /**
       * Array of properties to forward
       */
      aProperties?: any[],
      /**
       * Control to which should be forward
       */
      oControl?: UI5Element
    ): void;
    /**
     * Forwards properties to default tooltips
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    forwardPropertiesToDefaultTooltips(
      /**
       * Count of the tooltips
       */
      iTooltipCount?: number
    ): void;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets content of aggregation {@link #getCustomTooltips customTooltips}.
     *
     * Aggregation for user-defined tooltips. **Note:** In case of Slider, only the first tooltip of the aggregation
     * is used. In the RangeSlider case - the first two. If no custom tooltips are provided, the default are
     * used
     *
     * @since 1.56
     */
    getCustomTooltips(): SliderTooltipBase[];
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Indicates whether the user can change the value.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets current value of property {@link #getEnableTickmarks enableTickmarks}.
     *
     * Enables tickmarks visualisation
     *
     * Default value is `false`.
     *
     * @since 1.44
     *
     * @returns Value of property `enableTickmarks`
     */
    getEnableTickmarks(): boolean;
    /**
     * Gets current value of property {@link #getInputsAsTooltips inputsAsTooltips}.
     *
     * Indicates whether input fields should be used as tooltips for the handles. **Note:** Setting this option
     * to `true` will only work if `showAdvancedTooltip` is set to `true`. *Note:** To comply with the accessibility
     * standard, it is recommended to set the `inputsAsTooltips` property to true.
     *
     * Default value is `false`.
     *
     * @since 1.42
     *
     * @returns Value of property `inputsAsTooltips`
     */
    getInputsAsTooltips(): boolean;
    /**
     * Gets current value of property {@link #getMax max}.
     *
     * The maximum value.
     *
     * Default value is `100`.
     *
     *
     * @returns Value of property `max`
     */
    getMax(): float;
    /**
     * Gets current value of property {@link #getMin min}.
     *
     * The minimum value.
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `min`
     */
    getMin(): float;
    /**
     * Gets current value of property {@link #getName name}.
     *
     * The name property to be used in the HTML code for the slider (e.g. for HTML forms that send data to the
     * server via submit).
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `name`
     */
    getName(): string;
    /**
     * Gets current value of property {@link #getProgress progress}.
     *
     * Indicate whether a progress bar indicator is shown.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `progress`
     */
    getProgress(): boolean;
    /**
     * Gets content of aggregation {@link #getScale scale}.
     *
     * Scale for visualisation of tickmarks and labels
     *
     * @since 1.46
     */
    getScale(): IScale;
    /**
     * Gets current value of property {@link #getShowAdvancedTooltip showAdvancedTooltip}.
     *
     * Indicate whether the handle's advanced tooltip is shown. **Note:** Setting this option to `true` will
     * ignore the value set in `showHandleTooltip`. This will cause only the advanced tooltip to be shown.
     *
     * Default value is `false`.
     *
     * @since 1.42
     *
     * @returns Value of property `showAdvancedTooltip`
     */
    getShowAdvancedTooltip(): boolean;
    /**
     * Gets current value of property {@link #getShowHandleTooltip showHandleTooltip}.
     *
     * Indicate whether the handle tooltip is shown.
     *
     * Default value is `true`.
     *
     * @since 1.31
     *
     * @returns Value of property `showHandleTooltip`
     */
    getShowHandleTooltip(): boolean;
    /**
     * Gets current value of property {@link #getStep step}.
     *
     * Define the amount of units to change the slider when adjusting by drag and drop.
     *
     * Defines the size of the slider's selection intervals. (e.g. min = 0, max = 10, step = 5 would result
     * in possible selection of the values 0, 5, 10).
     *
     * The step must be positive, if a negative number is provided, the default value will be used instead.
     * If the width of the slider converted to pixels is less than the range (max - min), the value will be
     * rounded to multiples of the step size.
     *
     * Default value is `1`.
     *
     *
     * @returns Value of property `step`
     */
    getStep(): float;
    /**
     * Gets the tooltips that should be shown. Returns custom tooltips if provided. Otherwise - default tooltips
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns SliderTooltipBase instances.
     */
    getUsedTooltips(): SliderTooltipBase[];
    /**
     * Gets current value of property {@link #getValue value}.
     *
     * Define the value.
     *
     * If the value is lower/higher than the allowed minimum/maximum, the value of the properties `min`/`max`
     * are used instead.
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `value`
     */
    getValue(): float;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Defines the width of the control.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Handles change of Tooltip's inputs.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    handleTooltipChange(oEvent: jQuery.Event): void;
    /**
     * Checks for the provided `sap.m.SliderTooltipBase` in the aggregation {@link #getCustomTooltips customTooltips}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.56
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfCustomTooltip(
      /**
       * The customTooltip whose index is looked for
       */
      oCustomTooltip: SliderTooltipBase
    ): int;
    /**
     * Assigns tooltips and forwards properties to them
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    initAndSyncTooltips(
      /**
       * Array of strings for ID generation
       */
      aTooltipIds?: any[]
    ): void;
    /**
     * Creates a default SliderTooltip instance and adds it as an aggregation
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    initDefaultTooltip(
      /**
       * The tooltip ID
       */
      sId?: string
    ): void;
    /**
     * Creates a SliderTooltipContainer
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    initTooltipContainer(): void;
    /**
     * Inserts a customTooltip into the aggregation {@link #getCustomTooltips customTooltips}.
     *
     * @since 1.56
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertCustomTooltip(
      /**
       * The customTooltip to insert; if empty, nothing is inserted
       */
      oCustomTooltip: SliderTooltipBase,
      /**
       * The `0`-based index the customTooltip should be inserted at; for a negative value of `iIndex`, the customTooltip
       * is inserted at position 0; for a value greater than the current size of the aggregation, the customTooltip
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all the controls from the aggregation {@link #getCustomTooltips customTooltips}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.56
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllCustomTooltips(): SliderTooltipBase[];
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes a customTooltip from the aggregation {@link #getCustomTooltips customTooltips}.
     *
     * @since 1.56
     *
     * @returns The removed customTooltip or `null`
     */
    removeCustomTooltip(
      /**
       * The customTooltip to remove or its index or id
       */
      vCustomTooltip: int | string | SliderTooltipBase
    ): SliderTooltipBase | null;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Indicates whether the user can change the value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnableTickmarks enableTickmarks}.
     *
     * Enables tickmarks visualisation
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.44
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableTickmarks(
      /**
       * New value for property `enableTickmarks`
       */
      bEnableTickmarks?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getInputsAsTooltips inputsAsTooltips}.
     *
     * Indicates whether input fields should be used as tooltips for the handles. **Note:** Setting this option
     * to `true` will only work if `showAdvancedTooltip` is set to `true`. *Note:** To comply with the accessibility
     * standard, it is recommended to set the `inputsAsTooltips` property to true.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.42
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInputsAsTooltips(
      /**
       * New value for property `inputsAsTooltips`
       */
      bInputsAsTooltips?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getMax max}.
     *
     * The maximum value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `100`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMax(
      /**
       * New value for property `max`
       */
      fMax?: float
    ): this;
    /**
     * Sets a new value for property {@link #getMin min}.
     *
     * The minimum value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMin(
      /**
       * New value for property `min`
       */
      fMin?: float
    ): this;
    /**
     * Sets a new value for property {@link #getName name}.
     *
     * The name property to be used in the HTML code for the slider (e.g. for HTML forms that send data to the
     * server via submit).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setName(
      /**
       * New value for property `name`
       */
      sName?: string
    ): this;
    /**
     * Sets a new value for property {@link #getProgress progress}.
     *
     * Indicate whether a progress bar indicator is shown.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setProgress(
      /**
       * New value for property `progress`
       */
      bProgress?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getScale scale}.
     *
     * @since 1.46
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setScale(
      /**
       * The scale to set
       */
      oScale: IScale
    ): this;
    /**
     * Sets a new value for property {@link #getShowAdvancedTooltip showAdvancedTooltip}.
     *
     * Indicate whether the handle's advanced tooltip is shown. **Note:** Setting this option to `true` will
     * ignore the value set in `showHandleTooltip`. This will cause only the advanced tooltip to be shown.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.42
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowAdvancedTooltip(
      /**
       * New value for property `showAdvancedTooltip`
       */
      bShowAdvancedTooltip?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowHandleTooltip showHandleTooltip}.
     *
     * Indicate whether the handle tooltip is shown.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.31
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowHandleTooltip(
      /**
       * New value for property `showHandleTooltip`
       */
      bShowHandleTooltip?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getStep step}.
     *
     * Define the amount of units to change the slider when adjusting by drag and drop.
     *
     * Defines the size of the slider's selection intervals. (e.g. min = 0, max = 10, step = 5 would result
     * in possible selection of the values 0, 5, 10).
     *
     * The step must be positive, if a negative number is provided, the default value will be used instead.
     * If the width of the slider converted to pixels is less than the range (max - min), the value will be
     * rounded to multiples of the step size.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `1`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setStep(
      /**
       * New value for property `step`
       */
      fStep?: float
    ): this;
    /**
     * Sets the property `value`.
     *
     * Default value is `0`.
     *
     *
     * @returns `this` to allow method chaining.
     */
    setValue(
      /**
       * new value for property `value`.
       */
      fNewValue: float,
      /**
       * The options object
       */
      mOptions:
        | {
            snapValue: boolean;
          }
        | object
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Defines the width of the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Decrements the value by multiplying the step the `step` with the given parameter.
     *
     *
     * @returns `this` to allow method chaining.
     */
    stepDown(
      /**
       * The number of steps the slider goes down.
       */
      iStep?: int
    ): this;
    /**
     * Increments the value by multiplying the `step` with the given parameter.
     *
     *
     * @returns `this` to allow method chaining.
     */
    stepUp(
      /**
       * The number of steps the slider goes up.
       */
      iStep?: int
    ): this;
    /**
     * Updates value of the advanced tooltip.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    updateAdvancedTooltipDom(
      /**
       * The new value
       */
      sNewValue: string
    ): void;
  }
  /**
   * Describes the settings that can be provided to the Slider constructor.
   */
  export interface $SliderSettings extends $ControlSettings {
    /**
     * Defines the width of the control.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether the user can change the value.
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The name property to be used in the HTML code for the slider (e.g. for HTML forms that send data to the
     * server via submit).
     */
    name?: string | PropertyBindingInfo;

    /**
     * The minimum value.
     */
    min?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * The maximum value.
     */
    max?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * Define the amount of units to change the slider when adjusting by drag and drop.
     *
     * Defines the size of the slider's selection intervals. (e.g. min = 0, max = 10, step = 5 would result
     * in possible selection of the values 0, 5, 10).
     *
     * The step must be positive, if a negative number is provided, the default value will be used instead.
     * If the width of the slider converted to pixels is less than the range (max - min), the value will be
     * rounded to multiples of the step size.
     */
    step?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicate whether a progress bar indicator is shown.
     */
    progress?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Define the value.
     *
     * If the value is lower/higher than the allowed minimum/maximum, the value of the properties `min`/`max`
     * are used instead.
     */
    value?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicate whether the handle tooltip is shown.
     *
     * @since 1.31
     */
    showHandleTooltip?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicate whether the handle's advanced tooltip is shown. **Note:** Setting this option to `true` will
     * ignore the value set in `showHandleTooltip`. This will cause only the advanced tooltip to be shown.
     *
     * @since 1.42
     */
    showAdvancedTooltip?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether input fields should be used as tooltips for the handles. **Note:** Setting this option
     * to `true` will only work if `showAdvancedTooltip` is set to `true`. **Note:** To comply with the accessibility
     * standard, it is recommended to set the `inputsAsTooltips` property to true.
     *
     * @since 1.42
     */
    inputsAsTooltips?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Enables tickmarks visualisation
     *
     * @since 1.44
     */
    enableTickmarks?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Scale for visualisation of tickmarks and labels
     *
     * @since 1.46
     */
    scale?: IScale;

    /**
     * Aggregation for user-defined tooltips. **Note:** In case of Slider, only the first tooltip of the aggregation
     * is used. In the RangeSlider case - the first two. If no custom tooltips are provided, the default are
     * used
     *
     * @since 1.56
     */
    customTooltips?:
      | SliderTooltipBase[]
      | SliderTooltipBase
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Association to controls / IDs which label this control (see WAI-ARIA attribute `aria-labelledby`).
     *
     * @since 1.27.0
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * This event is triggered after the end user finishes interacting, if there is any change.
     */
    change?: (oEvent: Slider$ChangeEvent) => void;

    /**
     * This event is triggered during the dragging period, each time the slider value changes.
     */
    liveChange?: (oEvent: Slider$LiveChangeEvent) => void;
  }

  /**
   * Parameters of the Slider#change event.
   */
  export interface Slider$ChangeEventParameters {
    /**
     * The current value of the slider after a change.
     */
    value?: float;
  }

  /**
   * Event object of the Slider#change event.
   */
  export type Slider$ChangeEvent = Event<Slider$ChangeEventParameters, Slider>;

  /**
   * Parameters of the Slider#liveChange event.
   */
  export interface Slider$LiveChangeEventParameters {
    /**
     * The current value of the slider after a live change.
     */
    value?: float;
  }

  /**
   * Event object of the Slider#liveChange event.
   */
  export type Slider$LiveChangeEvent = Event<
    Slider$LiveChangeEventParameters,
    Slider
  >;
}

declare module "sap/m/SliderTooltipBase" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * A Control that visualizes `Slider` and `RangeSlider` tooltips.
   *
   * @since 1.56
   */
  export default abstract class SliderTooltipBase extends Control {
    /**
     * Constructor for a new SliderTooltipBase.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.ui.core.Control#constructor sap.ui.core.Control }
     * can be used.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SliderTooltipBaseSettings
    );
    /**
     * Constructor for a new SliderTooltipBase.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.ui.core.Control#constructor sap.ui.core.Control }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SliderTooltipBaseSettings
    );

    /**
     * Creates a new subclass of class sap.m.SliderTooltipBase with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SliderTooltipBase>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SliderTooltipBase.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets the value of the tooltip.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The current value of the tooltip.
     */
    getValue(): float;
    /**
     * Called once the value of the Slider is changed by interaction.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    sliderValueChanged(
      /**
       * The new Slider value
       */
      fValue?: float
    ): void;
  }
  /**
   * Describes the settings that can be provided to the SliderTooltipBase constructor.
   */
  export interface $SliderTooltipBaseSettings extends $ControlSettings {}
}

declare module "sap/m/SlideTile" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import GenericTile from "sap/m/GenericTile";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import { CSSSize } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { GenericTileScope, TileSizeBehavior } from "sap/m/library";

  import Event from "sap/ui/base/Event";

  /**
   * The control that displays multiple GenericTile controls as changing slides.
   *
   * @since 1.34
   */
  export default class SlideTile extends Control {
    /**
     * Constructor for a new sap.m.SlideTile control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $SlideTileSettings
    );
    /**
     * Constructor for a new sap.m.SlideTile control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $SlideTileSettings
    );

    /**
     * Creates a new subclass of class sap.m.SlideTile with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SlideTile>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SlideTile.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some tile to the aggregation {@link #getTiles tiles}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addTile(
      /**
       * The tile to add; if empty, nothing is inserted
       */
      oTile: GenericTile
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.SlideTile`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SlideTile` itself.
     *
     * The event is fired when the user chooses the tile. The event is available only in Actions scope.
     *
     * @since 1.46.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SlideTile$PressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SlideTile` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.SlideTile`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SlideTile` itself.
     *
     * The event is fired when the user chooses the tile. The event is available only in Actions scope.
     *
     * @since 1.46.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SlideTile$PressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SlideTile` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getTiles tiles} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindTiles(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the tiles in the aggregation {@link #getTiles tiles}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyTiles(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.SlideTile`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.46.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SlideTile$PressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @since 1.46.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SlideTile$PressEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getDisplayTime displayTime}.
     *
     * The time of the slide display in milliseconds.
     *
     * Default value is `5000`.
     *
     *
     * @returns Value of property `displayTime`
     */
    getDisplayTime(): int;
    /**
     * Gets current value of property {@link #getHeight height}.
     *
     * Height of the control.
     *
     * @since 1.96
     *
     * @returns Value of property `height`
     */
    getHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getScope scope}.
     *
     * Changes the visualization in order to enable additional actions with the SlideTile control.
     *
     * Default value is `"Display"`.
     *
     * @since 1.46.0
     *
     * @returns Value of property `scope`
     */
    getScope(): GenericTileScope;
    /**
     * Gets current value of property {@link #getSizeBehavior sizeBehavior}.
     *
     * If set to `TileSizeBehavior.Small`, the tile size is the same as it would be on a small-screened phone
     * (374px wide and lower), regardless of the screen size of the actual device being used. If set to `TileSizeBehavior.Responsive`,
     * the tile size adapts to the size of the screen. This property has to be set consistently for the `SlideTile`
     * along with all its inner `GenericTile` elements, so that they match one another visually.
     *
     * Default value is `Responsive`.
     *
     *
     * @returns Value of property `sizeBehavior`
     */
    getSizeBehavior(): TileSizeBehavior;
    /**
     * Gets content of aggregation {@link #getTiles tiles}.
     *
     * The set of Generic Tiles to be shown in the control.
     */
    getTiles(): GenericTile[];
    /**
     * Gets current value of property {@link #getTransitionTime transitionTime}.
     *
     * The time of the slide changing in milliseconds.
     *
     * Default value is `500`.
     *
     *
     * @returns Value of property `transitionTime`
     */
    getTransitionTime(): int;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Width of the control. If the tiles within the SlideTile are in ArticleMode and have a frameType of Stretch,
     * and if the SlideTile's width exceeds 799px, the image in the tile appears on the right side
     *
     * @since 1.72
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Checks for the provided `sap.m.GenericTile` in the aggregation {@link #getTiles tiles}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfTile(
      /**
       * The tile whose index is looked for
       */
      oTile: GenericTile
    ): int;
    /**
     * Inserts a tile into the aggregation {@link #getTiles tiles}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertTile(
      /**
       * The tile to insert; if empty, nothing is inserted
       */
      oTile: GenericTile,
      /**
       * The `0`-based index the tile should be inserted at; for a negative value of `iIndex`, the tile is inserted
       * at position 0; for a value greater than the current size of the aggregation, the tile is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getTiles tiles}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllTiles(): GenericTile[];
    /**
     * Removes a tile from the aggregation {@link #getTiles tiles}.
     *
     *
     * @returns The removed tile or `null`
     */
    removeTile(
      /**
       * The tile to remove or its index or id
       */
      vTile: int | string | GenericTile
    ): GenericTile | null;
    /**
     * Sets a new value for property {@link #getDisplayTime displayTime}.
     *
     * The time of the slide display in milliseconds.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `5000`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisplayTime(
      /**
       * New value for property `displayTime`
       */
      iDisplayTime?: int
    ): this;
    /**
     * Sets a new value for property {@link #getHeight height}.
     *
     * Height of the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.96
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeight(
      /**
       * New value for property `height`
       */
      sHeight: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getScope scope}.
     *
     * Changes the visualization in order to enable additional actions with the SlideTile control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Display"`.
     *
     * @since 1.46.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setScope(
      /**
       * New value for property `scope`
       */
      sScope?: GenericTileScope | keyof typeof GenericTileScope
    ): this;
    /**
     * Sets a new value for property {@link #getSizeBehavior sizeBehavior}.
     *
     * If set to `TileSizeBehavior.Small`, the tile size is the same as it would be on a small-screened phone
     * (374px wide and lower), regardless of the screen size of the actual device being used. If set to `TileSizeBehavior.Responsive`,
     * the tile size adapts to the size of the screen. This property has to be set consistently for the `SlideTile`
     * along with all its inner `GenericTile` elements, so that they match one another visually.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Responsive`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSizeBehavior(
      /**
       * New value for property `sizeBehavior`
       */
      sSizeBehavior?: TileSizeBehavior | keyof typeof TileSizeBehavior
    ): this;
    /**
     * Sets a new value for property {@link #getTransitionTime transitionTime}.
     *
     * The time of the slide changing in milliseconds.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `500`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTransitionTime(
      /**
       * New value for property `transitionTime`
       */
      iTransitionTime?: int
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Width of the control. If the tiles within the SlideTile are in ArticleMode and have a frameType of Stretch,
     * and if the SlideTile's width exceeds 799px, the image in the tile appears on the right side
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.72
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth: CSSSize
    ): this;
    /**
     * Unbinds aggregation {@link #getTiles tiles} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindTiles(): this;
  }
  /**
   * Describes the settings that can be provided to the SlideTile constructor.
   */
  export interface $SlideTileSettings extends $ControlSettings {
    /**
     * The time of the slide display in milliseconds.
     */
    displayTime?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * The time of the slide changing in milliseconds.
     */
    transitionTime?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Changes the visualization in order to enable additional actions with the SlideTile control.
     *
     * @since 1.46.0
     */
    scope?:
      | (GenericTileScope | keyof typeof GenericTileScope)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * If set to `TileSizeBehavior.Small`, the tile size is the same as it would be on a small-screened phone
     * (374px wide and lower), regardless of the screen size of the actual device being used. If set to `TileSizeBehavior.Responsive`,
     * the tile size adapts to the size of the screen. This property has to be set consistently for the `SlideTile`
     * along with all its inner `GenericTile` elements, so that they match one another visually.
     */
    sizeBehavior?:
      | (TileSizeBehavior | keyof typeof TileSizeBehavior)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Width of the control. If the tiles within the SlideTile are in ArticleMode and have a frameType of Stretch,
     * and if the SlideTile's width exceeds 799px, the image in the tile appears on the right side
     *
     * @since 1.72
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Height of the control.
     *
     * @since 1.96
     */
    height?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * The set of Generic Tiles to be shown in the control.
     */
    tiles?:
      | GenericTile[]
      | GenericTile
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * The event is fired when the user chooses the tile. The event is available only in Actions scope.
     *
     * @since 1.46.0
     */
    press?: (oEvent: SlideTile$PressEvent) => void;
  }

  /**
   * Parameters of the SlideTile#press event.
   */
  export interface SlideTile$PressEventParameters {
    /**
     * The current scope the SlideTile was in when the event occurred.
     */
    scope?: GenericTileScope | keyof typeof GenericTileScope;

    /**
     * The action that was pressed on the tile. In the Actions scope, the available actions are Press and Remove.
     */
    action?: string;

    /**
     * The Element's DOM Element. In Actions scope the domRef points to the DOM Element of the remove button
     * (if pressed) or the more icon.
     */
    domRef?: any;
  }

  /**
   * Event object of the SlideTile#press event.
   */
  export type SlideTile$PressEvent = Event<
    SlideTile$PressEventParameters,
    SlideTile
  >;
}

declare module "sap/m/SplitApp" {
  import {
    default as SplitContainer,
    $SplitContainerSettings,
  } from "sap/m/SplitContainer";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * A container control that is used to display a master-detail view, suitable for mobile applications.
   *
   * Overview: The control extends the functionalities of the {@link sap.m.SplitContainer}. It adds certain
   * header tags to the HTML page which are considered useful for mobile applications and allows the configuration
   * of the application's home icon via the `homeIcon` property.
   *
   * Usage: SplitApp should take the full width of the page and be used as the root of the application, not
   * as child of another container.
   */
  export default class SplitApp extends SplitContainer {
    /**
     * Constructor for a new SplitApp.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/eedfe79e4c19462eafe8780aeab16a3c Split App}
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/split-screen/ Split App}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SplitAppSettings
    );
    /**
     * Constructor for a new SplitApp.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link https://ui5.sap.com/#/topic/eedfe79e4c19462eafe8780aeab16a3c Split App}
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/split-screen/ Split App}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SplitAppSettings
    );

    /**
     * Creates a new subclass of class sap.m.SplitApp with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.SplitContainer.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SplitApp>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SplitApp.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:orientationChange orientationChange} event of
     * this `sap.m.SplitApp`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitApp` itself.
     *
     * Fires when orientation (portrait/landscape) is changed.
     *
     * @deprecated As of version 1.87. use {@link sap.ui.Device.orientation.attachHandler} instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachOrientationChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SplitApp$OrientationChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitApp` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:orientationChange orientationChange} event of
     * this `sap.m.SplitApp`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitApp` itself.
     *
     * Fires when orientation (portrait/landscape) is changed.
     *
     * @deprecated As of version 1.87. use {@link sap.ui.Device.orientation.attachHandler} instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachOrientationChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SplitApp$OrientationChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitApp` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:orientationChange orientationChange} event
     * of this `sap.m.SplitApp`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @deprecated As of version 1.87. use {@link sap.ui.Device.orientation.attachHandler} instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachOrientationChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SplitApp$OrientationChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:orientationChange orientationChange} to attached listeners.
     *
     * @deprecated As of version 1.87. use {@link sap.ui.Device.orientation.attachHandler} instead.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireOrientationChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SplitApp$OrientationChangeEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getHomeIcon homeIcon}.
     *
     * Represents the icon to be displayed on the home screen of iOS devices after the user does "add to home
     * screen". Note that only the first attempt to set the homeIcon is executed, subsequent settings are ignored.
     * The icon must be in PNG format. The property can either store the URL of one single icon or an object
     * holding icon URLs for the different required sizes. Note that if single icon is used for all devices,
     * when scaled, its quality can regress. A desktop icon (used for bookmarks and overriding the favicon)
     * can also be configured. This requires an object to be given and the "icon" property of this object then
     * defines the desktop bookmark icon. The ICO format is supported by all browsers. ICO is also preferred
     * for this desktop icon setting as the file can contain different images for different resolutions.
     *
     * One example is:
     *
     * app.setHomeIcon({ 'phone':'phone-icon.png', 'phone@2':'phone-retina.png', 'tablet':'tablet-icon.png',
     * 'tablet@2':'tablet-retina.png', 'icon':'desktop.ico' });
     *
     * The image size is 57/114 px for the phone and 72/144 px for the tablet. If an object is given but one
     * of the sizes is not given, the largest given icon will be used for this size.
     *
     * On Android, these icons may or may not be used by the device. Chances can be improved by adding glare
     * effect, rounded corners, setting the file name to end with "-precomposed.png", and setting the homeIconPrecomposed
     * property to true.
     *
     *
     * @returns Value of property `homeIcon`
     */
    getHomeIcon(): any;
    /**
     * Sets a new value for property {@link #getHomeIcon homeIcon}.
     *
     * Represents the icon to be displayed on the home screen of iOS devices after the user does "add to home
     * screen". Note that only the first attempt to set the homeIcon is executed, subsequent settings are ignored.
     * The icon must be in PNG format. The property can either store the URL of one single icon or an object
     * holding icon URLs for the different required sizes. Note that if single icon is used for all devices,
     * when scaled, its quality can regress. A desktop icon (used for bookmarks and overriding the favicon)
     * can also be configured. This requires an object to be given and the "icon" property of this object then
     * defines the desktop bookmark icon. The ICO format is supported by all browsers. ICO is also preferred
     * for this desktop icon setting as the file can contain different images for different resolutions.
     *
     * One example is:
     *
     * app.setHomeIcon({ 'phone':'phone-icon.png', 'phone@2':'phone-retina.png', 'tablet':'tablet-icon.png',
     * 'tablet@2':'tablet-retina.png', 'icon':'desktop.ico' });
     *
     * The image size is 57/114 px for the phone and 72/144 px for the tablet. If an object is given but one
     * of the sizes is not given, the largest given icon will be used for this size.
     *
     * On Android, these icons may or may not be used by the device. Chances can be improved by adding glare
     * effect, rounded corners, setting the file name to end with "-precomposed.png", and setting the homeIconPrecomposed
     * property to true.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHomeIcon(
      /**
       * New value for property `homeIcon`
       */
      oHomeIcon?: any
    ): this;
  }
  /**
   * Describes the settings that can be provided to the SplitApp constructor.
   */
  export interface $SplitAppSettings extends $SplitContainerSettings {
    /**
     * Represents the icon to be displayed on the home screen of iOS devices after the user does "add to home
     * screen". Note that only the first attempt to set the homeIcon is executed, subsequent settings are ignored.
     * The icon must be in PNG format. The property can either store the URL of one single icon or an object
     * holding icon URLs for the different required sizes. Note that if single icon is used for all devices,
     * when scaled, its quality can regress. A desktop icon (used for bookmarks and overriding the favicon)
     * can also be configured. This requires an object to be given and the "icon" property of this object then
     * defines the desktop bookmark icon. The ICO format is supported by all browsers. ICO is also preferred
     * for this desktop icon setting as the file can contain different images for different resolutions.
     *
     * One example is:
     *
     * app.setHomeIcon({ 'phone':'phone-icon.png', 'phone@2':'phone-retina.png', 'tablet':'tablet-icon.png',
     * 'tablet@2':'tablet-retina.png', 'icon':'desktop.ico' });
     *
     * The image size is 57/114 px for the phone and 72/144 px for the tablet. If an object is given but one
     * of the sizes is not given, the largest given icon will be used for this size.
     *
     * On Android, these icons may or may not be used by the device. Chances can be improved by adding glare
     * effect, rounded corners, setting the file name to end with "-precomposed.png", and setting the homeIconPrecomposed
     * property to true.
     */
    homeIcon?: any | PropertyBindingInfo | `{${string}}`;

    /**
     * Fires when orientation (portrait/landscape) is changed.
     *
     * @deprecated As of version 1.87. use {@link sap.ui.Device.orientation.attachHandler} instead.
     */
    orientationChange?: (oEvent: SplitApp$OrientationChangeEvent) => void;
  }

  /**
   * Parameters of the SplitApp#orientationChange event.
   *
   * @deprecated As of version 1.87. use {@link sap.ui.Device.orientation.attachHandler} instead.
   */
  export interface SplitApp$OrientationChangeEventParameters {
    /**
     * Returns true if the device is in landscape mode.
     */
    landscape?: boolean;
  }

  /**
   * Event object of the SplitApp#orientationChange event.
   *
   * @deprecated As of version 1.87. use {@link sap.ui.Device.orientation.attachHandler} instead.
   */
  export type SplitApp$OrientationChangeEvent = Event<
    SplitApp$OrientationChangeEventParameters,
    SplitApp
  >;
}

declare module "sap/m/SplitContainer" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { IPlaceholderSupport, URI, ID } from "sap/ui/core/library";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { SplitAppMode } from "sap/m/library";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * A container control that is used to display a master-detail view.
   *
   * Overview: The SplitContainer divides the screen into two areas:
   * 	 - Master area - contains a list of available items where the user can search and filter.
   * 	 - Details area - contains a control which shows further details on the item(s) selected from the master
   *     view.  Both areas have separate headers and footer bars with navigation and actions.
   *
   * Usage: SplitContainer should take the full width of the page in order to work properly. When to use:
   *
   * 	 - You need to review and process different items quickly with minimal navigation.  When not to
   *     use:
   * 	 - You need to offer complex filters for the list of items.
   * 	 - You need to see different attributes for each item in the list, and compare these values across items.
   *
   * 	 - You want to display a single object. Do not use the master list to display different facets of the
   *     same object.
   *
   * Responsive Behavior: On narrow screens, such as phones or tablet devices in portrait mode, the master
   * list and the details are split into two separate pages. The user can navigate between the list and details,
   * and see all the available information for each area.
   */
  export default class SplitContainer
    extends Control
    implements IPlaceholderSupport
  {
    __implements__sap_ui_core_IPlaceholderSupport: boolean;
    /**
     * Constructor for a new SplitContainer.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SplitContainerSettings
    );
    /**
     * Constructor for a new SplitContainer.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SplitContainerSettings
    );

    /**
     * Creates a new subclass of class sap.m.SplitContainer with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SplitContainer>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SplitContainer.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some detailPage to the aggregation {@link #getDetailPages detailPages}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addDetailPage(
      /**
       * The detailPage to add; if empty, nothing is inserted
       */
      oDetailPage: Control
    ): this;
    /**
     * Adds some masterPage to the aggregation {@link #getMasterPages masterPages}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addMasterPage(
      /**
       * The masterPage to add; if empty, nothing is inserted
       */
      oMasterPage: Control
    ): this;
    /**
     * Adds a content entity either to master area or detail area depending on the master parameter.
     *
     * The method is provided mainly for providing API consistency between sap.m.SplitContainer and sap.m.App.
     * So that the same code line can be reused.
     *
     * @since 1.11.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addPage(
      /**
       * The content entities between which this SplitContainer navigates in either master area or detail area
       * depending on the master parameter. These can be of type sap.m.Page, sap.ui.core.mvc.View, sap.m.Carousel
       * or any other control with fullscreen/page semantics.
       */
      oPage: Control,
      /**
       * States if the page should be added to the master area. If it's set to false, the page is added to detail
       * area.
       */
      bMaster: boolean
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterDetailNavigate afterDetailNavigate} event
     * of this `sap.m.SplitContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitContainer` itself.
     *
     * Fires when navigation between two pages in detail area has completed. NOTE: In case of animated transitions
     * this event is fired with some delay after the "navigate" event.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterDetailNavigate(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SplitContainer$AfterDetailNavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterDetailNavigate afterDetailNavigate} event
     * of this `sap.m.SplitContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitContainer` itself.
     *
     * Fires when navigation between two pages in detail area has completed. NOTE: In case of animated transitions
     * this event is fired with some delay after the "navigate" event.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterDetailNavigate(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SplitContainer$AfterDetailNavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterMasterClose afterMasterClose} event of
     * this `sap.m.SplitContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitContainer` itself.
     *
     * Fires when the master area is fully closed after the animation (if any).
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterMasterClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterMasterClose afterMasterClose} event of
     * this `sap.m.SplitContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitContainer` itself.
     *
     * Fires when the master area is fully closed after the animation (if any).
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterMasterClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterMasterNavigate afterMasterNavigate} event
     * of this `sap.m.SplitContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitContainer` itself.
     *
     * Fires when navigation between two pages in master area has completed. NOTE: In case of animated transitions
     * this event is fired with some delay after the navigate event.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterMasterNavigate(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SplitContainer$AfterMasterNavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterMasterNavigate afterMasterNavigate} event
     * of this `sap.m.SplitContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitContainer` itself.
     *
     * Fires when navigation between two pages in master area has completed. NOTE: In case of animated transitions
     * this event is fired with some delay after the navigate event.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterMasterNavigate(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SplitContainer$AfterMasterNavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterMasterOpen afterMasterOpen} event of this
     * `sap.m.SplitContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitContainer` itself.
     *
     * Fires when the master area is fully opened after animation if any.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterMasterOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterMasterOpen afterMasterOpen} event of this
     * `sap.m.SplitContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitContainer` itself.
     *
     * Fires when the master area is fully opened after animation if any.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterMasterOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeMasterClose beforeMasterClose} event of
     * this `sap.m.SplitContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitContainer` itself.
     *
     * Fires before the master area is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeMasterClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeMasterClose beforeMasterClose} event of
     * this `sap.m.SplitContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitContainer` itself.
     *
     * Fires before the master area is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeMasterClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeMasterOpen beforeMasterOpen} event of
     * this `sap.m.SplitContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitContainer` itself.
     *
     * Fires before the master area is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeMasterOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeMasterOpen beforeMasterOpen} event of
     * this `sap.m.SplitContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitContainer` itself.
     *
     * Fires before the master area is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeMasterOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:detailNavigate detailNavigate} event of this
     * `sap.m.SplitContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitContainer` itself.
     *
     * Fires when navigation between two pages in detail area has been triggered. The transition (if any) to
     * the new page has not started yet. NOTE: This event can be aborted by the application with preventDefault(),
     * which means that there will be no navigation.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDetailNavigate(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SplitContainer$DetailNavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:detailNavigate detailNavigate} event of this
     * `sap.m.SplitContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitContainer` itself.
     *
     * Fires when navigation between two pages in detail area has been triggered. The transition (if any) to
     * the new page has not started yet. NOTE: This event can be aborted by the application with preventDefault(),
     * which means that there will be no navigation.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDetailNavigate(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SplitContainer$DetailNavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:masterButton masterButton} event of this `sap.m.SplitContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitContainer` itself.
     *
     * Fires when a Master Button needs to be shown or hidden. This is necessary for custom headers when the
     * SplitContainer control does not handle the placement of the master button automatically.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachMasterButton(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:masterButton masterButton} event of this `sap.m.SplitContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitContainer` itself.
     *
     * Fires when a Master Button needs to be shown or hidden. This is necessary for custom headers when the
     * SplitContainer control does not handle the placement of the master button automatically.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachMasterButton(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:masterNavigate masterNavigate} event of this
     * `sap.m.SplitContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitContainer` itself.
     *
     * Fires when navigation between two pages in master area has been triggered. The transition (if any) to
     * the new page has not started yet. This event can be aborted by the application with preventDefault(),
     * which means that there will be no navigation.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachMasterNavigate(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SplitContainer$MasterNavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:masterNavigate masterNavigate} event of this
     * `sap.m.SplitContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.SplitContainer` itself.
     *
     * Fires when navigation between two pages in master area has been triggered. The transition (if any) to
     * the new page has not started yet. This event can be aborted by the application with preventDefault(),
     * which means that there will be no navigation.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachMasterNavigate(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: SplitContainer$MasterNavigateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.SplitContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Navigates back to the previous detail page found in the history.
     */
    backDetail(
      /**
       * This optional object can carry any payload data which should be made available to the target page of
       * the back navigation. The event on the target page will contain this data object as backData property.
       * (The original data from the to() navigation will still be available as data property.)
       *
       * In scenarios where the entity triggering the navigation can or should not directly initialize the target
       * page, it can fill this object and the target page itself (or a listener on it) can take over the initialization,
       * using the given data. For back navigation this can be used, for example, when returning from a detail
       * page to transfer any settings done there.
       *
       * When the transitionParameters object is used, this data object must also be given (either as object or
       * as null) in order to have a proper parameter order.
       */
      backData?: object,
      /**
       * This optional object can give additional information to the transition function, like the DOM element,
       * which triggered the transition or the desired transition duration. The animation type can NOT be selected
       * here - it is always the inverse of the "to" navigation.
       *
       * In order to use the transitionParameters property, the data property must be used (at least "null" must
       * be given) for a proper parameter order.
       *
       * NOTE: it depends on the transition function how the object should be structured and which parameters
       * are actually used to influence the transition.
       */
      transitionParameters?: object
    ): void;
    /**
     * Navigates back to the previous master page which is found in the history.
     */
    backMaster(
      /**
       * This optional object can carry any payload data which should be made available to the target page of
       * the back navigation. The event on the target page will contain this data object as backData property
       * (the original data from the to() navigation will still be available as data property).
       *
       * In scenarios where the entity triggering the navigation can or should not directly initialize the target
       * page, it can fill this object and the target page itself (or a listener on it) can take over the initialization,
       * using the given data. For back navigation this can be used, for example, when returning from a detail
       * page to transfer any settings done there.
       *
       * When the transitionParameters object is used, this data object must also be given (either as object or
       * as null) in order to have a proper parameter order.
       */
      backData?: object,
      /**
       * This optional object can give additional information to the transition function, like the DOM element,
       * which triggered the transition or the desired transition duration. The animation type can NOT be selected
       * here - it is always the inverse of the "to" navigation.
       *
       * In order to use the transitionParameters property, the data property must be used (at least "null" must
       * be given) for a proper parameter order.
       *
       * NOTE: it depends on the transition function how the object should be structured and which parameters
       * are actually used to influence the transition.
       */
      transitionParameters?: object
    ): void;
    /**
     * Navigates back to the nearest previous page in the SplitContainer history with the given ID (if there
     * is no such page among the previous pages, nothing happens). The transition effect, which had been used
     * to get to the current page is inverted and used for this navigation.
     *
     * Calling this navigation method, first triggers the (cancelable) navigate event on the SplitContainer,
     * then the BeforeHide pseudo event on the source page, BeforeFirstShow (if applicable), and BeforeShow
     * on the target page. Later, after the transition has completed, the AfterShow pseudo event is triggered
     * on the target page and AfterHide - on the page, which has been left. The given backData object is available
     * in the BeforeFirstShow, BeforeShow, and AfterShow event objects as data property. The original "data"
     * object from the "to" navigation is also available in these event objects.
     *
     * @since 1.10.0
     */
    backToPage(
      /**
       * The screen to which is being navigated to. The ID or the control itself can be given.
       */
      pageId: string,
      /**
       * This optional object can carry any payload data which should be made available to the target page of
       * the back navigation. The event on the target page will contain this data object as backData property.
       * (the original data from the to() navigation will still be available as data property).
       *
       * In scenarios, where the entity triggering the navigation can't or shouldn't directly initialize the target
       * page, it can fill this object and the target page itself (or a listener on it) can take over the initialization,
       * using the given data. For back navigation this can be used, for example, when returning from a detail
       * page to transfer any settings done there.
       *
       * When the transitionParameters object is used, this data object must also be given (either as object or
       * as null) in order to have a proper parameter order.
       */
      backData?: object,
      /**
       * This optional object can give additional information to the transition function, like the DOM element,
       * which triggered the transition or the desired transition duration. The animation type can NOT be selected
       * here - it is always the inverse of the "to" navigation.
       *
       * In order to use the transitionParameters property, the data property must be used (at least "null" must
       * be given) for a proper parameter order.
       *
       * NOTE: it depends on the transition function how the object should be structured and which parameters
       * are actually used to influence the transition.
       */
      transitionParameters?: object
    ): void;
    /**
     * Navigates back to the initial/top level of Detail (this is the element aggregated as initialPage, or
     * the first added element). NOTE: If already on the initial page, nothing happens. The transition effect
     * which had been used to get to the current page is inverted and used for this navigation.
     */
    backToTopDetail(
      /**
       * This optional object can carry any payload data which should be made available to the target page of
       * the back navigation. The event on the target page will contain this data object as backData property
       * (the original data from the to() navigation will still be available as data property).
       *
       * In scenarios where the entity triggering the navigation can or should not directly initialize the target
       * page, it can fill this object and the target page itself (or a listener on it) can take over the initialization,
       * using the given data. For back navigation this can be used, for example, when returning from a detail
       * page to transfer any settings done there.
       *
       * When the transitionParameters object is used, this data object must also be given (either as object or
       * as null) in order to have a proper parameter order.
       */
      backData?: object,
      /**
       * This optional object can give additional information to the transition function, like the DOM element,
       * which triggered the transition or the desired transition duration. The animation type can NOT be selected
       * here - it is always the inverse of the "to" navigation.
       *
       * In order to use the transitionParameters property, the data property must be used (at least "null" must
       * be given) for a proper parameter order.
       *
       * NOTE: it depends on the transition function how the object should be structured and which parameters
       * are actually used to influence the transition.
       */
      transitionParameters?: object
    ): void;
    /**
     * Navigates back to the initial/top level of Master (this is the element aggregated as "initialPage", or
     * the first added element). NOTE: If already on the initial page, nothing happens. The transition effect
     * which had been used to get to the current page is inverted and used for this navigation.
     */
    backToTopMaster(
      /**
       * This optional object can carry any payload data which should be made available to the target page of
       * the back navigation. The event on the target page will contain this data object as "backData" property.
       * (The original data from the "to()" navigation will still be available as "data" property.)
       *
       * In scenarios where the entity triggering the navigation can or should not directly initialize the target
       * page, it can fill this object and the target page itself (or a listener on it) can take over the initialization,
       * using the given data. For back navigation this can be used e.g. when returning from a detail page to
       * transfer any settings done there.
       *
       * When the "transitionParameters" object is used, this "data" object must also be given (either as object
       * or as null) in order to have a proper parameter order.
       */
      backData?: object,
      /**
       * This optional object can give additional information to the transition function, like the DOM element
       * which triggered the transition or the desired transition duration. The animation type can NOT be selected
       * here - it is always the inverse of the "to" navigation.
       *
       * In order to use the transitionParameters property, the data property must be used (at least "null" must
       * be given) for a proper parameter order.
       *
       * NOTE: it depends on the transition function how the object should be structured and which parameters
       * are actually used to influence the transition.
       */
      transitionParameters?: object
    ): void;
    /**
     * Destroys all the detailPages in the aggregation {@link #getDetailPages detailPages}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyDetailPages(): this;
    /**
     * Destroys all the masterPages in the aggregation {@link #getMasterPages masterPages}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyMasterPages(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterDetailNavigate afterDetailNavigate} event
     * of this `sap.m.SplitContainer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterDetailNavigate(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SplitContainer$AfterDetailNavigateEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterMasterClose afterMasterClose} event of
     * this `sap.m.SplitContainer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterMasterClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterMasterNavigate afterMasterNavigate} event
     * of this `sap.m.SplitContainer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterMasterNavigate(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SplitContainer$AfterMasterNavigateEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterMasterOpen afterMasterOpen} event of
     * this `sap.m.SplitContainer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterMasterOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeMasterClose beforeMasterClose} event
     * of this `sap.m.SplitContainer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeMasterClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeMasterOpen beforeMasterOpen} event of
     * this `sap.m.SplitContainer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeMasterOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:detailNavigate detailNavigate} event of this
     * `sap.m.SplitContainer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachDetailNavigate(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SplitContainer$DetailNavigateEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:masterButton masterButton} event of this `sap.m.SplitContainer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachMasterButton(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:masterNavigate masterNavigate} event of this
     * `sap.m.SplitContainer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachMasterNavigate(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: SplitContainer$MasterNavigateEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:afterDetailNavigate afterDetailNavigate} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterDetailNavigate(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SplitContainer$AfterDetailNavigateEventParameters
    ): this;
    /**
     * Fires event {@link #event:afterMasterClose afterMasterClose} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterMasterClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:afterMasterNavigate afterMasterNavigate} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterMasterNavigate(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SplitContainer$AfterMasterNavigateEventParameters
    ): this;
    /**
     * Fires event {@link #event:afterMasterOpen afterMasterOpen} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterMasterOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:beforeMasterClose beforeMasterClose} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforeMasterClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:beforeMasterOpen beforeMasterOpen} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforeMasterOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:detailNavigate detailNavigate} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireDetailNavigate(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SplitContainer$DetailNavigateEventParameters
    ): boolean;
    /**
     * Fires event {@link #event:masterButton masterButton} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireMasterButton(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:masterNavigate masterNavigate} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireMasterNavigate(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: SplitContainer$MasterNavigateEventParameters
    ): boolean;
    /**
     * Gets current value of property {@link #getBackgroundColor backgroundColor}.
     *
     * Determines the background color of the SplitContainer. If set, this color overrides the default one,
     * which is defined by the theme (should only be used when really required). Any configured background image
     * will be placed above this colored background, but any theme adaptation in the Theme Designer will override
     * this setting. Use the backgroundRepeat property to define whether this image should be stretched to cover
     * the complete SplitContainer or whether it should be tiled.
     *
     * @since 1.11.2
     *
     * @returns Value of property `backgroundColor`
     */
    getBackgroundColor(): string;
    /**
     * Gets current value of property {@link #getBackgroundImage backgroundImage}.
     *
     * Sets the background image of the SplitContainer. When set, this image overrides the default background
     * defined by the theme (should only be used when really required). This background image will be placed
     * above any color set for the background, but any theme adaptation in the Theme Designer will override
     * this image setting. Use the backgroundRepeat property to define whether this image should be stretched
     * to cover the complete SplitContainer or whether it should be tiled.
     *
     * @since 1.11.2
     *
     * @returns Value of property `backgroundImage`
     */
    getBackgroundImage(): URI;
    /**
     * Gets current value of property {@link #getBackgroundOpacity backgroundOpacity}.
     *
     * Defines the opacity of the background image - between 0 (fully transparent) and 1 (fully opaque). This
     * can be used to improve the content visibility by making the background image partly transparent.
     *
     * Default value is `1`.
     *
     * @since 1.11.2
     *
     * @returns Value of property `backgroundOpacity`
     */
    getBackgroundOpacity(): float;
    /**
     * Gets current value of property {@link #getBackgroundRepeat backgroundRepeat}.
     *
     * Defines whether the background image (if configured) is proportionally stretched to cover the whole SplitContainer
     * (false) or whether it should be tiled (true).
     *
     * Default value is `false`.
     *
     * @since 1.11.2
     *
     * @returns Value of property `backgroundRepeat`
     */
    getBackgroundRepeat(): boolean;
    /**
     * Returns the current displayed detail page.
     */
    getCurrentDetailPage(): Control;
    /**
     * Returns the current displayed master page.
     */
    getCurrentMasterPage(): Control;
    /**
     * Returns the currently displayed page either in master area or in detail area. When the parameter is set
     * to true, the current page in master area is returned, otherwise, the current page in detail area is returned.
     *
     * This method is provided mainly for API consistency between sap.m.SplitContainer and sap.m.App, so that
     * the same code line can be reused.
     *
     * @since 1.11.1
     */
    getCurrentPage(
      /**
       * States if this function returns the current page in master area. If it's set to false, the current page
       * in detail area will be returned.
       */
      bMaster: boolean
    ): Control;
    /**
     * Gets current value of property {@link #getDefaultTransitionNameDetail defaultTransitionNameDetail}.
     *
     * Determines the type of the transition/animation to apply when to() is called without defining the transition
     * to use. The default is "slide", other options are "fade", "show", and the names of any registered custom
     * transitions.
     *
     * Default value is `"slide"`.
     *
     *
     * @returns Value of property `defaultTransitionNameDetail`
     */
    getDefaultTransitionNameDetail(): string;
    /**
     * Gets current value of property {@link #getDefaultTransitionNameMaster defaultTransitionNameMaster}.
     *
     * Determines the type of the transition/animation to apply when to() is called, without defining the transition
     * to use. The default is "slide", other options are "fade", "show", and the names of any registered custom
     * transitions.
     *
     * Default value is `"slide"`.
     *
     *
     * @returns Value of property `defaultTransitionNameMaster`
     */
    getDefaultTransitionNameMaster(): string;
    /**
     * Returns the page with the given ID in detail area. If there's no page that has the given ID, null is
     * returned.
     *
     * @since 1.11.1
     *
     * @returns the requested page
     */
    getDetailPage(
      /**
       * The ID of the page that needs to be fetched.
       */
      pageId: string
    ): Control | null;
    /**
     * Gets content of aggregation {@link #getDetailPages detailPages}.
     *
     * Determines the content entities, between which the SplitContainer navigates in detail area. These can
     * be of type sap.m.Page, sap.ui.core.mvc.View, sap.m.Carousel or any other control with fullscreen/page
     * semantics. These aggregated controls receive navigation events like {@link sap.m.NavContainerChild#event:BeforeShow BeforeShow},
     * they are documented in the pseudo interface {@link sap.m.NavContainerChild sap.m.NavContainerChild}.
     */
    getDetailPages(): Control[];
    /**
     * ID of the element which is the current target of the association {@link #getInitialDetail initialDetail},
     * or `null`.
     */
    getInitialDetail(): ID | null;
    /**
     * ID of the element which is the current target of the association {@link #getInitialMaster initialMaster},
     * or `null`.
     */
    getInitialMaster(): ID | null;
    /**
     * Gets current value of property {@link #getMasterButtonText masterButtonText}.
     *
     * Determines the text displayed in master button, which has a default value "Navigation". This text is
     * only displayed in iOS platform and the icon from the current page in detail area is displayed in the
     * master button for the other platforms. The master button is shown/hidden depending on the orientation
     * of the device and whether the master area is opened or not. SplitContainer manages the show/hide of the
     * master button by itself only when the pages added to the detail area are sap.m.Page with built-in header
     * or sap.m.Page with built-in header, which is wrapped by one or several sap.ui.core.mvc.View. Otherwise,
     * the show/hide of master button needs to be managed by the application.
     *
     *
     * @returns Value of property `masterButtonText`
     */
    getMasterButtonText(): string;
    /**
     * Gets current value of property {@link #getMasterButtonTooltip masterButtonTooltip}.
     *
     * Specifies the tooltip of the master button. If the tooltip is not specified, the title of the page, which
     * is displayed is the master part, is set as tooltip to the master button.
     *
     * @since 1.48
     *
     * @returns Value of property `masterButtonTooltip`
     */
    getMasterButtonTooltip(): string;
    /**
     * Returns the page with the given ID in master area (if there's no page that has the given ID, null is
     * returned).
     *
     * @since 1.11.1
     *
     * @returns The requested page
     */
    getMasterPage(
      /**
       * The ID of the page that needs to be fetched
       */
      pageId: string
    ): Control | null;
    /**
     * Gets content of aggregation {@link #getMasterPages masterPages}.
     *
     * Determines the content entities, between which the SplitContainer navigates in master area. These can
     * be of type sap.m.Page, sap.ui.core.mvc.View, sap.m.Carousel or any other control with fullscreen/page
     * semantics. These aggregated controls receive navigation events like {@link sap.m.NavContainerChild#event:BeforeShow BeforeShow},
     * they are documented in the pseudo interface {@link sap.m.NavContainerChild sap.m.NavContainerChild}.
     */
    getMasterPages(): Control[];
    /**
     * Gets current value of property {@link #getMode mode}.
     *
     * Defines whether the master page will always be displayed (in portrait and landscape mode - StretchCompressMode),
     * or if it should be hidden when in portrait mode (ShowHideMode). Default is ShowHideMode. Other possible
     * values are Hide (Master is always hidden) and Popover (master is displayed in popover).
     *
     * Default value is `ShowHideMode`.
     *
     *
     * @returns Value of property `mode`
     */
    getMode(): SplitAppMode;
    /**
     * Returns the page with the given ID from either master area, or detail area depending on the master parameter
     * (if there's no page that has the given ID, null is returned).
     *
     * @since 1.11.1
     */
    getPage(
      /**
       * The ID of the page that needs to be fetched
       */
      pageId: string,
      /**
       * If the page with given ID should be fetched from the master area. If it's set to false, the page will
       * be fetched from detail area.
       */
      bMaster: boolean
    ): Control | null;
    /**
     * Returns the previous page (the page, from which the user drilled down to the current page with to()).
     * Note: this is not the page, which the user has seen before, but the page which is the target of the next
     * back() navigation. If there is no previous page, "undefined" is returned.
     */
    getPreviousPage(
      /**
       * States if this function returns the previous page in master area. If it's set to false, the previous
       * page in detail area will be returned.
       */
      bMaster: boolean
    ): Control;
    /**
     * Used to hide the master page when in ShowHideMode and the device is in portrait mode.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    hideMaster(): this;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getDetailPages detailPages}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfDetailPage(
      /**
       * The detailPage whose index is looked for
       */
      oDetailPage: Control
    ): int;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getMasterPages masterPages}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfMasterPage(
      /**
       * The masterPage whose index is looked for
       */
      oMasterPage: Control
    ): int;
    /**
     * Inserts a detailPage into the aggregation {@link #getDetailPages detailPages}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertDetailPage(
      /**
       * The detailPage to insert; if empty, nothing is inserted
       */
      oDetailPage: Control,
      /**
       * The `0`-based index the detailPage should be inserted at; for a negative value of `iIndex`, the detailPage
       * is inserted at position 0; for a value greater than the current size of the aggregation, the detailPage
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a masterPage into the aggregation {@link #getMasterPages masterPages}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertMasterPage(
      /**
       * The masterPage to insert; if empty, nothing is inserted
       */
      oMasterPage: Control,
      /**
       * The `0`-based index the masterPage should be inserted at; for a negative value of `iIndex`, the masterPage
       * is inserted at position 0; for a value greater than the current size of the aggregation, the masterPage
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts the page/control with the specified ID into the navigation history stack of the NavContainer.
     *
     * This can be used for deep-linking when the user directly reached a drilldown detail page using a bookmark
     * and then wants to navigate up in the drilldown hierarchy. Normally, such a back navigation would not
     * be possible as there is no previous page in the SplitContainer's history stack.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertPreviousPage(
      /**
       * The ID of the control/page/screen, which is inserted into the history stack. The respective control must
       * be aggregated by the SplitContainer, otherwise this will cause an error.
       */
      pageId: string,
      /**
       * The type of the transition/animation which would have been used to navigate from the (inserted) previous
       * page to the current page. When navigating back, the inverse animation will be applied. Options are "slide"
       * (horizontal movement from the right), "baseSlide", "fade", "flip", and "show" and the names of any registered
       * custom transitions.
       */
      transitionName: string,
      /**
       * This optional object can carry any payload data which would have been given to the inserted previous
       * page if the user would have done a normal forward navigation to it.
       */
      data: object
    ): this;
    /**
     * Inserts the page/control with the specified ID into the navigation history stack of the NavContainer.
     *
     * This can be used for deep-linking when the user directly reached a drilldown detail page using a bookmark
     * and then wants to navigate up in the drilldown hierarchy. Normally, such a back navigation would not
     * be possible as there is no previous page in the SplitContainer's history stack.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertPreviousPage(
      /**
       * The ID of the control/page/screen, which is inserted into the history stack. The respective control must
       * be aggregated by the SplitContainer, otherwise this will cause an error.
       */
      pageId: string,
      /**
       * This optional object can carry any payload data which would have been given to the inserted previous
       * page if the user would have done a normal forward navigation to it.
       */
      data: object
    ): this;
    /**
     * Returns whether master area is currently displayed on the screen.
     *
     * In desktop browser or tablet, this method returns true when master area is displayed on the screen, regardless
     * if in portrait or landscape mode. On mobile phone devices, this method returns true when the currently
     * displayed page is from the pages, which are added to the master area, otherwise, it returns false.
     *
     * @since 1.16.5
     */
    isMasterShown(): boolean;
    /**
     * Removes all the controls from the aggregation {@link #getDetailPages detailPages}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllDetailPages(): Control[];
    /**
     * Removes all the controls from the aggregation {@link #getMasterPages masterPages}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllMasterPages(): Control[];
    /**
     * Removes a detailPage from the aggregation {@link #getDetailPages detailPages}.
     *
     *
     * @returns The removed detailPage or `null`
     */
    removeDetailPage(
      /**
       * The detailPage to remove or its index or id
       */
      vDetailPage: int | string | Control
    ): Control | null;
    /**
     * Removes a masterPage from the aggregation {@link #getMasterPages masterPages}.
     *
     *
     * @returns The removed masterPage or `null`
     */
    removeMasterPage(
      /**
       * The masterPage to remove or its index or id
       */
      vMasterPage: int | string | Control
    ): Control | null;
    /**
     * Sets a new value for property {@link #getBackgroundColor backgroundColor}.
     *
     * Determines the background color of the SplitContainer. If set, this color overrides the default one,
     * which is defined by the theme (should only be used when really required). Any configured background image
     * will be placed above this colored background, but any theme adaptation in the Theme Designer will override
     * this setting. Use the backgroundRepeat property to define whether this image should be stretched to cover
     * the complete SplitContainer or whether it should be tiled.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.11.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundColor(
      /**
       * New value for property `backgroundColor`
       */
      sBackgroundColor?: string
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundImage backgroundImage}.
     *
     * Sets the background image of the SplitContainer. When set, this image overrides the default background
     * defined by the theme (should only be used when really required). This background image will be placed
     * above any color set for the background, but any theme adaptation in the Theme Designer will override
     * this image setting. Use the backgroundRepeat property to define whether this image should be stretched
     * to cover the complete SplitContainer or whether it should be tiled.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.11.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundImage(
      /**
       * New value for property `backgroundImage`
       */
      sBackgroundImage?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundOpacity backgroundOpacity}.
     *
     * Defines the opacity of the background image - between 0 (fully transparent) and 1 (fully opaque). This
     * can be used to improve the content visibility by making the background image partly transparent.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `1`.
     *
     * @since 1.11.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundOpacity(
      /**
       * New value for property `backgroundOpacity`
       */
      fBackgroundOpacity?: float
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundRepeat backgroundRepeat}.
     *
     * Defines whether the background image (if configured) is proportionally stretched to cover the whole SplitContainer
     * (false) or whether it should be tiled (true).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.11.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundRepeat(
      /**
       * New value for property `backgroundRepeat`
       */
      bBackgroundRepeat?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getDefaultTransitionNameDetail defaultTransitionNameDetail}.
     *
     * Determines the type of the transition/animation to apply when to() is called without defining the transition
     * to use. The default is "slide", other options are "fade", "show", and the names of any registered custom
     * transitions.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"slide"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDefaultTransitionNameDetail(
      /**
       * New value for property `defaultTransitionNameDetail`
       */
      sDefaultTransitionNameDetail?: string
    ): this;
    /**
     * Sets a new value for property {@link #getDefaultTransitionNameMaster defaultTransitionNameMaster}.
     *
     * Determines the type of the transition/animation to apply when to() is called, without defining the transition
     * to use. The default is "slide", other options are "fade", "show", and the names of any registered custom
     * transitions.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"slide"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDefaultTransitionNameMaster(
      /**
       * New value for property `defaultTransitionNameMaster`
       */
      sDefaultTransitionNameMaster?: string
    ): this;
    /**
     * Sets the associated {@link #getInitialDetail initialDetail}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInitialDetail(
      /**
       * ID of an element which becomes the new target of this initialDetail association; alternatively, an element
       * instance may be given
       */
      oInitialDetail: ID | Control
    ): this;
    /**
     * Sets the associated {@link #getInitialMaster initialMaster}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInitialMaster(
      /**
       * ID of an element which becomes the new target of this initialMaster association; alternatively, an element
       * instance may be given
       */
      oInitialMaster: ID | Control
    ): this;
    /**
     * Sets a new value for property {@link #getMasterButtonText masterButtonText}.
     *
     * Determines the text displayed in master button, which has a default value "Navigation". This text is
     * only displayed in iOS platform and the icon from the current page in detail area is displayed in the
     * master button for the other platforms. The master button is shown/hidden depending on the orientation
     * of the device and whether the master area is opened or not. SplitContainer manages the show/hide of the
     * master button by itself only when the pages added to the detail area are sap.m.Page with built-in header
     * or sap.m.Page with built-in header, which is wrapped by one or several sap.ui.core.mvc.View. Otherwise,
     * the show/hide of master button needs to be managed by the application.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMasterButtonText(
      /**
       * New value for property `masterButtonText`
       */
      sMasterButtonText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getMasterButtonTooltip masterButtonTooltip}.
     *
     * Specifies the tooltip of the master button. If the tooltip is not specified, the title of the page, which
     * is displayed is the master part, is set as tooltip to the master button.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.48
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMasterButtonTooltip(
      /**
       * New value for property `masterButtonTooltip`
       */
      sMasterButtonTooltip?: string
    ): this;
    /**
     * Sets a new value for property {@link #getMode mode}.
     *
     * Defines whether the master page will always be displayed (in portrait and landscape mode - StretchCompressMode),
     * or if it should be hidden when in portrait mode (ShowHideMode). Default is ShowHideMode. Other possible
     * values are Hide (Master is always hidden) and Popover (master is displayed in popover).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `ShowHideMode`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMode(
      /**
       * New value for property `mode`
       */
      sMode?: SplitAppMode | keyof typeof SplitAppMode
    ): this;
    /**
     * Used to make the master page visible when in ShowHideMode and the device is in portrait mode.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    showMaster(): this;
    /**
     * Navigates to the given page inside the SplitContainer. The navigation is done inside the master area
     * if the page has been added, otherwise, it tries to do the page navigation in the detail area.
     *
     * @since 1.10.0
     */
    to(
      /**
       * The screen to which we are navigating to. The ID or the control itself can be given.
       */
      pageId: string,
      /**
       * The type of the transition/animation to apply. Options are "slide" (horizontal movement from the right),
       * "baseSlide", "fade", "flip", and "show" and the names of any registered custom transitions.
       *
       * None of the standard transitions is currently making use of any given transition parameters.
       */
      transitionName?: string,
      /**
       * This optional object can carry any payload data which should be made available to the target page. The
       * BeforeShow event on the target page will contain this data object as data property.
       *
       * Use case: in scenarios where the entity triggering the navigation can or should not directly initialize
       * the target page, it can fill this object and the target page itself (or a listener on it) can take over
       * the initialization, using the given data.
       *
       * When the transitionParameters object is used, this "data" object must also be given (either as object
       * or as null) in order to have a proper parameter order.
       */
      data?: object,
      /**
       * This optional object can contain additional information for the transition function, like the DOM element
       * which triggered the transition or the desired transition duration.
       *
       * For a proper parameter order, the "data" parameter must be given when the transitionParameters parameter
       * is used (it can be given as "null").
       *
       * NOTE: It depends on the transition function how the object should be structured and which parameters
       * are actually used to influence the transition. The "show", "slide" and "fade" transitions do not use
       * any parameter.
       */
      transitionParameters?: object
    ): void;
    /**
     * Navigates to a given detail page.
     */
    toDetail(
      /**
       * Id of the page
       */
      pageId: string,
      /**
       * The type of the transition/animation to apply. Options are "slide" (horizontal movement from the right),
       * "baseSlide", "fade", "flip", and "show" and the names of any registered custom transitions.
       *
       * None of the standard transitions is currently making use of any given transition parameters.
       */
      transitionName: string,
      /**
       * This optional object can carry any payload data which should be made available to the target page. The
       * BeforeShow event on the target page will contain this data object as data property.
       *
       * Use case: in scenarios where the entity triggering the navigation can or should not directly initialize
       * the target page, it can fill this object and the target page itself (or a listener on it) can take over
       * the initialization, using the given data.
       *
       * When the transitionParameters object is used, this data object must also be given (either as object or
       * as null) in order to have a proper parameter order.
       */
      data?: object,
      /**
       * This optional object can contain additional information for the transition function, like the DOM element,
       * which triggered the transition or the desired transition duration.
       *
       * For a proper parameter order, the data parameter must be given when the transitionParameters parameter
       * is used (it can be given as "null").
       *
       * NOTE: it depends on the transition function how the object should be structured and which parameters
       * are actually used to influence the transition. The "show", "slide" and "fade" transitions do not use
       * any parameter.
       */
      transitionParameters?: object
    ): void;
    /**
     * Navigates to a given master page.
     */
    toMaster(
      /**
       * The screen to which drilldown should happen. The ID or the control itself can be given.
       */
      pageId: string,
      /**
       * The type of the transition/animation to apply. Options are "slide" (horizontal movement from the right),
       * "baseSlide", "fade", "flip", and "show" and the names of any registered custom transitions.
       *
       * None of the standard transitions is currently making use of any given transition parameters.
       */
      transitionName: string,
      /**
       * Since version 1.7.1. This optional object can carry any payload data which should be made available to
       * the target page. The BeforeShow event on the target page will contain this data object as data property.
       *
       * Use case: in scenarios where the entity triggering the navigation can't or shouldn't directly initialize
       * the target page, it can fill this object and the target page itself (or a listener on it) can take over
       * the initialization, using the given data.
       *
       * When the transitionParameters object is used, this data object must also be given (either as object or
       * as null) in order to have a proper parameter order.
       */
      data?: object,
      /**
       * Since version 1.7.1. This optional object can contain additional information for the transition function,
       * like the DOM element, which triggered the transition or the desired transition duration.
       *
       * For a proper parameter order, the data parameter must be given when the transitionParameters parameter
       * is used (it can be given as "null").
       *
       * NOTE: it depends on the transition function how the object should be structured and which parameters
       * are actually used to influence the transition. The "show", "slide" and "fade" transitions do not use
       * any parameter.
       */
      transitionParameters?: object
    ): void;
  }
  /**
   * Describes the settings that can be provided to the SplitContainer constructor.
   */
  export interface $SplitContainerSettings extends $ControlSettings {
    /**
     * Determines the type of the transition/animation to apply when to() is called without defining the transition
     * to use. The default is "slide", other options are "fade", "show", and the names of any registered custom
     * transitions.
     */
    defaultTransitionNameDetail?: string | PropertyBindingInfo;

    /**
     * Determines the type of the transition/animation to apply when to() is called, without defining the transition
     * to use. The default is "slide", other options are "fade", "show", and the names of any registered custom
     * transitions.
     */
    defaultTransitionNameMaster?: string | PropertyBindingInfo;

    /**
     * Defines whether the master page will always be displayed (in portrait and landscape mode - StretchCompressMode),
     * or if it should be hidden when in portrait mode (ShowHideMode). Default is ShowHideMode. Other possible
     * values are Hide (Master is always hidden) and Popover (master is displayed in popover).
     */
    mode?:
      | (SplitAppMode | keyof typeof SplitAppMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines the text displayed in master button, which has a default value "Navigation". This text is
     * only displayed in iOS platform and the icon from the current page in detail area is displayed in the
     * master button for the other platforms. The master button is shown/hidden depending on the orientation
     * of the device and whether the master area is opened or not. SplitContainer manages the show/hide of the
     * master button by itself only when the pages added to the detail area are sap.m.Page with built-in header
     * or sap.m.Page with built-in header, which is wrapped by one or several sap.ui.core.mvc.View. Otherwise,
     * the show/hide of master button needs to be managed by the application.
     */
    masterButtonText?: string | PropertyBindingInfo;

    /**
     * Specifies the tooltip of the master button. If the tooltip is not specified, the title of the page, which
     * is displayed is the master part, is set as tooltip to the master button.
     *
     * @since 1.48
     */
    masterButtonTooltip?: string | PropertyBindingInfo;

    /**
     * Determines the background color of the SplitContainer. If set, this color overrides the default one,
     * which is defined by the theme (should only be used when really required). Any configured background image
     * will be placed above this colored background, but any theme adaptation in the Theme Designer will override
     * this setting. Use the backgroundRepeat property to define whether this image should be stretched to cover
     * the complete SplitContainer or whether it should be tiled.
     *
     * @since 1.11.2
     */
    backgroundColor?: string | PropertyBindingInfo;

    /**
     * Sets the background image of the SplitContainer. When set, this image overrides the default background
     * defined by the theme (should only be used when really required). This background image will be placed
     * above any color set for the background, but any theme adaptation in the Theme Designer will override
     * this image setting. Use the backgroundRepeat property to define whether this image should be stretched
     * to cover the complete SplitContainer or whether it should be tiled.
     *
     * @since 1.11.2
     */
    backgroundImage?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether the background image (if configured) is proportionally stretched to cover the whole SplitContainer
     * (false) or whether it should be tiled (true).
     *
     * @since 1.11.2
     */
    backgroundRepeat?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the opacity of the background image - between 0 (fully transparent) and 1 (fully opaque). This
     * can be used to improve the content visibility by making the background image partly transparent.
     *
     * @since 1.11.2
     */
    backgroundOpacity?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the content entities, between which the SplitContainer navigates in master area. These can
     * be of type sap.m.Page, sap.ui.core.mvc.View, sap.m.Carousel or any other control with fullscreen/page
     * semantics. These aggregated controls receive navigation events like {@link sap.m.NavContainerChild#event:BeforeShow BeforeShow},
     * they are documented in the pseudo interface {@link sap.m.NavContainerChild sap.m.NavContainerChild}.
     */
    masterPages?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * Determines the content entities, between which the SplitContainer navigates in detail area. These can
     * be of type sap.m.Page, sap.ui.core.mvc.View, sap.m.Carousel or any other control with fullscreen/page
     * semantics. These aggregated controls receive navigation events like {@link sap.m.NavContainerChild#event:BeforeShow BeforeShow},
     * they are documented in the pseudo interface {@link sap.m.NavContainerChild sap.m.NavContainerChild}.
     */
    detailPages?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * Sets the initial detail page, which is displayed on application launch.
     */
    initialDetail?: Control | string;

    /**
     * Sets the initial master page, which is displayed on application launch.
     */
    initialMaster?: Control | string;

    /**
     * Fires when navigation between two pages in master area has been triggered. The transition (if any) to
     * the new page has not started yet. This event can be aborted by the application with preventDefault(),
     * which means that there will be no navigation.
     */
    masterNavigate?: (oEvent: SplitContainer$MasterNavigateEvent) => void;

    /**
     * Fires when navigation between two pages in master area has completed. NOTE: In case of animated transitions
     * this event is fired with some delay after the navigate event.
     */
    afterMasterNavigate?: (
      oEvent: SplitContainer$AfterMasterNavigateEvent
    ) => void;

    /**
     * Fires when a Master Button needs to be shown or hidden. This is necessary for custom headers when the
     * SplitContainer control does not handle the placement of the master button automatically.
     */
    masterButton?: (oEvent: Event) => void;

    /**
     * Fires before the master area is opened.
     */
    beforeMasterOpen?: (oEvent: Event) => void;

    /**
     * Fires when the master area is fully opened after animation if any.
     */
    afterMasterOpen?: (oEvent: Event) => void;

    /**
     * Fires before the master area is closed.
     */
    beforeMasterClose?: (oEvent: Event) => void;

    /**
     * Fires when the master area is fully closed after the animation (if any).
     */
    afterMasterClose?: (oEvent: Event) => void;

    /**
     * Fires when navigation between two pages in detail area has been triggered. The transition (if any) to
     * the new page has not started yet. NOTE: This event can be aborted by the application with preventDefault(),
     * which means that there will be no navigation.
     */
    detailNavigate?: (oEvent: SplitContainer$DetailNavigateEvent) => void;

    /**
     * Fires when navigation between two pages in detail area has completed. NOTE: In case of animated transitions
     * this event is fired with some delay after the "navigate" event.
     */
    afterDetailNavigate?: (
      oEvent: SplitContainer$AfterDetailNavigateEvent
    ) => void;
  }

  /**
   * Parameters of the SplitContainer#afterDetailNavigate event.
   */
  export interface SplitContainer$AfterDetailNavigateEventParameters {
    /**
     * The page, which had been displayed before navigation.
     */
    from?: Control;

    /**
     * The ID of the page, which had been displayed before navigation.
     */
    fromId?: string;

    /**
     * The page, which is now displayed after navigation.
     */
    to?: Control;

    /**
     * The ID of the page, which is now displayed after navigation.
     */
    toId?: string;

    /**
     * Determines whether the "to" page (more precisely: a control with the ID of the page, which has been navigated
     * to) has not been displayed/navigated to before.
     */
    firstTime?: boolean;

    /**
     * Determines whether was a forward navigation, triggered by to().
     */
    isTo?: boolean;

    /**
     * Determines whether this was a back navigation, triggered by back().
     */
    isBack?: boolean;

    /**
     * Determines whether this was a navigation to the root page, triggered by backToTop().
     */
    isBackToTop?: boolean;

    /**
     * Determines whether this was a navigation to a specific page, triggered by backToPage().
     */
    isBackToPage?: boolean;

    /**
     * Determines how the navigation was triggered, possible values are "to", "back", "backToPage", and "backToTop".
     */
    direction?: string;
  }

  /**
   * Event object of the SplitContainer#afterDetailNavigate event.
   */
  export type SplitContainer$AfterDetailNavigateEvent = Event<
    SplitContainer$AfterDetailNavigateEventParameters,
    SplitContainer
  >;

  /**
   * Parameters of the SplitContainer#afterMasterClose event.
   */
  export interface SplitContainer$AfterMasterCloseEventParameters {}

  /**
   * Event object of the SplitContainer#afterMasterClose event.
   */
  export type SplitContainer$AfterMasterCloseEvent = Event<
    SplitContainer$AfterMasterCloseEventParameters,
    SplitContainer
  >;

  /**
   * Parameters of the SplitContainer#afterMasterNavigate event.
   */
  export interface SplitContainer$AfterMasterNavigateEventParameters {
    /**
     * The page, which had been displayed before navigation.
     */
    from?: Control;

    /**
     * The ID of the page, which had been displayed before navigation.
     */
    fromId?: string;

    /**
     * The page, which is now displayed after navigation.
     */
    to?: Control;

    /**
     * The ID of the page, which is now displayed after navigation.
     */
    toId?: string;

    /**
     * Whether the "to" page (more precisely: a control with the ID of the page, which has been navigated to)
     * has not been displayed/navigated to before.
     */
    firstTime?: boolean;

    /**
     * Determines whether was a forward navigation, triggered by to().
     */
    isTo?: boolean;

    /**
     * Determines whether this was a back navigation, triggered by back().
     */
    isBack?: boolean;

    /**
     * Determines whether this was a navigation to the root page, triggered by backToTop().
     */
    isBackToTop?: boolean;

    /**
     * Determines whether this was a navigation to a specific page, triggered by backToPage().
     */
    isBackToPage?: boolean;

    /**
     * Determines how the navigation was triggered, possible values are "to", "back", "backToPage", and "backToTop".
     */
    direction?: string;
  }

  /**
   * Event object of the SplitContainer#afterMasterNavigate event.
   */
  export type SplitContainer$AfterMasterNavigateEvent = Event<
    SplitContainer$AfterMasterNavigateEventParameters,
    SplitContainer
  >;

  /**
   * Parameters of the SplitContainer#afterMasterOpen event.
   */
  export interface SplitContainer$AfterMasterOpenEventParameters {}

  /**
   * Event object of the SplitContainer#afterMasterOpen event.
   */
  export type SplitContainer$AfterMasterOpenEvent = Event<
    SplitContainer$AfterMasterOpenEventParameters,
    SplitContainer
  >;

  /**
   * Parameters of the SplitContainer#beforeMasterClose event.
   */
  export interface SplitContainer$BeforeMasterCloseEventParameters {}

  /**
   * Event object of the SplitContainer#beforeMasterClose event.
   */
  export type SplitContainer$BeforeMasterCloseEvent = Event<
    SplitContainer$BeforeMasterCloseEventParameters,
    SplitContainer
  >;

  /**
   * Parameters of the SplitContainer#beforeMasterOpen event.
   */
  export interface SplitContainer$BeforeMasterOpenEventParameters {}

  /**
   * Event object of the SplitContainer#beforeMasterOpen event.
   */
  export type SplitContainer$BeforeMasterOpenEvent = Event<
    SplitContainer$BeforeMasterOpenEventParameters,
    SplitContainer
  >;

  /**
   * Parameters of the SplitContainer#detailNavigate event.
   */
  export interface SplitContainer$DetailNavigateEventParameters {
    /**
     * The page, which was displayed before the current navigation.
     */
    from?: Control;

    /**
     * The ID of the page, which was displayed before the current navigation.
     */
    fromId?: string;

    /**
     * The page, which will be displayed after the current navigation.
     */
    to?: Control;

    /**
     * The ID of the page, which will be displayed after the current navigation.
     */
    toId?: string;

    /**
     * Determines whether the "to" page (more precisely: a control with the ID of the page, which is currently
     * navigated to) has not been displayed/navigated to before.
     */
    firstTime?: boolean;

    /**
     * Determines whether this is a forward navigation, triggered by to().
     */
    isTo?: boolean;

    /**
     * Determines whether this is a back navigation, triggered by back().
     */
    isBack?: boolean;

    /**
     * Determines whether this is a navigation to the root page, triggered by backToTop().
     */
    isBackToTop?: boolean;

    /**
     * Determines whether this was a navigation to a specific page, triggered by backToPage().
     */
    isBackToPage?: boolean;

    /**
     * Determines how the navigation was triggered, possible values are "to", "back", "backToPage", and "backToTop".
     */
    direction?: string;
  }

  /**
   * Event object of the SplitContainer#detailNavigate event.
   */
  export type SplitContainer$DetailNavigateEvent = Event<
    SplitContainer$DetailNavigateEventParameters,
    SplitContainer
  >;

  /**
   * Parameters of the SplitContainer#masterButton event.
   */
  export interface SplitContainer$MasterButtonEventParameters {}

  /**
   * Event object of the SplitContainer#masterButton event.
   */
  export type SplitContainer$MasterButtonEvent = Event<
    SplitContainer$MasterButtonEventParameters,
    SplitContainer
  >;

  /**
   * Parameters of the SplitContainer#masterNavigate event.
   */
  export interface SplitContainer$MasterNavigateEventParameters {
    /**
     * The page, which was displayed before the current navigation.
     */
    from?: Control;

    /**
     * The ID of the page, which was displayed before the current navigation.
     */
    fromId?: string;

    /**
     * The page, which will be displayed after the current navigation.
     */
    to?: Control;

    /**
     * The ID of the page, which will be displayed after the current navigation.
     */
    toId?: string;

    /**
     * Determines whether the "to" page (more precisely: a control with the ID of the page, which is currently
     * being navigated to) has not been displayed/navigated to before.
     */
    firstTime?: boolean;

    /**
     * Determines whether this is a forward navigation, triggered by to().
     */
    isTo?: boolean;

    /**
     * Determines whether this is a back navigation, triggered by back().
     */
    isBack?: boolean;

    /**
     * Determines whether this is a navigation to the root page, triggered by backToTop().
     */
    isBackToTop?: boolean;

    /**
     * Determines whether this was a navigation to a specific page, triggered by backToPage().
     */
    isBackToPage?: boolean;

    /**
     * Determines how the navigation was triggered, possible values are "to", "back", "backToPage", and "backToTop".
     */
    direction?: string;
  }

  /**
   * Event object of the SplitContainer#masterNavigate event.
   */
  export type SplitContainer$MasterNavigateEvent = Event<
    SplitContainer$MasterNavigateEventParameters,
    SplitContainer
  >;
}

declare module "sap/m/StandardListItem" {
  import {
    default as ListItemBase,
    $ListItemBaseSettings,
  } from "sap/m/ListItemBase";

  import { URI, ValueState, TextDirection } from "sap/ui/core/library";

  import Avatar from "sap/m/Avatar";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * `sap.m.StandardListItem` is a list item providing the most common use cases, e.g. image, title and description.
   */
  export default class StandardListItem extends ListItemBase {
    /**
     * Constructor for a new StandardListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:/standard-list-item/ Standard List Item}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $StandardListItemSettings
    );
    /**
     * Constructor for a new StandardListItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:/standard-list-item/ Standard List Item}
     */
    constructor(
      /**
       * Id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $StandardListItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.StandardListItem with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ListItemBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, StandardListItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.StandardListItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Destroys the avatar in the aggregation {@link #getAvatar avatar}.
     *
     * @since 1.98
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyAvatar(): this;
    /**
     * Gets current value of property {@link #getActiveIcon activeIcon}.
     *
     * Defines the icon that is shown while the list item is pressed.
     *
     *
     * @returns Value of property `activeIcon`
     */
    getActiveIcon(): URI;
    /**
     * Gets current value of property {@link #getAdaptTitleSize adaptTitleSize}.
     *
     * By default, the title size adapts to the available space and gets bigger if the description is empty.
     * If you have list items with and without descriptions, this results in titles with different sizes. In
     * this case, it can be better to switch the size adaption off by setting this property to `false`.
     *
     * Default value is `true`.
     *
     * @since 1.16.3
     *
     * @returns Value of property `adaptTitleSize`
     */
    getAdaptTitleSize(): boolean;
    /**
     * Gets content of aggregation {@link #getAvatar avatar}.
     *
     * A `sap.m.Avatar` control instance that, if set, is used instead of an icon or image.
     *
     * The size of the `Avatar` control depends on the `insetIcon` property of `StandardListItem`. The `displaySize`
     * property of the `Avatar` control is not supported. If the `insetIcon` property of `StandardListItem`
     * is set to `true`, the size of the `Avatar` control is set to XS; if the `insetIcon` property of `StandardListItem`
     * is set to `false`, the size of the `Avatar` control is set to "S".
     *
     * @since 1.98
     */
    getAvatar(): Avatar;
    /**
     * Gets current value of property {@link #getDescription description}.
     *
     * Defines the additional information for the title. **Note:** This is only visible when the `title` property
     * is not empty.
     *
     *
     * @returns Value of property `description`
     */
    getDescription(): string;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Defines the list item icon.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getIconDensityAware iconDensityAware}.
     *
     * By default, one or more requests are sent to get the density perfect version of the icon if the given
     * version of the icon doesn't exist on the server. **Note:** If bandwidth is a key factor for the application,
     * set this value to `false`.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `iconDensityAware`
     */
    getIconDensityAware(): boolean;
    /**
     * Gets current value of property {@link #getIconInset iconInset}.
     *
     * Defines the indentation of the icon. If set to `false`, the icon will not be shown as embedded. Instead
     * it will take the full height of the list item.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `iconInset`
     */
    getIconInset(): boolean;
    /**
     * Gets current value of property {@link #getInfo info}.
     *
     * Defines an additional information text. **Note:** A wrapping of the information text is also supported
     * as of version 1.95, if `wrapping=true`. Although long strings are supported for the information text,
     * it is recommended to use short strings. For more details, see {@link #getWrapping wrapping}.
     *
     *
     * @returns Value of property `info`
     */
    getInfo(): string;
    /**
     * Gets current value of property {@link #getInfoState infoState}.
     *
     * Defines the state of the information text, e.g. `Error`, `Warning`, `Success`.
     *
     * Default value is `None`.
     *
     *
     * @returns Value of property `infoState`
     */
    getInfoState(): ValueState;
    /**
     * Gets current value of property {@link #getInfoStateInverted infoStateInverted}.
     *
     * Determines the inverted rendering behavior of the info text and the info state. The color defined by
     * the `infoState` property is rendered as the background color for the info text, if this property is set
     * to `true`.
     *
     * Default value is `false`.
     *
     * @since 1.74
     *
     * @returns Value of property `infoStateInverted`
     */
    getInfoStateInverted(): boolean;
    /**
     * Gets current value of property {@link #getInfoTextDirection infoTextDirection}.
     *
     * Defines the `info` directionality with enumerated options. By default, the control inherits text direction
     * from the DOM.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Value of property `infoTextDirection`
     */
    getInfoTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Defines the title of the list item.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getTitleTextDirection titleTextDirection}.
     *
     * Defines the `title` text directionality with enumerated options. By default, the control inherits text
     * direction from the DOM.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Value of property `titleTextDirection`
     */
    getTitleTextDirection(): TextDirection;
    /**
     * Gets current value of property {@link #getWrapCharLimit wrapCharLimit}.
     *
     * This property can be used to change the default character limits for the wrapping behavior.
     *
     * If this property is set to 0, then the default character limit used by the wrapping behavior is used.
     * For details see {@link #getWrapping wrapping}.
     *
     * **Note:**
     *
     * 0 or a positive integer must be used for this property.
     *
     * Default value is `0`.
     *
     * @since 1.94
     *
     * @returns Value of property `wrapCharLimit`
     */
    getWrapCharLimit(): int;
    /**
     * Gets current value of property {@link #getWrapping wrapping}.
     *
     * Defines the wrapping behavior of title and description texts.
     *
     * **Note:**
     *
     * In the desktop mode, initial rendering of the control contains 300 characters along with a button to
     * expand and collapse the text whereas in the phone mode, the character limit is set to 100 characters.
     *  A wrapping of the information text is supported as of 1.95. But expanding and collapsing the information
     * text is not possible. A wrapping of the information text is disabled if `infoStateInverted` is set to
     * `true`.
     *
     * Default value is `false`.
     *
     * @since 1.67
     *
     * @returns Value of property `wrapping`
     */
    getWrapping(): boolean;
    /**
     * Sets a new value for property {@link #getActiveIcon activeIcon}.
     *
     * Defines the icon that is shown while the list item is pressed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setActiveIcon(
      /**
       * New value for property `activeIcon`
       */
      sActiveIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getAdaptTitleSize adaptTitleSize}.
     *
     * By default, the title size adapts to the available space and gets bigger if the description is empty.
     * If you have list items with and without descriptions, this results in titles with different sizes. In
     * this case, it can be better to switch the size adaption off by setting this property to `false`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.16.3
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAdaptTitleSize(
      /**
       * New value for property `adaptTitleSize`
       */
      bAdaptTitleSize?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getAvatar avatar}.
     *
     * @since 1.98
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAvatar(
      /**
       * The avatar to set
       */
      oAvatar: Avatar
    ): this;
    /**
     * Sets a new value for property {@link #getDescription description}.
     *
     * Defines the additional information for the title. **Note:** This is only visible when the `title` property
     * is not empty.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDescription(
      /**
       * New value for property `description`
       */
      sDescription?: string
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Defines the list item icon.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getIconDensityAware iconDensityAware}.
     *
     * By default, one or more requests are sent to get the density perfect version of the icon if the given
     * version of the icon doesn't exist on the server. **Note:** If bandwidth is a key factor for the application,
     * set this value to `false`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconDensityAware(
      /**
       * New value for property `iconDensityAware`
       */
      bIconDensityAware?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIconInset iconInset}.
     *
     * Defines the indentation of the icon. If set to `false`, the icon will not be shown as embedded. Instead
     * it will take the full height of the list item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconInset(
      /**
       * New value for property `iconInset`
       */
      bIconInset?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getInfo info}.
     *
     * Defines an additional information text. **Note:** A wrapping of the information text is also supported
     * as of version 1.95, if `wrapping=true`. Although long strings are supported for the information text,
     * it is recommended to use short strings. For more details, see {@link #getWrapping wrapping}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInfo(
      /**
       * New value for property `info`
       */
      sInfo?: string
    ): this;
    /**
     * Sets a new value for property {@link #getInfoState infoState}.
     *
     * Defines the state of the information text, e.g. `Error`, `Warning`, `Success`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInfoState(
      /**
       * New value for property `infoState`
       */
      sInfoState?: ValueState | keyof typeof ValueState
    ): this;
    /**
     * Sets a new value for property {@link #getInfoStateInverted infoStateInverted}.
     *
     * Determines the inverted rendering behavior of the info text and the info state. The color defined by
     * the `infoState` property is rendered as the background color for the info text, if this property is set
     * to `true`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.74
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInfoStateInverted(
      /**
       * New value for property `infoStateInverted`
       */
      bInfoStateInverted?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getInfoTextDirection infoTextDirection}.
     *
     * Defines the `info` directionality with enumerated options. By default, the control inherits text direction
     * from the DOM.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInfoTextDirection(
      /**
       * New value for property `infoTextDirection`
       */
      sInfoTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Defines the title of the list item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitleTextDirection titleTextDirection}.
     *
     * Defines the `title` text directionality with enumerated options. By default, the control inherits text
     * direction from the DOM.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleTextDirection(
      /**
       * New value for property `titleTextDirection`
       */
      sTitleTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getWrapCharLimit wrapCharLimit}.
     *
     * This property can be used to change the default character limits for the wrapping behavior.
     *
     * If this property is set to 0, then the default character limit used by the wrapping behavior is used.
     * For details see {@link #getWrapping wrapping}.
     *
     * **Note:**
     *
     * 0 or a positive integer must be used for this property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     * @since 1.94
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWrapCharLimit(
      /**
       * New value for property `wrapCharLimit`
       */
      iWrapCharLimit?: int
    ): this;
    /**
     * Sets a new value for property {@link #getWrapping wrapping}.
     *
     * Defines the wrapping behavior of title and description texts.
     *
     * **Note:**
     *
     * In the desktop mode, initial rendering of the control contains 300 characters along with a button to
     * expand and collapse the text whereas in the phone mode, the character limit is set to 100 characters.
     *  A wrapping of the information text is supported as of 1.95. But expanding and collapsing the information
     * text is not possible. A wrapping of the information text is disabled if `infoStateInverted` is set to
     * `true`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.67
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWrapping(
      /**
       * New value for property `wrapping`
       */
      bWrapping?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the StandardListItem constructor.
   */
  export interface $StandardListItemSettings extends $ListItemBaseSettings {
    /**
     * Defines the title of the list item.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Defines the additional information for the title. **Note:** This is only visible when the `title` property
     * is not empty.
     */
    description?: string | PropertyBindingInfo;

    /**
     * Defines the list item icon.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the indentation of the icon. If set to `false`, the icon will not be shown as embedded. Instead
     * it will take the full height of the list item.
     */
    iconInset?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * By default, one or more requests are sent to get the density perfect version of the icon if the given
     * version of the icon doesn't exist on the server. **Note:** If bandwidth is a key factor for the application,
     * set this value to `false`.
     */
    iconDensityAware?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the icon that is shown while the list item is pressed.
     */
    activeIcon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines an additional information text. **Note:** A wrapping of the information text is also supported
     * as of version 1.95, if `wrapping=true`. Although long strings are supported for the information text,
     * it is recommended to use short strings. For more details, see {@link #getWrapping wrapping}.
     */
    info?: string | PropertyBindingInfo;

    /**
     * Defines the state of the information text, e.g. `Error`, `Warning`, `Success`.
     */
    infoState?:
      | (ValueState | keyof typeof ValueState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * By default, the title size adapts to the available space and gets bigger if the description is empty.
     * If you have list items with and without descriptions, this results in titles with different sizes. In
     * this case, it can be better to switch the size adaption off by setting this property to `false`.
     *
     * @since 1.16.3
     */
    adaptTitleSize?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the `title` text directionality with enumerated options. By default, the control inherits text
     * direction from the DOM.
     *
     * @since 1.28.0
     */
    titleTextDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the `info` directionality with enumerated options. By default, the control inherits text direction
     * from the DOM.
     *
     * @since 1.28.0
     */
    infoTextDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the wrapping behavior of title and description texts.
     *
     * **Note:**
     *
     * In the desktop mode, initial rendering of the control contains 300 characters along with a button to
     * expand and collapse the text whereas in the phone mode, the character limit is set to 100 characters.
     *  A wrapping of the information text is supported as of 1.95. But expanding and collapsing the information
     * text is not possible. A wrapping of the information text is disabled if `infoStateInverted` is set to
     * `true`.
     *
     * @since 1.67
     */
    wrapping?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the inverted rendering behavior of the info text and the info state. The color defined by
     * the `infoState` property is rendered as the background color for the info text, if this property is set
     * to `true`.
     *
     * @since 1.74
     */
    infoStateInverted?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This property can be used to change the default character limits for the wrapping behavior.
     *
     * If this property is set to 0, then the default character limit used by the wrapping behavior is used.
     * For details see {@link #getWrapping wrapping}.
     *
     * **Note:**
     *
     * 0 or a positive integer must be used for this property.
     *
     * @since 1.94
     */
    wrapCharLimit?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * A `sap.m.Avatar` control instance that, if set, is used instead of an icon or image.
     *
     * The size of the `Avatar` control depends on the `insetIcon` property of `StandardListItem`. The `displaySize`
     * property of the `Avatar` control is not supported. If the `insetIcon` property of `StandardListItem`
     * is set to `true`, the size of the `Avatar` control is set to XS; if the `insetIcon` property of `StandardListItem`
     * is set to `false`, the size of the `Avatar` control is set to "S".
     *
     * @since 1.98
     */
    avatar?: Avatar;
  }
}

declare module "sap/m/StandardTile" {
  import { default as Tile, $TileSettings } from "sap/m/Tile";

  import { ID, URI, ValueState } from "sap/ui/core/library";

  import Control from "sap/ui/core/Control";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { StandardTileType } from "sap/m/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The StandardTile control is displayed in the tile container.
   *
   * @since 1.12
   * @deprecated As of version 1.50. replaced by {@link sap.m.GenericTile}
   */
  export default class StandardTile extends Tile {
    /**
     * Constructor for a new StandardTile.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $StandardTileSettings
    );
    /**
     * Constructor for a new StandardTile.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $StandardTileSettings
    );

    /**
     * Creates a new subclass of class sap.m.StandardTile with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.Tile.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, StandardTile>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.StandardTile.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Gets current value of property {@link #getActiveIcon activeIcon}.
     *
     * Defines the active icon of the StandardTile.
     *
     *
     * @returns Value of property `activeIcon`
     */
    getActiveIcon(): URI;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Gets the icon of the `StandardTile` control.
     *
     *
     * @returns The icon of the control
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getIconDensityAware iconDensityAware}.
     *
     * By default, this is set to true but then one or more requests are sent trying to get the density perfect
     * version of image if this version of image doesn't exist on the server.
     *
     * If bandwidth is key for the application, set this value to false.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `iconDensityAware`
     */
    getIconDensityAware(): boolean;
    /**
     * Gets current value of property {@link #getInfo info}.
     *
     * Defines the description of the StandardTile.
     *
     *
     * @returns Value of property `info`
     */
    getInfo(): string;
    /**
     * Gets current value of property {@link #getInfoState infoState}.
     *
     * Defines the color of the info text. Possible values are Error, Warning, Success and so on.
     *
     * Default value is `None`.
     *
     *
     * @returns Value of property `infoState`
     */
    getInfoState(): ValueState;
    /**
     * Gets current value of property {@link #getNumber number}.
     *
     * Defines the number field of the StandardTile.
     *
     *
     * @returns Value of property `number`
     */
    getNumber(): string;
    /**
     * Gets current value of property {@link #getNumberUnit numberUnit}.
     *
     * Defines the number units qualifier of the StandardTile.
     *
     *
     * @returns Value of property `numberUnit`
     */
    getNumberUnit(): string;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Defines the title of the StandardTile.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getType type}.
     *
     * Defines the type of the StandardTile.
     *
     * Default value is `None`.
     *
     *
     * @returns Value of property `type`
     */
    getType(): StandardTileType;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getActiveIcon activeIcon}.
     *
     * Defines the active icon of the StandardTile.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setActiveIcon(
      /**
       * New value for property `activeIcon`
       */
      sActiveIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Defines the icon of the StandardTile.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getIconDensityAware iconDensityAware}.
     *
     * By default, this is set to true but then one or more requests are sent trying to get the density perfect
     * version of image if this version of image doesn't exist on the server.
     *
     * If bandwidth is key for the application, set this value to false.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconDensityAware(
      /**
       * New value for property `iconDensityAware`
       */
      bIconDensityAware?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getInfo info}.
     *
     * Defines the description of the StandardTile.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInfo(
      /**
       * New value for property `info`
       */
      sInfo?: string
    ): this;
    /**
     * Sets a new value for property {@link #getInfoState infoState}.
     *
     * Defines the color of the info text. Possible values are Error, Warning, Success and so on.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInfoState(
      /**
       * New value for property `infoState`
       */
      sInfoState?: ValueState | keyof typeof ValueState
    ): this;
    /**
     * Sets a new value for property {@link #getNumber number}.
     *
     * Defines the number field of the StandardTile.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNumber(
      /**
       * New value for property `number`
       */
      sNumber?: string
    ): this;
    /**
     * Sets a new value for property {@link #getNumberUnit numberUnit}.
     *
     * Defines the number units qualifier of the StandardTile.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNumberUnit(
      /**
       * New value for property `numberUnit`
       */
      sNumberUnit?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Defines the title of the StandardTile.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getType type}.
     *
     * Defines the type of the StandardTile.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setType(
      /**
       * New value for property `type`
       */
      sType?: StandardTileType | keyof typeof StandardTileType
    ): this;
  }
  /**
   * Describes the settings that can be provided to the StandardTile constructor.
   *
   * @deprecated As of version 1.50. replaced by {@link sap.m.GenericTile}
   */
  export interface $StandardTileSettings extends $TileSettings {
    /**
     * Defines the title of the StandardTile.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Defines the description of the StandardTile.
     */
    info?: string | PropertyBindingInfo;

    /**
     * Defines the icon of the StandardTile.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the active icon of the StandardTile.
     */
    activeIcon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the number field of the StandardTile.
     */
    number?: string | PropertyBindingInfo;

    /**
     * Defines the number units qualifier of the StandardTile.
     */
    numberUnit?: string | PropertyBindingInfo;

    /**
     * Defines the color of the info text. Possible values are Error, Warning, Success and so on.
     */
    infoState?:
      | (ValueState | keyof typeof ValueState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the type of the StandardTile.
     */
    type?:
      | (StandardTileType | keyof typeof StandardTileType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * By default, this is set to true but then one or more requests are sent trying to get the density perfect
     * version of image if this version of image doesn't exist on the server.
     *
     * If bandwidth is key for the application, set this value to false.
     */
    iconDensityAware?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Association to controls / IDs, which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;
  }
}

declare module "sap/m/StandardTreeItem" {
  import {
    default as TreeItemBase,
    $TreeItemBaseSettings,
  } from "sap/m/TreeItemBase";

  import { URI } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The `sap.m.StandardTreeItem` is a tree item providing a title, image, etc.
   *
   * @since 1.42.0
   */
  export default class StandardTreeItem extends TreeItemBase {
    /**
     * Constructor for a new StandardTreeItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $StandardTreeItemSettings
    );
    /**
     * Constructor for a new StandardTreeItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $StandardTreeItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.StandardTreeItem with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.TreeItemBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, StandardTreeItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.StandardTreeItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Defines the tree item icon.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Defines the title of the item.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Defines the tree item icon.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Defines the title of the item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the StandardTreeItem constructor.
   */
  export interface $StandardTreeItemSettings extends $TreeItemBaseSettings {
    /**
     * Defines the title of the item.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Defines the tree item icon.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/StepInput" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IFormContent,
    ID,
    CSSSize,
    TextAlign,
    ValueState,
  } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    StepInputStepModeType,
    StepInputValidationMode,
  } from "sap/m/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * Allows the user to change the input values with predefined increments (steps).
   *
   * Overview:
   *
   * The `StepInput` consists of an input field and buttons with icons to increase/decrease the value.
   *
   * The user can change the value of the control by pressing the increase/decrease buttons, by typing a number
   * directly, by using the keyboard up/down and page up/down, or by using the mouse scroll wheel. Decimal
   * values are supported.
   *
   * Usage:
   *
   * The default step is 1 but the app developer can set a different one.
   *
   * On desktop, the control supports a larger step, when using the keyboard page up/down keys. You can set
   * a multiple of the step with the use of the `largerStep` property. The default value is 2 (two times the
   * set step). For example, when using the keyboard page up/down keys the value increases/decreases with
   * a double of the default step. If the set step is 2, the larger step is also 2 and the current value is
   * 1, using the page up key will increase the value to 5 (1 + 2*2).
   *
   * App developers can set a maximum and minimum value for the `StepInput`. The increase/decrease button
   * and the up/down keyboard navigation become disabled when the value reaches the max/min or a new value
   * is entered from the input which is greater/less than the max/min.
   *
   * When to use
   * 	 - To adjust amounts, quantities, or other values quickly.
   * 	 - To adjust values for a specific step.
   *
   * When not to use
   * 	 - To enter a static number (for example, postal code, phone number, or ID). In this case, use the regular
   *     {@link sap.m.Input} instead.
   * 	 - To display a value that rarely needs to be adjusted and does not pertain to a particular step. In
   *     this case, use the regular {@link sap.m.Input} instead.
   * 	 - To enter dates and times. In this case, use the {@link sap.m.DatePicker}, {@link sap.m.DateRangeSelection},
   *     {@link sap.m.TimePicker}, or {@link sap.m.DateTimePicker} instead.
   *
   * **Note:** The control uses a JavaScript number to keep its value, which has a certain precision limit.
   *
   * In general, exponential notation is used:
   * 	 - if there are more than 21 digits before the decimal point.
   * 	 - if number starts with "0." followed by more than five zeros.
   *
   * Exponential notation is not supported by the control and using it may lead to unpredictable behavior.
   *
   * Also, the JavaScript number persists its precision up to 16 digits. If the user enters a number with
   * a greater precision, the value will be rounded.
   *
   * This restriction comes from JavaScript itself and it cannot be worked around in a feasible way.
   *
   * **Note:** Formatting of decimal numbers is browser dependent, regardless of framework number formatting.
   *
   * @since 1.40
   */
  export default class StepInput extends Control implements IFormContent {
    __implements__sap_ui_core_IFormContent: boolean;
    /**
     * Constructor for a new `StepInput`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/step-input/ Step Input}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $StepInputSettings
    );
    /**
     * Constructor for a new `StepInput`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/step-input/ Step Input}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $StepInputSettings
    );

    /**
     * Creates a new subclass of class sap.m.StepInput with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, StepInput>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.StepInput.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.StepInput`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.StepInput` itself.
     *
     * Is fired when one of the following happens:
     *
     * 	 - the text in the input has changed and the focus leaves the input field or the enter key is pressed.
     *
     * 	 - One of the decrement or increment buttons is pressed
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: StepInput$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.StepInput` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.StepInput`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.StepInput` itself.
     *
     * Is fired when one of the following happens:
     *
     * 	 - the text in the input has changed and the focus leaves the input field or the enter key is pressed.
     *
     * 	 - One of the decrement or increment buttons is pressed
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: StepInput$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.StepInput` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:change change} event of this `sap.m.StepInput`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: StepInput$ChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:change change} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: StepInput$ChangeEventParameters
    ): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getDescription description}.
     *
     * Determines the description text after the input field, for example units of measurement, currencies.
     *
     * @since 1.54
     *
     * @returns Value of property `description`
     */
    getDescription(): string;
    /**
     * Gets current value of property {@link #getDisplayValuePrecision displayValuePrecision}.
     *
     * Determines the number of digits after the decimal point.
     *
     * The value should be between 0 (default) and 20. In case the value is not valid it will be set to the
     * default value.
     *
     * Default value is `0`.
     *
     * @since 1.46
     *
     * @returns Value of property `displayValuePrecision`
     */
    getDisplayValuePrecision(): int;
    /**
     * Gets current value of property {@link #getEditable editable}.
     *
     * Defines whether the control can be modified by the user or not. **Note:** A user can tab to the non-editable
     * control, highlight it, and copy the text from it.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `editable`
     */
    getEditable(): boolean;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Indicates whether the user can interact with the control or not. **Note:** Disabled controls cannot be
     * focused and they are out of the tab-chain.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets current value of property {@link #getFieldWidth fieldWidth}.
     *
     * Determines the distribution of space between the input field and the description text . Default value
     * is 50% (leaving the other 50% for the description).
     *
     * **Note:** This property takes effect only if the `description` property is also set.
     *
     * Default value is `'50%'`.
     *
     * @since 1.54
     *
     * @returns Value of property `fieldWidth`
     */
    getFieldWidth(): CSSSize;
    /**
     * Returns the DOMNode Id to be used for the "labelFor" attribute of the label.
     *
     * By default, this is the Id of the control itself.
     *
     *
     * @returns Id to be used for the `labelFor`
     */
    getIdForLabel(): string;
    /**
     * Gets current value of property {@link #getLargerStep largerStep}.
     *
     * Increases/decreases the value with a larger value than the set step only when using the PageUp/PageDown
     * keys. Default value is 2 times larger than the set step.
     *
     * Default value is `2`.
     *
     *
     * @returns Value of property `largerStep`
     */
    getLargerStep(): float;
    /**
     * Gets current value of property {@link #getMax max}.
     *
     * Sets the maximum possible value of the defined range.
     *
     *
     * @returns Value of property `max`
     */
    getMax(): float;
    /**
     * Gets current value of property {@link #getMin min}.
     *
     * Sets the minimum possible value of the defined range.
     *
     *
     * @returns Value of property `min`
     */
    getMin(): float;
    /**
     * Gets current value of property {@link #getName name}.
     *
     * Defines the name of the control for the purposes of form submission.
     *
     * @since 1.44.15
     *
     * @returns Value of property `name`
     */
    getName(): string;
    /**
     * Gets current value of property {@link #getPlaceholder placeholder}.
     *
     * Defines a short hint intended to aid the user with data entry when the control has no value.
     *
     * @since 1.44.15
     *
     * @returns Value of property `placeholder`
     */
    getPlaceholder(): string;
    /**
     * Gets current value of property {@link #getRequired required}.
     *
     * Indicates that user input is required. This property is only needed for accessibility purposes when a
     * single relationship between the field and a label (see aggregation `labelFor` of `sap.m.Label`) cannot
     * be established (e.g. one label should label multiple fields).
     *
     * Default value is `false`.
     *
     * @since 1.44.15
     *
     * @returns Value of property `required`
     */
    getRequired(): boolean;
    /**
     * Gets current value of property {@link #getStep step}.
     *
     * Increases/decreases the value of the input. **Note:**
     * 	 - The value of the `step` property should not contain more digits after the decimal point than what
     *     is set to the `displayValuePrecision` property, as it may lead to an increase/decrease that is not visible
     *     for the user. For example, if the `value` is set to 1.22 and the `displayValuePrecision` is set to one
     *     digit after the decimal, the user will see 1.2. In this case, if the `value` of the `step` property is
     *     set to 1.005 and the user selects `increase`, the resulting value will increase to 1.2261 but the displayed
     *     value will remain as 1.2 as it will be rounded to the first digit after the decimal point.
     * 	 - Depending on what is set for the `value` and the `displayValuePrecision` properties, it is possible
     *     the displayed value to be rounded to a higher number, for example to 3.0 when the actual value is 2.99.
     *
     * Default value is `1`.
     *
     *
     * @returns Value of property `step`
     */
    getStep(): float;
    /**
     * Gets current value of property {@link #getStepMode stepMode}.
     *
     * Defines the calculation mode for the provided `step` and `largerStep`.
     *
     * If the user increases/decreases the value by `largerStep`, this calculation will consider it as well.
     * For example, if the current `value` is 3, `step` is 5, `largerStep` is 5 and the user chooses PageUp,
     * the calculation logic will consider the value of 3x5=15 to decide what will be the next `value`.
     *
     * Default value is `AdditionAndSubtraction`.
     *
     * @since 1.54
     *
     * @returns Value of property `stepMode`
     */
    getStepMode(): StepInputStepModeType;
    /**
     * Gets current value of property {@link #getTextAlign textAlign}.
     *
     * Defines the horizontal alignment of the text that is displayed inside the input field.
     *
     * Default value is `End`.
     *
     * @since 1.54
     *
     * @returns Value of property `textAlign`
     */
    getTextAlign(): TextAlign;
    /**
     * Gets current value of property {@link #getValidationMode validationMode}.
     *
     * Defines when the validation of the typed value will happen. By default this happens on focus out.
     *
     * Default value is `FocusOut`.
     *
     * @since 1.54
     *
     * @returns Value of property `validationMode`
     */
    getValidationMode(): StepInputValidationMode;
    /**
     * Gets current value of property {@link #getValue value}.
     *
     * Determines the value of the `StepInput` and can be set initially from the app developer.
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `value`
     */
    getValue(): float;
    /**
     * Gets current value of property {@link #getValueState valueState}.
     *
     * Accepts the core enumeration ValueState.type that supports `None`, `Error`, `Warning` and `Success`.
     * ValueState is managed internally only when validation is triggered by user interaction.
     *
     * Default value is `None`.
     *
     *
     * @returns Value of property `valueState`
     */
    getValueState(): ValueState;
    /**
     * Gets current value of property {@link #getValueStateText valueStateText}.
     *
     * Defines the text that appears in the value state message pop-up.
     *
     * @since 1.52
     *
     * @returns Value of property `valueStateText`
     */
    getValueStateText(): string;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Defines the width of the control.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getDescription description}.
     *
     * Determines the description text after the input field, for example units of measurement, currencies.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDescription(
      /**
       * New value for property `description`
       */
      sDescription?: string
    ): this;
    /**
     * Sets a new value for property {@link #getDisplayValuePrecision displayValuePrecision}.
     *
     * Determines the number of digits after the decimal point.
     *
     * The value should be between 0 (default) and 20. In case the value is not valid it will be set to the
     * default value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     * @since 1.46
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisplayValuePrecision(
      /**
       * New value for property `displayValuePrecision`
       */
      iDisplayValuePrecision?: int
    ): this;
    /**
     * Sets a new value for property {@link #getEditable editable}.
     *
     * Defines whether the control can be modified by the user or not. **Note:** A user can tab to the non-editable
     * control, highlight it, and copy the text from it.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEditable(
      /**
       * New value for property `editable`
       */
      bEditable?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Indicates whether the user can interact with the control or not. **Note:** Disabled controls cannot be
     * focused and they are out of the tab-chain.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getFieldWidth fieldWidth}.
     *
     * Determines the distribution of space between the input field and the description text . Default value
     * is 50% (leaving the other 50% for the description).
     *
     * **Note:** This property takes effect only if the `description` property is also set.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `'50%'`.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFieldWidth(
      /**
       * New value for property `fieldWidth`
       */
      sFieldWidth?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getLargerStep largerStep}.
     *
     * Increases/decreases the value with a larger value than the set step only when using the PageUp/PageDown
     * keys. Default value is 2 times larger than the set step.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `2`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLargerStep(
      /**
       * New value for property `largerStep`
       */
      fLargerStep?: float
    ): this;
    /**
     * Sets a new value for property {@link #getName name}.
     *
     * Defines the name of the control for the purposes of form submission.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.44.15
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setName(
      /**
       * New value for property `name`
       */
      sName?: string
    ): this;
    /**
     * Sets a new value for property {@link #getPlaceholder placeholder}.
     *
     * Defines a short hint intended to aid the user with data entry when the control has no value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.44.15
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPlaceholder(
      /**
       * New value for property `placeholder`
       */
      sPlaceholder?: string
    ): this;
    /**
     * Sets a new value for property {@link #getRequired required}.
     *
     * Indicates that user input is required. This property is only needed for accessibility purposes when a
     * single relationship between the field and a label (see aggregation `labelFor` of `sap.m.Label`) cannot
     * be established (e.g. one label should label multiple fields).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.44.15
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRequired(
      /**
       * New value for property `required`
       */
      bRequired?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getStep step}.
     *
     * Increases/decreases the value of the input. **Note:**
     * 	 - The value of the `step` property should not contain more digits after the decimal point than what
     *     is set to the `displayValuePrecision` property, as it may lead to an increase/decrease that is not visible
     *     for the user. For example, if the `value` is set to 1.22 and the `displayValuePrecision` is set to one
     *     digit after the decimal, the user will see 1.2. In this case, if the `value` of the `step` property is
     *     set to 1.005 and the user selects `increase`, the resulting value will increase to 1.2261 but the displayed
     *     value will remain as 1.2 as it will be rounded to the first digit after the decimal point.
     * 	 - Depending on what is set for the `value` and the `displayValuePrecision` properties, it is possible
     *     the displayed value to be rounded to a higher number, for example to 3.0 when the actual value is 2.99.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `1`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setStep(
      /**
       * New value for property `step`
       */
      fStep?: float
    ): this;
    /**
     * Sets a new value for property {@link #getStepMode stepMode}.
     *
     * Defines the calculation mode for the provided `step` and `largerStep`.
     *
     * If the user increases/decreases the value by `largerStep`, this calculation will consider it as well.
     * For example, if the current `value` is 3, `step` is 5, `largerStep` is 5 and the user chooses PageUp,
     * the calculation logic will consider the value of 3x5=15 to decide what will be the next `value`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `AdditionAndSubtraction`.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setStepMode(
      /**
       * New value for property `stepMode`
       */
      sStepMode?: StepInputStepModeType | keyof typeof StepInputStepModeType
    ): this;
    /**
     * Sets a new value for property {@link #getTextAlign textAlign}.
     *
     * Defines the horizontal alignment of the text that is displayed inside the input field.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `End`.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextAlign(
      /**
       * New value for property `textAlign`
       */
      sTextAlign?: TextAlign | keyof typeof TextAlign
    ): this;
    /**
     * Sets a new value for property {@link #getValue value}.
     *
     * Determines the value of the `StepInput` and can be set initially from the app developer.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValue(
      /**
       * New value for property `value`
       */
      fValue?: float
    ): this;
    /**
     * Sets a new value for property {@link #getValueState valueState}.
     *
     * Accepts the core enumeration ValueState.type that supports `None`, `Error`, `Warning` and `Success`.
     * ValueState is managed internally only when validation is triggered by user interaction.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueState(
      /**
       * New value for property `valueState`
       */
      sValueState?: ValueState | keyof typeof ValueState
    ): this;
    /**
     * Sets a new value for property {@link #getValueStateText valueStateText}.
     *
     * Defines the text that appears in the value state message pop-up.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.52
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueStateText(
      /**
       * New value for property `valueStateText`
       */
      sValueStateText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Defines the width of the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth: CSSSize
    ): this;
  }
  /**
   * Describes the settings that can be provided to the StepInput constructor.
   */
  export interface $StepInputSettings extends $ControlSettings {
    /**
     * Sets the minimum possible value of the defined range.
     */
    min?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the maximum possible value of the defined range.
     */
    max?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * Increases/decreases the value of the input. **Note:**
     * 	 - The value of the `step` property should not contain more digits after the decimal point than what
     *     is set to the `displayValuePrecision` property, as it may lead to an increase/decrease that is not visible
     *     for the user. For example, if the `value` is set to 1.22 and the `displayValuePrecision` is set to one
     *     digit after the decimal, the user will see 1.2. In this case, if the `value` of the `step` property is
     *     set to 1.005 and the user selects `increase`, the resulting value will increase to 1.2261 but the displayed
     *     value will remain as 1.2 as it will be rounded to the first digit after the decimal point.
     * 	 - Depending on what is set for the `value` and the `displayValuePrecision` properties, it is possible
     *     the displayed value to be rounded to a higher number, for example to 3.0 when the actual value is 2.99.
     */
    step?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the calculation mode for the provided `step` and `largerStep`.
     *
     * If the user increases/decreases the value by `largerStep`, this calculation will consider it as well.
     * For example, if the current `value` is 3, `step` is 5, `largerStep` is 5 and the user chooses PageUp,
     * the calculation logic will consider the value of 3x5=15 to decide what will be the next `value`.
     *
     * @since 1.54
     */
    stepMode?:
      | (StepInputStepModeType | keyof typeof StepInputStepModeType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Increases/decreases the value with a larger value than the set step only when using the PageUp/PageDown
     * keys. Default value is 2 times larger than the set step.
     */
    largerStep?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the value of the `StepInput` and can be set initially from the app developer.
     */
    value?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the name of the control for the purposes of form submission.
     *
     * @since 1.44.15
     */
    name?: string | PropertyBindingInfo;

    /**
     * Defines a short hint intended to aid the user with data entry when the control has no value.
     *
     * @since 1.44.15
     */
    placeholder?: string | PropertyBindingInfo;

    /**
     * Indicates that user input is required. This property is only needed for accessibility purposes when a
     * single relationship between the field and a label (see aggregation `labelFor` of `sap.m.Label`) cannot
     * be established (e.g. one label should label multiple fields).
     *
     * @since 1.44.15
     */
    required?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the width of the control.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Accepts the core enumeration ValueState.type that supports `None`, `Error`, `Warning` and `Success`.
     * ValueState is managed internally only when validation is triggered by user interaction.
     */
    valueState?:
      | (ValueState | keyof typeof ValueState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the text that appears in the value state message pop-up.
     *
     * @since 1.52
     */
    valueStateText?: string | PropertyBindingInfo;

    /**
     * Defines whether the control can be modified by the user or not. **Note:** A user can tab to the non-editable
     * control, highlight it, and copy the text from it.
     */
    editable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether the user can interact with the control or not. **Note:** Disabled controls cannot be
     * focused and they are out of the tab-chain.
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the number of digits after the decimal point.
     *
     * The value should be between 0 (default) and 20. In case the value is not valid it will be set to the
     * default value.
     *
     * @since 1.46
     */
    displayValuePrecision?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the description text after the input field, for example units of measurement, currencies.
     *
     * @since 1.54
     */
    description?: string | PropertyBindingInfo;

    /**
     * Determines the distribution of space between the input field and the description text . Default value
     * is 50% (leaving the other 50% for the description).
     *
     * **Note:** This property takes effect only if the `description` property is also set.
     *
     * @since 1.54
     */
    fieldWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the horizontal alignment of the text that is displayed inside the input field.
     *
     * @since 1.54
     */
    textAlign?:
      | (TextAlign | keyof typeof TextAlign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines when the validation of the typed value will happen. By default this happens on focus out.
     *
     * @since 1.54
     */
    validationMode?:
      | (StepInputValidationMode | keyof typeof StepInputValidationMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Association to controls / IDs that label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Association to controls / IDs which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Is fired when one of the following happens:
     *
     * 	 - the text in the input has changed and the focus leaves the input field or the enter key is pressed.
     *
     * 	 - One of the decrement or increment buttons is pressed
     */
    change?: (oEvent: StepInput$ChangeEvent) => void;
  }

  /**
   * Parameters of the StepInput#change event.
   */
  export interface StepInput$ChangeEventParameters {
    /**
     * The new `value` of the `control`.
     */
    value?: string;
  }

  /**
   * Event object of the StepInput#change event.
   */
  export type StepInput$ChangeEvent = Event<
    StepInput$ChangeEventParameters,
    StepInput
  >;
}

declare module "sap/m/SuggestionItem" {
  import { default as Item, $ItemSettings } from "sap/ui/core/Item";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import RenderManager from "sap/ui/core/RenderManager";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Display suggestion list items.
   *
   * **Note:** The inherited `enabled` property is not supported. If an item shouldn't be selected, remove
   * it from the list instead.
   *
   * @since 1.34
   */
  export default class SuggestionItem extends Item {
    /**
     * Constructor for a new SuggestionItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $SuggestionItemSettings
    );
    /**
     * Constructor for a new SuggestionItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $SuggestionItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.SuggestionItem with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Item.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, SuggestionItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.SuggestionItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getDescription description}.
     *
     * Additional text of type string, optionally to be displayed along with this item.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `description`
     */
    getDescription(): string;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * The icon belonging to this list item instance. This can be a URI to an image or an icon font URI.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): string;
    /**
     * Return suggestion text. By default, it is the value of the `text` property.
     *
     * Subclasses may override this function.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns suggestion text.
     */
    getSuggestionText(): string;
    /**
     * Produces the HTML of the suggestion item and writes it to render-output-buffer.
     *
     * Subclasses may override this function.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    render(
      /**
       * The `RenderManager`
       */
      oRM: RenderManager,
      /**
       * The item which should be rendered
       */
      oItem: SuggestionItem,
      /**
       * The search text that should be emphasized
       */
      sSearch: string,
      /**
       * The item is selected
       */
      bSelected: boolean
    ): void;
    /**
     * Sets a new value for property {@link #getDescription description}.
     *
     * Additional text of type string, optionally to be displayed along with this item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDescription(
      /**
       * New value for property `description`
       */
      sDescription?: string
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * The icon belonging to this list item instance. This can be a URI to an image or an icon font URI.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the SuggestionItem constructor.
   */
  export interface $SuggestionItemSettings extends $ItemSettings {
    /**
     * The icon belonging to this list item instance. This can be a URI to an image or an icon font URI.
     */
    icon?: string | PropertyBindingInfo;

    /**
     * Additional text of type string, optionally to be displayed along with this item.
     */
    description?: string | PropertyBindingInfo;
  }
}

declare module "sap/m/Switch" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { IFormContent, ID } from "sap/ui/core/library";

  import {
    IOverflowToolbarContent,
    IToolbarInteractiveControl,
    SwitchType,
  } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * A switch is a user interface control on mobile devices that is used for change between binary states.
   * The user can also drag the button handle or tap to change the state.
   */
  export default class Switch
    extends Control
    implements IFormContent, IOverflowToolbarContent, IToolbarInteractiveControl
  {
    __implements__sap_ui_core_IFormContent: boolean;
    __implements__sap_m_IOverflowToolbarContent: boolean;
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new Switch.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/switch/ Switch}
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $SwitchSettings
    );
    /**
     * Constructor for a new Switch.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/switch/ Switch}
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $SwitchSettings
    );

    /**
     * Creates a new subclass of class sap.m.Switch with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Switch>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Switch.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.Switch`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Switch` itself.
     *
     * Triggered when a switch changes the state.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Switch$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Switch` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.Switch`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Switch` itself.
     *
     * Triggered when a switch changes the state.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Switch$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Switch` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:change change} event of this `sap.m.Switch`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Switch$ChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:change change} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Switch$ChangeEventParameters
    ): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getCustomTextOff customTextOff}.
     *
     * Custom text for the "OFF" state.
     *
     * "OFF" translated to the current language is the default value. Beware that the given text will be cut
     * off if available space is exceeded.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `customTextOff`
     */
    getCustomTextOff(): string;
    /**
     * Gets current value of property {@link #getCustomTextOn customTextOn}.
     *
     * Custom text for the "ON" state.
     *
     * "ON" translated to the current language is the default value. Beware that the given text will be cut
     * off if available space is exceeded.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `customTextOn`
     */
    getCustomTextOn(): string;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Whether the switch is enabled.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets current value of property {@link #getName name}.
     *
     * The name to be used in the HTML code for the switch (e.g. for HTML forms that send data to the server
     * via submit).
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `name`
     */
    getName(): string;
    /**
     * Gets current value of property {@link #getState state}.
     *
     * A boolean value indicating whether the switch is on or off.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `state`
     */
    getState(): boolean;
    /**
     * Gets current value of property {@link #getType type}.
     *
     * Type of a Switch. Possibles values "Default", "AcceptReject".
     *
     * Default value is `Default`.
     *
     *
     * @returns Value of property `type`
     */
    getType(): SwitchType;
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     * @since 1.27.0
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getCustomTextOff customTextOff}.
     *
     * Custom text for the "OFF" state.
     *
     * "OFF" translated to the current language is the default value. Beware that the given text will be cut
     * off if available space is exceeded.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomTextOff(
      /**
       * New value for property `customTextOff`
       */
      sCustomTextOff?: string
    ): this;
    /**
     * Sets a new value for property {@link #getCustomTextOn customTextOn}.
     *
     * Custom text for the "ON" state.
     *
     * "ON" translated to the current language is the default value. Beware that the given text will be cut
     * off if available space is exceeded.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomTextOn(
      /**
       * New value for property `customTextOn`
       */
      sCustomTextOn?: string
    ): this;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Whether the switch is enabled.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getName name}.
     *
     * The name to be used in the HTML code for the switch (e.g. for HTML forms that send data to the server
     * via submit).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setName(
      /**
       * New value for property `name`
       */
      sName?: string
    ): this;
    /**
     * Sets a new value for property {@link #getState state}.
     *
     * A boolean value indicating whether the switch is on or off.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setState(
      /**
       * New value for property `state`
       */
      bState?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getType type}.
     *
     * Type of a Switch. Possibles values "Default", "AcceptReject".
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Default`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setType(
      /**
       * New value for property `type`
       */
      sType?: SwitchType | keyof typeof SwitchType
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Switch constructor.
   */
  export interface $SwitchSettings extends $ControlSettings {
    /**
     * A boolean value indicating whether the switch is on or off.
     */
    state?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Custom text for the "ON" state.
     *
     * "ON" translated to the current language is the default value. Beware that the given text will be cut
     * off if available space is exceeded.
     */
    customTextOn?: string | PropertyBindingInfo;

    /**
     * Custom text for the "OFF" state.
     *
     * "OFF" translated to the current language is the default value. Beware that the given text will be cut
     * off if available space is exceeded.
     */
    customTextOff?: string | PropertyBindingInfo;

    /**
     * Whether the switch is enabled.
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The name to be used in the HTML code for the switch (e.g. for HTML forms that send data to the server
     * via submit).
     */
    name?: string | PropertyBindingInfo;

    /**
     * Type of a Switch. Possibles values "Default", "AcceptReject".
     */
    type?:
      | (SwitchType | keyof typeof SwitchType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledby).
     *
     * @since 1.27.0
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Triggered when a switch changes the state.
     */
    change?: (oEvent: Switch$ChangeEvent) => void;
  }

  /**
   * Parameters of the Switch#change event.
   */
  export interface Switch$ChangeEventParameters {
    /**
     * The new state of the switch.
     */
    state?: boolean;
  }

  /**
   * Event object of the Switch#change event.
   */
  export type Switch$ChangeEvent = Event<Switch$ChangeEventParameters, Switch>;
}

declare module "sap/m/TabContainer" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import TabContainerItem from "sap/m/TabContainerItem";

  import Event from "sap/ui/base/Event";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Button from "sap/m/Button";

  import { PageBackgroundDesign } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { ID } from "sap/ui/core/library";

  /**
   * A container control for managing multiple tabs, allowing the user to open and edit different items simultaneously.
   *
   * Overview:
   *
   * The control contains a `TabStrip` area where the user can choose which tab to view/edit. When the open
   * tabs are more than what can be displayed on the screen, there is an overflow mechanism. To access the
   * tabs hidden in the overflow area, the user has to either use the overflow button (left or right arrow)
   * to scroll them horizontally or the overflow overview button (down arrow) and view all open items as a
   * list.
   *
   * Each tab has a title and a Close Tab button. The title is truncated, if it's longer than 25 characters.
   * On desktop, the Close Tab button is displayed on the currently active tab and for the other tabs
   * it appears on mouse hover. On mobile devices, the Close Tab buttons are always visible.
   *
   * To show that the open items have unsaved changes, the corresponding tabs can display an asterisk (*)
   * after the title as a visual indication that the item is not saved. This is managed by the app developer
   * using {@link sap.m.TabContainerItem TabContainerItem}'s `modified` property.
   *
   * Usage:
   *
   * The `TabContainer` can have an Add New Tab button, which appears as a '+' icon on the top-right
   * area of the control. When the user clicks or taps this button, the `addNewButtonPress` event is fired.
   *
   * Responsive behavior:
   *
   * The `TabContainer` is a full-page container that takes 100% of its parent width and height. As the control
   * is expected to occupy the whole parent, it should be the only child of its parent.
   *
   * When using the `sap.m.TabContainer` in SAP Quartz theme, the breakpoints and layout paddings could be
   * determined by the container's width. To enable this concept and add responsive padding to the `TabContainer`
   * control, you may add the following class: `sapUiResponsivePadding--header`.
   *
   * @since 1.34
   */
  export default class TabContainer extends Control {
    /**
     * Constructor for a new `TabContainer`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $TabContainerSettings
    );
    /**
     * Constructor for a new `TabContainer`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $TabContainerSettings
    );

    /**
     * Creates a new subclass of class sap.m.TabContainer with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, TabContainer>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.TabContainer.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds a new `TabContainerItem` to the `items` aggregation.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    addItem(
      /**
       * The new `TabContainerItem` to be added
       */
      oItem: TabContainerItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:addNewButtonPress addNewButtonPress} event of
     * this `sap.m.TabContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TabContainer` itself.
     *
     * Fired when the Add New Tab button is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAddNewButtonPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TabContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:addNewButtonPress addNewButtonPress} event of
     * this `sap.m.TabContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TabContainer` itself.
     *
     * Fired when the Add New Tab button is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAddNewButtonPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TabContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemClose itemClose} event of this `sap.m.TabContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TabContainer` itself.
     *
     * Fired when an item is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TabContainer$ItemCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TabContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemClose itemClose} event of this `sap.m.TabContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TabContainer` itself.
     *
     * Fired when an item is closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TabContainer$ItemCloseEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TabContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemSelect itemSelect} event of this `sap.m.TabContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TabContainer` itself.
     *
     * Fired when an item is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TabContainer$ItemSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TabContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemSelect itemSelect} event of this `sap.m.TabContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TabContainer` itself.
     *
     * Fired when an item is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TabContainer$ItemSelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TabContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getItems items} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all `TabContainerItem` entities from the `items` aggregation.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:addNewButtonPress addNewButtonPress} event
     * of this `sap.m.TabContainer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAddNewButtonPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:itemClose itemClose} event of this `sap.m.TabContainer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachItemClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: TabContainer$ItemCloseEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:itemSelect itemSelect} event of this `sap.m.TabContainer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachItemSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: TabContainer$ItemSelectEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:addNewButtonPress addNewButtonPress} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAddNewButtonPress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:itemClose itemClose} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireItemClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: TabContainer$ItemCloseEventParameters
    ): boolean;
    /**
     * Fires event {@link #event:itemSelect itemSelect} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireItemSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: TabContainer$ItemSelectEventParameters
    ): boolean;
    /**
     * Overrides the addButton property getter to proxy to the `TabStrip`.
     *
     *
     * @returns The `Add New Tab` button displayed in the `TabStrip`
     */
    getAddButton(): Button;
    /**
     * Gets current value of property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Determines the background color of the content in `TabContainer`.
     *
     * Default value is `List`.
     *
     * @since 1.71
     *
     * @returns Value of property `backgroundDesign`
     */
    getBackgroundDesign(): PageBackgroundDesign;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * The items displayed in the `TabContainer`.
     */
    getItems(): TabContainerItem[];
    /**
     * ID of the element which is the current target of the association {@link #getSelectedItem selectedItem},
     * or `null`.
     */
    getSelectedItem(): ID | null;
    /**
     * Gets current value of property {@link #getShowAddNewButton showAddNewButton}.
     *
     * Defines whether an Add New Tab button is displayed in the `TabStrip`.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showAddNewButton`
     */
    getShowAddNewButton(): boolean;
    /**
     * Checks for the provided `sap.m.TabContainerItem` in the aggregation {@link #getItems items}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: TabContainerItem
    ): int;
    /**
     * Inserts a new `TabContainerItem`, to the `items` aggregation, at a specified index.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    insertItem(
      /**
       * The new `TabContainerItem` to be inserted
       */
      oItem: TabContainerItem,
      /**
       * The index where the passed `TabContainerItem` to be inserted
       */
      iIndex: int
    ): this;
    /**
     * Removes all `TabContainerItem` entities from the `items` aggregation.
     *
     *
     * @returns The removed items
     */
    removeAllItems(): TabContainerItem[];
    /**
     * Removes an item from the aggregation named `items`.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or ID
       */
      vItem: int | ID | TabContainerItem
    ): TabContainerItem | null;
    /**
     * Overrides the `addButton` property setter to proxy to the `TabStrip`.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setAddButton(
      /**
       * The `Add New Tab` button displayed in the `TabStrip`
       */
      oButton: Button
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Determines the background color of the content in `TabContainer`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `List`.
     *
     * @since 1.71
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundDesign(
      /**
       * New value for property `backgroundDesign`
       */
      sBackgroundDesign?:
        | PageBackgroundDesign
        | keyof typeof PageBackgroundDesign
    ): this;
    /**
     * Sets the associated {@link #getSelectedItem selectedItem}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSelectedItem(
      /**
       * ID of an element which becomes the new target of this selectedItem association; alternatively, an element
       * instance may be given
       */
      oSelectedItem: ID | TabContainerItem
    ): this;
    /**
     * Sets a new value for property {@link #getShowAddNewButton showAddNewButton}.
     *
     * Defines whether an Add New Tab button is displayed in the `TabStrip`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowAddNewButton(
      /**
       * New value for property `showAddNewButton`
       */
      bShowAddNewButton?: boolean
    ): this;
    /**
     * Unbinds aggregation {@link #getItems items} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindItems(): this;
  }
  /**
   * Describes the settings that can be provided to the TabContainer constructor.
   */
  export interface $TabContainerSettings extends $ControlSettings {
    /**
     * Defines whether an Add New Tab button is displayed in the `TabStrip`.
     */
    showAddNewButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the background color of the content in `TabContainer`.
     *
     * @since 1.71
     */
    backgroundDesign?:
      | (PageBackgroundDesign | keyof typeof PageBackgroundDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The items displayed in the `TabContainer`.
     */
    items?:
      | TabContainerItem[]
      | TabContainerItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Sets or retrieves the selected item from the `items` aggregation.
     */
    selectedItem?: TabContainerItem | string;

    /**
     * Fired when an item is closed.
     */
    itemClose?: (oEvent: TabContainer$ItemCloseEvent) => void;

    /**
     * Fired when an item is pressed.
     */
    itemSelect?: (oEvent: TabContainer$ItemSelectEvent) => void;

    /**
     * Fired when the Add New Tab button is pressed.
     */
    addNewButtonPress?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the TabContainer#addNewButtonPress event.
   */
  export interface TabContainer$AddNewButtonPressEventParameters {}

  /**
   * Event object of the TabContainer#addNewButtonPress event.
   */
  export type TabContainer$AddNewButtonPressEvent = Event<
    TabContainer$AddNewButtonPressEventParameters,
    TabContainer
  >;

  /**
   * Parameters of the TabContainer#itemClose event.
   */
  export interface TabContainer$ItemCloseEventParameters {
    /**
     * The item to be closed.
     */
    item?: TabContainerItem;
  }

  /**
   * Event object of the TabContainer#itemClose event.
   */
  export type TabContainer$ItemCloseEvent = Event<
    TabContainer$ItemCloseEventParameters,
    TabContainer
  >;

  /**
   * Parameters of the TabContainer#itemSelect event.
   */
  export interface TabContainer$ItemSelectEventParameters {
    /**
     * The selected item.
     */
    item?: TabContainerItem;
  }

  /**
   * Event object of the TabContainer#itemSelect event.
   */
  export type TabContainer$ItemSelectEvent = Event<
    TabContainer$ItemSelectEventParameters,
    TabContainer
  >;
}

declare module "sap/m/TabContainerItem" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import Control from "sap/ui/core/Control";

  import { URI } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * An item to be used in a TabContainer.
   *
   * @since 1.34
   */
  export default class TabContainerItem extends UI5Element {
    /**
     * Constructor for a new `TabContainerItem`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $TabContainerItemSettings
    );
    /**
     * Constructor for a new `TabContainerItem`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $TabContainerItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.TabContainerItem with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, TabContainerItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.TabContainerItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some content to the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContent(
      /**
       * The content to add; if empty, nothing is inserted
       */
      oContent: Control
    ): this;
    /**
     * Destroys all the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Gets current value of property {@link #getAdditionalText additionalText}.
     *
     * Determines additional text to be displayed for the item.
     *
     * Default value is `empty string`.
     *
     * @since 1.63
     *
     * @returns Value of property `additionalText`
     */
    getAdditionalText(): string;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * The content displayed for this item.
     */
    getContent(): Control[];
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Defines the icon to be displayed as graphical element within the `TabContainerItem`. It can be an image
     * or an icon from the icon font.
     *
     * @since 1.63
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getIconTooltip iconTooltip}.
     *
     * Determines the tooltip text of the `TabContainerItem`'s icon.
     *
     * @since 1.63
     *
     * @returns Value of property `iconTooltip`
     */
    getIconTooltip(): string;
    /**
     * Gets current value of property {@link #getKey key}.
     *
     * Determines the name of the item. Can be used as input for subsequent actions.
     *
     *
     * @returns Value of property `key`
     */
    getKey(): string;
    /**
     * Gets current value of property {@link #getModified modified}.
     *
     * Shows if a control is edited (default is false). Items that are marked as modified have a * symbol to
     * indicate that they haven't been saved.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `modified`
     */
    getModified(): boolean;
    /**
     * Gets current value of property {@link #getName name}.
     *
     * Determines the text to be displayed for the item.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `name`
     */
    getName(): string;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContent content}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContent(
      /**
       * The content whose index is looked for
       */
      oContent: Control
    ): int;
    /**
     * Inserts a content into the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContent(
      /**
       * The content to insert; if empty, nothing is inserted
       */
      oContent: Control,
      /**
       * The `0`-based index the content should be inserted at; for a negative value of `iIndex`, the content
       * is inserted at position 0; for a value greater than the current size of the aggregation, the content
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getContent content}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContent(): Control[];
    /**
     * Removes a content from the aggregation {@link #getContent content}.
     *
     *
     * @returns The removed content or `null`
     */
    removeContent(
      /**
       * The content to remove or its index or id
       */
      vContent: int | string | Control
    ): Control | null;
    /**
     * Sets a new value for property {@link #getAdditionalText additionalText}.
     *
     * Determines additional text to be displayed for the item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @since 1.63
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAdditionalText(
      /**
       * New value for property `additionalText`
       */
      sAdditionalText?: string
    ): this;
    /**
     * Property setter for the icon
     *
     *
     * @returns `this` to allow method chaining
     */
    setIcon(
      /**
       * new value of the Icon property
       */
      sIcon: URI
    ): this;
    /**
     * Sets a new value for property {@link #getIconTooltip iconTooltip}.
     *
     * Determines the tooltip text of the `TabContainerItem`'s icon.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.63
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIconTooltip(
      /**
       * New value for property `iconTooltip`
       */
      sIconTooltip?: string
    ): this;
    /**
     * Sets a new value for property {@link #getKey key}.
     *
     * Determines the name of the item. Can be used as input for subsequent actions.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setKey(
      /**
       * New value for property `key`
       */
      sKey?: string
    ): this;
    /**
     * Sets a new value for property {@link #getModified modified}.
     *
     * Shows if a control is edited (default is false). Items that are marked as modified have a * symbol to
     * indicate that they haven't been saved.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setModified(
      /**
       * New value for property `modified`
       */
      bModified?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getName name}.
     *
     * Determines the text to be displayed for the item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setName(
      /**
       * New value for property `name`
       */
      sName?: string
    ): this;
    /**
     * Overwrites the method in order to suppress invalidation for some properties.
     *
     *
     * @returns This instance for chaining
     */
    setProperty(
      /**
       * Property name to be set
       */
      sName: string,
      /**
       * Property value to be set
       */
      vValue: boolean | string | object,
      /**
       * Whether invalidation to be suppressed
       */
      bSuppressInvalidation: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the TabContainerItem constructor.
   */
  export interface $TabContainerItemSettings extends $ElementSettings {
    /**
     * Determines the text to be displayed for the item.
     */
    name?: string | PropertyBindingInfo;

    /**
     * Determines additional text to be displayed for the item.
     *
     * @since 1.63
     */
    additionalText?: string | PropertyBindingInfo;

    /**
     * Defines the icon to be displayed as graphical element within the `TabContainerItem`. It can be an image
     * or an icon from the icon font.
     *
     * @since 1.63
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the tooltip text of the `TabContainerItem`'s icon.
     *
     * @since 1.63
     */
    iconTooltip?: string | PropertyBindingInfo;

    /**
     * Determines the name of the item. Can be used as input for subsequent actions.
     */
    key?: string | PropertyBindingInfo;

    /**
     * Shows if a control is edited (default is false). Items that are marked as modified have a * symbol to
     * indicate that they haven't been saved.
     */
    modified?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The content displayed for this item.
     */
    content?: Control[] | Control | AggregationBindingInfo | `{${string}}`;
  }

  /**
   * Parameters of the TabContainerItem#itemPropertyChanged event.
   */
  export interface TabContainerItem$ItemPropertyChangedEventParameters {
    /**
     * The item changed.
     */
    itemChanged?: TabContainerItem;

    /**
     * The key of the property.
     */
    propertyKey?: string;

    /**
     * The value of the property.
     */
    propertyValue?: any;
  }

  /**
   * Event object of the TabContainerItem#itemPropertyChanged event.
   */
  export type TabContainerItem$ItemPropertyChangedEvent = Event<
    TabContainerItem$ItemPropertyChangedEventParameters,
    TabContainerItem
  >;
}

declare module "sap/m/Table" {
  import {
    default as ListBase,
    $ListBaseSettings,
    ListBase$BeforeOpenContextMenuEventParameters,
  } from "sap/m/ListBase";

  import Column from "sap/m/Column";

  import { BackgroundDesign, PopinLayout } from "sap/m/library";

  import { Priority } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * The `sap.m.Table` control provides a set of sophisticated and easy-to-use functions for responsive table
   * design.
   *
   * To render the `sap.m.Table` control properly, the order of the `columns` aggregation should match with
   * the order of the `cells` aggregation (`sap.m.ColumnListItem`).
   *
   * The `sap.m.Table` control requires at least one visible `sap.m.Column` in the `columns` aggregation,
   * therefore applications must avoid configuring all columns to be shown in the pop-in. If such a conflict
   * is detected, then the table prevents one column from moving to the pop-in.
   *
   * For mobile devices, the recommended limit of table rows is 100 (based on 4 columns) to assure proper
   * performance. To improve initial rendering of large tables, use the `growing` feature.
   *
   * **Note:** In the `items` aggregation only items which implements the `sap.m.ITableItem` interface must
   * be used.
   *
   * See section "{@link https://ui5.sap.com/#/topic/5eb6f63e0cc547d0bdc934d3652fdc9b Creating Tables}" and
   * "{@link https://ui5.sap.com/#/topic/38855e06486f4910bfa6f4485f7c2bac Configuring Responsive Behavior of a Table}"
   * in the documentation for an introduction to `sap.m.Table` control.
   *
   * @since 1.16
   */
  export default class Table extends ListBase {
    /**
     * Constructor for a new Table.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:/responsive-table/ Responsive Table}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $TableSettings
    );
    /**
     * Constructor for a new Table.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:/responsive-table/ Responsive Table}
     */
    constructor(
      /**
       * Id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $TableSettings
    );

    /**
     * Creates a new subclass of class sap.m.Table with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ListBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Table>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Table.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some column to the aggregation {@link #getColumns columns}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addColumn(
      /**
       * The column to add; if empty, nothing is inserted
       */
      oColumn: Column
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpenContextMenu beforeOpenContextMenu }
     * event of this `sap.m.Table`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Table` itself.
     *
     * Fired when the context menu is opened. When the context menu is opened, the binding context of the item
     * is set to the given `contextMenu`.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpenContextMenu(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Table$BeforeOpenContextMenuEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Table` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpenContextMenu beforeOpenContextMenu }
     * event of this `sap.m.Table`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Table` itself.
     *
     * Fired when the context menu is opened. When the context menu is opened, the binding context of the item
     * is set to the given `contextMenu`.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpenContextMenu(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Table$BeforeOpenContextMenuEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Table` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:paste paste} event of this `sap.m.Table`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Table` itself.
     *
     * This event gets fired when the user pastes content from the clipboard to the table. Pasting can be done
     * via the context menu or the standard paste keyboard shortcut, if the focus is inside the table.
     *
     * @since 1.60
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPaste(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Table$PasteEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Table` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:paste paste} event of this `sap.m.Table`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Table` itself.
     *
     * This event gets fired when the user pastes content from the clipboard to the table. Pasting can be done
     * via the context menu or the standard paste keyboard shortcut, if the focus is inside the table.
     *
     * @since 1.60
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPaste(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Table$PasteEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Table` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:popinChanged popinChanged} event of this `sap.m.Table`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Table` itself.
     *
     * Fired when the table pop-in has changed.
     *
     * @since 1.77
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPopinChanged(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Table$PopinChangedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Table` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:popinChanged popinChanged} event of this `sap.m.Table`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Table` itself.
     *
     * Fired when the table pop-in has changed.
     *
     * @since 1.77
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPopinChanged(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Table$PopinChangedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Table` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the columns in the aggregation {@link #getColumns columns}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyColumns(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeOpenContextMenu beforeOpenContextMenu }
     * event of this `sap.m.Table`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeOpenContextMenu(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Table$BeforeOpenContextMenuEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:paste paste} event of this `sap.m.Table`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.60
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPaste(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Table$PasteEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:popinChanged popinChanged} event of this `sap.m.Table`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.77
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPopinChanged(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Table$PopinChangedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:beforeOpenContextMenu beforeOpenContextMenu} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @since 1.54
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireBeforeOpenContextMenu(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Table$BeforeOpenContextMenuEventParameters
    ): boolean;
    /**
     * Fires event {@link #event:paste paste} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @since 1.60
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    firePaste(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Table$PasteEventParameters
    ): boolean;
    /**
     * Fires event {@link #event:popinChanged popinChanged} to attached listeners.
     *
     * @since 1.77
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePopinChanged(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Table$PopinChangedEventParameters
    ): this;
    /**
     * Sets the focus on the stored focus DOM reference.
     *
     * If `oFocusInfo.targetInfo` is of type {@link sap.ui.core.message.Message}, the focus will be set as accurately
     * as possible according to the information provided by {@link sap.ui.core.message.Message}.
     */
    focus(
      /**
       * Options for setting the focus
       */
      oFocusInfo?: {
        /**
         * @since 1.60 If set to `true`, the focused element won't be moved into the viewport if it's not completely
         * visible before the focus is set
         */
        preventScroll?: boolean;
        /**
         * @since 1.98 Further control-specific setting of the focus target within the control
         */
        targetInfo?: any;
      }
    ): void;
    /**
     * Gets current value of property {@link #getAlternateRowColors alternateRowColors}.
     *
     * Enables alternating table row colors. **Note:** This property can only be used with the Belize and Belize
     * Deep themes. Alternate row coloring is not available for the High Contrast Black/White themes.
     *
     * Default value is `false`.
     *
     * @since 1.52
     *
     * @returns Value of property `alternateRowColors`
     */
    getAlternateRowColors(): boolean;
    /**
     * Gets current value of property {@link #getAutoPopinMode autoPopinMode}.
     *
     * Enables the auto pop-in behavior for the table control.
     *
     * If this property is set to `true`, the table control overwrites the `demandPopin` and the `minScreenWidth`
     * properties of the `sap.m.Column` control. The pop-in behavior depends on the `importance` property of
     * the `sap.m.Column` control. Columns configured with this property are moved to the pop-in area in the
     * following order:
     *
     *
     * 	 - With importance `High`: moved last
     * 	 - With importance `Medium` or `None`: moved second
     * 	 - With importance `Low`: moved first
     *
     * **Note:** If this property is changed from `true` to `false`, the application must reconfigure the `demandPopin`
     * and `minScreenWidth` properties of the `sap.m.Column` control by itself. There is no automatic mechanism
     * that restores the old values if `autoPopinMode` was set from `false` to `true` before.
     *
     * Default value is `false`.
     *
     * @since 1.76
     *
     * @returns Value of property `autoPopinMode`
     */
    getAutoPopinMode(): boolean;
    /**
     * Gets current value of property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Sets the background style of the table. Depending on the theme, you can change the state of the background
     * from `Solid` to `Translucent` or to `Transparent`.
     *
     * Default value is `Translucent`.
     *
     *
     * @returns Value of property `backgroundDesign`
     */
    getBackgroundDesign(): BackgroundDesign;
    /**
     * Getter for aggregation columns.
     *
     *
     * @returns Columns of the Table
     */
    getColumns(
      /**
       * Set true to get the columns in an order that respects personalization settings.
       */
      bSort?: boolean
    ): Column[];
    /**
     * Gets current value of property {@link #getContextualWidth contextualWidth}.
     *
     * Defines the contextual width for the `sap.m.Table` control. By defining this property the table adapts
     * the pop-in behavior based on the container in which the table is placed or the configured contextual
     * width. By default, `sap.m.Table` renders in pop-in behavior only depending on the window size or device.
     *
     * For example, by setting the `contextualWidth` property to 600px or Tablet, the table can be placed in
     * a container with 600px width, where the pop-in is used. You can use specific CSS sizes (for example,
     * 600px or 600), you can also use the `sap.m.ScreenSize` enumeration (for example, Phone, Tablet, Desktop,
     * Small, Medium, Large, ....). If this property is set to `Auto`, the `ResizeHandler` will manage the contextual
     * width of the table. **Note:** Only "Inherit", "Auto", and pixel-based CSS sizes (for example, 200, 200px)
     * can be applied to the `contextualWidth` property. Due to the rendering cost, we recommend to use the
     * valid value mentioned before except for "Auto".
     *
     * Default value is `"Inherit"`.
     *
     * @since 1.60
     *
     * @returns Value of property `contextualWidth`
     */
    getContextualWidth(): string;
    /**
     * Gets current value of property {@link #getFixedLayout fixedLayout}.
     *
     * Defines the algorithm to be used to layout the table cells, rows, and columns. This property allows three
     * possible values:
     * 	 - `true`
     * 	 - `false`
     * 	 - `Strict`
     *
     * By default, the table is rendered with a fixed layout algorithm (`fixedLayout=true`). This means the
     * horizontal layout only depends on the table's width and the width of the columns, not the content of
     * the cells. Cells in subsequent rows do not affect column width. This allows a browser to provide a faster
     * table layout since the browser can begin to display the table once the first row has been analyzed.
     *
     * If this property is set to `false`, `sap.m.Table` is rendered with an auto layout algorithm. This means,
     * the width of the table and its cells depends on the content of the cells. The column width is set by
     * the widest unbreakable content inside the cells. This can make the rendering slow, since the browser
     * needs to go through all the content in the table before determining the final layout.
     *
     *
     * If this property is set to `Strict` and the `width` property is defined for all columns (and not the
     * expected "auto" value), then the `sap.m.Table` control renders a placeholder column which occupies the
     * remaining width of the control to ensure the column width setting is strictly applied.
     *
     *
     * If there is only one remaining column with a width larger than the table, then this column gets the maximum
     * width available in the table. If the column width is smaller than the table, then the column width is
     * retained, and the remaining width of the table is occupied by the placeholder column.
     *
     *
     * The placeholder column gets rendered only if there are no columns in the pop-in area.
     *
     *
     * **Note:** Since `sap.m.Table` does not have its own scrollbars, setting `fixedLayout` to false can force
     * the table to overflow, which may cause visual problems. It is suggested to use this property when a table
     * has a few columns in wide screens or within the horizontal scroll container (e.g `sap.m.Dialog`) to handle
     * overflow. In auto layout mode the `width` property of `sap.m.Column` is taken into account as a minimum
     * width.
     *
     * Default value is `true`.
     *
     * @since 1.22
     *
     * @returns Value of property `fixedLayout`
     */
    getFixedLayout(): any;
    /**
     * Gets current value of property {@link #getHiddenInPopin hiddenInPopin}.
     *
     * Defines which columns should be hidden instead of moved into the pop-in area depending on their importance.
     * See {@link sap.m.Column#getImportance}
     *
     * **Note:** To hide columns based on their importance, it's mandatory to set `demandPopin="true"` for the
     * `sap.m.Column` control or set `autoPopinMode="true"` for the `sap.m.Table` control. See {@link https://ui5.sap.com/#/topic/38855e06486f4910bfa6f4485f7c2bac Configuring Responsive Behavior of a Table }
     * and {@link sap.m.Table#getAutoPopinMode}.
     *
     * @since 1.77
     *
     * @returns Value of property `hiddenInPopin`
     */
    getHiddenInPopin(): Priority[];
    /**
     * Gets current value of property {@link #getPopinLayout popinLayout}.
     *
     * Defines the layout in which the table pop-in rows are rendered. **Note:** The `demandPopin` and `minScreenWidth`
     * properties of the `Column` control must be configured appropriately.
     *
     * Default value is `Block`.
     *
     * @since 1.52
     *
     * @returns Value of property `popinLayout`
     */
    getPopinLayout(): PopinLayout;
    /**
     * Gets current value of property {@link #getShowOverlay showOverlay}.
     *
     * Setting this property to `true` will show an overlay on top of the table content and prevents the user
     * interaction with it.
     *
     * Default value is `false`.
     *
     * @since 1.22.1
     *
     * @returns Value of property `showOverlay`
     */
    getShowOverlay(): boolean;
    /**
     * Checks for the provided `sap.m.Column` in the aggregation {@link #getColumns columns}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfColumn(
      /**
       * The column whose index is looked for
       */
      oColumn: Column
    ): int;
    /**
     * Inserts a column into the aggregation {@link #getColumns columns}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertColumn(
      /**
       * The column to insert; if empty, nothing is inserted
       */
      oColumn: Column,
      /**
       * The `0`-based index the column should be inserted at; for a negative value of `iIndex`, the column is
       * inserted at position 0; for a value greater than the current size of the aggregation, the column is inserted
       * at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getColumns columns}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllColumns(): Column[];
    /**
     * Removes a column from the aggregation {@link #getColumns columns}.
     *
     *
     * @returns The removed column or `null`
     */
    removeColumn(
      /**
       * The column to remove or its index or id
       */
      vColumn: int | string | Column
    ): Column | null;
    /**
     * Sets a new value for property {@link #getAlternateRowColors alternateRowColors}.
     *
     * Enables alternating table row colors. **Note:** This property can only be used with the Belize and Belize
     * Deep themes. Alternate row coloring is not available for the High Contrast Black/White themes.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.52
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAlternateRowColors(
      /**
       * New value for property `alternateRowColors`
       */
      bAlternateRowColors?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getAutoPopinMode autoPopinMode}.
     *
     * Enables the auto pop-in behavior for the table control.
     *
     * If this property is set to `true`, the table control overwrites the `demandPopin` and the `minScreenWidth`
     * properties of the `sap.m.Column` control. The pop-in behavior depends on the `importance` property of
     * the `sap.m.Column` control. Columns configured with this property are moved to the pop-in area in the
     * following order:
     *
     *
     * 	 - With importance `High`: moved last
     * 	 - With importance `Medium` or `None`: moved second
     * 	 - With importance `Low`: moved first
     *
     * **Note:** If this property is changed from `true` to `false`, the application must reconfigure the `demandPopin`
     * and `minScreenWidth` properties of the `sap.m.Column` control by itself. There is no automatic mechanism
     * that restores the old values if `autoPopinMode` was set from `false` to `true` before.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.76
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAutoPopinMode(
      /**
       * New value for property `autoPopinMode`
       */
      bAutoPopinMode?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getBackgroundDesign backgroundDesign}.
     *
     * Sets the background style of the table. Depending on the theme, you can change the state of the background
     * from `Solid` to `Translucent` or to `Transparent`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Translucent`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundDesign(
      /**
       * New value for property `backgroundDesign`
       */
      sBackgroundDesign?: BackgroundDesign | keyof typeof BackgroundDesign
    ): this;
    /**
     * Sets a new value for property {@link #getContextualWidth contextualWidth}.
     *
     * Defines the contextual width for the `sap.m.Table` control. By defining this property the table adapts
     * the pop-in behavior based on the container in which the table is placed or the configured contextual
     * width. By default, `sap.m.Table` renders in pop-in behavior only depending on the window size or device.
     *
     * For example, by setting the `contextualWidth` property to 600px or Tablet, the table can be placed in
     * a container with 600px width, where the pop-in is used. You can use specific CSS sizes (for example,
     * 600px or 600), you can also use the `sap.m.ScreenSize` enumeration (for example, Phone, Tablet, Desktop,
     * Small, Medium, Large, ....). If this property is set to `Auto`, the `ResizeHandler` will manage the contextual
     * width of the table. **Note:** Only "Inherit", "Auto", and pixel-based CSS sizes (for example, 200, 200px)
     * can be applied to the `contextualWidth` property. Due to the rendering cost, we recommend to use the
     * valid value mentioned before except for "Auto".
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Inherit"`.
     *
     * @since 1.60
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContextualWidth(
      /**
       * New value for property `contextualWidth`
       */
      sContextualWidth?: string
    ): this;
    /**
     * Sets a new value for property {@link #getFixedLayout fixedLayout}.
     *
     * Defines the algorithm to be used to layout the table cells, rows, and columns. This property allows three
     * possible values:
     * 	 - `true`
     * 	 - `false`
     * 	 - `Strict`
     *
     * By default, the table is rendered with a fixed layout algorithm (`fixedLayout=true`). This means the
     * horizontal layout only depends on the table's width and the width of the columns, not the content of
     * the cells. Cells in subsequent rows do not affect column width. This allows a browser to provide a faster
     * table layout since the browser can begin to display the table once the first row has been analyzed.
     *
     * If this property is set to `false`, `sap.m.Table` is rendered with an auto layout algorithm. This means,
     * the width of the table and its cells depends on the content of the cells. The column width is set by
     * the widest unbreakable content inside the cells. This can make the rendering slow, since the browser
     * needs to go through all the content in the table before determining the final layout.
     *
     *
     * If this property is set to `Strict` and the `width` property is defined for all columns (and not the
     * expected "auto" value), then the `sap.m.Table` control renders a placeholder column which occupies the
     * remaining width of the control to ensure the column width setting is strictly applied.
     *
     *
     * If there is only one remaining column with a width larger than the table, then this column gets the maximum
     * width available in the table. If the column width is smaller than the table, then the column width is
     * retained, and the remaining width of the table is occupied by the placeholder column.
     *
     *
     * The placeholder column gets rendered only if there are no columns in the pop-in area.
     *
     *
     * **Note:** Since `sap.m.Table` does not have its own scrollbars, setting `fixedLayout` to false can force
     * the table to overflow, which may cause visual problems. It is suggested to use this property when a table
     * has a few columns in wide screens or within the horizontal scroll container (e.g `sap.m.Dialog`) to handle
     * overflow. In auto layout mode the `width` property of `sap.m.Column` is taken into account as a minimum
     * width.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.22
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFixedLayout(
      /**
       * New value for property `fixedLayout`
       */
      oFixedLayout?: any
    ): this;
    /**
     * Sets a new value for property {@link #getHiddenInPopin hiddenInPopin}.
     *
     * Defines which columns should be hidden instead of moved into the pop-in area depending on their importance.
     * See {@link sap.m.Column#getImportance}
     *
     * **Note:** To hide columns based on their importance, it's mandatory to set `demandPopin="true"` for the
     * `sap.m.Column` control or set `autoPopinMode="true"` for the `sap.m.Table` control. See {@link https://ui5.sap.com/#/topic/38855e06486f4910bfa6f4485f7c2bac Configuring Responsive Behavior of a Table }
     * and {@link sap.m.Table#getAutoPopinMode}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.77
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHiddenInPopin(
      /**
       * New value for property `hiddenInPopin`
       */
      sHiddenInPopin: Array<Priority | keyof typeof Priority>
    ): this;
    /**
     * Sets a new value for property {@link #getPopinLayout popinLayout}.
     *
     * Defines the layout in which the table pop-in rows are rendered. **Note:** The `demandPopin` and `minScreenWidth`
     * properties of the `Column` control must be configured appropriately.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Block`.
     *
     * @since 1.52
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPopinLayout(
      /**
       * New value for property `popinLayout`
       */
      sPopinLayout?: PopinLayout | keyof typeof PopinLayout
    ): this;
    /**
     * Sets a new value for property {@link #getShowOverlay showOverlay}.
     *
     * Setting this property to `true` will show an overlay on top of the table content and prevents the user
     * interaction with it.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.22.1
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowOverlay(
      /**
       * New value for property `showOverlay`
       */
      bShowOverlay?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Table constructor.
   */
  export interface $TableSettings extends $ListBaseSettings {
    /**
     * Sets the background style of the table. Depending on the theme, you can change the state of the background
     * from `Solid` to `Translucent` or to `Transparent`.
     */
    backgroundDesign?:
      | (BackgroundDesign | keyof typeof BackgroundDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the algorithm to be used to layout the table cells, rows, and columns. This property allows three
     * possible values:
     * 	 - `true`
     * 	 - `false`
     * 	 - `Strict`
     *
     * By default, the table is rendered with a fixed layout algorithm (`fixedLayout=true`). This means the
     * horizontal layout only depends on the table's width and the width of the columns, not the content of
     * the cells. Cells in subsequent rows do not affect column width. This allows a browser to provide a faster
     * table layout since the browser can begin to display the table once the first row has been analyzed.
     *
     * If this property is set to `false`, `sap.m.Table` is rendered with an auto layout algorithm. This means,
     * the width of the table and its cells depends on the content of the cells. The column width is set by
     * the widest unbreakable content inside the cells. This can make the rendering slow, since the browser
     * needs to go through all the content in the table before determining the final layout.
     *
     *
     * If this property is set to `Strict` and the `width` property is defined for all columns (and not the
     * expected "auto" value), then the `sap.m.Table` control renders a placeholder column which occupies the
     * remaining width of the control to ensure the column width setting is strictly applied.
     *
     *
     * If there is only one remaining column with a width larger than the table, then this column gets the maximum
     * width available in the table. If the column width is smaller than the table, then the column width is
     * retained, and the remaining width of the table is occupied by the placeholder column.
     *
     *
     * The placeholder column gets rendered only if there are no columns in the pop-in area.
     *
     *
     * **Note:** Since `sap.m.Table` does not have its own scrollbars, setting `fixedLayout` to false can force
     * the table to overflow, which may cause visual problems. It is suggested to use this property when a table
     * has a few columns in wide screens or within the horizontal scroll container (e.g `sap.m.Dialog`) to handle
     * overflow. In auto layout mode the `width` property of `sap.m.Column` is taken into account as a minimum
     * width.
     *
     * @since 1.22
     */
    fixedLayout?: any | PropertyBindingInfo | `{${string}}`;

    /**
     * Setting this property to `true` will show an overlay on top of the table content and prevents the user
     * interaction with it.
     *
     * @since 1.22.1
     */
    showOverlay?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Enables alternating table row colors. **Note:** This property can only be used with the Belize and Belize
     * Deep themes. Alternate row coloring is not available for the High Contrast Black/White themes.
     *
     * @since 1.52
     */
    alternateRowColors?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the layout in which the table pop-in rows are rendered. **Note:** The `demandPopin` and `minScreenWidth`
     * properties of the `Column` control must be configured appropriately.
     *
     * @since 1.52
     */
    popinLayout?:
      | (PopinLayout | keyof typeof PopinLayout)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the contextual width for the `sap.m.Table` control. By defining this property the table adapts
     * the pop-in behavior based on the container in which the table is placed or the configured contextual
     * width. By default, `sap.m.Table` renders in pop-in behavior only depending on the window size or device.
     *
     * For example, by setting the `contextualWidth` property to 600px or Tablet, the table can be placed in
     * a container with 600px width, where the pop-in is used. You can use specific CSS sizes (for example,
     * 600px or 600), you can also use the `sap.m.ScreenSize` enumeration (for example, Phone, Tablet, Desktop,
     * Small, Medium, Large, ....). If this property is set to `Auto`, the `ResizeHandler` will manage the contextual
     * width of the table. **Note:** Only "Inherit", "Auto", and pixel-based CSS sizes (for example, 200, 200px)
     * can be applied to the `contextualWidth` property. Due to the rendering cost, we recommend to use the
     * valid value mentioned before except for "Auto".
     *
     * @since 1.60
     */
    contextualWidth?: string | PropertyBindingInfo;

    /**
     * Enables the auto pop-in behavior for the table control.
     *
     * If this property is set to `true`, the table control overwrites the `demandPopin` and the `minScreenWidth`
     * properties of the `sap.m.Column` control. The pop-in behavior depends on the `importance` property of
     * the `sap.m.Column` control. Columns configured with this property are moved to the pop-in area in the
     * following order:
     *
     *
     * 	 - With importance `High`: moved last
     * 	 - With importance `Medium` or `None`: moved second
     * 	 - With importance `Low`: moved first
     *
     * **Note:** If this property is changed from `true` to `false`, the application must reconfigure the `demandPopin`
     * and `minScreenWidth` properties of the `sap.m.Column` control by itself. There is no automatic mechanism
     * that restores the old values if `autoPopinMode` was set from `false` to `true` before.
     *
     * @since 1.76
     */
    autoPopinMode?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines which columns should be hidden instead of moved into the pop-in area depending on their importance.
     * See {@link sap.m.Column#getImportance}
     *
     * **Note:** To hide columns based on their importance, it's mandatory to set `demandPopin="true"` for the
     * `sap.m.Column` control or set `autoPopinMode="true"` for the `sap.m.Table` control. See {@link https://ui5.sap.com/#/topic/38855e06486f4910bfa6f4485f7c2bac Configuring Responsive Behavior of a Table }
     * and {@link sap.m.Table#getAutoPopinMode}.
     *
     * @since 1.77
     */
    hiddenInPopin?:
      | Array<Priority | keyof typeof Priority>
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the columns of the table.
     */
    columns?: Column[] | Column | AggregationBindingInfo | `{${string}}`;

    /**
     * Fired when the context menu is opened. When the context menu is opened, the binding context of the item
     * is set to the given `contextMenu`.
     *
     * @since 1.54
     */
    beforeOpenContextMenu?: (oEvent: Table$BeforeOpenContextMenuEvent) => void;

    /**
     * This event gets fired when the user pastes content from the clipboard to the table. Pasting can be done
     * via the context menu or the standard paste keyboard shortcut, if the focus is inside the table.
     *
     * @since 1.60
     */
    paste?: (oEvent: Table$PasteEvent) => void;

    /**
     * Fired when the table pop-in has changed.
     *
     * @since 1.77
     */
    popinChanged?: (oEvent: Table$PopinChangedEvent) => void;
  }

  /**
   * Parameters of the Table#beforeOpenContextMenu event.
   */
  export interface Table$BeforeOpenContextMenuEventParameters
    extends ListBase$BeforeOpenContextMenuEventParameters {
    /**
     * Column in which the context menu was opened. **Note:** This parameter might be undefined for the items
     * that are not part of a column definition.
     */
    column?: Column;
  }

  /**
   * Event object of the Table#beforeOpenContextMenu event.
   */
  export type Table$BeforeOpenContextMenuEvent = Event<
    Table$BeforeOpenContextMenuEventParameters,
    Table
  >;

  /**
   * Parameters of the Table#paste event.
   */
  export interface Table$PasteEventParameters {
    /**
     * 2D array of strings with data from the clipboard. The first dimension represents the rows, and the second
     * dimension represents the cells of the tabular data.
     */
    data?: string[][];
  }

  /**
   * Event object of the Table#paste event.
   */
  export type Table$PasteEvent = Event<Table$PasteEventParameters, Table>;

  /**
   * Parameters of the Table#popinChanged event.
   */
  export interface Table$PopinChangedEventParameters {
    /**
     * Returns true if there are visible columns in the pop-in area
     */
    hasPopin?: boolean;

    /**
     * Returns array of all visible columns in the pop-in area.
     */
    visibleInPopin?: Column[];

    /**
     * Returns array of columns that are hidden in the pop-in based on their importance. See {@link sap.m.Column#getImportance}
     */
    hiddenInPopin?: Column[];
  }

  /**
   * Event object of the Table#popinChanged event.
   */
  export type Table$PopinChangedEvent = Event<
    Table$PopinChangedEventParameters,
    Table
  >;
}

declare module "sap/m/table/columnmenu/ActionItem" {
  import {
    default as ItemBase,
    $ItemBaseSettings,
  } from "sap/m/table/columnmenu/ItemBase";

  import Event from "sap/ui/base/Event";

  import { URI } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The `ActionItem` class is used for action items for the `sap.m.table.columnmenu.Menu`. It can be used
   * to specify control- and application-specific items that should solely serve as actions.
   *
   * @since 1.110
   */
  export default class ActionItem extends ItemBase {
    /**
     * Constructor for a new `ActionItem`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new `ActionItem`
       */
      mSettings?: $ActionItemSettings
    );
    /**
     * Constructor for a new `ActionItem`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new `ActionItem`, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new `ActionItem`
       */
      mSettings?: $ActionItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.table.columnmenu.ActionItem with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.table.columnmenu.ItemBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ActionItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.table.columnmenu.ActionItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.table.columnmenu.ActionItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.ActionItem` itself.
     *
     * This event is fired when the action item is pressed. The default behavior can be prevented by the application,
     * in which case the menu will not close.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.ActionItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.table.columnmenu.ActionItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.ActionItem` itself.
     *
     * This event is fired when the action item is pressed. The default behavior can be prevented by the application,
     * in which case the menu will not close.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.ActionItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.table.columnmenu.ActionItem`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): boolean;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Defines the icon for the action item.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getLabel label}.
     *
     * Defines the label that is used for the action item.
     *
     *
     * @returns Value of property `label`
     */
    getLabel(): string;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Defines the icon for the action item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon: URI
    ): this;
    /**
     * Sets a new value for property {@link #getLabel label}.
     *
     * Defines the label that is used for the action item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLabel(
      /**
       * New value for property `label`
       */
      sLabel: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ActionItem constructor.
   */
  export interface $ActionItemSettings extends $ItemBaseSettings {
    /**
     * Defines the label that is used for the action item.
     */
    label?: string | PropertyBindingInfo;

    /**
     * Defines the icon for the action item.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * This event is fired when the action item is pressed. The default behavior can be prevented by the application,
     * in which case the menu will not close.
     */
    press?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the ActionItem#press event.
   */
  export interface ActionItem$PressEventParameters {}

  /**
   * Event object of the ActionItem#press event.
   */
  export type ActionItem$PressEvent = Event<
    ActionItem$PressEventParameters,
    ActionItem
  >;
}

declare module "sap/m/table/columnmenu/Entry" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import Menu from "sap/m/table/columnmenu/Menu";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The `Entry` class is used as a base class for elements residing inside the `sap.m.table.columnmenu.Menu`.
   * This faceless class can be used to specify control- and application-specific menu items and quick actions.
   *
   * @since 1.110
   */
  export default class Entry extends UI5Element {
    /**
     * Constructor for a new `Entry`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new `Entry`
       */
      mSettings?: $EntrySettings
    );
    /**
     * Constructor for a new `Entry`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new `Entry`, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new `Entry`
       */
      mSettings?: $EntrySettings
    );

    /**
     * Creates a new subclass of class sap.m.table.columnmenu.Entry with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Entry>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.table.columnmenu.Entry.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Retrieves the `Menu` in which the entry resides.
     *
     * If an entry is internally creating entries that use {@link #getMenu} or {@link #getParent}, and returns
     * them in {@link #getEffectiveItems} or {@link #getEffectiveQuickActions}, they must be its children in
     * the control tree.
     *
     *
     * @returns The menu of the entry
     */
    getMenu(): Menu;
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * Determines whether the entry is visible.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * Determines whether the entry is visible.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Entry constructor.
   */
  export interface $EntrySettings extends $ElementSettings {
    /**
     * Determines whether the entry is visible.
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/table/columnmenu/Item" {
  import {
    default as ItemBase,
    $ItemBaseSettings,
  } from "sap/m/table/columnmenu/ItemBase";

  import Event from "sap/ui/base/Event";

  import Control from "sap/ui/core/Control";

  import { URI } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The `Item` class is used for menu items for the `sap.m.table.columnmenu.Menu`. It can be used to specify
   * control- and application-specific menu items.
   *
   * @since 1.110
   * @deprecated As of version 1.132. the concept has been discarded.
   */
  export default class Item extends ItemBase {
    /**
     * Constructor for a new `Item`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new `Item`
       */
      mSettings?: $ItemSettings
    );
    /**
     * Constructor for a new `Item`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new `Item`, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new `Item`
       */
      mSettings?: $ItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.table.columnmenu.Item with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.table.columnmenu.ItemBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Item>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.table.columnmenu.Item.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cancel cancel} event of this `sap.m.table.columnmenu.Item`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.Item` itself.
     *
     * This event is fired when the Cancel button is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCancel(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.Item` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cancel cancel} event of this `sap.m.table.columnmenu.Item`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.Item` itself.
     *
     * This event is fired when the Cancel button is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCancel(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.Item` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:confirm confirm} event of this `sap.m.table.columnmenu.Item`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.Item` itself.
     *
     * This event is fired when the Confirm button is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachConfirm(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.Item` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:confirm confirm} event of this `sap.m.table.columnmenu.Item`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.Item` itself.
     *
     * This event is fired when the Confirm button is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachConfirm(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.Item` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:reset reset} event of this `sap.m.table.columnmenu.Item`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.Item` itself.
     *
     * This event is fired when the Reset button is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachReset(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.Item` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:reset reset} event of this `sap.m.table.columnmenu.Item`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.Item` itself.
     *
     * This event is fired when the Reset button is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachReset(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.Item` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:cancel cancel} event of this `sap.m.table.columnmenu.Item`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachCancel(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:confirm confirm} event of this `sap.m.table.columnmenu.Item`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachConfirm(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:reset reset} event of this `sap.m.table.columnmenu.Item`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachReset(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:cancel cancel} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireCancel(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): boolean;
    /**
     * Fires event {@link #event:confirm confirm} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireConfirm(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): boolean;
    /**
     * Fires event {@link #event:reset reset} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireReset(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * Defines the content that is shown when navigating to the item.
     */
    getContent(): Control;
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Defines the icon for the item.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getLabel label}.
     *
     * Defines the label that is used for the item.
     *
     *
     * @returns Value of property `label`
     */
    getLabel(): string;
    /**
     * Gets current value of property {@link #getResetButtonEnabled resetButtonEnabled}.
     *
     * Defines whether the Reset button is enabled when navigating to the item.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `resetButtonEnabled`
     */
    getResetButtonEnabled(): boolean;
    /**
     * Gets current value of property {@link #getShowCancelButton showCancelButton}.
     *
     * Defines whether the Cancel button is shown when navigating to the item.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showCancelButton`
     */
    getShowCancelButton(): boolean;
    /**
     * Gets current value of property {@link #getShowConfirmButton showConfirmButton}.
     *
     * Defines whether the Confirm button is shown when navigating to the item.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showConfirmButton`
     */
    getShowConfirmButton(): boolean;
    /**
     * Gets current value of property {@link #getShowResetButton showResetButton}.
     *
     * Defines whether the Reset button is shown when navigating to the item.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showResetButton`
     */
    getShowResetButton(): boolean;
    /**
     * Sets the aggregated {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContent(
      /**
       * The content to set
       */
      oContent: Control
    ): this;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Defines the icon for the item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon: URI
    ): this;
    /**
     * Sets a new value for property {@link #getLabel label}.
     *
     * Defines the label that is used for the item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLabel(
      /**
       * New value for property `label`
       */
      sLabel: string
    ): this;
    /**
     * Sets a new value for property {@link #getResetButtonEnabled resetButtonEnabled}.
     *
     * Defines whether the Reset button is enabled when navigating to the item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setResetButtonEnabled(
      /**
       * New value for property `resetButtonEnabled`
       */
      bResetButtonEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowCancelButton showCancelButton}.
     *
     * Defines whether the Cancel button is shown when navigating to the item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowCancelButton(
      /**
       * New value for property `showCancelButton`
       */
      bShowCancelButton?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowConfirmButton showConfirmButton}.
     *
     * Defines whether the Confirm button is shown when navigating to the item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowConfirmButton(
      /**
       * New value for property `showConfirmButton`
       */
      bShowConfirmButton?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowResetButton showResetButton}.
     *
     * Defines whether the Reset button is shown when navigating to the item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowResetButton(
      /**
       * New value for property `showResetButton`
       */
      bShowResetButton?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Item constructor.
   *
   * @deprecated As of version 1.132. the concept has been discarded.
   */
  export interface $ItemSettings extends $ItemBaseSettings {
    /**
     * Defines the label that is used for the item.
     */
    label?: string | PropertyBindingInfo;

    /**
     * Defines the icon for the item.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether the Reset button is shown when navigating to the item.
     */
    showResetButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether the Reset button is enabled when navigating to the item.
     */
    resetButtonEnabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether the Confirm button is shown when navigating to the item.
     */
    showConfirmButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether the Cancel button is shown when navigating to the item.
     */
    showCancelButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the content that is shown when navigating to the item.
     */
    content?: Control;

    /**
     * This event is fired when the Reset button is pressed.
     */
    reset?: (oEvent: Event) => void;

    /**
     * This event is fired when the Confirm button is pressed.
     */
    confirm?: (oEvent: Event) => void;

    /**
     * This event is fired when the Cancel button is pressed.
     */
    cancel?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the Item#cancel event.
   */
  export interface Item$CancelEventParameters {}

  /**
   * Event object of the Item#cancel event.
   */
  export type Item$CancelEvent = Event<Item$CancelEventParameters, Item>;

  /**
   * Parameters of the Item#confirm event.
   */
  export interface Item$ConfirmEventParameters {}

  /**
   * Event object of the Item#confirm event.
   */
  export type Item$ConfirmEvent = Event<Item$ConfirmEventParameters, Item>;

  /**
   * Parameters of the Item#reset event.
   */
  export interface Item$ResetEventParameters {}

  /**
   * Event object of the Item#reset event.
   */
  export type Item$ResetEvent = Event<Item$ResetEventParameters, Item>;
}

declare module "sap/m/table/columnmenu/ItemBase" {
  import {
    default as Entry,
    $EntrySettings,
  } from "sap/m/table/columnmenu/Entry";

  import { URI } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * The `ItemBase` class is used as a base class for menu items for the `sap.m.table.columnmenu.Menu`. This
   * faceless class can be used to specify control- and application-specific menu items.
   *
   * @since 1.110
   */
  export default class ItemBase extends Entry {
    /**
     * Constructor for a new `ItemBase`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.table.columnmenu.Entry#constructor sap.m.table.columnmenu.Entry }
     * can be used.
     */
    constructor(
      /**
       * Initial settings for the new `ItemBase`
       */
      mSettings?: $ItemBaseSettings
    );
    /**
     * Constructor for a new `ItemBase`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.table.columnmenu.Entry#constructor sap.m.table.columnmenu.Entry }
     * can be used.
     */
    constructor(
      /**
       * ID for the new `ItemBase`, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new `ItemBase`
       */
      mSettings?: $ItemBaseSettings
    );

    /**
     * Creates a new subclass of class sap.m.table.columnmenu.ItemBase with name `sClassName` and enriches it
     * with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.table.columnmenu.Entry.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ItemBase>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.table.columnmenu.ItemBase.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Changes the button settings of an item.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    changeButtonSettings(
      /**
       * Object containing button settings
       */
      oButtonSettings: object
    ): void;
    /**
     * Retrieves the button settings.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The button settings
     */
    getButtonSettings(): object;
    /**
     * Retrieves the effective items of the item.
     *
     * This method allows subclasses to return composition of other items, if they contain multiple items or
     * controls.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns A composition of effective items
     */
    getEffectiveItems(): ItemBase[];
    /**
     * Retrieves the icon specified for an item.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The specified icon
     */
    getIcon(): URI;
    /**
     * Event handler for a back event.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onBack(
      /**
       * The event
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * Event handler for a cancel event.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onCancel(
      /**
       * The event
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * Event handler for a confirm event.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onConfirm(
      /**
       * The event
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * Event handler for a press event.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onPress(
      /**
       * The event
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * Event handler for a reset event.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onReset(
      /**
       * The event
       */
      oEvent: jQuery.Event
    ): void;
  }
  /**
   * Describes the settings that can be provided to the ItemBase constructor.
   */
  export interface $ItemBaseSettings extends $EntrySettings {}
}

declare module "sap/m/table/columnmenu/Menu" {
  import {
    default as MenuBase,
    $MenuBaseSettings,
  } from "sap/m/table/columnmenu/MenuBase";

  import ItemBase from "sap/m/table/columnmenu/ItemBase";

  import QuickActionBase from "sap/m/table/columnmenu/QuickActionBase";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Control from "sap/ui/core/Control";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * The `Menu` control is a popover, intended to be used by a table. It serves as an entry point for the
   * table personalization via the column headers. The menu is separated into two sections: quick actions
   * and menu items.
   *
   * The top section of the popover contains contextual quick actions for the column the menu was triggered
   * from. The lower section contains menu items related to generic and global table settings.
   *
   * There are control- and application-specific quick actions and menu items. Applications can add their
   * own quick actions and items.
   *
   * @since 1.110
   */
  export default class Menu extends MenuBase {
    /**
     * Constructor for a new `Menu`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new `Menu`
       */
      mSettings?: $MenuSettings
    );
    /**
     * Constructor for a new `Menu`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new `Menu`, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new `Menu`
       */
      mSettings?: $MenuSettings
    );

    /**
     * Creates a new subclass of class sap.m.table.columnmenu.Menu with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.table.columnmenu.MenuBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Menu>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.table.columnmenu.Menu.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: ItemBase
    ): this;
    /**
     * Adds some quickAction to the aggregation {@link #getQuickActions quickActions}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addQuickAction(
      /**
       * The quickAction to add; if empty, nothing is inserted
       */
      oQuickAction: QuickActionBase
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tableSettingsPressed tableSettingsPressed} event
     * of this `sap.m.table.columnmenu.Menu`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.Menu` itself.
     *
     * Fires when the table settings button is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTableSettingsPressed(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.Menu` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tableSettingsPressed tableSettingsPressed} event
     * of this `sap.m.table.columnmenu.Menu`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.Menu` itself.
     *
     * Fires when the table settings button is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTableSettingsPressed(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.Menu` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Destroys all the quickActions in the aggregation {@link #getQuickActions quickActions}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyQuickActions(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:tableSettingsPressed tableSettingsPressed }
     * event of this `sap.m.table.columnmenu.Menu`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachTableSettingsPressed(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:tableSettingsPressed tableSettingsPressed} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireTableSettingsPressed(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * Defines the items of the column menu.
     */
    getItems(): ItemBase[];
    /**
     * Gets content of aggregation {@link #getQuickActions quickActions}.
     *
     * Defines the quick actions of the column menu.
     */
    getQuickActions(): QuickActionBase[];
    /**
     * Gets current value of property {@link #getShowTableSettingsButton showTableSettingsButton}.
     *
     * Specifies whether the table settings button is visible.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `showTableSettingsButton`
     */
    getShowTableSettingsButton(): boolean;
    /**
     * Checks for the provided `sap.m.table.columnmenu.ItemBase` in the aggregation {@link #getItems items}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: ItemBase
    ): int;
    /**
     * Checks for the provided `sap.m.table.columnmenu.QuickActionBase` in the aggregation {@link #getQuickActions quickActions}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfQuickAction(
      /**
       * The quickAction whose index is looked for
       */
      oQuickAction: QuickActionBase
    ): int;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: ItemBase,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a quickAction into the aggregation {@link #getQuickActions quickActions}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertQuickAction(
      /**
       * The quickAction to insert; if empty, nothing is inserted
       */
      oQuickAction: QuickActionBase,
      /**
       * The `0`-based index the quickAction should be inserted at; for a negative value of `iIndex`, the quickAction
       * is inserted at position 0; for a value greater than the current size of the aggregation, the quickAction
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Opens the popover at the specified target.
     */
    openBy(
      /**
       * This is the control or HTMLElement where the popover is placed.
       */
      oAnchor: Control | HTMLElement,
      /**
       * Whether to suppress the beforeOpen event.
       */
      bSuppressEvent?: boolean
    ): void;
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): ItemBase[];
    /**
     * Removes all the controls from the aggregation {@link #getQuickActions quickActions}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllQuickActions(): QuickActionBase[];
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | ItemBase
    ): ItemBase | null;
    /**
     * Removes a quickAction from the aggregation {@link #getQuickActions quickActions}.
     *
     *
     * @returns The removed quickAction or `null`
     */
    removeQuickAction(
      /**
       * The quickAction to remove or its index or id
       */
      vQuickAction: int | string | QuickActionBase
    ): QuickActionBase | null;
    /**
     * Sets a new value for property {@link #getShowTableSettingsButton showTableSettingsButton}.
     *
     * Specifies whether the table settings button is visible.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowTableSettingsButton(
      /**
       * New value for property `showTableSettingsButton`
       */
      bShowTableSettingsButton?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Menu constructor.
   */
  export interface $MenuSettings extends $MenuBaseSettings {
    /**
     * Specifies whether the table settings button is visible.
     */
    showTableSettingsButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the quick actions of the column menu.
     */
    quickActions?:
      | QuickActionBase[]
      | QuickActionBase
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Defines the items of the column menu.
     */
    items?: ItemBase[] | ItemBase | AggregationBindingInfo | `{${string}}`;

    /**
     * Fires when the table settings button is pressed.
     */
    tableSettingsPressed?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the Menu#tableSettingsPressed event.
   */
  export interface Menu$TableSettingsPressedEventParameters {}

  /**
   * Event object of the Menu#tableSettingsPressed event.
   */
  export type Menu$TableSettingsPressedEvent = Event<
    Menu$TableSettingsPressedEventParameters,
    Menu
  >;
}

declare module "sap/m/table/columnmenu/MenuBase" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { IColumnHeaderMenu, aria } from "sap/ui/core/library";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import UI5Element from "sap/ui/core/Element";

  /**
   * This control serves as base class for column menus. It implements the {@link sap.m.table.IColumnHeaderMenu }
   * interface.
   *
   * @since 1.126
   */
  export default abstract class MenuBase
    extends Control
    implements IColumnHeaderMenu
  {
    __implements__sap_ui_core_IColumnHeaderMenu: boolean;
    /**
     * Constructor for a new `MenuBase`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $MenuBaseSettings
    );
    /**
     * Constructor for a new `MenuBase`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $MenuBaseSettings
    );

    /**
     * Creates a new subclass of class sap.m.table.columnmenu.MenuBase with name `sClassName` and enriches it
     * with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, MenuBase>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.table.columnmenu.MenuBase.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterClose afterClose} event of this `sap.m.table.columnmenu.MenuBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.MenuBase` itself.
     *
     * Fired after the column menu has been closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.MenuBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterClose afterClose} event of this `sap.m.table.columnmenu.MenuBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.MenuBase` itself.
     *
     * Fired after the column menu has been closed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.MenuBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.table.columnmenu.MenuBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.MenuBase` itself.
     *
     * Fired before the column menu is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MenuBase$BeforeOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.MenuBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeOpen beforeOpen} event of this `sap.m.table.columnmenu.MenuBase`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.MenuBase` itself.
     *
     * Fired before the column menu is opened.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: MenuBase$BeforeOpenEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.MenuBase` itself
       */
      oListener?: object
    ): this;
    /**
     * Closes the menu.
     */
    close(): void;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterClose afterClose} event of this `sap.m.table.columnmenu.MenuBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeOpen beforeOpen} event of this `sap.m.table.columnmenu.MenuBase`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: MenuBase$BeforeOpenEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:afterClose afterClose} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:beforeOpen beforeOpen} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireBeforeOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: MenuBase$BeforeOpenEventParameters
    ): boolean;
    /**
     * Returns the `sap.ui.core.aria.HasPopup` type of the menu.
     *
     *
     * @returns `sap.ui.core.aria.HasPopup` type of the menu
     */
    getAriaHasPopupType(): aria.HasPopup;
    /**
     * Determines whether the menu is open.
     *
     *
     * @returns Whether the menu is open
     */
    isOpen(): boolean;
    /**
     * Opens the popover at the specified target.
     */
    openBy(
      /**
       * This is the control or HTMLElement where the popover is placed
       */
      oAnchor: UI5Element | HTMLElement
    ): void;
  }
  /**
   * Describes the settings that can be provided to the MenuBase constructor.
   */
  export interface $MenuBaseSettings extends $ControlSettings {
    /**
     * Fired before the column menu is opened.
     */
    beforeOpen?: (oEvent: MenuBase$BeforeOpenEvent) => void;

    /**
     * Fired after the column menu has been closed.
     */
    afterClose?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the MenuBase#afterClose event.
   */
  export interface MenuBase$AfterCloseEventParameters {}

  /**
   * Event object of the MenuBase#afterClose event.
   */
  export type MenuBase$AfterCloseEvent = Event<
    MenuBase$AfterCloseEventParameters,
    MenuBase
  >;

  /**
   * Parameters of the MenuBase#beforeOpen event.
   */
  export interface MenuBase$BeforeOpenEventParameters {
    /**
     * The element for which the menu is opened. If it is an `HTMLElement`, the nearest {@link sap.ui.core.Element }
     * that wraps the given DOM element is passed for this event (if it exists).
     */
    openBy?: UI5Element;
  }

  /**
   * Event object of the MenuBase#beforeOpen event.
   */
  export type MenuBase$BeforeOpenEvent = Event<
    MenuBase$BeforeOpenEventParameters,
    MenuBase
  >;
}

declare module "sap/m/table/columnmenu/QuickAction" {
  import {
    default as QuickActionBase,
    $QuickActionBaseSettings,
  } from "sap/m/table/columnmenu/QuickActionBase";

  import Control from "sap/ui/core/Control";

  import { table } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * The `QuickAction` class is used for quick actions for the `sap.m.table.columnmenu.Menu`. It can be used
   * to specify control- and application-specific quick actions.
   *
   * @since 1.110
   */
  export default class QuickAction extends QuickActionBase {
    /**
     * Constructor for a new `QuickAction`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new `QuickAction`
       */
      mSettings?: $QuickActionSettings
    );
    /**
     * Constructor for a new `QuickAction`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new `QuickAction`, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new `QuickAction`
       */
      mSettings?: $QuickActionSettings
    );

    /**
     * Creates a new subclass of class sap.m.table.columnmenu.QuickAction with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.table.columnmenu.QuickActionBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, QuickAction>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.table.columnmenu.QuickAction.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some content to the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContent(
      /**
       * The content to add; if empty, nothing is inserted
       */
      oContent: Control
    ): this;
    /**
     * Destroys all the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Gets current value of property {@link #getCategory category}.
     *
     * Defines the category. In the menu all `QuickActions` are implicitly ordered by their category.
     *
     * Default value is `Generic`.
     *
     *
     * @returns Value of property `category`
     */
    getCategory(): table.columnmenu.Category;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * Defines the content that is shown for the quick action.
     *
     * **Note:**Adding content to the quick action, altering its layout or visibility will only take effect
     * once the popover has been closed and reopened again.
     *
     * The expected content are single controls that implement the `sap.ui.core.IFormContent` interface. The
     * use case with more complex content and layouts that use the `sap.ui.layout.GridData` is deprecated as
     * of version 1.132.
     */
    getContent(): Control[];
    /**
     * Gets current value of property {@link #getContentSize contentSize}.
     *
     * Determines how much space is allocated for the content.
     *
     * Default value is `"L"`.
     *
     *
     * @returns Value of property `contentSize`
     */
    getContentSize(): table.columnmenu.QuickActionContentSize;
    /**
     * Gets current value of property {@link #getLabel label}.
     *
     * Defines the text for the label.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `label`
     */
    getLabel(): string;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContent content}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContent(
      /**
       * The content whose index is looked for
       */
      oContent: Control
    ): int;
    /**
     * Inserts a content into the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContent(
      /**
       * The content to insert; if empty, nothing is inserted
       */
      oContent: Control,
      /**
       * The `0`-based index the content should be inserted at; for a negative value of `iIndex`, the content
       * is inserted at position 0; for a value greater than the current size of the aggregation, the content
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getContent content}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContent(): Control[];
    /**
     * Removes a content from the aggregation {@link #getContent content}.
     *
     *
     * @returns The removed content or `null`
     */
    removeContent(
      /**
       * The content to remove or its index or id
       */
      vContent: int | string | Control
    ): Control | null;
    /**
     * Sets a new value for property {@link #getCategory category}.
     *
     * Defines the category. In the menu all `QuickActions` are implicitly ordered by their category.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Generic`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCategory(
      /**
       * New value for property `category`
       */
      sCategory?:
        | table.columnmenu.Category
        | keyof typeof table.columnmenu.Category
    ): this;
    /**
     * Sets a new value for property {@link #getContentSize contentSize}.
     *
     * Determines how much space is allocated for the content.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"L"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContentSize(
      /**
       * New value for property `contentSize`
       */
      sContentSize?:
        | table.columnmenu.QuickActionContentSize
        | keyof typeof table.columnmenu.QuickActionContentSize
    ): this;
    /**
     * Sets a new value for property {@link #getLabel label}.
     *
     * Defines the text for the label.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLabel(
      /**
       * New value for property `label`
       */
      sLabel?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the QuickAction constructor.
   */
  export interface $QuickActionSettings extends $QuickActionBaseSettings {
    /**
     * Defines the text for the label.
     */
    label?: string | PropertyBindingInfo;

    /**
     * Defines the category. In the menu all `QuickActions` are implicitly ordered by their category.
     */
    category?:
      | (table.columnmenu.Category | keyof typeof table.columnmenu.Category)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Determines how much space is allocated for the content.
     */
    contentSize?:
      | (
          | table.columnmenu.QuickActionContentSize
          | keyof typeof table.columnmenu.QuickActionContentSize
        )
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the content that is shown for the quick action.
     *
     * **Note:**Adding content to the quick action, altering its layout or visibility will only take effect
     * once the popover has been closed and reopened again.
     *
     * The expected content are single controls that implement the `sap.ui.core.IFormContent` interface. The
     * use case with more complex content and layouts that use the `sap.ui.layout.GridData` is deprecated as
     * of version 1.132.
     */
    content?: Control[] | Control | AggregationBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/table/columnmenu/QuickActionBase" {
  import {
    default as Entry,
    $EntrySettings,
  } from "sap/m/table/columnmenu/Entry";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * The `QuickActionBase` class is used as a base class for quick actions for the `sap.m.table.columnmenu.Menu`.
   * This faceless class can be used to specify control- and application-specific quick actions.
   *
   * @since 1.110
   */
  export default class QuickActionBase extends Entry {
    /**
     * Constructor for a new `QuickActionBase`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.table.columnmenu.Entry#constructor sap.m.table.columnmenu.Entry }
     * can be used.
     */
    constructor(
      /**
       * Initial settings for the new `QuickActionBase`
       */
      mSettings?: $QuickActionBaseSettings
    );
    /**
     * Constructor for a new `QuickActionBase`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.table.columnmenu.Entry#constructor sap.m.table.columnmenu.Entry }
     * can be used.
     */
    constructor(
      /**
       * ID for the new `QuickActionBase`, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new `QuickActionBase`
       */
      mSettings?: $QuickActionBaseSettings
    );

    /**
     * Creates a new subclass of class sap.m.table.columnmenu.QuickActionBase with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.table.columnmenu.Entry.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, QuickActionBase>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.table.columnmenu.QuickActionBase.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Retrieves the effective quick actions.
     *
     * Subclasses can implement this method, if there are compositions of other quick actions.
     *
     *
     * @returns The effective quick actions
     */
    getEffectiveQuickActions(): QuickActionBase[];
  }
  /**
   * Describes the settings that can be provided to the QuickActionBase constructor.
   */
  export interface $QuickActionBaseSettings extends $EntrySettings {}
}

declare module "sap/m/table/columnmenu/QuickActionItem" {
  import {
    default as Entry,
    $EntrySettings,
  } from "sap/m/table/columnmenu/Entry";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The `QuickActionItem` class is used for quick action items for the `sap.m.table.columnmenu.Menu`. It
   * can be used to specify control- and application-specific quick action items.
   *
   * @since 1.110
   */
  export default class QuickActionItem extends Entry {
    /**
     * Constructor for a new `>QuickActionItem`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new `QuickActionItem`
       */
      mSettings?: $QuickActionItemSettings
    );
    /**
     * Constructor for a new `>QuickActionItem`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new `QuickActionItem`, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new `QuickActionItem`
       */
      mSettings?: $QuickActionItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.table.columnmenu.QuickActionItem with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.table.columnmenu.Entry.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, QuickActionItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.table.columnmenu.QuickActionItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getKey key}.
     *
     * The property name
     *
     *
     * @returns Value of property `key`
     */
    getKey(): string;
    /**
     * Gets current value of property {@link #getLabel label}.
     *
     * Defines the text for the label.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `label`
     */
    getLabel(): string;
    /**
     * Sets a new value for property {@link #getKey key}.
     *
     * The property name
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setKey(
      /**
       * New value for property `key`
       */
      sKey: string
    ): this;
    /**
     * Sets a new value for property {@link #getLabel label}.
     *
     * Defines the text for the label.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLabel(
      /**
       * New value for property `label`
       */
      sLabel?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the QuickActionItem constructor.
   */
  export interface $QuickActionItemSettings extends $EntrySettings {
    /**
     * The property name
     */
    key?: string | PropertyBindingInfo;

    /**
     * Defines the text for the label.
     */
    label?: string | PropertyBindingInfo;
  }
}

declare module "sap/m/table/columnmenu/QuickGroup" {
  import {
    default as QuickActionBase,
    $QuickActionBaseSettings,
  } from "sap/m/table/columnmenu/QuickActionBase";

  import QuickGroupItem from "sap/m/table/columnmenu/QuickGroupItem";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { AggregationBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * The `QuickGroup` class is used for quick grouping for the `sap.m.table.columnmenu.Menu`. It can be used
   * to specify control- and application-specific quick actions for grouping.
   *
   * @since 1.110
   */
  export default class QuickGroup extends QuickActionBase {
    /**
     * Constructor for a new `QuickGroup`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new `QuickGroup`
       */
      mSettings?: $QuickGroupSettings
    );
    /**
     * Constructor for a new `QuickGroup`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new `QuickGroup`, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new `QuickGroup`
       */
      mSettings?: $QuickGroupSettings
    );

    /**
     * Creates a new subclass of class sap.m.table.columnmenu.QuickGroup with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.table.columnmenu.QuickActionBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, QuickGroup>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.table.columnmenu.QuickGroup.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: QuickGroupItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.table.columnmenu.QuickGroup`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.QuickGroup` itself.
     *
     * Fires the change event.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: QuickGroup$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.QuickGroup` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.table.columnmenu.QuickGroup`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.QuickGroup` itself.
     *
     * Fires the change event.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: QuickGroup$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.QuickGroup` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:change change} event of this `sap.m.table.columnmenu.QuickGroup`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: QuickGroup$ChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:change change} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: QuickGroup$ChangeEventParameters
    ): this;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * The groupable properties and the initial state.
     */
    getItems(): QuickGroupItem[];
    /**
     * Checks for the provided `sap.m.table.columnmenu.QuickGroupItem` in the aggregation {@link #getItems items}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: QuickGroupItem
    ): int;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: QuickGroupItem,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): QuickGroupItem[];
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | QuickGroupItem
    ): QuickGroupItem | null;
  }
  /**
   * Describes the settings that can be provided to the QuickGroup constructor.
   */
  export interface $QuickGroupSettings extends $QuickActionBaseSettings {
    /**
     * The groupable properties and the initial state.
     */
    items?:
      | QuickGroupItem[]
      | QuickGroupItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Fires the change event.
     */
    change?: (oEvent: QuickGroup$ChangeEvent) => void;
  }

  /**
   * Parameters of the QuickGroup#change event.
   */
  export interface QuickGroup$ChangeEventParameters {
    /**
     * The key of the property to be grouped.
     */
    key?: string;

    /**
     * The new grouped state.
     */
    grouped?: boolean;
  }

  /**
   * Event object of the QuickGroup#change event.
   */
  export type QuickGroup$ChangeEvent = Event<
    QuickGroup$ChangeEventParameters,
    QuickGroup
  >;
}

declare module "sap/m/table/columnmenu/QuickGroupItem" {
  import {
    default as QuickActionItem,
    $QuickActionItemSettings,
  } from "sap/m/table/columnmenu/QuickActionItem";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The `QuickGroupItem` class is used for items for the `sap.m.table.columnmenu.QuickGroup`. It can be used
   * to specify control- and application-specific items for grouping.
   *
   * @since 1.110
   */
  export default class QuickGroupItem extends QuickActionItem {
    /**
     * Constructor for a new `QuickGroupItem`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new `QuickGroupItem`
       */
      mSettings?: $QuickGroupItemSettings
    );
    /**
     * Constructor for a new `QuickGroupItem`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new `QuickGroupItem`, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new `QuickGroupItem`
       */
      mSettings?: $QuickGroupItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.table.columnmenu.QuickGroupItem with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.table.columnmenu.QuickActionItem.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, QuickGroupItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.table.columnmenu.QuickGroupItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getGrouped grouped}.
     *
     * Specifies whether the respective column is grouped.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `grouped`
     */
    getGrouped(): boolean;
    /**
     * Sets a new value for property {@link #getGrouped grouped}.
     *
     * Specifies whether the respective column is grouped.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGrouped(
      /**
       * New value for property `grouped`
       */
      bGrouped?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the QuickGroupItem constructor.
   */
  export interface $QuickGroupItemSettings extends $QuickActionItemSettings {
    /**
     * Specifies whether the respective column is grouped.
     */
    grouped?: boolean | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/table/columnmenu/QuickSort" {
  import {
    default as QuickActionBase,
    $QuickActionBaseSettings,
  } from "sap/m/table/columnmenu/QuickActionBase";

  import QuickSortItem from "sap/m/table/columnmenu/QuickSortItem";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { AggregationBindingInfo } from "sap/ui/base/ManagedObject";

  import { SortOrder } from "sap/ui/core/library";

  import Event from "sap/ui/base/Event";

  /**
   * The `QuickSort` class is used for quick sorting for the `sap.m.table.columnmenu.Menu`. It can be used
   * to specify control- and application-specific quick actions for sorting.
   *
   * @since 1.110
   */
  export default class QuickSort extends QuickActionBase {
    /**
     * Constructor for a new `QuickSort`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new `QuickSort`
       */
      mSettings?: $QuickSortSettings
    );
    /**
     * Constructor for a new `QuickSort`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new `QuickSort`, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new `QuickSort`
       */
      mSettings?: $QuickSortSettings
    );

    /**
     * Creates a new subclass of class sap.m.table.columnmenu.QuickSort with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.table.columnmenu.QuickActionBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, QuickSort>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.table.columnmenu.QuickSort.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: QuickSortItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.table.columnmenu.QuickSort`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.QuickSort` itself.
     *
     * Fires the change event.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: QuickSort$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.QuickSort` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.table.columnmenu.QuickSort`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.QuickSort` itself.
     *
     * Fires the change event.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: QuickSort$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.QuickSort` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:change change} event of this `sap.m.table.columnmenu.QuickSort`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: QuickSort$ChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:change change} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: QuickSort$ChangeEventParameters
    ): this;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * The sortable properties and the initial state.
     */
    getItems(): QuickSortItem[];
    /**
     * Checks for the provided `sap.m.table.columnmenu.QuickSortItem` in the aggregation {@link #getItems items}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: QuickSortItem
    ): int;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: QuickSortItem,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): QuickSortItem[];
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | QuickSortItem
    ): QuickSortItem | null;
  }
  /**
   * Describes the settings that can be provided to the QuickSort constructor.
   */
  export interface $QuickSortSettings extends $QuickActionBaseSettings {
    /**
     * The sortable properties and the initial state.
     */
    items?:
      | QuickSortItem[]
      | QuickSortItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Fires the change event.
     */
    change?: (oEvent: QuickSort$ChangeEvent) => void;
  }

  /**
   * Parameters of the QuickSort#change event.
   */
  export interface QuickSort$ChangeEventParameters {
    /**
     * The key of the property that is sorted.
     */
    key?: string;

    /**
     * The new sort order.
     */
    sortOrder?: SortOrder | keyof typeof SortOrder;
  }

  /**
   * Event object of the QuickSort#change event.
   */
  export type QuickSort$ChangeEvent = Event<
    QuickSort$ChangeEventParameters,
    QuickSort
  >;
}

declare module "sap/m/table/columnmenu/QuickSortItem" {
  import {
    default as QuickActionItem,
    $QuickActionItemSettings,
  } from "sap/m/table/columnmenu/QuickActionItem";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { SortOrder } from "sap/ui/core/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The `QuickSortItem` class is used for items for the `sap.m.table.columnmenu.QuickSort`. It can be used
   * to specify control- and application-specific items for sorting.
   *
   * @since 1.110
   */
  export default class QuickSortItem extends QuickActionItem {
    /**
     * Constructor for a new `QuickSortItem`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new `QuickSortItem`
       */
      mSettings?: $QuickSortItemSettings
    );
    /**
     * Constructor for a new `QuickSortItem`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new `QuickSortItem`, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new `QuickSortItem`
       */
      mSettings?: $QuickSortItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.table.columnmenu.QuickSortItem with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.table.columnmenu.QuickActionItem.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, QuickSortItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.table.columnmenu.QuickSortItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getSortOrder sortOrder}.
     *
     * Specifies the sort order that is applied for the respective column.
     *
     * Default value is `None`.
     *
     *
     * @returns Value of property `sortOrder`
     */
    getSortOrder(): SortOrder;
    /**
     * Sets a new value for property {@link #getSortOrder sortOrder}.
     *
     * Specifies the sort order that is applied for the respective column.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSortOrder(
      /**
       * New value for property `sortOrder`
       */
      sSortOrder?: SortOrder | keyof typeof SortOrder
    ): this;
  }
  /**
   * Describes the settings that can be provided to the QuickSortItem constructor.
   */
  export interface $QuickSortItemSettings extends $QuickActionItemSettings {
    /**
     * Specifies the sort order that is applied for the respective column.
     */
    sortOrder?:
      | (SortOrder | keyof typeof SortOrder)
      | PropertyBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/table/columnmenu/QuickTotal" {
  import {
    default as QuickActionBase,
    $QuickActionBaseSettings,
  } from "sap/m/table/columnmenu/QuickActionBase";

  import QuickTotalItem from "sap/m/table/columnmenu/QuickTotalItem";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { AggregationBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * The `QuickTotal` class is used for quick totaling for the `sap.m.table.columnmenu.Menu`. It can be used
   * to specify control- and application-specific quick actions for totaling.
   *
   * @since 1.110
   */
  export default class QuickTotal extends QuickActionBase {
    /**
     * Constructor for a new `QuickTotal`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new `QuickTotal`
       */
      mSettings?: $QuickTotalSettings
    );
    /**
     * Constructor for a new `QuickTotal`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new `QuickTotal`, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new `QuickTotal`
       */
      mSettings?: $QuickTotalSettings
    );

    /**
     * Creates a new subclass of class sap.m.table.columnmenu.QuickTotal with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.table.columnmenu.QuickActionBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, QuickTotal>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.table.columnmenu.QuickTotal.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: QuickTotalItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.table.columnmenu.QuickTotal`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.QuickTotal` itself.
     *
     * Fires the change event.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: QuickTotal$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.QuickTotal` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.table.columnmenu.QuickTotal`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.table.columnmenu.QuickTotal` itself.
     *
     * Fires the change event.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: QuickTotal$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.table.columnmenu.QuickTotal` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:change change} event of this `sap.m.table.columnmenu.QuickTotal`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: QuickTotal$ChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:change change} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: QuickTotal$ChangeEventParameters
    ): this;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * Defines the totalable properties and the initial state.
     */
    getItems(): QuickTotalItem[];
    /**
     * Checks for the provided `sap.m.table.columnmenu.QuickTotalItem` in the aggregation {@link #getItems items}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: QuickTotalItem
    ): int;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: QuickTotalItem,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): QuickTotalItem[];
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | QuickTotalItem
    ): QuickTotalItem | null;
  }
  /**
   * Describes the settings that can be provided to the QuickTotal constructor.
   */
  export interface $QuickTotalSettings extends $QuickActionBaseSettings {
    /**
     * Defines the totalable properties and the initial state.
     */
    items?:
      | QuickTotalItem[]
      | QuickTotalItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Fires the change event.
     */
    change?: (oEvent: QuickTotal$ChangeEvent) => void;
  }

  /**
   * Parameters of the QuickTotal#change event.
   */
  export interface QuickTotal$ChangeEventParameters {
    /**
     * The key of the property.
     */
    key?: string;

    /**
     * The new value.
     */
    totaled?: boolean;
  }

  /**
   * Event object of the QuickTotal#change event.
   */
  export type QuickTotal$ChangeEvent = Event<
    QuickTotal$ChangeEventParameters,
    QuickTotal
  >;
}

declare module "sap/m/table/columnmenu/QuickTotalItem" {
  import {
    default as QuickActionItem,
    $QuickActionItemSettings,
  } from "sap/m/table/columnmenu/QuickActionItem";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The `QuickTotalItem` class is used for items for the `sap.m.table.columnmenu.QuickTotal`. It can be used
   * to specify control- and application-specific items for totaling.
   *
   * @since 1.110
   */
  export default class QuickTotalItem extends QuickActionItem {
    /**
     * Constructor for a new `QuickTotalItem`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new `QuickTotalItem`
       */
      mSettings?: $QuickTotalItemSettings
    );
    /**
     * Constructor for a new `QuickTotalItem`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new `QuickTotalItem`, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new `QuickTotalItem`
       */
      mSettings?: $QuickTotalItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.table.columnmenu.QuickTotalItem with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.table.columnmenu.QuickActionItem.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, QuickTotalItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.table.columnmenu.QuickTotalItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getTotaled totaled}.
     *
     * Specifies whether a total for the respective column is shown.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `totaled`
     */
    getTotaled(): boolean;
    /**
     * Sets a new value for property {@link #getTotaled totaled}.
     *
     * Specifies whether a total for the respective column is shown.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTotaled(
      /**
       * New value for property `totaled`
       */
      bTotaled?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the QuickTotalItem constructor.
   */
  export interface $QuickTotalItemSettings extends $QuickActionItemSettings {
    /**
     * Specifies whether a total for the respective column is shown.
     */
    totaled?: boolean | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/table/ColumnWidthController" {
  import SelectionController from "sap/m/p13n/SelectionController";

  import Control from "sap/ui/core/Control";

  import Metadata from "sap/ui/base/Metadata";

  /**
   * The `ColumnWidthController` entity serves to create table-specific column width personalization changes.
   */
  export default class ColumnWidthController extends SelectionController {
    /**
     * Constructor for a new `ColumnWidthController`. This controller can be registered using the `sap.m.p13n.Engine`
     * to persist table column width changes and can be used in combination with `sap.m.Table` and `sap.ui.table.Table`
     * controls.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings: {
        /**
         * The table instance that is personalized by this controller
         */
        control: Control;
      }
    );

    /**
     * Creates a new subclass of class sap.m.table.ColumnWidthController with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.p13n.SelectionController.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ColumnWidthController>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.table.ColumnWidthController.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): Metadata;
  }
}

declare module "sap/m/TablePersoController" {
  import {
    default as ManagedObject,
    $ManagedObjectSettings,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import { ID, CSSSize } from "sap/ui/core/library";

  import Table from "sap/m/Table";

  import Event from "sap/ui/base/Event";

  import ManagedObjectMetadata from "sap/ui/base/ManagedObjectMetadata";

  import { ResetAllMode } from "sap/m/library";

  import TablePersoDialog from "sap/m/TablePersoDialog";

  /**
   * Table Personalization Controller
   *
   * @deprecated As of version 1.115. Please use the {@link sap.m.p13n.Engine Engine} for personalization
   * instead.
   */
  export default class TablePersoController extends ManagedObject {
    /**
     * The TablePersoController can be used to connect a table that you want to provide a personalization dialog
     * for, with a persistence service such as one provided by the unified shell.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * optional map/JSON-object with initial settings for the new component instance
       */
      mSettings?: $TablePersoControllerSettings
    );
    /**
     * The TablePersoController can be used to connect a table that you want to provide a personalization dialog
     * for, with a persistence service such as one provided by the unified shell.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * optional id for the new control; generated automatically if no non-empty id is given Note: this can be
       * omitted, no matter whether `mSettings` will be given or not!
       */
      sId?: string,
      /**
       * optional map/JSON-object with initial settings for the new component instance
       */
      mSettings?: $TablePersoControllerSettings
    );

    /**
     * Creates a new subclass of class sap.m.TablePersoController with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.base.ManagedObject.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, TablePersoController>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.TablePersoController.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ManagedObjectMetadata;
    /**
     * Activates the controller, i.e. tries to retrieve existing persisted personalizations, creates a TablePersoDialog
     * for the associated table and attaches a close handler to apply the personalizations to the table and
     * persist them.
     *
     * This method should be called when the table to be personalized knows its columns. Usually, this is when
     * that table's view has set its model, which is typically done in the corresponding controller's init method.
     * For example
     * ```javascript
     *
     *  onInit: function () {
     *
     * 		// set explored app's demo model on this sample
     * 		var oModel = new JSONModel(sap.ui.require.toUrl("sap/ui/demo/mock/products.json"));
     * 		var oGroupingModel = new JSONModel({ hasGrouping: false});
     * 		this.getView().setModel(oModel);
     * 		this.getView().setModel(oGroupingModel, 'Grouping');
     *
     * 		// init and activate controller
     * 		this._oTPC = new TablePersoController({
     * 			table: this.getView().byId("productsTable"),
     * 			//specify the first part of persistence ids e.g. 'demoApp-productsTable-dimensionsCol'
     * 			componentName: "demoApp",
     * 			persoService: DemoPersoService,
     * 		}).activate();
     * 	}
     * ```
     *
     *
     *
     * @returns the TablePersoController instance.
     */
    activate(): this;
    /**
     * Adds some table into the association {@link #getTables tables}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addTable(
      /**
       * The tables to add; if empty, nothing is inserted
       */
      vTable: ID | Table
    ): this;
    /**
     * Applies the personalizations by getting the existing personalizations and adjusting to the table.
     */
    applyPersonalizations(
      /**
       * the table to be personalized.
       */
      oTable: Table
    ): void;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:personalizationsDone personalizationsDone} event
     * of this `sap.m.TablePersoController`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TablePersoController` itself.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPersonalizationsDone(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TablePersoController` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:personalizationsDone personalizationsDone} event
     * of this `sap.m.TablePersoController`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TablePersoController` itself.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPersonalizationsDone(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TablePersoController` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys the persoService in the aggregation {@link #getPersoService persoService}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyPersoService(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:personalizationsDone personalizationsDone }
     * event of this `sap.m.TablePersoController`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPersonalizationsDone(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Do some clean up: remove event delegates, etc
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    exit(): void;
    /**
     * Fires event {@link #event:personalizationsDone personalizationsDone} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePersonalizationsDone(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getComponentName componentName}.
     *
     * Available options for the text direction are LTR and RTL. By default the control inherits the text direction
     * from its parent control.
     *
     *
     * @returns Value of property `componentName`
     */
    getComponentName(): string;
    /**
     * Gets current value of property {@link #getContentHeight contentHeight}.
     *
     *
     * @returns Value of property `contentHeight`
     */
    getContentHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getContentWidth contentWidth}.
     *
     *
     * @returns Value of property `contentWidth`
     */
    getContentWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getHasGrouping hasGrouping}.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `hasGrouping`
     */
    getHasGrouping(): boolean;
    /**
     * Gets content of aggregation {@link #getPersoService persoService}.
     */
    getPersoService(): Object;
    /**
     * Gets current value of property {@link #getResetAllMode resetAllMode}.
     *
     * Controls the behavior of the Reset button of the `TablePersoDialog`.
     *  The value must be specified in the constructor and cannot be set or modified later.
     *  If set to `Default`, the Reset button sets the table back to the initial state of the attached table
     * when the controller is activated.
     *  If set to `ServiceDefault`, the Reset button goes back to the initial settings of `persoService`.
     *  If set to `ServiceReset`, the Reset button calls the `getResetPersData` of the attached `persoService`
     * and uses it to reset the table.
     *
     *
     * Default value is `Default`.
     *
     *
     * @returns Value of property `resetAllMode`
     */
    getResetAllMode(): ResetAllMode;
    /**
     * Gets current value of property {@link #getShowResetAll showResetAll}.
     *
     * Controls the visibility of the Reset button of the `TablePersoDialog`.
     *
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showResetAll`
     */
    getShowResetAll(): boolean;
    /**
     * Gets current value of property {@link #getShowSelectAll showSelectAll}.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showSelectAll`
     */
    getShowSelectAll(): boolean;
    /**
     * ID of the element which is the current target of the association {@link #getTable table}, or `null`.
     */
    getTable(): ID | null;
    /**
     * Returns a _tablePersoDialog instance if available. It can be NULL if the controller has not been activated
     * yet.
     *
     * This function makes a private aggregate publicly accessable. This is necessary for downward compatibility
     * reasons: in the first versions of the tablePersoProvider developers still worked with the TablePersoDialog
     * directly, which is now not necessary any longer.
     *
     *
     * @returns the TablePersoDialog instance.
     */
    getTablePersoDialog(): TablePersoDialog;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getTables tables}.
     */
    getTables(): ID[];
    /**
     * Initializes the TablePersoController instance after creation.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    init(): void;
    /**
     * Opens the TablePersoDialog, stores the personalized settings on close, modifies the table columns, and
     * sends them to the persistence service
     */
    openDialog(): void;
    /**
     * Refresh the personalizations: reloads the personalization information from the table perso provider,
     * applies it to the controller's table and updates the controller's table perso dialog.
     *
     * Use case for a 'refresh' call would be that the table which is personalized changed its columns during
     * runtime, after personalization has been activated.
     */
    refresh(): void;
    /**
     * Removes all the controls in the association named {@link #getTables tables}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllTables(): ID[];
    /**
     * Removes an table from the association named {@link #getTables tables}.
     *
     *
     * @returns The removed table or `null`
     */
    removeTable(
      /**
       * The table to be removed or its index or ID
       */
      vTable: int | ID | Table
    ): ID | null;
    /**
     * Persist the personalizations
     */
    savePersonalizations(): void;
    /**
     * Using this method, the first part of tablePerso persistence ids can be provided, in case the table's
     * app does not provide that part itself.
     *
     * If a component name is set using this method, it will be used, regardless of whether the table's app
     * has a different component name or not.
     *
     *
     * @returns the TablePersoController instance.
     */
    setComponentName(
      /**
       * the new component name.
       */
      sCompName: string
    ): this;
    /**
     * Reflector for the controller's 'contentHeight' property.
     *
     *
     * @returns the TablePersoController instance.
     */
    setContentHeight(
      /**
       * the new height of the TablePersoDialog.
       */
      sHeight: CSSSize
    ): this;
    /**
     * Reflector for the controller's 'contentWidth' property.
     *
     *
     * @returns the TablePersoController instance.
     */
    setContentWidth(
      /**
       * the new width of the tablePersoDialog
       */
      sWidth: CSSSize
    ): this;
    /**
     * Reflector for the controller's 'hasGrouping' property.
     *
     *
     * @returns the TablePersoController instance.
     */
    setHasGrouping(
      /**
       * is the tablePersoDialog displayed in grouping mode or not.
       */
      bHasGrouping: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getPersoService persoService}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPersoService(
      /**
       * The persoService to set
       */
      oPersoService: Object
    ): this;
    /**
     * Sets a new value for property {@link #getResetAllMode resetAllMode}.
     *
     * Controls the behavior of the Reset button of the `TablePersoDialog`.
     *  The value must be specified in the constructor and cannot be set or modified later.
     *  If set to `Default`, the Reset button sets the table back to the initial state of the attached table
     * when the controller is activated.
     *  If set to `ServiceDefault`, the Reset button goes back to the initial settings of `persoService`.
     *  If set to `ServiceReset`, the Reset button calls the `getResetPersData` of the attached `persoService`
     * and uses it to reset the table.
     *
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Default`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setResetAllMode(
      /**
       * New value for property `resetAllMode`
       */
      sResetAllMode?: ResetAllMode | keyof typeof ResetAllMode
    ): this;
    /**
     * Reflector for the controller's 'showResetAll' property.
     *
     *
     * @returns the TablePersoController instance.
     */
    setShowResetAll(
      /**
       * is the tablePersoDialog's 'UndoPersonalization' button displayed or not.
       */
      bShowResetAll: boolean
    ): this;
    /**
     * Reflector for the controller's 'showSelectAll' property.
     *
     *
     * @returns the TablePersoController instance.
     */
    setShowSelectAll(
      /**
       * is the tablePersoDialog's 'Display All' checkbox displayed or not.
       */
      bShowSelectAll: boolean
    ): this;
    /**
     * Sets the associated {@link #getTable table}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTable(
      /**
       * ID of an element which becomes the new target of this table association; alternatively, an element instance
       * may be given
       */
      oTable: ID | Table
    ): this;
  }
  /**
   * Describes the settings that can be provided to the TablePersoController constructor.
   *
   * @deprecated As of version 1.115. Please use the {@link sap.m.p13n.Engine Engine} for personalization
   * instead.
   */
  export interface $TablePersoControllerSettings
    extends $ManagedObjectSettings {
    contentWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    contentHeight?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Available options for the text direction are LTR and RTL. By default the control inherits the text direction
     * from its parent control.
     */
    componentName?: string | PropertyBindingInfo;

    hasGrouping?: boolean | PropertyBindingInfo | `{${string}}`;

    showSelectAll?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Controls the visibility of the Reset button of the `TablePersoDialog`.
     */
    showResetAll?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Controls the behavior of the Reset button of the `TablePersoDialog`.
     *  The value must be specified in the constructor and cannot be set or modified later.
     *  If set to `Default`, the Reset button sets the table back to the initial state of the attached table
     * when the controller is activated.
     *  If set to `ServiceDefault`, the Reset button goes back to the initial settings of `persoService`.
     *  If set to `ServiceReset`, the Reset button calls the `getResetPersData` of the attached `persoService`
     * and uses it to reset the table.
     */
    resetAllMode?:
      | (ResetAllMode | keyof typeof ResetAllMode)
      | PropertyBindingInfo
      | `{${string}}`;

    persoService?: Object;

    table?: Table | string;

    /**
     * Also several tables may be personalized at once given they have same columns.
     */
    tables?: Array<Table | string>;

    personalizationsDone?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the TablePersoController#personalizationsDone event.
   */
  export interface TablePersoController$PersonalizationsDoneEventParameters {}

  /**
   * Event object of the TablePersoController#personalizationsDone event.
   */
  export type TablePersoController$PersonalizationsDoneEvent = Event<
    TablePersoController$PersonalizationsDoneEventParameters,
    TablePersoController
  >;
}

declare module "sap/m/TablePersoDialog" {
  import {
    default as ManagedObject,
    $ManagedObjectSettings,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  import { CSSSize, ID } from "sap/ui/core/library";

  import ManagedObjectMetadata from "sap/ui/base/ManagedObjectMetadata";

  import Table from "sap/m/Table";

  /**
   * Table Personalization Dialog
   *
   * @deprecated As of version 1.115. Please use the {@link sap.m.p13n.Popup Popup} for personalization instead.
   */
  export default class TablePersoDialog extends ManagedObject {
    /**
     * The TablePersoDialog can be used to display and allow modification of personalization settings relating
     * to a Table. It displays the columns of the table that it refers to by using
     * 	 - The result of calling sap.m.TablePersoProvider's 'getCaption' callback if it is implemented and delivers
     *     a non-null value for a column
     * 	 - the column header control's 'text' property if no caption property is available
     * 	 - the column header control's 'title' property if neither 'text' nor 'caption' property are available
     *
     * 	 - the column id is displayed as last fallback, if none of the above is at hand. In that case, a warning
     *     is logged.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * optional map/JSON-object with initial settings for the new component instance
       */
      mSettings?: $TablePersoDialogSettings
    );
    /**
     * The TablePersoDialog can be used to display and allow modification of personalization settings relating
     * to a Table. It displays the columns of the table that it refers to by using
     * 	 - The result of calling sap.m.TablePersoProvider's 'getCaption' callback if it is implemented and delivers
     *     a non-null value for a column
     * 	 - the column header control's 'text' property if no caption property is available
     * 	 - the column header control's 'title' property if neither 'text' nor 'caption' property are available
     *
     * 	 - the column id is displayed as last fallback, if none of the above is at hand. In that case, a warning
     *     is logged.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * optional id for the new control; generated automatically if no non-empty id is given Note: this can be
       * omitted, no matter whether `mSettings` will be given or not!
       */
      sId?: string,
      /**
       * optional map/JSON-object with initial settings for the new component instance
       */
      mSettings?: $TablePersoDialogSettings
    );

    /**
     * Creates a new subclass of class sap.m.TablePersoDialog with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.base.ManagedObject.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, TablePersoDialog>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.TablePersoDialog.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ManagedObjectMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cancel cancel} event of this `sap.m.TablePersoDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TablePersoDialog` itself.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCancel(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TablePersoDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cancel cancel} event of this `sap.m.TablePersoDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TablePersoDialog` itself.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCancel(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TablePersoDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:confirm confirm} event of this `sap.m.TablePersoDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TablePersoDialog` itself.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachConfirm(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TablePersoDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:confirm confirm} event of this `sap.m.TablePersoDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TablePersoDialog` itself.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachConfirm(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TablePersoDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys the persoService in the aggregation {@link #getPersoService persoService}.
     *
     * @deprecated As of version 1.30.1. This aggregate is no longer used. It collided with the TablePersoController's
     * persoService reference
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyPersoService(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:cancel cancel} event of this `sap.m.TablePersoDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachCancel(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:confirm confirm} event of this `sap.m.TablePersoDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachConfirm(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:cancel cancel} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireCancel(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:confirm confirm} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireConfirm(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getColumnInfoCallback columnInfoCallback}.
     *
     *
     * @returns Value of property `columnInfoCallback`
     */
    getColumnInfoCallback(): object;
    /**
     * Gets current value of property {@link #getContentHeight contentHeight}.
     *
     *
     * @returns Value of property `contentHeight`
     */
    getContentHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getContentWidth contentWidth}.
     *
     *
     * @returns Value of property `contentWidth`
     */
    getContentWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getHasGrouping hasGrouping}.
     *
     *
     * @returns Value of property `hasGrouping`
     */
    getHasGrouping(): boolean;
    /**
     * Gets current value of property {@link #getInitialColumnState initialColumnState}.
     *
     *
     * @returns Value of property `initialColumnState`
     */
    getInitialColumnState(): object;
    /**
     * ID of the element which is the current target of the association {@link #getPersoDialogFor persoDialogFor},
     * or `null`.
     */
    getPersoDialogFor(): ID | null;
    /**
     * Gets current value of property {@link #getPersoMap persoMap}.
     *
     *
     * @returns Value of property `persoMap`
     */
    getPersoMap(): object;
    /**
     * Gets content of aggregation {@link #getPersoService persoService}.
     *
     * Refers to the service for reading and writing the personalization.
     *
     * @deprecated As of version 1.30.1. This aggregate is no longer used. It collided with the TablePersoController's
     * persoService reference
     */
    getPersoService(): Object;
    /**
     * Gets current value of property {@link #getShowResetAll showResetAll}.
     *
     *
     * @returns Value of property `showResetAll`
     */
    getShowResetAll(): boolean;
    /**
     * Gets current value of property {@link #getShowSelectAll showSelectAll}.
     *
     *
     * @returns Value of property `showSelectAll`
     */
    getShowSelectAll(): boolean;
    /**
     * Initializes the TablePersoDialog instance after creation.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    init(): void;
    /**
     * Sets the content of the dialog, being list items representing the associated table's column settings,
     * and opens the dialog
     */
    open(): void;
    /**
     * Returns the personalizations made. Currently supports a 'columns' property which holds an array of settings,
     * one element per column in the associated table. The element contains column-specific information as follows:
     * id: column id; order: new order; text: the column's header text that was displayed in the dialog; visible:
     * visibility (true or false).
     *
     *
     * @returns the personalization data
     */
    retrievePersonalizations(): object;
    /**
     * Sets a new value for property {@link #getColumnInfoCallback columnInfoCallback}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setColumnInfoCallback(
      /**
       * New value for property `columnInfoCallback`
       */
      oColumnInfoCallback: object
    ): this;
    /**
     * Sets a new value for property {@link #getContentHeight contentHeight}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContentHeight(
      /**
       * New value for property `contentHeight`
       */
      sContentHeight: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getContentWidth contentWidth}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContentWidth(
      /**
       * New value for property `contentWidth`
       */
      sContentWidth: CSSSize
    ): this;
    /**
     * Setter to turn on/ switch off TablePersoDialog's grouping mode.
     *
     *
     * @returns the TablePersoDialog instance.
     */
    setHasGrouping(
      /**
       * groping mode on or off.
       */
      bHasGrouping: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getInitialColumnState initialColumnState}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInitialColumnState(
      /**
       * New value for property `initialColumnState`
       */
      oInitialColumnState: object
    ): this;
    /**
     * Sets the associated {@link #getPersoDialogFor persoDialogFor}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPersoDialogFor(
      /**
       * ID of an element which becomes the new target of this persoDialogFor association; alternatively, an element
       * instance may be given
       */
      oPersoDialogFor: ID | Table
    ): this;
    /**
     * Sets a new value for property {@link #getPersoMap persoMap}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPersoMap(
      /**
       * New value for property `persoMap`
       */
      oPersoMap: object
    ): this;
    /**
     * Sets the aggregated {@link #getPersoService persoService}.
     *
     * @deprecated As of version 1.30.1. This aggregate is no longer used. It collided with the TablePersoController's
     * persoService reference
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPersoService(
      /**
       * The persoService to set
       */
      oPersoService: Object
    ): this;
    /**
     * Setter to show/hide TablePersoDialog's 'Undo Personalization' button.
     *
     *
     * @returns the TablePersoDialog instance.
     */
    setShowResetAll(
      /**
       * 'undo Personalization' button visible or not.
       */
      bShowResetAll: boolean
    ): this;
    /**
     * Setter to show/hide TablePersoDialog's 'selectAll' checkbox.
     *
     *
     * @returns the TablePersoDialog instance.
     */
    setShowSelectAll(
      /**
       * selectAll checkbox visible or not.
       */
      bShowSelectAll: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the TablePersoDialog constructor.
   *
   * @deprecated As of version 1.115. Please use the {@link sap.m.p13n.Popup Popup} for personalization instead.
   */
  export interface $TablePersoDialogSettings extends $ManagedObjectSettings {
    contentWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    contentHeight?: CSSSize | PropertyBindingInfo | `{${string}}`;

    persoMap?: object | PropertyBindingInfo | `{${string}}`;

    columnInfoCallback?: object | PropertyBindingInfo | `{${string}}`;

    initialColumnState?: object | PropertyBindingInfo | `{${string}}`;

    hasGrouping?: boolean | PropertyBindingInfo | `{${string}}`;

    showSelectAll?: boolean | PropertyBindingInfo | `{${string}}`;

    showResetAll?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Refers to the service for reading and writing the personalization.
     *
     * @deprecated As of version 1.30.1. This aggregate is no longer used. It collided with the TablePersoController's
     * persoService reference
     */
    persoService?: Object;

    /**
     * The table which shall be personalized.
     */
    persoDialogFor?: Table | string;

    confirm?: (oEvent: Event) => void;

    cancel?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the TablePersoDialog#cancel event.
   */
  export interface TablePersoDialog$CancelEventParameters {}

  /**
   * Event object of the TablePersoDialog#cancel event.
   */
  export type TablePersoDialog$CancelEvent = Event<
    TablePersoDialog$CancelEventParameters,
    TablePersoDialog
  >;

  /**
   * Parameters of the TablePersoDialog#confirm event.
   */
  export interface TablePersoDialog$ConfirmEventParameters {}

  /**
   * Event object of the TablePersoDialog#confirm event.
   */
  export type TablePersoDialog$ConfirmEvent = Event<
    TablePersoDialog$ConfirmEventParameters,
    TablePersoDialog
  >;
}

declare module "sap/m/TablePersoProvider" {
  import {
    default as ManagedObject,
    $ManagedObjectSettings,
  } from "sap/ui/base/ManagedObject";

  import Column from "sap/m/Column";

  import ManagedObjectMetadata from "sap/ui/base/ManagedObjectMetadata";

  /**
   * Table Personalization Provider
   *
   * @deprecated As of version 1.115. replaced by {@link sap.m.p13n.Engine}
   */
  export default abstract class TablePersoProvider extends ManagedObject {
    /**
     * This is an abstract TablePersoProvider, describing the interface for a real TablePersoProvider.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.ui.base.ManagedObject#constructor sap.ui.base.ManagedObject }
     * can be used.
     */
    constructor();

    /**
     * Creates a new subclass of class sap.m.TablePersoProvider with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.base.ManagedObject.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, TablePersoProvider>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.TablePersoProvider.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ManagedObjectMetadata;
    /**
     * Removes the personalization bundle.
     *  This must return a {@link http://api.jquery.com/promise/ jQuery promise}.
     */
    delPersData(): void;
    /**
     * Callback function which can be used to determine the title of a given column within the TablePersoDialog.
     * As a default, the column header controls are asked for their 'text' or 'title' property. This works in
     * most cases, for example if the header control is an sap.m.Label (has 'text' property) or an sap.m.ObjectListItem
     * (has 'title' property).
     *
     * If the header control used in a column has neither 'text' nor 'title' property, or if you would like
     * to display a modified column name for a certain column, this callback function can be used.
     *
     * If the callback delivers null for a column (which is the default implementation), the default texts described
     * above are displayed for that column in the TablePersoDialog.
     *
     * In case neither the callback delivers null and neither 'text' nor ' title' property are at hand, the
     * TablePersoDialog will display the column id and a warning message is logged.
     */
    getCaption(
      /**
       * column whose caption shall be determined
       */
      oColumn: Column
    ): void;
    /**
     * Callback function which can be used to determine the group of a given column within the TablePersoDialog.
     * As a default, the columns are not assigned to a group.
     *
     * This information is used to group the columns within the TablePersoDialog if the TablePersoController's
     * 'group' flag is set, otherwise, the groups are ignored.
     */
    getGroup(
      /**
       * column whose group shall be determined
       */
      oColumn: Column
    ): void;
    /**
     * Retrieves the personalization bundle.
     *  This must return a {@link http://api.jquery.com/promise/ jQuery Promise}, which resolves in the desired
     * table state.
     */
    getPersData(): void;
    /**
     * Retrieves the desired reset state. This getter is used by the `TablePersoController` if the `resetAllMode`
     * is `ServiceReset`.
     *
     *
     * This must return a {@link http://api.jquery.com/promise/ jQuery promise}.
     *
     * @since 1.88
     */
    getResetPersData(): void;
    /**
     * Initializes the TablePersoProvider instance after creation.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    init(): void;
    /**
     * Resets user’s personalization for a given table so that ‘getPersData’ will deliver its initial state.
     * If no table is specified, all personalizations of the currently logged on user are reset.
     *
     *
     * This must return a {@link http://api.jquery.com/promise/ jQuery promise}.
     */
    resetPersData(): void;
    /**
     * Stores the personalization bundle, overwriting any previous bundle completely.
     *  This must return a {@link http://api.jquery.com/promise/ jQuery promise}.
     */
    setPersData(oBundle: object): void;
  }
  /**
   * Describes the settings that can be provided to the TablePersoProvider constructor.
   *
   * @deprecated As of version 1.115. replaced by {@link sap.m.p13n.Engine}
   */
  export interface $TablePersoProviderSettings extends $ManagedObjectSettings {}
}

declare module "sap/m/TableSelectDialog" {
  import {
    default as SelectDialogBase,
    $SelectDialogBaseSettings,
  } from "sap/m/SelectDialogBase";

  import Column from "sap/m/Column";

  import ColumnListItem from "sap/m/ColumnListItem";

  import Event from "sap/ui/base/Event";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import { CSSSize } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { TitleAlignment } from "sap/m/library";

  import Context from "sap/ui/model/Context";

  import SelectDialog from "sap/m/SelectDialog";

  import Model from "sap/ui/model/Model";

  import StandardListItem from "sap/m/StandardListItem";

  /**
   * A dialog to select items in a table containing multiple values and attributes. Overview: The table select
   * dialog helps users select items in a table-like structure with several attributes and values per item.
   * A search fields helps narrow down the results. Structure: The table select dialog consists of the following
   * elements:
   * 	 -  Search field - used to search enter search terms for a specific item.
   * 	 -  Info toolbar (only in multi-select mode) - displays the number of currently selected items.
   * 	 -  Content - the table with the items.
   * 	 -  Footer (optional) - a toolbar for actions.  Table Select Dialog supports multi-selection when
   *     the `multiSelect` property is set to `true`.
   *
   * The selected items can be stored for later editing when the `rememberSelections` property is set. **Note:**
   * This property has to be set before the dialog is opened. Usage: When to use::
   * 	 - You need to select one or more items from a comprehensive list that contains multiple attributes
   *     or values.  When not to use::
   * 	 - You need to select only one item from a predefined list of single-value options. Use the {@link sap.m.Select Select }
   *     control instead.
   * 	 - You need to display complex content without having the user navigate away from the current page or
   *     you want to prompt the user for an action. Use the {@link sap.m.Dialog Dialog} control instead.
   * 	 - You need to select items within a query-based range. Use the {@link https://experience.sap.com/fiori-design-web/value-help-dialog/ Value Help Dialog }
   *     control instead.
   * 	 - You need to filter a set of items without any selection. Use the {@link https://experience.sap.com/fiori-design-web/filter-bar/ Filter Bar }
   *     control instead.  Notes::
   * 	 - The property `growing` must not be used together with two-way binding. When the property `growing`
   *     is set to `true` (default value), selected count (if present) and search, will work for currently loaded
   *     items only. To make sure that all items in the table are loaded at once and the above features work properly,
   *     set the property to `false`. **Note: **The default size limit for entries used for table bindings is
   *     set to 100. To change this behavior, you can adjust the size limit by using `sap.ui.model.Model.prototype.setSizeLimit`;
   *     see {@link sap.ui.model.Model#setSizeLimit}. Since version 1.58, the columns headers and the info
   *     toolbar are sticky (remain fixed on top when scrolling). This feature is not supported in all browsers.
   *     The TableSelectDialog is usually displayed at the center of the screen. Its size and position can
   *     be changed by the user. To enable this you need to set the `resizable` and `draggable` properties. Both
   *     properties are available only in desktop mode. For more information on current restrictions, you can
   *     refer to the {@link sap.m.ListBase sap.m.ListBase} `sticky` property.  Responsive Behavior:
   *
   * 	 - On smaller screens, the columns of the table wrap and build a list that shows all the information.
   *      When using the `sap.m.TableSelectDialog` in SAP Quartz and Horizon themes, the breakpoints and
   *     layout paddings could be determined by the dialog's width. To enable this concept and add responsive
   *     paddings to an element of the control, you have to add the following classes depending on your use case:
   *     `sapUiResponsivePadding--header`, `sapUiResponsivePadding--subHeader`, `sapUiResponsivePadding--content`,
   *     `sapUiResponsivePadding--footer`.
   *
   * @since 1.16
   */
  export default class TableSelectDialog extends SelectDialogBase {
    /**
     * Constructor for a new TableSelectDialog.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/table-select-dialog/ Table Select Dialog}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $TableSelectDialogSettings
    );
    /**
     * Constructor for a new TableSelectDialog.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/table-select-dialog/ Table Select Dialog}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $TableSelectDialogSettings
    );

    /**
     * Creates a new subclass of class sap.m.TableSelectDialog with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.SelectDialogBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, TableSelectDialog>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.TableSelectDialog.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some column to the aggregation {@link #getColumns columns}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addColumn(
      /**
       * The column to add; if empty, nothing is inserted
       */
      oColumn: Column
    ): this;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: ColumnListItem
    ): this;
    /**
     * Transfers method to the inner dialog: addStyleClass
     *
     *
     * @returns this pointer for chaining
     */
    addStyleClass(
      /**
       * CSS class name to add
       */
      sStyleClass: string
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cancel cancel} event of this `sap.m.TableSelectDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TableSelectDialog` itself.
     *
     * Fires when the Cancel button is clicked.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCancel(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TableSelectDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cancel cancel} event of this `sap.m.TableSelectDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TableSelectDialog` itself.
     *
     * Fires when the Cancel button is clicked.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCancel(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TableSelectDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:confirm confirm} event of this `sap.m.TableSelectDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TableSelectDialog` itself.
     *
     * Fires when the dialog is confirmed by selecting an item in single-selection mode or by pressing the confirmation
     * button in multi-selection mode. The items being selected are returned as event parameters.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachConfirm(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TableSelectDialog$ConfirmEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TableSelectDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:confirm confirm} event of this `sap.m.TableSelectDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TableSelectDialog` itself.
     *
     * Fires when the dialog is confirmed by selecting an item in single-selection mode or by pressing the confirmation
     * button in multi-selection mode. The items being selected are returned as event parameters.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachConfirm(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TableSelectDialog$ConfirmEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TableSelectDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.TableSelectDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TableSelectDialog` itself.
     *
     * Fires when the value of the search field is changed by a user (for example at each key press).
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TableSelectDialog$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TableSelectDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.TableSelectDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TableSelectDialog` itself.
     *
     * Fires when the value of the search field is changed by a user (for example at each key press).
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TableSelectDialog$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TableSelectDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:search search} event of this `sap.m.TableSelectDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TableSelectDialog` itself.
     *
     * Fires when the search button has been clicked on dialog.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSearch(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TableSelectDialog$SearchEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TableSelectDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:search search} event of this `sap.m.TableSelectDialog`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TableSelectDialog` itself.
     *
     * Fires when the search button has been clicked on dialog.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSearch(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TableSelectDialog$SearchEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TableSelectDialog` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getColumns columns} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindColumns(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Binds aggregation {@link #getItems items} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the columns in the aggregation {@link #getColumns columns}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyColumns(): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:cancel cancel} event of this `sap.m.TableSelectDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachCancel(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:confirm confirm} event of this `sap.m.TableSelectDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachConfirm(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: TableSelectDialog$ConfirmEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:liveChange liveChange} event of this `sap.m.TableSelectDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLiveChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: TableSelectDialog$LiveChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:search search} event of this `sap.m.TableSelectDialog`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSearch(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: TableSelectDialog$SearchEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:cancel cancel} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireCancel(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:confirm confirm} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireConfirm(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: TableSelectDialog$ConfirmEventParameters
    ): this;
    /**
     * Fires event {@link #event:liveChange liveChange} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLiveChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: TableSelectDialog$LiveChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:search search} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSearch(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: TableSelectDialog$SearchEventParameters
    ): this;
    /**
     * Gets current busy state.
     *
     *
     * @returns value of currtent busy state.
     */
    getBusy(): boolean;
    /**
     * Gets content of aggregation {@link #getColumns columns}.
     *
     * The columns bindings.
     */
    getColumns(): Column[];
    /**
     * Gets current value of property {@link #getConfirmButtonText confirmButtonText}.
     *
     * Overwrites the default text for the confirmation button. Note: This property applies only when the property
     * `multiSelect` is set to `true`.
     *
     * @since 1.68
     *
     * @returns Value of property `confirmButtonText`
     */
    getConfirmButtonText(): string;
    /**
     * Retrieves content height of the select dialog {@link sap.m.Dialog}
     *
     *
     * @returns sHeight the content height of the internal dialog
     */
    getContentHeight(): CSSSize;
    /**
     * Retrieves content width of the select dialog {@link sap.m.Dialog}
     *
     *
     * @returns sWidth the content width of the internal dialog
     */
    getContentWidth(): CSSSize;
    /**
     * Transfers method to the inner dialog: getDomRef
     *
     *
     * @returns The Element's DOM Element, sub DOM Element or `null`
     */
    getDomRef(): Element | null;
    /**
     * Gets current value of property {@link #getDraggable draggable}.
     *
     * When set to `true`, the TableSelectDialog is draggable by its header. The default value is `false`. **Note**:
     * The TableSelectDialog can be draggable only in desktop mode.
     *
     * Default value is `false`.
     *
     * @since 1.71
     *
     * @returns Value of property `draggable`
     */
    getDraggable(): boolean;
    /**
     * Gets current value of property {@link #getGrowing growing}.
     *
     * Determines the progressive loading. When set to `true`, enables the growing feature of the control to
     * load more items by requesting from the bound model. **Note:** This feature only works when an `items`
     * aggregation is bound. Growing must not be used together with two-way binding. **Note:** If the property
     * is set to `true`, selected count (if present) and search, will work for currently loaded items only.
     * To make sure that all items in the table are loaded at once and the above features work properly, we
     * recommend setting the `growing` property to `false`.
     *
     * Default value is `true`.
     *
     * @since 1.56
     *
     * @returns Value of property `growing`
     */
    getGrowing(): boolean;
    /**
     * Gets current value of property {@link #getGrowingThreshold growingThreshold}.
     *
     * Determines the number of items initially displayed in the table and defines the number of items to be
     * requested from the model for each grow. This property can only be used if the property `growing` is set
     * to `true`.
     *
     *
     * @returns Value of property `growingThreshold`
     */
    getGrowingThreshold(): int;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * The items of the table.
     */
    getItems(): ColumnListItem[];
    /**
     * Gets current value of property {@link #getMultiSelect multiSelect}.
     *
     * Enables the user to select several options from the table.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `multiSelect`
     */
    getMultiSelect(): boolean;
    /**
     * Retrieves the internal List's no data text property
     *
     *
     * @returns the current no data text
     */
    getNoDataText(): string;
    /**
     * Gets current value of property {@link #getRememberSelections rememberSelections}.
     *
     * Controls whether the dialog clears the selection or not. When the dialog is opened multiple times in
     * the same context to allow for corrections of previous user inputs, set this flag to `true`. When the
     * dialog should reset the selection to allow for a new selection each time set it to `false` Note: This
     * property must be set before the Dialog is opened to have an effect.
     *
     * Default value is `false`.
     *
     * @since 1.18
     *
     * @returns Value of property `rememberSelections`
     */
    getRememberSelections(): boolean;
    /**
     * Gets current value of property {@link #getResizable resizable}.
     *
     * When set to `true`, the TableSelectDialog will have a resize handler in its bottom right corner. The
     * default value is `false`. **Note**: The TableSelectDialog can be resizable only in desktop mode.
     *
     * Default value is `false`.
     *
     * @since 1.71
     *
     * @returns Value of property `resizable`
     */
    getResizable(): boolean;
    /**
     * Get the internal SearchField's placeholder property
     *
     *
     * @returns the current placeholder text
     */
    getSearchPlaceholder(): string;
    /**
     * Gets current value of property {@link #getShowClearButton showClearButton}.
     *
     * This flag controls whether the Clear button is shown. When set to `true`, it provides a way to clear
     * a selection made in Table Select Dialog.
     *
     * We recommend enabling of the Clear button in the following cases, where a mechanism to clear the value
     * is needed: In case the Table Select Dialog is in single-selection mode (default mode) and `rememberSelections`
     * is set to `true`. The Clear button needs to be enabled in order to allow users to clear the selection.
     * In case of using `sap.m.Input` with `valueHelpOnly` set to `true`, the Clear button can be used for clearing
     * the selection. In case the application stores a value and uses only Table Select Dialog to edit/maintain
     * it.
     *
     * Optional: In case `multiSelect` is set to `true`, the selection can be easily cleared with one click.
     *
     * **Note:** When used with OData, only the loaded selections will be cleared.
     *
     * Default value is `false`.
     *
     * @since 1.58
     *
     * @returns Value of property `showClearButton`
     */
    getShowClearButton(): boolean;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Specifies the title text in the dialog header.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getTitleAlignment titleAlignment}.
     *
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * Default value is `Auto`.
     *
     * @since 1.72
     *
     * @returns Value of property `titleAlignment`
     */
    getTitleAlignment(): TitleAlignment;
    /**
     * Transfers method to the inner dialog: hasStyleClass
     *
     *
     * @returns true if the class is set, false otherwise
     */
    hasStyleClass(): boolean;
    /**
     * Checks for the provided `sap.m.Column` in the aggregation {@link #getColumns columns}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfColumn(
      /**
       * The column whose index is looked for
       */
      oColumn: Column
    ): int;
    /**
     * Checks for the provided `sap.m.ColumnListItem` in the aggregation {@link #getItems items}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: ColumnListItem
    ): int;
    /**
     * Inserts a column into the aggregation {@link #getColumns columns}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertColumn(
      /**
       * The column to insert; if empty, nothing is inserted
       */
      oColumn: Column,
      /**
       * The `0`-based index the column should be inserted at; for a negative value of `iIndex`, the column is
       * inserted at position 0; for a value greater than the current size of the aggregation, the column is inserted
       * at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: ColumnListItem,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Invalidates the dialog instead of this control, as there is no renderer.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns this pointer for chaining
     */
    invalidate(): this;
    /**
     * Shows the busy state and is called after the renderer is finished.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onAfterRendering(): void;
    /**
     * Opens the internal dialog with a searchfield and a table.
     *
     *
     * @returns `this` to allow method chaining
     */
    open(
      /**
       * Value for the search. The table will be automatically trigger the search event if this parameter is set.
       */
      sSearchValue: string
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getColumns columns}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllColumns(): Column[];
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): ColumnListItem[];
    /**
     * Removes a column from the aggregation {@link #getColumns columns}.
     *
     *
     * @returns The removed column or `null`
     */
    removeColumn(
      /**
       * The column to remove or its index or id
       */
      vColumn: int | string | Column
    ): Column | null;
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | ColumnListItem
    ): ColumnListItem | null;
    /**
     * Transfers method to the inner dialog: removeStyleClass
     *
     *
     * @returns this pointer for chaining
     */
    removeStyleClass(
      /**
       * CSS class name to remove
       */
      sStyleClass: string
    ): this;
    /**
     * Set the binding context for the internal table AND the current control so that both controls can be used
     * with the context.
     *
     *
     * @returns `this` pointer for chaining
     */
    setBindingContext(
      /**
       * The new context
       */
      oContext: Context,
      /**
       * The optional model name
       */
      sModelName?: string
    ): this;
    /**
     * Enables/Disables busy state.
     *
     *
     * @returns this pointer for chaining
     */
    setBusy(
      /**
       * flag for enabling busy indicator
       */
      bBusy: boolean
    ): this;
    /**
     * Sets the busyIndicatorDelay value to the internal table
     *
     *
     * @returns this pointer for chaining
     */
    setBusyIndicatorDelay(
      /**
       * Value for the busyIndicatorDelay.
       */
      iValue: int
    ): this;
    /**
     * Sets the text of the confirmation button.
     *
     *
     * @returns `this` pointer for chaining
     */
    setConfirmButtonText(
      /**
       * The text for the confirm button
       */
      sText: string
    ): this;
    /**
     * Sets content height of the select dialog {@link sap.m.Dialog}
     *
     *
     * @returns this pointer for chaining
     */
    setContentHeight(
      /**
       * the new content height value for the dialog
       */
      sHeight: CSSSize
    ): this;
    /**
     * Sets content width of the select dialog {@link sap.m.Dialog}
     *
     *
     * @returns this pointer for chaining
     */
    setContentWidth(
      /**
       * the new content width value for the dialog
       */
      sWidth: CSSSize
    ): this;
    /**
     * Sets the draggable property.
     *
     *
     * @returns `this` pointer for chaining
     */
    setDraggable(
      /**
       * Value for the draggable property
       */
      bValue: boolean
    ): SelectDialog;
    /**
     * Sets the growing to the internal table
     *
     *
     * @returns this pointer for chaining
     */
    setGrowing(
      /**
       * Value for the table's growing.
       */
      bValue: boolean
    ): this;
    /**
     * Sets the growing threshold to the internal table
     *
     *
     * @returns this pointer for chaining
     */
    setGrowingThreshold(
      /**
       * Value for the table's growing threshold.
       */
      iValue: int
    ): this;
    /**
     * Sets the model for the internal table and the current control, so that both controls can be used with
     * data binding.
     *
     *
     * @returns This pointer for chaining
     */
    setModel(
      /**
       * The model that holds the data for the table
       */
      oModel: Model,
      /**
       * The optional model name
       */
      sModelName?: string
    ): this;
    /**
     * Enables/Disables multi selection mode.
     *
     *
     * @returns this pointer for chaining
     */
    setMultiSelect(
      /**
       * flag for multi selection mode
       */
      bMulti: boolean
    ): this;
    /**
     * Sets the no data text of the internal table
     */
    setNoDataText(
      /**
       * the no data text for the table
       */
      sNoDataText: string
    ): void;
    /**
     * Sets a new value for property {@link #getRememberSelections rememberSelections}.
     *
     * Controls whether the dialog clears the selection or not. When the dialog is opened multiple times in
     * the same context to allow for corrections of previous user inputs, set this flag to `true`. When the
     * dialog should reset the selection to allow for a new selection each time set it to `false` Note: This
     * property must be set before the Dialog is opened to have an effect.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.18
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRememberSelections(
      /**
       * New value for property `rememberSelections`
       */
      bRememberSelections?: boolean
    ): this;
    /**
     * Sets the resizable property.
     *
     *
     * @returns `this` pointer for chaining
     */
    setResizable(
      /**
       * Value for the resizable property
       */
      bValue: boolean
    ): SelectDialog;
    /**
     * Set the internal SearchField's placeholder property
     *
     *
     * @returns `this` pointer for chaining
     */
    setSearchPlaceholder(
      /**
       * The placeholder text
       */
      sSearchPlaceholder: string
    ): this;
    /**
     * Sets the Clear button visible state
     *
     *
     * @returns this pointer for chaining
     */
    setShowClearButton(
      /**
       * Value for the Clear button visible state.
       */
      bVisible: boolean
    ): this;
    /**
     * Sets the title of the internal dialog
     *
     *
     * @returns this pointer for chaining
     */
    setTitle(
      /**
       * the title text for the dialog
       */
      sTitle: string
    ): this;
    /**
     * Sets a new value for property {@link #getTitleAlignment titleAlignment}.
     *
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     * @since 1.72
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleAlignment(
      /**
       * New value for property `titleAlignment`
       */
      sTitleAlignment?: TitleAlignment | keyof typeof TitleAlignment
    ): this;
    /**
     * Transfers method to the inner dialog: toggleStyleClass
     *
     *
     * @returns this pointer for chaining
     */
    toggleStyleClass(
      /**
       * CSS class name to add or remove
       */
      sStyleClass: string,
      /**
       * Whether style class should be added (or removed); when this parameter is not given, the given style class
       * will be toggled (removed, if present, and added if not present)
       */
      bAdd?: boolean
    ): this;
    /**
     * Unbinds aggregation {@link #getColumns columns} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindColumns(): this;
    /**
     * Unbinds aggregation {@link #getItems items} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindItems(): this;
  }
  /**
   * Describes the settings that can be provided to the TableSelectDialog constructor.
   */
  export interface $TableSelectDialogSettings
    extends $SelectDialogBaseSettings {
    /**
     * Specifies the title text in the dialog header.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Specifies the text displayed when the table has no data.
     */
    noDataText?: string | PropertyBindingInfo;

    /**
     * Enables the user to select several options from the table.
     */
    multiSelect?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the progressive loading. When set to `true`, enables the growing feature of the control to
     * load more items by requesting from the bound model. **Note:** This feature only works when an `items`
     * aggregation is bound. Growing must not be used together with two-way binding. **Note:** If the property
     * is set to `true`, selected count (if present) and search, will work for currently loaded items only.
     * To make sure that all items in the table are loaded at once and the above features work properly, we
     * recommend setting the `growing` property to `false`.
     *
     * @since 1.56
     */
    growing?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the number of items initially displayed in the table and defines the number of items to be
     * requested from the model for each grow. This property can only be used if the property `growing` is set
     * to `true`.
     */
    growingThreshold?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the content width of the inner dialog. For more information, see the Dialog documentation.
     *
     * @since 1.18
     */
    contentWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Controls whether the dialog clears the selection or not. When the dialog is opened multiple times in
     * the same context to allow for corrections of previous user inputs, set this flag to `true`. When the
     * dialog should reset the selection to allow for a new selection each time set it to `false` Note: This
     * property must be set before the Dialog is opened to have an effect.
     *
     * @since 1.18
     */
    rememberSelections?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the content height of the inner dialog. For more information, see the Dialog documentation.
     */
    contentHeight?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * This flag controls whether the Clear button is shown. When set to `true`, it provides a way to clear
     * a selection made in Table Select Dialog.
     *
     * We recommend enabling of the Clear button in the following cases, where a mechanism to clear the value
     * is needed: In case the Table Select Dialog is in single-selection mode (default mode) and `rememberSelections`
     * is set to `true`. The Clear button needs to be enabled in order to allow users to clear the selection.
     * In case of using `sap.m.Input` with `valueHelpOnly` set to `true`, the Clear button can be used for clearing
     * the selection. In case the application stores a value and uses only Table Select Dialog to edit/maintain
     * it.
     *
     * Optional: In case `multiSelect` is set to `true`, the selection can be easily cleared with one click.
     *
     * **Note:** When used with OData, only the loaded selections will be cleared.
     *
     * @since 1.58
     */
    showClearButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Overwrites the default text for the confirmation button. Note: This property applies only when the property
     * `multiSelect` is set to `true`.
     *
     * @since 1.68
     */
    confirmButtonText?: string | PropertyBindingInfo;

    /**
     * When set to `true`, the TableSelectDialog is draggable by its header. The default value is `false`. **Note**:
     * The TableSelectDialog can be draggable only in desktop mode.
     *
     * @since 1.71
     */
    draggable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * When set to `true`, the TableSelectDialog will have a resize handler in its bottom right corner. The
     * default value is `false`. **Note**: The TableSelectDialog can be resizable only in desktop mode.
     *
     * @since 1.71
     */
    resizable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the Title alignment (theme specific). If set to `TitleAlignment.Auto`, the Title will be aligned
     * as it is set in the theme (if not set, the default value is `center`); Other possible values are `TitleAlignment.Start`
     * (left or right depending on LTR/RTL), and `TitleAlignment.Center` (centered)
     *
     * @since 1.72
     */
    titleAlignment?:
      | (TitleAlignment | keyof typeof TitleAlignment)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Allows overriding the SearchField's default placeholder text. If not set, the word "Search" in the current
     * local language or English will be used as a placeholder.
     *
     * @since 1.110
     */
    searchPlaceholder?: string | PropertyBindingInfo;

    /**
     * The items of the table.
     */
    items?:
      | ColumnListItem[]
      | ColumnListItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * The columns bindings.
     */
    columns?: Column[] | Column | AggregationBindingInfo | `{${string}}`;

    /**
     * Fires when the dialog is confirmed by selecting an item in single-selection mode or by pressing the confirmation
     * button in multi-selection mode. The items being selected are returned as event parameters.
     */
    confirm?: (oEvent: TableSelectDialog$ConfirmEvent) => void;

    /**
     * Fires when the search button has been clicked on dialog.
     */
    search?: (oEvent: TableSelectDialog$SearchEvent) => void;

    /**
     * Fires when the value of the search field is changed by a user (for example at each key press).
     */
    liveChange?: (oEvent: TableSelectDialog$LiveChangeEvent) => void;

    /**
     * Fires when the Cancel button is clicked.
     */
    cancel?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the TableSelectDialog#cancel event.
   */
  export interface TableSelectDialog$CancelEventParameters {}

  /**
   * Event object of the TableSelectDialog#cancel event.
   */
  export type TableSelectDialog$CancelEvent = Event<
    TableSelectDialog$CancelEventParameters,
    TableSelectDialog
  >;

  /**
   * Parameters of the TableSelectDialog#confirm event.
   */
  export interface TableSelectDialog$ConfirmEventParameters {
    /**
     * Returns the selected list item. When no item is selected, "null" is returned. When multi-selection is
     * enabled and multiple items are selected, only the first selected item is returned.
     */
    selectedItem?: StandardListItem;

    /**
     * Returns an array containing the visible selected list items. If no items are selected, an empty array
     * is returned.
     */
    selectedItems?: StandardListItem[];

    /**
     * Returns the binding contexts of the selected items including the non-visible items, but excluding the
     * not loaded items. Note: In contrast to the parameter "selectedItems", this parameter includes the selected
     * but NOT visible items (due to list filtering). An empty array is set for this parameter if no Databinding
     * is used. NOTE: When the list binding is pre-filtered and there are items in the selection that are not
     * visible upon opening the dialog, these contexts are not loaded. Therefore, these items will not be included
     * in the selectedContexts array unless they are displayed at least once.
     */
    selectedContexts?: object[];
  }

  /**
   * Event object of the TableSelectDialog#confirm event.
   */
  export type TableSelectDialog$ConfirmEvent = Event<
    TableSelectDialog$ConfirmEventParameters,
    TableSelectDialog
  >;

  /**
   * Parameters of the TableSelectDialog#liveChange event.
   */
  export interface TableSelectDialog$LiveChangeEventParameters {
    /**
     * Specifies the value entered in the search field.
     */
    value?: string;

    /**
     * The Items binding of the Table Select Dialog. Only available if the items aggregation is bound to a model.
     */
    itemsBinding?: any;
  }

  /**
   * Event object of the TableSelectDialog#liveChange event.
   */
  export type TableSelectDialog$LiveChangeEvent = Event<
    TableSelectDialog$LiveChangeEventParameters,
    TableSelectDialog
  >;

  /**
   * Parameters of the TableSelectDialog#search event.
   */
  export interface TableSelectDialog$SearchEventParameters {
    /**
     * Specifies the value entered in the search field.
     */
    value?: string;

    /**
     * Determines the Items binding of the Table Select Dialog. Only available if the items aggregation is bound
     * to a model.
     */
    itemsBinding?: any;

    /**
     * Returns if the Clear button is pressed.
     */
    clearButtonPressed?: boolean;
  }

  /**
   * Event object of the TableSelectDialog#search event.
   */
  export type TableSelectDialog$SearchEvent = Event<
    TableSelectDialog$SearchEventParameters,
    TableSelectDialog
  >;
}

declare module "sap/m/Text" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IShrinkable,
    IFormContent,
    ISemanticFormContent,
    ILabelable,
    AccessibilityInfo,
    TextAlign,
    TextDirection,
    CSSSize,
  } from "sap/ui/core/library";

  import {
    IToolbarInteractiveControl,
    EmptyIndicatorMode,
    WrappingType,
  } from "sap/m/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * The `Text` control can be used for embedding longer text paragraphs, that need text wrapping, into your
   * app. If the configured text value contains HTML code or script tags, those will be escaped.
   *
   * As of version 1.60, you can hyphenate the text with the use of the `wrappingType` property. For more
   * information, see {@link https://ui5.sap.com/#/topic/6322164936f047de941ec522b95d7b70 Text Controls Hyphenation}.
   *
   * **Note:** Line breaks will always be visualized except when the `wrapping` property is set to `false`.
   * In addition, tabs and whitespace can be preserved by setting the `renderWhitespace` property to `true`.
   */
  export default class Text
    extends Control
    implements
      IShrinkable,
      IFormContent,
      ISemanticFormContent,
      ILabelable,
      IToolbarInteractiveControl
  {
    __implements__sap_ui_core_IShrinkable: boolean;
    __implements__sap_ui_core_IFormContent: boolean;
    __implements__sap_ui_core_ISemanticFormContent: boolean;
    __implements__sap_ui_core_ILabelable: boolean;
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new Text.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/text/ Text}
     * 	{@link https://ui5.sap.com/#/topic/f94deb45de184a3a87850b75d610d9c0 Text}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $TextSettings
    );
    /**
     * Constructor for a new Text.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/text/ Text}
     * 	{@link https://ui5.sap.com/#/topic/f94deb45de184a3a87850b75d610d9c0 Text}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $TextSettings
    );
    /**
     * Determines per instance whether line height should be cached or not.
     *
     * Default value is true.
     *
     * @since 1.22
     * @deprecated As of version 1.121. Native line clamp is now available in all supported browsers.
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    cacheLineHeight: boolean;

    /**
     * Ellipsis(...) text to indicate more text when clampText function is used.
     *
     * Can be overwritten with 3dots(...) if fonts do not support this UTF-8 character.
     *
     * @since 1.13.2
     * @deprecated As of version 1.121. Native line clamp is now available in all supported browsers.
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    ellipsis: string;

    /**
     * Defines whether browser supports native line clamp or not
     *
     * @since 1.13.2
     * @deprecated As of version 1.121. Native line clamp is now available in all supported browsers.
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    static hasNativeLineClamp: undefined;

    /**
     * Default line height value as a number when line height is normal.
     *
     * This value is required during max height calculation for the browsers that do not support line clamping.
     * It is better to define line height in CSS instead of "normal" to get consistent `maxLines` results since
     * normal line height not only varies from browser to browser but it also varies from one font face to another
     * and can also vary within a given face.
     *
     * @since 1.22
     * @deprecated As of version 1.121.
     * @ui5-protected DO NOT USE IN APPLICATIONS (only for related classes in the framework)
     */
    normalLineHeight: int;

    /**
     * Creates a new subclass of class sap.m.Text with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Text>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Text.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * To prevent from the layout thrashing of the `textContent` call, this method first tries to set the `nodeValue`
     * of the first child if it exists.
     *
     * @since 1.30.3
     * @deprecated As of version 1.121. Since native line clamp is now available in all supported browsers and
     * the renderer uses `apiVersion: 2`, this method is no longer needed.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    static setNodeValue(
      /**
       * DOM reference of the text node container.
       */
      oDomRef: HTMLElement,
      /**
       * new Node value.
       */
      sNodeValue?: string
    ): void;
    /**
     * Binds property {@link #getText text} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindProperty ManagedObject.bindProperty} for a detailed description
     * of the possible properties of `oBindingInfo`
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindText(
      /**
       * The binding information
       */
      oBindingInfo: PropertyBindingInfo
    ): this;
    /**
     * Decides whether the control can use native line clamp feature or not.
     *
     * In RTL mode native line clamp feature is not supported.
     *
     * @since 1.20
     * @deprecated As of version 1.121. Native line clamp is now available in all supported browsers.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    canUseNativeLineClamp(): boolean;
    /**
     * Sets the max height to support `maxLines` property.
     *
     * @since 1.22
     * @deprecated As of version 1.121. Native line clamp is now available in all supported browsers.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Calculated max height value.
     */
    clampHeight(
      /**
       * DOM reference of the text container.
       */
      oDomRef?: HTMLElement
    ): int;
    /**
     * Clamps the wrapping text according to max lines and returns the found ellipsis position. Parameters can
     * be used for better performance.
     *
     * @since 1.20
     * @deprecated As of version 1.121. Native line clamp is now available in all supported browsers.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Returns found ellipsis position or `undefined`.
     */
    clampText(
      /**
       * DOM reference of the text container.
       */
      oDomRef?: HTMLElement,
      /**
       * Start point of the ellipsis search.
       */
      iStartPos?: int,
      /**
       * End point of the ellipsis search.
       */
      iEndPos?: int
    ): int | undefined;
    /**
     * Gets the accessibility information for the text.
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Accessibility information for the text.
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Returns the max height according to max lines and line height calculation. This is not calculated max
     * height!
     *
     * @since 1.22
     * @deprecated As of version 1.121. Native line clamp is now available in all supported browsers.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The clamp height of the text.
     */
    getClampHeight(
      /**
       * DOM reference of the text container.
       */
      oDomRef?: HTMLElement
    ): int;
    /**
     * Gets current value of property {@link #getEmptyIndicatorMode emptyIndicatorMode}.
     *
     * Specifies if an empty indicator should be displayed when there is no text.
     *
     * Default value is `Off`.
     *
     * @since 1.87
     *
     * @returns Value of property `emptyIndicatorMode`
     */
    getEmptyIndicatorMode(): EmptyIndicatorMode;
    /**
     * Caches and returns the computed line height of the text.
     * See:
     * 	sap.m.Text#cacheLineHeight
     *
     * @since 1.22
     * @deprecated As of version 1.121. Native line clamp is now available in all supported browsers.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns returns calculated line height
     */
    getLineHeight(
      /**
       * DOM reference of the text container.
       */
      oDomRef?: HTMLElement
    ): int;
    /**
     * Gets current value of property {@link #getMaxLines maxLines}.
     *
     * Limits the number of lines for wrapping texts.
     *
     * @since 1.13.2
     *
     * @returns Value of property `maxLines`
     */
    getMaxLines(): int;
    /**
     * Gets current value of property {@link #getRenderWhitespace renderWhitespace}.
     *
     * Specifies how whitespace and tabs inside the control are handled. If true, whitespace will be preserved
     * by the browser. Depending on wrapping property text will either only wrap on line breaks or wrap when
     * necessary, and on line breaks.
     *
     * Default value is `false`.
     *
     * @since 1.51
     *
     * @returns Value of property `renderWhitespace`
     */
    getRenderWhitespace(): boolean;
    /**
     * Gets the text.
     *
     *
     * @returns Text value.
     */
    getText(
      /**
       * Indication for normalized text.
       */
      bNormalize?: boolean
    ): string;
    /**
     * Gets current value of property {@link #getTextAlign textAlign}.
     *
     * Sets the horizontal alignment of the text.
     *
     * Default value is `Begin`.
     *
     *
     * @returns Value of property `textAlign`
     */
    getTextAlign(): TextAlign;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * Available options for the text direction are LTR and RTL. By default the control inherits the text direction
     * from its parent control.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Returns the text node container's DOM reference. This can be different from `getDomRef` when inner wrapper
     * is needed.
     *
     * @since 1.22
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns DOM reference of the text.
     */
    getTextDomRef(): HTMLElement | null;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Sets the width of the Text control. By default, the Text control uses the full width available. Set this
     * property to restrict the width to a custom value.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getWrapping wrapping}.
     *
     * Enables text wrapping.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `wrapping`
     */
    getWrapping(): boolean;
    /**
     * Gets current value of property {@link #getWrappingType wrappingType}.
     *
     * Defines the type of text wrapping to be used (hyphenated or normal).
     *
     * **Note:** This property takes effect only when the `wrapping` property is set to `true`.
     *
     * Default value is `Normal`.
     *
     * @since 1.60
     *
     * @returns Value of property `wrappingType`
     */
    getWrappingType(): WrappingType;
    /**
     * Returns if the control can be bound to a label
     *
     *
     * @returns `true` if the control can be bound to a label
     */
    hasLabelableHTMLElement(): boolean;
    /**
     * Determines whether max lines should be rendered or not.
     *
     * @since 1.22
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Max lines of the text.
     */
    hasMaxLines(): HTMLElement | null;
    /**
     * Sets a new value for property {@link #getEmptyIndicatorMode emptyIndicatorMode}.
     *
     * Specifies if an empty indicator should be displayed when there is no text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Off`.
     *
     * @since 1.87
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEmptyIndicatorMode(
      /**
       * New value for property `emptyIndicatorMode`
       */
      sEmptyIndicatorMode?: EmptyIndicatorMode | keyof typeof EmptyIndicatorMode
    ): this;
    /**
     * Sets a new value for property {@link #getMaxLines maxLines}.
     *
     * Limits the number of lines for wrapping texts.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.13.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxLines(
      /**
       * New value for property `maxLines`
       */
      iMaxLines?: int
    ): this;
    /**
     * Sets a new value for property {@link #getRenderWhitespace renderWhitespace}.
     *
     * Specifies how whitespace and tabs inside the control are handled. If true, whitespace will be preserved
     * by the browser. Depending on wrapping property text will either only wrap on line breaks or wrap when
     * necessary, and on line breaks.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.51
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRenderWhitespace(
      /**
       * New value for property `renderWhitespace`
       */
      bRenderWhitespace?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Determines the text to be displayed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTextAlign textAlign}.
     *
     * Sets the horizontal alignment of the text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Begin`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextAlign(
      /**
       * New value for property `textAlign`
       */
      sTextAlign?: TextAlign | keyof typeof TextAlign
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * Available options for the text direction are LTR and RTL. By default the control inherits the text direction
     * from its parent control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Sets the width of the Text control. By default, the Text control uses the full width available. Set this
     * property to restrict the width to a custom value.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getWrapping wrapping}.
     *
     * Enables text wrapping.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWrapping(
      /**
       * New value for property `wrapping`
       */
      bWrapping?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getWrappingType wrappingType}.
     *
     * Defines the type of text wrapping to be used (hyphenated or normal).
     *
     * **Note:** This property takes effect only when the `wrapping` property is set to `true`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Normal`.
     *
     * @since 1.60
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWrappingType(
      /**
       * New value for property `wrappingType`
       */
      sWrappingType?: WrappingType | keyof typeof WrappingType
    ): this;
    /**
     * Unbinds property {@link #getText text} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindText(): this;
  }
  /**
   * Describes the settings that can be provided to the Text constructor.
   */
  export interface $TextSettings extends $ControlSettings {
    /**
     * Determines the text to be displayed.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Available options for the text direction are LTR and RTL. By default the control inherits the text direction
     * from its parent control.
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Enables text wrapping.
     */
    wrapping?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the type of text wrapping to be used (hyphenated or normal).
     *
     * **Note:** This property takes effect only when the `wrapping` property is set to `true`.
     *
     * @since 1.60
     */
    wrappingType?:
      | (WrappingType | keyof typeof WrappingType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Sets the horizontal alignment of the text.
     */
    textAlign?:
      | (TextAlign | keyof typeof TextAlign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Sets the width of the Text control. By default, the Text control uses the full width available. Set this
     * property to restrict the width to a custom value.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Limits the number of lines for wrapping texts.
     *
     * @since 1.13.2
     */
    maxLines?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies how whitespace and tabs inside the control are handled. If true, whitespace will be preserved
     * by the browser. Depending on wrapping property text will either only wrap on line breaks or wrap when
     * necessary, and on line breaks.
     *
     * @since 1.51
     */
    renderWhitespace?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies if an empty indicator should be displayed when there is no text.
     *
     * @since 1.87
     */
    emptyIndicatorMode?:
      | (EmptyIndicatorMode | keyof typeof EmptyIndicatorMode)
      | PropertyBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/TextArea" {
  import { default as InputBase, $InputBaseSettings } from "sap/m/InputBase";

  import { CSSSize, Wrapping } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * A control that is used for multi-line input of text. Overview: The text area is used to enter multiple
   * lines of text. When empty, it can hold a placeholder similar to an {@link sap.m.Input input}. You can
   * define the height and width of the text area and also determine specific behavior when handling long
   * texts. Structure: Parameters that determine the size:
   * 	 - `rows` - Number of visible text lines (overruled by `height`, if both are set)
   * 	 - `cols` - Number of visible characters per line line (overruled by `width`, if both are set)
   * 	 - `height` - Height of the control
   * 	 - `width` - Width of the control  Parameters that determine the behavior:
   * 	 - `growing` - The text area adjusts its size based on the content
   * 	 - `growingMaxLines` - Threshold for the `growing` property (shouldn't exceed the screen size)
   * 	 - `maxLength` - Maximum number of characters that can be entered in a text area
   * 	 - `wrapping` - The way the entered text is wrapped by the control
   * 	 - `showExceededText` - Determines how text beyond the `maxLength` length is handled  Usage: When
   *     to use:
   * 	 - You want to enter multiple lines of text.
   * 	 - Always provide labels for a text area.
   * 	 - A placeholder does not substitute a label.  Responsive Behavior:
   * 	 - On smaller screens, you can scroll down the text area to see the entire text. To indicate that the
   *     text continues, the control shows only half of the last line.
   * 	 - If you have a growing text area, have in mind that its maximum height should not exceed the height
   *     of the screen. If that is the case, the screen height is used instead.
   * 	 - If `showExceededText` is set to TRUE and you paste a longer text, all characters beyond the `maxLength`
   *     limit are automatically selected. If `showExceededText` is set to TRUE, the control will display
   *     a counter for the remaining characters.
   *
   * @since 1.9.0
   */
  export default class TextArea extends InputBase {
    /**
     * Constructor for a new TextArea.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/text-area/ Text Area}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $TextAreaSettings
    );
    /**
     * Constructor for a new TextArea.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/text-area/ Text Area}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $TextAreaSettings
    );

    /**
     * Creates a new subclass of class sap.m.TextArea with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.InputBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, TextArea>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.TextArea.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.TextArea`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TextArea` itself.
     *
     * Is fired whenever the user has modified the text shown on the text area.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TextArea$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TextArea` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.TextArea`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TextArea` itself.
     *
     * Is fired whenever the user has modified the text shown on the text area.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TextArea$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TextArea` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:liveChange liveChange} event of this `sap.m.TextArea`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLiveChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: TextArea$LiveChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:liveChange liveChange} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLiveChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: TextArea$LiveChangeEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getCols cols}.
     *
     * Defines the visible width of the control, in average character widths. **Note:** The `width` property
     * wins over the `cols` property, if both are set.
     *
     * Default value is `20`.
     *
     *
     * @returns Value of property `cols`
     */
    getCols(): int;
    /**
     * Gets current value of property {@link #getGrowing growing}.
     *
     * Indicates the ability of the control to automatically grow and shrink dynamically with its content. **Note:**
     * This property should not be used when the `height` property is set.
     *
     * Default value is `false`.
     *
     * @since 1.38.0
     *
     * @returns Value of property `growing`
     */
    getGrowing(): boolean;
    /**
     * Gets current value of property {@link #getGrowingMaxLines growingMaxLines}.
     *
     * Defines the maximum number of lines that the control can grow.
     *
     * Default value is `0`.
     *
     * @since 1.38.0
     *
     * @returns Value of property `growingMaxLines`
     */
    getGrowingMaxLines(): int;
    /**
     * Gets current value of property {@link #getHeight height}.
     *
     * Defines the height of the control.
     *
     *
     * @returns Value of property `height`
     */
    getHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getMaxLength maxLength}.
     *
     * Defines the maximum number of characters that the `value` can be.
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `maxLength`
     */
    getMaxLength(): int;
    /**
     * Gets current value of property {@link #getRows rows}.
     *
     * Defines the number of visible text lines for the control. **Note:** The `height` property wins over the
     * `rows` property, if both are set.
     *
     * Default value is `2`.
     *
     *
     * @returns Value of property `rows`
     */
    getRows(): int;
    /**
     * Gets current value of property {@link #getShowExceededText showExceededText}.
     *
     * Determines whether the characters, exceeding the maximum allowed character count, are visible in the
     * input field.
     *
     * If set to `false` the user is not allowed to enter more characters than what is set in the `maxLength`
     * property. If set to `true` the characters exceeding the `maxLength` value are selected on paste and the
     * counter below the input field displays their number.
     *
     * Default value is `false`.
     *
     * @since 1.48
     *
     * @returns Value of property `showExceededText`
     */
    getShowExceededText(): boolean;
    /**
     * Gets current value of property {@link #getValueLiveUpdate valueLiveUpdate}.
     *
     * Indicates when the `value` property gets updated with the user changes. Setting it to `true` updates
     * the `value` property whenever the user has modified the text shown on the text area.
     *
     * Default value is `false`.
     *
     * @since 1.30
     *
     * @returns Value of property `valueLiveUpdate`
     */
    getValueLiveUpdate(): boolean;
    /**
     * Gets current value of property {@link #getWrapping wrapping}.
     *
     * Indicates how the control wraps the text, e.g. `Soft`, `Hard`, `Off`.
     *
     * Default value is `None`.
     *
     *
     * @returns Value of property `wrapping`
     */
    getWrapping(): Wrapping;
    /**
     * Sets a new value for property {@link #getCols cols}.
     *
     * Defines the visible width of the control, in average character widths. **Note:** The `width` property
     * wins over the `cols` property, if both are set.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `20`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCols(
      /**
       * New value for property `cols`
       */
      iCols?: int
    ): this;
    /**
     * Sets a new value for property {@link #getGrowing growing}.
     *
     * Indicates the ability of the control to automatically grow and shrink dynamically with its content. **Note:**
     * This property should not be used when the `height` property is set.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.38.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGrowing(
      /**
       * New value for property `growing`
       */
      bGrowing?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getGrowingMaxLines growingMaxLines}.
     *
     * Defines the maximum number of lines that the control can grow.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     * @since 1.38.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGrowingMaxLines(
      /**
       * New value for property `growingMaxLines`
       */
      iGrowingMaxLines?: int
    ): this;
    /**
     * Sets a new value for property {@link #getHeight height}.
     *
     * Defines the height of the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeight(
      /**
       * New value for property `height`
       */
      sHeight?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getMaxLength maxLength}.
     *
     * Defines the maximum number of characters that the `value` can be.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxLength(
      /**
       * New value for property `maxLength`
       */
      iMaxLength?: int
    ): this;
    /**
     * Sets a new value for property {@link #getRows rows}.
     *
     * Defines the number of visible text lines for the control. **Note:** The `height` property wins over the
     * `rows` property, if both are set.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `2`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRows(
      /**
       * New value for property `rows`
       */
      iRows?: int
    ): this;
    /**
     * Sets a new value for property {@link #getShowExceededText showExceededText}.
     *
     * Determines whether the characters, exceeding the maximum allowed character count, are visible in the
     * input field.
     *
     * If set to `false` the user is not allowed to enter more characters than what is set in the `maxLength`
     * property. If set to `true` the characters exceeding the `maxLength` value are selected on paste and the
     * counter below the input field displays their number.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.48
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowExceededText(
      /**
       * New value for property `showExceededText`
       */
      bShowExceededText?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getValueLiveUpdate valueLiveUpdate}.
     *
     * Indicates when the `value` property gets updated with the user changes. Setting it to `true` updates
     * the `value` property whenever the user has modified the text shown on the text area.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.30
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueLiveUpdate(
      /**
       * New value for property `valueLiveUpdate`
       */
      bValueLiveUpdate?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getWrapping wrapping}.
     *
     * Indicates how the control wraps the text, e.g. `Soft`, `Hard`, `Off`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `None`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWrapping(
      /**
       * New value for property `wrapping`
       */
      sWrapping?: Wrapping | keyof typeof Wrapping
    ): this;
  }
  /**
   * Describes the settings that can be provided to the TextArea constructor.
   */
  export interface $TextAreaSettings extends $InputBaseSettings {
    /**
     * Defines the number of visible text lines for the control. **Note:** The `height` property wins over the
     * `rows` property, if both are set.
     */
    rows?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the visible width of the control, in average character widths. **Note:** The `width` property
     * wins over the `cols` property, if both are set.
     */
    cols?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the height of the control.
     */
    height?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the maximum number of characters that the `value` can be.
     */
    maxLength?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the characters, exceeding the maximum allowed character count, are visible in the
     * input field.
     *
     * If set to `false` the user is not allowed to enter more characters than what is set in the `maxLength`
     * property. If set to `true` the characters exceeding the `maxLength` value are selected on paste and the
     * counter below the input field displays their number.
     *
     * @since 1.48
     */
    showExceededText?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates how the control wraps the text, e.g. `Soft`, `Hard`, `Off`.
     */
    wrapping?:
      | (Wrapping | keyof typeof Wrapping)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Indicates when the `value` property gets updated with the user changes. Setting it to `true` updates
     * the `value` property whenever the user has modified the text shown on the text area.
     *
     * @since 1.30
     */
    valueLiveUpdate?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates the ability of the control to automatically grow and shrink dynamically with its content. **Note:**
     * This property should not be used when the `height` property is set.
     *
     * @since 1.38.0
     */
    growing?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the maximum number of lines that the control can grow.
     *
     * @since 1.38.0
     */
    growingMaxLines?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Is fired whenever the user has modified the text shown on the text area.
     */
    liveChange?: (oEvent: TextArea$LiveChangeEvent) => void;
  }

  /**
   * Parameters of the TextArea#liveChange event.
   */
  export interface TextArea$LiveChangeEventParameters {
    /**
     * The new `value` of the control.
     */
    value?: string;
  }

  /**
   * Event object of the TextArea#liveChange event.
   */
  export type TextArea$LiveChangeEvent = Event<
    TextArea$LiveChangeEventParameters,
    TextArea
  >;
}

declare module "sap/m/Tile" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * A tile to be displayed in the tile container. Use this tile as the base class for specialized tile implementations.
   * Use the renderer _addOuterClass methods to add a style class to the main surface of the Tile. In this
   * class set the background color, gradients or background images. Instead of implementing the default render
   * method in the renderer, implement your content HTML in the _renderContent method of the specialized tile.
   *
   * @since 1.12
   * @deprecated As of version 1.50. replaced by {@link sap.m.GenericTile}
   */
  export default class Tile extends Control {
    /**
     * Constructor for a new Tile.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $TileSettings
    );
    /**
     * Constructor for a new Tile.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $TileSettings
    );

    /**
     * Creates a new subclass of class sap.m.Tile with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Tile>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Tile.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.Tile`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Tile` itself.
     *
     * Tap event is raised if the user taps or clicks the control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Tile` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.Tile`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Tile` itself.
     *
     * Tap event is raised if the user taps or clicks the control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Tile` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.Tile`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getRemovable removable}.
     *
     * Determines whether the tile is movable within the surrounding tile container. The remove event is fired
     * by the tile container.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `removable`
     */
    getRemovable(): boolean;
    /**
     * Sets a new value for property {@link #getRemovable removable}.
     *
     * Determines whether the tile is movable within the surrounding tile container. The remove event is fired
     * by the tile container.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRemovable(
      /**
       * New value for property `removable`
       */
      bRemovable?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Tile constructor.
   *
   * @deprecated As of version 1.50. replaced by {@link sap.m.GenericTile}
   */
  export interface $TileSettings extends $ControlSettings {
    /**
     * Determines whether the tile is movable within the surrounding tile container. The remove event is fired
     * by the tile container.
     */
    removable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Tap event is raised if the user taps or clicks the control.
     */
    press?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the Tile#press event.
   */
  export interface Tile$PressEventParameters {}

  /**
   * Event object of the Tile#press event.
   */
  export type Tile$PressEvent = Event<Tile$PressEventParameters, Tile>;
}

declare module "sap/m/TileAttribute" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ContentConfig from "sap/m/ContentConfig";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * Holds detail of an attribute used in the ActionTile.
   *
   * @since 1.122
   * @experimental As of version 1.122.
   */
  export default class TileAttribute extends Control {
    /**
     * Constructor for a new TileAttribute.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $TileAttributeSettings
    );
    /**
     * Constructor for a new TileAttribute.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $TileAttributeSettings
    );

    /**
     * Creates a new subclass of class sap.m.TileAttribute with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, TileAttribute>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.TileAttribute.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Binds aggregation {@link #getContentConfig contentConfig} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindContentConfig(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys the contentConfig in the aggregation {@link #getContentConfig contentConfig}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContentConfig(): this;
    /**
     * Gets content of aggregation {@link #getContentConfig contentConfig}.
     *
     * LinkTileContent is being added to the GenericTile, it is advised to use in TwoByOne frameType
     */
    getContentConfig(): ContentConfig;
    /**
     * Gets current value of property {@link #getKey key}.
     *
     * key of the attribute that identifies its position, if the attribute is rendered as a group.
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `key`
     */
    getKey(): int;
    /**
     * Gets current value of property {@link #getLabel label}.
     *
     * Label of the attribute. If set to null, the label is not displayed.
     *
     *
     * @returns Value of property `label`
     */
    getLabel(): string;
    /**
     * Sets the aggregated {@link #getContentConfig contentConfig}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContentConfig(
      /**
       * The contentConfig to set
       */
      oContentConfig: ContentConfig
    ): this;
    /**
     * Sets a new value for property {@link #getKey key}.
     *
     * key of the attribute that identifies its position, if the attribute is rendered as a group.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setKey(
      /**
       * New value for property `key`
       */
      iKey?: int
    ): this;
    /**
     * Sets a new value for property {@link #getLabel label}.
     *
     * Label of the attribute. If set to null, the label is not displayed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLabel(
      /**
       * New value for property `label`
       */
      sLabel?: string
    ): this;
    /**
     * Unbinds aggregation {@link #getContentConfig contentConfig} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindContentConfig(): this;
  }
  /**
   * Describes the settings that can be provided to the TileAttribute constructor.
   *
   * @experimental As of version 1.122.
   */
  export interface $TileAttributeSettings extends $ControlSettings {
    /**
     * key of the attribute that identifies its position, if the attribute is rendered as a group.
     */
    key?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Label of the attribute. If set to null, the label is not displayed.
     */
    label?: string | PropertyBindingInfo;

    /**
     * LinkTileContent is being added to the GenericTile, it is advised to use in TwoByOne frameType
     */
    contentConfig?: ContentConfig;
  }
}

declare module "sap/m/TileContainer" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import Tile from "sap/m/Tile";

  import Event from "sap/ui/base/Event";

  import { CSSSize } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * A container that arranges same-size tiles nicely on carousel pages.
   *
   * @since 1.12
   * @deprecated As of version 1.50. replaced by a container of your choice with {@link sap.m.GenericTile }
   * instances
   */
  export default class TileContainer extends Control {
    /**
     * Constructor for a new TileContainer.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $TileContainerSettings
    );
    /**
     * Constructor for a new TileContainer.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $TileContainerSettings
    );

    /**
     * Creates a new subclass of class sap.m.TileContainer with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, TileContainer>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.TileContainer.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds a Tile to the end of the tiles collection.
     *
     *
     * @returns this pointer for chaining
     */
    addTile(
      /**
       * The tile to add
       */
      oTile: Tile
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tileAdd tileAdd} event of this `sap.m.TileContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TileContainer` itself.
     *
     * Fires when a Tile is added.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTileAdd(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TileContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tileAdd tileAdd} event of this `sap.m.TileContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TileContainer` itself.
     *
     * Fires when a Tile is added.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTileAdd(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TileContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tileDelete tileDelete} event of this `sap.m.TileContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TileContainer` itself.
     *
     * Fires if a Tile is deleted in Edit mode.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTileDelete(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TileContainer$TileDeleteEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TileContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tileDelete tileDelete} event of this `sap.m.TileContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TileContainer` itself.
     *
     * Fires if a Tile is deleted in Edit mode.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTileDelete(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TileContainer$TileDeleteEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TileContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tileMove tileMove} event of this `sap.m.TileContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TileContainer` itself.
     *
     * Fires if a Tile is moved.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTileMove(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TileContainer$TileMoveEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TileContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tileMove tileMove} event of this `sap.m.TileContainer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TileContainer` itself.
     *
     * Fires if a Tile is moved.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTileMove(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TileContainer$TileMoveEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TileContainer` itself
       */
      oListener?: object
    ): this;
    /**
     * Deletes a Tile.
     *
     *
     * @returns this pointer for chaining
     */
    deleteTile(
      /**
       * The tile to move
       */
      oTile: Tile
    ): this;
    /**
     * Destroys all the tiles in the aggregation {@link #getTiles tiles}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyTiles(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:tileAdd tileAdd} event of this `sap.m.TileContainer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachTileAdd(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:tileDelete tileDelete} event of this `sap.m.TileContainer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachTileDelete(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: TileContainer$TileDeleteEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:tileMove tileMove} event of this `sap.m.TileContainer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachTileMove(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: TileContainer$TileMoveEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:tileAdd tileAdd} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireTileAdd(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:tileDelete tileDelete} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireTileDelete(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: TileContainer$TileDeleteEventParameters
    ): this;
    /**
     * Fires event {@link #event:tileMove tileMove} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireTileMove(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: TileContainer$TileMoveEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getAllowAdd allowAdd}.
     *
     * Determines whether the user is allowed to add Tiles in Edit mode (editable = true).
     *
     *
     * @returns Value of property `allowAdd`
     */
    getAllowAdd(): boolean;
    /**
     * Gets current value of property {@link #getEditable editable}.
     *
     * Determines whether the TileContainer is editable so you can move, delete or add tiles.
     *
     *
     * @returns Value of property `editable`
     */
    getEditable(): boolean;
    /**
     * Gets current value of property {@link #getHeight height}.
     *
     * Defines the height of the TileContainer in px.
     *
     * Default value is `'100%'`.
     *
     *
     * @returns Value of property `height`
     */
    getHeight(): CSSSize;
    /**
     * Returns the index of the first Tile visible in the current page.
     *
     *
     * @returns The index of the first Tile that is visible in the current page
     */
    getPageFirstTileIndex(): int;
    /**
     * Gets content of aggregation {@link #getTiles tiles}.
     *
     * The Tiles to be displayed by the TileContainer.
     */
    getTiles(): Tile[];
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Defines the width of the TileContainer in px.
     *
     * Default value is `'100%'`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Checks for the provided `sap.m.Tile` in the aggregation {@link #getTiles tiles}. and returns its index
     * if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfTile(
      /**
       * The tile whose index is looked for
       */
      oTile: Tile
    ): int;
    /**
     * Inserts a Tile to the given index.
     *
     *
     * @returns this pointer for chaining
     */
    insertTile(
      /**
       * The Tile to insert
       */
      oTile: Tile,
      /**
       * The new Tile position in the tiles aggregation
       */
      iIndex: int
    ): this;
    /**
     * Moves a given Tile to the given index.
     *
     *
     * @returns this pointer for chaining
     */
    moveTile(
      /**
       * The tile to move
       */
      vTile: Tile,
      /**
       * The new Tile position in the tiles aggregation
       */
      iNewIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getTiles tiles}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllTiles(): Tile[];
    /**
     * Removes a tile from the aggregation {@link #getTiles tiles}.
     *
     *
     * @returns The removed tile or `null`
     */
    removeTile(
      /**
       * The tile to remove or its index or id
       */
      vTile: int | string | Tile
    ): Tile | null;
    /**
     * Scrolls to the page where the given Tile or tile index is included. Optionally this can be done animated
     * or not. With IE9 the scroll is never animated.
     */
    scrollIntoView(
      /**
       * The Tile or tile index to be scrolled into view
       */
      vTile: Tile | int,
      /**
       * Whether the scroll should be animated
       */
      bAnimated: boolean,
      /**
       * optional list of visible tiles in order to avoid filtering them again.
       */
      aVisibleTiles?: Tile[]
    ): void;
    /**
     * Scrolls one page to the left.
     */
    scrollLeft(): void;
    /**
     * Scrolls one page to the right.
     */
    scrollRight(): void;
    /**
     * Sets a new value for property {@link #getAllowAdd allowAdd}.
     *
     * Determines whether the user is allowed to add Tiles in Edit mode (editable = true).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAllowAdd(
      /**
       * New value for property `allowAdd`
       */
      bAllowAdd?: boolean
    ): this;
    /**
     * Sets the editable property to the TileContainer, allowing to move icons. This is currently also set with
     * a long tap.
     *
     *
     * @returns this pointer for chaining
     */
    setEditable(
      /**
       * Whether the container is in edit mode or not
       */
      bValue: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getHeight height}.
     *
     * Defines the height of the TileContainer in px.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `'100%'`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeight(
      /**
       * New value for property `height`
       */
      sHeight?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Defines the width of the TileContainer in px.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `'100%'`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
  }
  /**
   * Describes the settings that can be provided to the TileContainer constructor.
   *
   * @deprecated As of version 1.50. replaced by a container of your choice with {@link sap.m.GenericTile }
   * instances
   */
  export interface $TileContainerSettings extends $ControlSettings {
    /**
     * Defines the width of the TileContainer in px.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the height of the TileContainer in px.
     */
    height?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the TileContainer is editable so you can move, delete or add tiles.
     */
    editable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the user is allowed to add Tiles in Edit mode (editable = true).
     */
    allowAdd?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The Tiles to be displayed by the TileContainer.
     */
    tiles?: Tile[] | Tile | AggregationBindingInfo | `{${string}}`;

    /**
     * Fires if a Tile is moved.
     */
    tileMove?: (oEvent: TileContainer$TileMoveEvent) => void;

    /**
     * Fires if a Tile is deleted in Edit mode.
     */
    tileDelete?: (oEvent: TileContainer$TileDeleteEvent) => void;

    /**
     * Fires when a Tile is added.
     */
    tileAdd?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the TileContainer#tileAdd event.
   */
  export interface TileContainer$TileAddEventParameters {}

  /**
   * Event object of the TileContainer#tileAdd event.
   */
  export type TileContainer$TileAddEvent = Event<
    TileContainer$TileAddEventParameters,
    TileContainer
  >;

  /**
   * Parameters of the TileContainer#tileDelete event.
   */
  export interface TileContainer$TileDeleteEventParameters {
    /**
     * The deleted Tile.
     */
    tile?: Tile;
  }

  /**
   * Event object of the TileContainer#tileDelete event.
   */
  export type TileContainer$TileDeleteEvent = Event<
    TileContainer$TileDeleteEventParameters,
    TileContainer
  >;

  /**
   * Parameters of the TileContainer#tileMove event.
   */
  export interface TileContainer$TileMoveEventParameters {
    /**
     * The Tile that has been moved.
     */
    tile?: Tile;

    /**
     * The new index of the Tile in the tiles aggregation.
     */
    newIndex?: int;
  }

  /**
   * Event object of the TileContainer#tileMove event.
   */
  export type TileContainer$TileMoveEvent = Event<
    TileContainer$TileMoveEventParameters,
    TileContainer
  >;
}

declare module "sap/m/TileContent" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import {
    ValueColor,
    FrameType,
    Priority,
    Size,
    LoadState,
  } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * This control is used within the GenericTile control.
   *
   * @since 1.34.0
   */
  export default class TileContent extends Control {
    /**
     * Constructor for a new sap.m.TileContent control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $TileContentSettings
    );
    /**
     * Constructor for a new sap.m.TileContent control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $TileContentSettings
    );

    /**
     * Creates a new subclass of class sap.m.TileContent with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, TileContent>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.TileContent.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Binds aggregation {@link #getContent content} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindContent(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * The switchable view that depends on the tile type.
     */
    getContent(): Control;
    /**
     * Gets current value of property {@link #getDisabled disabled}.
     *
     * Disables control if true.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `disabled`
     */
    getDisabled(): boolean;
    /**
     * Gets current value of property {@link #getFooter footer}.
     *
     * The footer text of the tile.
     *
     *
     * @returns Value of property `footer`
     */
    getFooter(): string;
    /**
     * Gets current value of property {@link #getFooterColor footerColor}.
     *
     * The semantic color of the footer.
     *
     * Default value is `"Neutral"`.
     *
     * @since 1.44
     *
     * @returns Value of property `footerColor`
     */
    getFooterColor(): ValueColor;
    /**
     * Gets current value of property {@link #getFrameType frameType}.
     *
     * Frame types: 1x1, 2x1, and auto.
     *
     * Default value is `"Auto"`.
     *
     *
     * @returns Value of property `frameType`
     */
    getFrameType(): FrameType;
    /**
     * Gets current value of property {@link #getPriority priority}.
     *
     * Adds a priority badge before the content. Works only in Generic Tiles in ActionMode or Article Mode containing
     * FrameType Stretch.
     *
     * Default value is `None`.
     *
     * @since 1.96
     *
     * @returns Value of property `priority`
     */
    getPriority(): Priority;
    /**
     * Gets current value of property {@link #getPriorityText priorityText}.
     *
     * Sets the Text inside the Priority badge in Generic Tile. Works only in Generic Tiles in ActionMode or
     * Article Mode containing FrameType Stretch.
     *
     * @since 1.103
     *
     * @returns Value of property `priorityText`
     */
    getPriorityText(): string;
    /**
     * Gets current value of property {@link #getSize size}.
     *
     * Updates the size of the tile. If it is not set, then the default size is applied based on the device
     * tile.
     *
     * Default value is `"Auto"`.
     *
     * @deprecated As of version 1.38.0. The TileContent control has now a fixed size, depending on the used
     * media (desktop, tablet or phone).
     *
     * @returns Value of property `size`
     */
    getSize(): Size;
    /**
     * Gets current value of property {@link #getState state}.
     *
     * The load status.
     *
     * Default value is `Loaded`.
     *
     * @since 1.100.0
     *
     * @returns Value of property `state`
     */
    getState(): LoadState;
    /**
     * Gets current value of property {@link #getUnit unit}.
     *
     * The percent sign, the currency symbol, or the unit of measure.
     *
     *
     * @returns Value of property `unit`
     */
    getUnit(): string;
    /**
     * Sets the aggregated {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContent(
      /**
       * The content to set
       */
      oContent: Control
    ): this;
    /**
     * Sets a new value for property {@link #getDisabled disabled}.
     *
     * Disables control if true.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDisabled(
      /**
       * New value for property `disabled`
       */
      bDisabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getFooter footer}.
     *
     * The footer text of the tile.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFooter(
      /**
       * New value for property `footer`
       */
      sFooter?: string
    ): this;
    /**
     * Sets a new value for property {@link #getFooterColor footerColor}.
     *
     * The semantic color of the footer.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Neutral"`.
     *
     * @since 1.44
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFooterColor(
      /**
       * New value for property `footerColor`
       */
      sFooterColor?: ValueColor | keyof typeof ValueColor
    ): this;
    /**
     * Sets a new value for property {@link #getFrameType frameType}.
     *
     * Frame types: 1x1, 2x1, and auto.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Auto"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFrameType(
      /**
       * New value for property `frameType`
       */
      sFrameType?: FrameType | keyof typeof FrameType
    ): this;
    /**
     * Sets the priority of the tile content.
     *
     *
     * @returns Reference to the current instance for method chaining.
     */
    setPriority(
      /**
       * The priority level.
       */
      sPriority: Priority | keyof typeof Priority
    ): this;
    /**
     * Sets the text for the priority badge.
     *
     *
     * @returns Reference to the current instance for method chaining.
     */
    setPriorityText(
      /**
       * The text to be displayed on the badge.
       */
      sPriorityText: string
    ): this;
    /**
     * Setter for protected property to enable or disable content rendering. This function does not invalidate
     * the control.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns this To allow method chaining
     */
    setRenderContent(
      /**
       * Determines whether the control's content is rendered or not
       */
      value: boolean
    ): this;
    /**
     * Setter for protected property to enable or disable footer rendering. This function does not invalidate
     * the control.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns this to allow method chaining
     */
    setRenderFooter(
      /**
       * Determines whether the control's footer is rendered or not
       */
      value: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getSize size}.
     *
     * Updates the size of the tile. If it is not set, then the default size is applied based on the device
     * tile.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Auto"`.
     *
     * @deprecated As of version 1.38.0. The TileContent control has now a fixed size, depending on the used
     * media (desktop, tablet or phone).
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSize(
      /**
       * New value for property `size`
       */
      sSize?: Size | keyof typeof Size
    ): this;
    /**
     * Sets a new value for property {@link #getState state}.
     *
     * The load status.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Loaded`.
     *
     * @since 1.100.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setState(
      /**
       * New value for property `state`
       */
      sState?: LoadState | keyof typeof LoadState
    ): this;
    /**
     * Sets a new value for property {@link #getUnit unit}.
     *
     * The percent sign, the currency symbol, or the unit of measure.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUnit(
      /**
       * New value for property `unit`
       */
      sUnit?: string
    ): this;
    /**
     * Unbinds aggregation {@link #getContent content} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindContent(): this;
  }
  /**
   * Describes the settings that can be provided to the TileContent constructor.
   */
  export interface $TileContentSettings extends $ControlSettings {
    /**
     * The footer text of the tile.
     */
    footer?: string | PropertyBindingInfo;

    /**
     * The semantic color of the footer.
     *
     * @since 1.44
     */
    footerColor?:
      | (ValueColor | keyof typeof ValueColor)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Updates the size of the tile. If it is not set, then the default size is applied based on the device
     * tile.
     *
     * @deprecated As of version 1.38.0. The TileContent control has now a fixed size, depending on the used
     * media (desktop, tablet or phone).
     */
    size?: (Size | keyof typeof Size) | PropertyBindingInfo | `{${string}}`;

    /**
     * The percent sign, the currency symbol, or the unit of measure.
     */
    unit?: string | PropertyBindingInfo;

    /**
     * Disables control if true.
     */
    disabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Frame types: 1x1, 2x1, and auto.
     */
    frameType?:
      | (FrameType | keyof typeof FrameType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Adds a priority badge before the content. Works only in Generic Tiles in ActionMode or Article Mode containing
     * FrameType Stretch.
     *
     * @since 1.96
     */
    priority?:
      | (Priority | keyof typeof Priority)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Sets the Text inside the Priority badge in Generic Tile. Works only in Generic Tiles in ActionMode or
     * Article Mode containing FrameType Stretch.
     *
     * @since 1.103
     */
    priorityText?: string | PropertyBindingInfo;

    /**
     * The load status.
     *
     * @since 1.100.0
     */
    state?:
      | (LoadState | keyof typeof LoadState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The switchable view that depends on the tile type.
     */
    content?: Control;
  }
}

declare module "sap/m/TileInfo" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import { TileInfoColor } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { URI } from "sap/ui/core/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * This element is used within the GenericTile control that generates a combination of an icon and a text
   * to create a TileInfo
   *
   * @since 1.124
   */
  export default class TileInfo extends UI5Element {
    /**
     * Constructor for a new TileInfo.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control.
       */
      mSettings?: $TileInfoSettings
    );
    /**
     * Constructor for a new TileInfo.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, it is generated automatically if an ID is not provided.
       */
      sId?: string,
      /**
       * Initial settings for the new control.
       */
      mSettings?: $TileInfoSettings
    );

    /**
     * Creates a new subclass of class sap.m.TileInfo with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, TileInfo>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.TileInfo.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getBackgroundColor backgroundColor}.
     *
     * Defines the background color inside the TileInfo
     *
     * Default value is `WarningBackground`.
     *
     *
     * @returns Value of property `backgroundColor`
     */
    getBackgroundColor(): TileInfoColor;
    /**
     * Gets current value of property {@link #getBorderColor borderColor}.
     *
     * Defines the border color of the TileInfo
     *
     * Default value is `WarningBorderColor`.
     *
     *
     * @returns Value of property `borderColor`
     */
    getBorderColor(): TileInfoColor;
    /**
     * Gets current value of property {@link #getSrc src}.
     *
     * This property can be set by following options:
     *
     * **Option 1:**
     *  The value has to be matched by following pattern `sap-icon://collection-name/icon-name` where `collection-name`
     * and `icon-name` have to be replaced by the desired values. In case the default UI5 icons are used the
     * `collection-name` can be omitted.
     *  Example: `sap-icon://accept`
     *
     * **Option 2:** The value is determined by using {@link sap.ui.core.IconPool.getIconURI} with an Icon name
     * parameter and an optional collection parameter which is required when using application extended Icons.
     *  Example: `IconPool.getIconURI("accept")`
     *
     *
     * @returns Value of property `src`
     */
    getSrc(): URI;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Defines the text inside the TileInfo.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getTextColor textColor}.
     *
     * Defines the text color inside the TileInfo
     *
     * Default value is `CriticalTextColor`.
     *
     *
     * @returns Value of property `textColor`
     */
    getTextColor(): TileInfoColor;
    /**
     * Sets a new value for property {@link #getBackgroundColor backgroundColor}.
     *
     * Defines the background color inside the TileInfo
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `WarningBackground`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBackgroundColor(
      /**
       * New value for property `backgroundColor`
       */
      sBackgroundColor?: TileInfoColor | keyof typeof TileInfoColor
    ): this;
    /**
     * Sets a new value for property {@link #getBorderColor borderColor}.
     *
     * Defines the border color of the TileInfo
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `WarningBorderColor`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setBorderColor(
      /**
       * New value for property `borderColor`
       */
      sBorderColor?: TileInfoColor | keyof typeof TileInfoColor
    ): this;
    /**
     * Sets a new value for property {@link #getSrc src}.
     *
     * This property can be set by following options:
     *
     * **Option 1:**
     *  The value has to be matched by following pattern `sap-icon://collection-name/icon-name` where `collection-name`
     * and `icon-name` have to be replaced by the desired values. In case the default UI5 icons are used the
     * `collection-name` can be omitted.
     *  Example: `sap-icon://accept`
     *
     * **Option 2:** The value is determined by using {@link sap.ui.core.IconPool.getIconURI} with an Icon name
     * parameter and an optional collection parameter which is required when using application extended Icons.
     *  Example: `IconPool.getIconURI("accept")`
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSrc(
      /**
       * New value for property `src`
       */
      sSrc?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Defines the text inside the TileInfo.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTextColor textColor}.
     *
     * Defines the text color inside the TileInfo
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `CriticalTextColor`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextColor(
      /**
       * New value for property `textColor`
       */
      sTextColor?: TileInfoColor | keyof typeof TileInfoColor
    ): this;
  }
  /**
   * Describes the settings that can be provided to the TileInfo constructor.
   */
  export interface $TileInfoSettings extends $ElementSettings {
    /**
     * This property can be set by following options:
     *
     * **Option 1:**
     *  The value has to be matched by following pattern `sap-icon://collection-name/icon-name` where `collection-name`
     * and `icon-name` have to be replaced by the desired values. In case the default UI5 icons are used the
     * `collection-name` can be omitted.
     *  Example: `sap-icon://accept`
     *
     * **Option 2:** The value is determined by using {@link sap.ui.core.IconPool.getIconURI} with an Icon name
     * parameter and an optional collection parameter which is required when using application extended Icons.
     *  Example: `IconPool.getIconURI("accept")`
     */
    src?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the text inside the TileInfo.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Defines the text color inside the TileInfo
     */
    textColor?:
      | (TileInfoColor | keyof typeof TileInfoColor)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the background color inside the TileInfo
     */
    backgroundColor?:
      | (TileInfoColor | keyof typeof TileInfoColor)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the border color of the TileInfo
     */
    borderColor?:
      | (TileInfoColor | keyof typeof TileInfoColor)
      | PropertyBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/TimePicker" {
  import {
    default as DateTimeField,
    $DateTimeFieldSettings,
    DateTimeField$LiveChangeEventParameters,
  } from "sap/m/DateTimeField";

  import MaskInputRule from "sap/m/MaskInputRule";

  import Event from "sap/ui/base/Event";

  import { AccessibilityInfo } from "sap/ui/core/library";

  import UI5Date from "sap/ui/core/date/UI5Date";

  import { TimePickerMaskMode } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import { InputBase$ChangeEventParameters } from "sap/m/InputBase";

  /**
   * A single-field input control that enables the users to fill time related input fields.
   *
   * Overview:
   *
   * The `TimePicker` control enables the users to fill time related input fields using touch, mouse, or keyboard
   * input.
   *
   * Usage:
   *
   * Use this control if you want the user to select a time. If you want the user to select a duration (1
   * hour), use the {@link sap.m.Select} control instead.
   *
   * The user can fill time by:
   *
   *
   * 	 - Using the time picker button that opens a popover with а time picker clock dial
   * 	 - Using the time input field. On desktop - by changing the time directly via keyboard input. On mobile/touch
   *     device - in another input field that opens in a popup after tap.
   *
   * On app level, there are two options to provide value for the `TimePicker` - as a string to the `value`
   * property or as a UI5Date or JavaScript Date object to the `dateValue` property (only one of these properties
   * should be used at a time):
   *
   *
   * 	 - Use the `value` property if you want to bind the `TimePicker` to a model using the `sap.ui.model.type.Time`
   *      binding the `value` property by using types
   * ```javascript
   *
   * new sap.ui.model.json.JSONModel({date: sap.ui.core.date.UI5Date.getInstance(2022,10,10,10,15,10)});
   *
   * new sap.m.TimePicker({
   *     value: {
   *         type: "sap.ui.model.type.Time",
   *         path:"/date"
   *     }
   * });
   * ```
   *
   * 	 - Use the `value` property if the date is provided as a string from the backend or inside the app (for
   *     example, as ABAP type DATS field)  binding the `value` property by using types
   * ```javascript
   *
   * new sap.ui.model.json.JSONModel({date:"10:15:10"});
   * new sap.m.TimePicker({
   *     value: {
   *         type: "sap.ui.model.type.Time",
   *         path: "/date",
   *         formatOptions: {
   *             source: {
   *                 pattern: "HH:mm:ss"
   *             }
   *         }
   *     }
   * });
   * ```
   *  **Note:** There are multiple binding type choices, such as: sap.ui.model.type.Date sap.ui.model.odata.type.DateTime
   * sap.ui.model.odata.type.DateTimeOffset See {@link sap.ui.model.type.Date}, {@link sap.ui.model.odata.type.DateTime }
   * or {@link sap.ui.model.odata.type.DateTimeOffset}
   *
   *
   * 	 - Use the `dateValue` property if the date is already provided as a UI5Date or JavaScript Date object
   *     or you want to work with a UI5Date or JavaScript Date object. Use `dateValue` as a helper property to
   *     easily obtain the hours, minutes and seconds of the chosen time. Although possible to bind it, the recommendation
   *     is to not to do it. When binding is needed, use `value` property instead
   *
   * Formatting:
   *
   * All formatting and parsing of values from and to strings is done using the {@link sap.ui.core.format.DateFormat}.
   * If a value is entered by typing it into the input field, it must fit to the used time format and locale.
   *
   * Supported format options are pattern-based on Unicode LDML Date Format notation. The format pattern symbols
   * supported in TimePicker are as follows: "h"/"H" (Hour), "m" (Minute), "s" (Second), and "a" (AM/PM).
   *
   * See {@link http://unicode.org/reports/tr35/#Date_Field_Symbol_Table}
   *
   * A time format must be specified, otherwise the default "HH:mm:ss a" will be used. For example, if the
   * `valueFormat` is "HH-mm-ss a", the `displayFormat` is "HH:mm:ss a", and the used locale is English, a
   * valid value string is "10-30-15 AM", which leads to an output of "10:30:15 AM".
   *
   * If no placeholder is set to the `TimePicker`, the used `displayFormat` is displayed as a placeholder.
   * If another placeholder is needed, it must be set.
   *
   * **Note:** If the string does NOT match the `displayFormat` (from user input) or the `valueFormat` (on
   * app level), the {@link sap.ui.core.format.DateFormat} makes an attempt to parse it based on the locale
   * settings. For more information, see the respective documentation in the API Reference.
   *
   * Responsive behavior:
   *
   * The `TimePicker` is responsive and fully adapts to all device types. For larger screens, such as tablet
   * or desktop, it opens as a popover. For mobile devices, it opens in full screen.
   *
   * @since 1.32
   */
  export default class TimePicker extends DateTimeField {
    /**
     * Constructor for a new `TimePicker`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/time-picker/ Time Picker}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $TimePickerSettings
    );
    /**
     * Constructor for a new `TimePicker`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/time-picker/ Time Picker}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $TimePickerSettings
    );

    /**
     * Creates a new subclass of class sap.m.TimePicker with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.DateTimeField.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, TimePicker>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.TimePicker.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some rule to the aggregation {@link #getRules rules}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addRule(
      /**
       * The rule to add; if empty, nothing is inserted
       */
      oRule: MaskInputRule
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterValueHelpClose afterValueHelpClose} event
     * of this `sap.m.TimePicker`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TimePicker` itself.
     *
     * Fired when `value help` dialog closes.
     *
     * @since 1.102.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterValueHelpClose(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TimePicker` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterValueHelpClose afterValueHelpClose} event
     * of this `sap.m.TimePicker`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TimePicker` itself.
     *
     * Fired when `value help` dialog closes.
     *
     * @since 1.102.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterValueHelpClose(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TimePicker` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterValueHelpOpen afterValueHelpOpen} event
     * of this `sap.m.TimePicker`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TimePicker` itself.
     *
     * Fired when `value help` dialog opens.
     *
     * @since 1.102.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterValueHelpOpen(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TimePicker` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterValueHelpOpen afterValueHelpOpen} event
     * of this `sap.m.TimePicker`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TimePicker` itself.
     *
     * Fired when `value help` dialog opens.
     *
     * @since 1.102.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterValueHelpOpen(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TimePicker` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.TimePicker`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TimePicker` itself.
     *
     * Fired when the value of the `TimePicker` is changed by user interaction - each keystroke, delete, paste,
     * etc.
     *
     * **Note:** Browsing autocomplete suggestions doesn't fire the event.
     *
     * @since 1.104.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TimePicker$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TimePicker` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:liveChange liveChange} event of this `sap.m.TimePicker`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TimePicker` itself.
     *
     * Fired when the value of the `TimePicker` is changed by user interaction - each keystroke, delete, paste,
     * etc.
     *
     * **Note:** Browsing autocomplete suggestions doesn't fire the event.
     *
     * @since 1.104.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachLiveChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TimePicker$LiveChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TimePicker` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the rules in the aggregation {@link #getRules rules}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyRules(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterValueHelpClose afterValueHelpClose} event
     * of this `sap.m.TimePicker`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.102.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterValueHelpClose(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterValueHelpOpen afterValueHelpOpen} event
     * of this `sap.m.TimePicker`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.102.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterValueHelpOpen(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:liveChange liveChange} event of this `sap.m.TimePicker`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.104.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachLiveChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: TimePicker$LiveChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:afterValueHelpClose afterValueHelpClose} to attached listeners.
     *
     * @since 1.102.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterValueHelpClose(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:afterValueHelpOpen afterValueHelpOpen} to attached listeners.
     *
     * @since 1.102.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterValueHelpOpen(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires change event to attached listeners.
     *
     * Expects following event parameters:
     * 	 - value parameter of type `string` - the new value of the input
     * 	 - valid parameter of type `boolean` - indicator for a valid time
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` for method chaining
     */
    fireChange(
      /**
       * The arguments to pass along with the event
       */
      mArguments?: object
    ): this;
    /**
     * Fires the change event for the listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    fireChangeEvent(
      /**
       * value of the input.
       */
      sValue: string,
      /**
       * extra event parameters.
       */
      oParams?: object
    ): void;
    /**
     * Fires event {@link #event:liveChange liveChange} to attached listeners.
     *
     * @since 1.104.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireLiveChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: TimePicker$LiveChangeEventParameters
    ): this;
    /**
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Current accessibility state of the control.
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Holds a reference to a UI5Date or JavaScript Date object. The `value` (string) property will be set according
     * to it. Alternatively, if the `value` and `valueFormat` pair properties are supplied instead, the `dateValue`
     * will be instantiated according to the parsed `value`.
     *
     *
     * @returns the value of property `dateValue`
     */
    getDateValue(): Date | UI5Date;
    /**
     * Determines the format, displayed in the input field and the picker clocks/numeric inputs.
     *
     * The default value is the browser's medium time format locale setting {@link sap.ui.core.LocaleData#getTimePattern}.
     * If data binding with type {@link sap.ui.model.type.Time} or {@link sap.ui.model.odata.type.Time} is used
     * for the `value` property, the `displayFormat` property is ignored as the information is provided from
     * the binding itself.
     *
     *
     * @returns the value of property `displayFormat`
     */
    getDisplayFormat(): string;
    /**
     * Gets current value of property {@link #getHideInput hideInput}.
     *
     * Determines whether the input field of the picker is hidden or visible. When set to `true`, the input
     * field becomes invisible and there is no way to open the picker popover. In that case it can be opened
     * by another control through calling of picker's `openBy` method, and the opening control's DOM reference
     * must be provided as parameter.
     *
     * Note: Since the picker is not responsible for accessibility attributes of the control which opens its
     * popover, those attributes should be added by the application developer. The following is recommended
     * to be added to the opening control: a text or tooltip that describes the action (example: "Open Time
     * Picker"), and also aria-haspopup attribute with value of `sap.ui.core.aria.HasPopup.Dialog`.
     *
     * Default value is `false`.
     *
     * @since 1.97
     *
     * @returns Value of property `hideInput`
     */
    getHideInput(): boolean;
    /**
     * Gets current value of property {@link #getLocaleId localeId}.
     *
     * Defines the locale used to parse string values representing time.
     *
     * Determines the locale, used to interpret the string, supplied by the `value` property.
     *
     * Example: AM in the string "09:04 AM" is locale (language) dependent. The format comes from the browser
     * language settings if not set explicitly. Used in combination with 12 hour `displayFormat` containing
     * 'a', which stands for day period string.
     *
     *
     * @returns Value of property `localeId`
     */
    getLocaleId(): string;
    /**
     * Gets current value of property {@link #getMask mask}.
     *
     * Mask defined by its characters type (respectively, by its length). You should consider the following
     * important facts: 1. The mask characters normally correspond to an existing rule (one rule per unique
     * char). Characters which don't, are considered immutable characters (for example, the mask '2099', where
     * '9' corresponds to a rule for digits, has the characters '2' and '0' as immutable). 2. Adding a rule
     * corresponding to the `placeholderSymbol` is not recommended and would lead to an unpredictable behavior.
     * 3. You can use the special escape character '^' called "Caret" prepending a rule character to make it
     * immutable. Use the double escape '^^' if you want to make use of the escape character as an immutable
     * one.
     *
     *
     * @returns Value of property `mask`
     */
    getMask(): string;
    /**
     * Gets current value of property {@link #getMaskMode maskMode}.
     *
     * Defines the state of the mask. The available mask modes are: `On` - The mask is automatically enabled
     * for fixed-length time formats, and disabled when the time format does not have a fixed length. `Off`
     * - The mask is disabled. In this mode, there are no restrictions or validations for the user input. `Enforce`
     * - The mask will always be enforced, regardless of the length of the time format.
     *
     * **Note:** The mask functions correctly only with fixed-length time formats. The mask is always disabled
     * when using a mobile device Using the `Enforce` value with time formats that do not have a fixed length
     * may lead to unpredictable behavior. Changing the mask mode does not reset any pre-set validation rules.
     * These rules will be applied according to the selected mask mode.
     *
     * Default value is `On`.
     *
     * @since 1.54
     *
     * @returns Value of property `maskMode`
     */
    getMaskMode(): TimePickerMaskMode;
    /**
     * Gets current value of property {@link #getMinutesStep minutesStep}.
     *
     * Sets the minutes step. If step is less than 1, it will be automatically converted back to 1. The minutes
     * clock is populated only by multiples of the step.
     *
     * Default value is `1`.
     *
     * @since 1.40
     *
     * @returns Value of property `minutesStep`
     */
    getMinutesStep(): int;
    /**
     * Gets current value of property {@link #getPlaceholderSymbol placeholderSymbol}.
     *
     * Defines a placeholder symbol. Shown at the position where there is no user input yet.
     *
     * Default value is `"_"`.
     *
     *
     * @returns Value of property `placeholderSymbol`
     */
    getPlaceholderSymbol(): string;
    /**
     * Gets content of aggregation {@link #getRules rules}.
     *
     * A list of validation rules (one rule per mask character).
     */
    getRules(): MaskInputRule[];
    /**
     * Gets current value of property {@link #getSecondsStep secondsStep}.
     *
     * Sets the seconds step. If step is less than 1, it will be automatically converted back to 1. The seconds
     * clock is populated only by multiples of the step.
     *
     * Default value is `1`.
     *
     * @since 1.40
     *
     * @returns Value of property `secondsStep`
     */
    getSecondsStep(): int;
    /**
     * Gets current value of property {@link #getShowCurrentTimeButton showCurrentTimeButton}.
     *
     * Determines whether there is a shortcut navigation to current time.
     *
     * Default value is `false`.
     *
     * @since 1.98
     *
     * @returns Value of property `showCurrentTimeButton`
     */
    getShowCurrentTimeButton(): boolean;
    /**
     * Gets current value of property {@link #getSupport2400 support2400}.
     *
     * Allows to set a value of 24:00, used to indicate the end of the day. Works only with HH or H formats.
     * Don't use it together with am/pm.
     *
     * Default value is `false`.
     *
     * @since 1.54
     *
     * @returns Value of property `support2400`
     */
    getSupport2400(): boolean;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Displays the text of the general picker label and is read by screen readers. It is visible only on phone.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Determines the format of the value property.
     *
     * The default value is the browser's medium time format locale setting {@link sap.ui.core.LocaleData#getTimePattern}.
     * If data binding with type {@link sap.ui.model.type.Time} or {@link sap.ui.model.odata.type.Time} is used
     * for the `value` property, the `valueFormat` property is ignored as the information is provided from the
     * binding itself.
     *
     *
     * @returns the value of property `valueFormat`
     */
    getValueFormat(): string;
    /**
     * Checks for the provided `sap.m.MaskInputRule` in the aggregation {@link #getRules rules}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfRule(
      /**
       * The rule whose index is looked for
       */
      oRule: MaskInputRule
    ): int;
    /**
     * Initializes the control.
     */
    init(): void;
    /**
     * Inserts a rule into the aggregation {@link #getRules rules}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertRule(
      /**
       * The rule to insert; if empty, nothing is inserted
       */
      oRule: MaskInputRule,
      /**
       * The `0`-based index the rule should be inserted at; for a negative value of `iIndex`, the rule is inserted
       * at position 0; for a value greater than the current size of the aggregation, the rule is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Called after the clock picker closes.
     */
    onAfterClose(): void;
    /**
     * Called after the clock picker appears.
     */
    onAfterOpen(): void;
    /**
     * Called before the clock picker appears.
     */
    onBeforeOpen(): void;
    /**
     * Opens the picker popover. The popover is positioned relatively to the control given as `oDomRef` parameter
     * on tablet or desktop and is full screen on phone. Therefore the control parameter is only used on tablet
     * or desktop and is ignored on phone.
     *
     * Note: use this method to open the picker popover only when the `hideInput` property is set to `true`.
     * Please consider opening of the picker popover by another control only in scenarios that comply with Fiori
     * guidelines. For example, opening the picker popover by another popover is not recommended. The application
     * developer should implement the following accessibility attributes to the opening control: a text or tooltip
     * that describes the action (example: "Open Time Picker"), and aria-haspopup attribute with value of `sap.ui.core.aria.HasPopup.Dialog`.
     *
     * @since 1.97
     */
    openBy(
      /**
       * DOM reference of the opening control. On tablet or desktop, the popover is positioned relatively to this
       * control.
       */
      oDomRef: HTMLElement
    ): void;
    /**
     * Removes all the controls from the aggregation {@link #getRules rules}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllRules(): MaskInputRule[];
    /**
     * Removes a rule from the aggregation {@link #getRules rules}.
     *
     *
     * @returns The removed rule or `null`
     */
    removeRule(
      /**
       * The rule to remove or its index or id
       */
      vRule: int | string | MaskInputRule
    ): MaskInputRule | null;
    /**
     * Sets the value of the date.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setDateValue(
      /**
       * A date instance
       */
      oDate: Date | UI5Date
    ): this;
    /**
     * Sets the display format.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setDisplayFormat(
      /**
       * display format to set
       */
      sDisplayFormat: string
    ): this;
    /**
     * Sets a new value for property {@link #getHideInput hideInput}.
     *
     * Determines whether the input field of the picker is hidden or visible. When set to `true`, the input
     * field becomes invisible and there is no way to open the picker popover. In that case it can be opened
     * by another control through calling of picker's `openBy` method, and the opening control's DOM reference
     * must be provided as parameter.
     *
     * Note: Since the picker is not responsible for accessibility attributes of the control which opens its
     * popover, those attributes should be added by the application developer. The following is recommended
     * to be added to the opening control: a text or tooltip that describes the action (example: "Open Time
     * Picker"), and also aria-haspopup attribute with value of `sap.ui.core.aria.HasPopup.Dialog`.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.97
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHideInput(
      /**
       * New value for property `hideInput`
       */
      bHideInput?: boolean
    ): this;
    /**
     * Sets the locale of the control.
     *
     * Used for parsing and formatting the time values in languages different than English. Necessary for translation
     * and auto-complete of the day periods, such as AM and PM.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setLocaleId(
      /**
       * A locale identifier like 'en_US'
       */
      sLocaleId: string
    ): this;
    /**
     * Sets a new value for property {@link #getMask mask}.
     *
     * Mask defined by its characters type (respectively, by its length). You should consider the following
     * important facts: 1. The mask characters normally correspond to an existing rule (one rule per unique
     * char). Characters which don't, are considered immutable characters (for example, the mask '2099', where
     * '9' corresponds to a rule for digits, has the characters '2' and '0' as immutable). 2. Adding a rule
     * corresponding to the `placeholderSymbol` is not recommended and would lead to an unpredictable behavior.
     * 3. You can use the special escape character '^' called "Caret" prepending a rule character to make it
     * immutable. Use the double escape '^^' if you want to make use of the escape character as an immutable
     * one.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMask(
      /**
       * New value for property `mask`
       */
      sMask?: string
    ): this;
    /**
     * Sets a new value for property {@link #getMaskMode maskMode}.
     *
     * Defines the state of the mask. The available mask modes are: `On` - The mask is automatically enabled
     * for fixed-length time formats, and disabled when the time format does not have a fixed length. `Off`
     * - The mask is disabled. In this mode, there are no restrictions or validations for the user input. `Enforce`
     * - The mask will always be enforced, regardless of the length of the time format.
     *
     * **Note:** The mask functions correctly only with fixed-length time formats. The mask is always disabled
     * when using a mobile device Using the `Enforce` value with time formats that do not have a fixed length
     * may lead to unpredictable behavior. Changing the mask mode does not reset any pre-set validation rules.
     * These rules will be applied according to the selected mask mode.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `On`.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaskMode(
      /**
       * New value for property `maskMode`
       */
      sMaskMode?: TimePickerMaskMode | keyof typeof TimePickerMaskMode
    ): this;
    /**
     * Sets the minutes step of clocks and inputs.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setMinutesStep(
      /**
       * The step used to generate values for the minutes clock/input
       */
      step: int
    ): this;
    /**
     * Sets a new value for property {@link #getPlaceholderSymbol placeholderSymbol}.
     *
     * Defines a placeholder symbol. Shown at the position where there is no user input yet.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"_"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPlaceholderSymbol(
      /**
       * New value for property `placeholderSymbol`
       */
      sPlaceholderSymbol?: string
    ): this;
    /**
     * Sets the seconds step of clocks and inputs.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setSecondsStep(
      /**
       * The step used to generate values for the seconds clock/input
       */
      step: int
    ): this;
    /**
     * Sets a new value for property {@link #getShowCurrentTimeButton showCurrentTimeButton}.
     *
     * Determines whether there is a shortcut navigation to current time.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.98
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowCurrentTimeButton(
      /**
       * New value for property `showCurrentTimeButton`
       */
      bShowCurrentTimeButton?: boolean
    ): this;
    /**
     * Sets `support2400` of the control.
     *
     * Allows the control to use 24-hour format. Recommended usage is to not use it with am/pm format.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setSupport2400(bSupport2400: boolean): this;
  }
  /**
   * Describes the settings that can be provided to the TimePicker constructor.
   */
  export interface $TimePickerSettings extends $DateTimeFieldSettings {
    /**
     * Defines the locale used to parse string values representing time.
     *
     * Determines the locale, used to interpret the string, supplied by the `value` property.
     *
     * Example: AM in the string "09:04 AM" is locale (language) dependent. The format comes from the browser
     * language settings if not set explicitly. Used in combination with 12 hour `displayFormat` containing
     * 'a', which stands for day period string.
     */
    localeId?: string | PropertyBindingInfo;

    /**
     * Displays the text of the general picker label and is read by screen readers. It is visible only on phone.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Sets the minutes step. If step is less than 1, it will be automatically converted back to 1. The minutes
     * clock is populated only by multiples of the step.
     *
     * @since 1.40
     */
    minutesStep?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the seconds step. If step is less than 1, it will be automatically converted back to 1. The seconds
     * clock is populated only by multiples of the step.
     *
     * @since 1.40
     */
    secondsStep?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines a placeholder symbol. Shown at the position where there is no user input yet.
     */
    placeholderSymbol?: string | PropertyBindingInfo;

    /**
     * Mask defined by its characters type (respectively, by its length). You should consider the following
     * important facts: 1. The mask characters normally correspond to an existing rule (one rule per unique
     * char). Characters which don't, are considered immutable characters (for example, the mask '2099', where
     * '9' corresponds to a rule for digits, has the characters '2' and '0' as immutable). 2. Adding a rule
     * corresponding to the `placeholderSymbol` is not recommended and would lead to an unpredictable behavior.
     * 3. You can use the special escape character '^' called "Caret" prepending a rule character to make it
     * immutable. Use the double escape '^^' if you want to make use of the escape character as an immutable
     * one.
     */
    mask?: string | PropertyBindingInfo;

    /**
     * Defines the state of the mask. The available mask modes are: `On` - The mask is automatically enabled
     * for fixed-length time formats, and disabled when the time format does not have a fixed length. `Off`
     * - The mask is disabled. In this mode, there are no restrictions or validations for the user input. `Enforce`
     * - The mask will always be enforced, regardless of the length of the time format.
     *
     * **Note:** The mask functions correctly only with fixed-length time formats. The mask is always disabled
     * when using a mobile device Using the `Enforce` value with time formats that do not have a fixed length
     * may lead to unpredictable behavior. Changing the mask mode does not reset any pre-set validation rules.
     * These rules will be applied according to the selected mask mode.
     *
     * @since 1.54
     */
    maskMode?:
      | (TimePickerMaskMode | keyof typeof TimePickerMaskMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Allows to set a value of 24:00, used to indicate the end of the day. Works only with HH or H formats.
     * Don't use it together with am/pm.
     *
     * @since 1.54
     */
    support2400?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether the input field of the picker is hidden or visible. When set to `true`, the input
     * field becomes invisible and there is no way to open the picker popover. In that case it can be opened
     * by another control through calling of picker's `openBy` method, and the opening control's DOM reference
     * must be provided as parameter.
     *
     * Note: Since the picker is not responsible for accessibility attributes of the control which opens its
     * popover, those attributes should be added by the application developer. The following is recommended
     * to be added to the opening control: a text or tooltip that describes the action (example: "Open Time
     * Picker"), and also aria-haspopup attribute with value of `sap.ui.core.aria.HasPopup.Dialog`.
     *
     * @since 1.97
     */
    hideInput?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines whether there is a shortcut navigation to current time.
     *
     * @since 1.98
     */
    showCurrentTimeButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * A list of validation rules (one rule per mask character).
     */
    rules?:
      | MaskInputRule[]
      | MaskInputRule
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Fired when `value help` dialog opens.
     *
     * @since 1.102.0
     */
    afterValueHelpOpen?: (oEvent: Event) => void;

    /**
     * Fired when `value help` dialog closes.
     *
     * @since 1.102.0
     */
    afterValueHelpClose?: (oEvent: Event) => void;

    /**
     * Fired when the value of the `TimePicker` is changed by user interaction - each keystroke, delete, paste,
     * etc.
     *
     * **Note:** Browsing autocomplete suggestions doesn't fire the event.
     *
     * @since 1.104.0
     */
    liveChange?: (oEvent: TimePicker$LiveChangeEvent) => void;
  }

  /**
   * Parameters of the TimePicker#afterValueHelpClose event.
   */
  export interface TimePicker$AfterValueHelpCloseEventParameters {}

  /**
   * Event object of the TimePicker#afterValueHelpClose event.
   */
  export type TimePicker$AfterValueHelpCloseEvent = Event<
    TimePicker$AfterValueHelpCloseEventParameters,
    TimePicker
  >;

  /**
   * Parameters of the TimePicker#afterValueHelpOpen event.
   */
  export interface TimePicker$AfterValueHelpOpenEventParameters {}

  /**
   * Event object of the TimePicker#afterValueHelpOpen event.
   */
  export type TimePicker$AfterValueHelpOpenEvent = Event<
    TimePicker$AfterValueHelpOpenEventParameters,
    TimePicker
  >;

  /**
   * Parameters of the TimePicker#change event.
   */
  export interface TimePicker$ChangeEventParameters
    extends InputBase$ChangeEventParameters {
    /**
     * Indicator for a valid time
     */
    valid?: boolean;
  }

  /**
   * Event object of the TimePicker#change event.
   */
  export type TimePicker$ChangeEvent = Event<
    TimePicker$ChangeEventParameters,
    TimePicker
  >;

  /**
   * Parameters of the TimePicker#liveChange event.
   */
  export interface TimePicker$LiveChangeEventParameters
    extends DateTimeField$LiveChangeEventParameters {}

  /**
   * Event object of the TimePicker#liveChange event.
   */
  export type TimePicker$LiveChangeEvent = Event<
    TimePicker$LiveChangeEventParameters,
    TimePicker
  >;
}

declare module "sap/m/TimePickerClocks" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import UI5Date from "sap/ui/core/date/UI5Date";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * A picker clocks container control used inside the {@link sap.m.TimePicker}.
   *
   * @since 1.90
   */
  export default class TimePickerClocks extends Control {
    /**
     * Constructor for a new `TimePickerClocks`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $TimePickerClocksSettings
    );
    /**
     * Constructor for a new `TimePickerClocks`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $TimePickerClocksSettings
    );

    /**
     * Creates a new subclass of class sap.m.TimePickerClocks with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, TimePickerClocks>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.TimePickerClocks.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getSkipAnimation skipAnimation}.
     *
     * When set to `true`, the clock will be displayed without the animation.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `skipAnimation`
     */
    getSkipAnimation(): boolean;
    /**
     * Gets the time values from the clocks, as a date object.
     *
     *
     * @returns A date instance
     */
    getTimeValues(): Date | UI5Date;
    /**
     * Initializes the control.
     */
    init(): void;
    /**
     * Prepare the control for opening. If there are already clock and button objects created, set their appearance-related
     * properties.
     *
     *
     * @returns Pointer to the control instance to allow method chaining
     */
    prepareForOpen(): this;
    /**
     * Sets a new value for property {@link #getSkipAnimation skipAnimation}.
     *
     * When set to `true`, the clock will be displayed without the animation.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSkipAnimation(
      /**
       * New value for property `skipAnimation`
       */
      bSkipAnimation?: boolean
    ): this;
    /**
     * Sets the value of the `TimePickerClocks` container.
     *
     *
     * @returns Pointer to the control instance to allow method chaining
     */
    setValue(
      /**
       * The value of the `TimePickerClocks`
       */
      sValue: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the TimePickerClocks constructor.
   */
  export interface $TimePickerClocksSettings extends $ControlSettings {
    /**
     * When set to `true`, the clock will be displayed without the animation.
     */
    skipAnimation?: boolean | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/TimePickerInputs" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import UI5Date from "sap/ui/core/date/UI5Date";

  /**
   * A picker Inputs container control used inside the {@link sap.m.TimePicker}.
   *
   * @since 1.90
   */
  export default class TimePickerInputs extends Control {
    /**
     * Constructor for a new `TimePickerInputs`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $TimePickerInputsSettings
    );
    /**
     * Constructor for a new `TimePickerInputs`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $TimePickerInputsSettings
    );

    /**
     * Creates a new subclass of class sap.m.TimePickerInputs with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, TimePickerInputs>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.TimePickerInputs.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets the time values from the clocks, as a date object.
     *
     *
     * @returns A date instance
     */
    getTimeValues(): Date | UI5Date;
    /**
     * Sets the value of the `TimePickerInputs` container.
     *
     *
     * @returns Pointer to the control instance to allow method chaining
     */
    setValue(
      /**
       * The value of the `TimePickerInputs`
       */
      sValue: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the TimePickerInputs constructor.
   */
  export interface $TimePickerInputsSettings extends $ControlSettings {}
}

declare module "sap/m/TimePickerSliders" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { CSSSize } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * A picker list container control used inside the {@link sap.m.TimePicker} or standalone to hold all the
   * sliders.
   *
   * @since 1.54
   */
  export default class TimePickerSliders extends Control {
    /**
     * Constructor for a new `TimePickerSliders`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $TimePickerSlidersSettings
    );
    /**
     * Constructor for a new `TimePickerSliders`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $TimePickerSlidersSettings
    );

    /**
     * Creates a new subclass of class sap.m.TimePickerSliders with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, TimePickerSliders>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.TimePickerSliders.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.TimePickerSliders`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TimePickerSliders` itself.
     *
     * Fired when the value is changed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TimePickerSliders$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TimePickerSliders` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.TimePickerSliders`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.TimePickerSliders` itself.
     *
     * Fired when the value is changed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: TimePickerSliders$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.TimePickerSliders` itself
       */
      oListener?: object
    ): this;
    /**
     * Collapses all the slider controls.
     *
     *
     * @returns Pointer to the control instance to allow method chaining
     */
    collapseAll(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:change change} event of this `sap.m.TimePickerSliders`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: TimePickerSliders$ChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:change change} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: TimePickerSliders$ChangeEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getDisplayFormat displayFormat}.
     *
     * Defines the time `displayFormat` of the sliders. The `displayFormat` comes from the browser language
     * settings if not set explicitly.
     *
     *
     * @returns Value of property `displayFormat`
     */
    getDisplayFormat(): string;
    /**
     * Gets current value of property {@link #getHeight height}.
     *
     * Sets the height of the container. If percentage value is used the parent container should have specified
     * height
     *
     *
     * @returns Value of property `height`
     */
    getHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getLabelText labelText}.
     *
     * Defines the text of the picker label.
     *
     * It is read by screen readers. It is visible only on phone.
     *
     *
     * @returns Value of property `labelText`
     */
    getLabelText(): string;
    /**
     * Gets current value of property {@link #getLocaleId localeId}.
     *
     * Defines the locale used to parse string values representing time.
     *
     * Determines the locale, used to interpret the string, supplied by the `value` property.
     *
     * Example: AM in the string "09:04 AM" is locale (language) dependent. The format comes from the browser
     * language settings if not set explicitly. Used in combination with 12 hour `displayFormat` containing
     * 'a', which stands for day period string.
     *
     *
     * @returns Value of property `localeId`
     */
    getLocaleId(): string;
    /**
     * Gets current value of property {@link #getMinutesStep minutesStep}.
     *
     * Sets the minutes slider step. If step is less than 1, it will be automatically converted back to 1. The
     * minutes slider is populated only by multiples of the step.
     *
     * Default value is `1`.
     *
     *
     * @returns Value of property `minutesStep`
     */
    getMinutesStep(): int;
    /**
     * Gets current value of property {@link #getSecondsStep secondsStep}.
     *
     * Sets the seconds slider step. If step is less than 1, it will be automatically converted back to 1. The
     * seconds slider is populated only by multiples of the step.
     *
     * Default value is `1`.
     *
     *
     * @returns Value of property `secondsStep`
     */
    getSecondsStep(): int;
    /**
     * Gets current value of property {@link #getSupport2400 support2400}.
     *
     * Allows to set a value of 24:00, used to indicate the end of the day. Works only with HH or H formats.
     * Don't use it together with am/pm.
     *
     * Default value is `false`.
     *
     * @since 1.54
     *
     * @returns Value of property `support2400`
     */
    getSupport2400(): boolean;
    /**
     * Gets the time values from the sliders, as a date object.
     *
     *
     * @returns A JavaScript date object
     */
    getTimeValues(): Date;
    /**
     * Gets current value of property {@link #getValue value}.
     *
     * Defines the value of the control.
     *
     *
     * @returns Value of property `value`
     */
    getValue(): string;
    /**
     * Gets current value of property {@link #getValueFormat valueFormat}.
     *
     * Determines the format of the `value` property.
     *
     *
     * @returns Value of property `valueFormat`
     */
    getValueFormat(): string;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Sets the width of the container. The minimum width is 320px.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Opens first slider.
     *
     *
     * @returns Pointer to the control instance to allow method chaining
     */
    openFirstSlider(): this;
    /**
     * Sets the time `displayFormat`.
     *
     *
     * @returns this instance, used for chaining
     */
    setDisplayFormat(
      /**
       * New display format
       */
      sFormat: string
    ): this;
    /**
     * Sets a new value for property {@link #getHeight height}.
     *
     * Sets the height of the container. If percentage value is used the parent container should have specified
     * height
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeight(
      /**
       * New value for property `height`
       */
      sHeight: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getLabelText labelText}.
     *
     * Defines the text of the picker label.
     *
     * It is read by screen readers. It is visible only on phone.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLabelText(
      /**
       * New value for property `labelText`
       */
      sLabelText: string
    ): this;
    /**
     * Sets the `localeId` property.
     *
     *
     * @returns this instance, used for chaining
     */
    setLocaleId(
      /**
       * The ID of the Locale
       */
      sLocaleId: string
    ): this;
    /**
     * Sets the minutes slider step.
     *
     *
     * @returns `this` to allow method chaining
     */
    setMinutesStep(
      /**
       * The step used to generate values for the minutes slider
       */
      value: int
    ): this;
    /**
     * Sets the seconds slider step.
     *
     *
     * @returns `this` to allow method chaining
     */
    setSecondsStep(
      /**
       * The step used to generate values for the seconds slider
       */
      value: int
    ): this;
    /**
     * Sets `support2400`.
     *
     *
     * @returns this instance, used for chaining
     */
    setSupport2400(bSupport2400: boolean): this;
    /**
     * Sets the value of the `TimepickerSliders` container.
     *
     *
     * @returns Pointer to the control instance to allow method chaining
     */
    setValue(
      /**
       * The value of the `TimepickerSliders`
       */
      sValue: string
    ): this;
    /**
     * Sets a new value for property {@link #getValueFormat valueFormat}.
     *
     * Determines the format of the `value` property.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValueFormat(
      /**
       * New value for property `valueFormat`
       */
      sValueFormat?: string
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Sets the width of the container. The minimum width is 320px.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth: CSSSize
    ): this;
  }
  /**
   * Describes the settings that can be provided to the TimePickerSliders constructor.
   */
  export interface $TimePickerSlidersSettings extends $ControlSettings {
    /**
     * Defines the locale used to parse string values representing time.
     *
     * Determines the locale, used to interpret the string, supplied by the `value` property.
     *
     * Example: AM in the string "09:04 AM" is locale (language) dependent. The format comes from the browser
     * language settings if not set explicitly. Used in combination with 12 hour `displayFormat` containing
     * 'a', which stands for day period string.
     */
    localeId?: string | PropertyBindingInfo;

    /**
     * Defines the time `displayFormat` of the sliders. The `displayFormat` comes from the browser language
     * settings if not set explicitly.
     */
    displayFormat?: string | PropertyBindingInfo;

    /**
     * Defines the text of the picker label.
     *
     * It is read by screen readers. It is visible only on phone.
     */
    labelText?: string | PropertyBindingInfo;

    /**
     * Sets the minutes slider step. If step is less than 1, it will be automatically converted back to 1. The
     * minutes slider is populated only by multiples of the step.
     */
    minutesStep?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the seconds slider step. If step is less than 1, it will be automatically converted back to 1. The
     * seconds slider is populated only by multiples of the step.
     */
    secondsStep?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the width of the container. The minimum width is 320px.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the height of the container. If percentage value is used the parent container should have specified
     * height
     */
    height?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the value of the control.
     */
    value?: string | PropertyBindingInfo;

    /**
     * Determines the format of the `value` property.
     */
    valueFormat?: string | PropertyBindingInfo;

    /**
     * Allows to set a value of 24:00, used to indicate the end of the day. Works only with HH or H formats.
     * Don't use it together with am/pm.
     *
     * @since 1.54
     */
    support2400?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Fired when the value is changed.
     */
    change?: (oEvent: TimePickerSliders$ChangeEvent) => void;
  }

  /**
   * Parameters of the TimePickerSliders#change event.
   */
  export interface TimePickerSliders$ChangeEventParameters {
    /**
     * The new `value` of the control.
     */
    value?: string;
  }

  /**
   * Event object of the TimePickerSliders#change event.
   */
  export type TimePickerSliders$ChangeEvent = Event<
    TimePickerSliders$ChangeEventParameters,
    TimePickerSliders
  >;
}

declare module "sap/m/Title" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IShrinkable,
    AccessibilityInfo,
    ITitleContent,
    TitleLevel,
    TextAlign,
    TextDirection,
    ID,
    CSSSize,
  } from "sap/ui/core/library";

  import { IToolbarInteractiveControl, WrappingType } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Title1 from "sap/ui/core/Title";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * A simple, large-sized text with explicit header / title semantics.
   *
   * Overview: The `Title` control is a simple, large-sized text containing additional semantic information
   * for accessibility purposes.
   *
   * As of version 1.52, you can truncate or wrap long titles if the screen is narrower than the full title
   * by using the with the use of the `wrapping` property.
   *
   * As of version 1.60, you can hyphenate the label's text with the use of the `wrappingType` property. For
   * more information, see {@link https://ui5.sap.com/#/topic/6322164936f047de941ec522b95d7b70 Text Controls Hyphenation}.
   *
   * As of version 1.87, you can set the `content` aggregation to use `sap.m.Link` or any control that implements
   * `sap.ui.core.ITitleContent` interface. This control will be rendered instead of the text placed in `text`
   * property. In this case the following properties of `sap.m.Title` control are overridden: `text`, `textAlign`,
   * `textDirection`, or not used: `wrapping`, `wrappingType`. The `title` association will be ignored too.
   *
   * If the `title` association is used, `text`, `level` and `tooltip` properties will override the corresponding
   * properties of the `sap.m.Title` control.
   *
   * Usage: When to use:
   * 	 - If you want to set the title above a table or form.
   * 	 - If you want to show text in the page header.  When not to use:
   * 	 - If the text is inside a text block.
   * 	 - If The text is inside a form element.
   *
   * @since 1.27.0
   */
  export default class Title
    extends Control
    implements IShrinkable, IToolbarInteractiveControl
  {
    __implements__sap_ui_core_IShrinkable: boolean;
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new Title control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/title/ Title}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $TitleSettings
    );
    /**
     * Constructor for a new Title control.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/title/ Title}
     */
    constructor(
      /**
       * Id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $TitleSettings
    );

    /**
     * Creates a new subclass of class sap.m.Title with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Title>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Title.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Destroys the content in the aggregation {@link #getContent content}.
     *
     * @since 1.87
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Gets the accessibility information for the `sap.m.Title` control.
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The accessibility info
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * Holds a control that implements `sap.ui.core.ITitleContent` and renders this control instead of simple
     * text
     *
     * **Note:** if a control is placed in this aggregation, the following properties of `sap.m.Title` will
     * be overridden - `text`, `textAlign`, `textDirection`; the following will be ignored - `wrapping`, `wrappingType`.
     * The `title` association will be ignored too.
     *
     * @since 1.87
     */
    getContent(): ITitleContent;
    /**
     * Gets current value of property {@link #getLevel level}.
     *
     * Defines the semantic level of the title. This information is e.g. used by assistive technologies like
     * screenreaders to create a hierarchical site map for faster navigation. Depending on this setting either
     * an HTML h1-h6 element is used or when using level `Auto` no explicit level information is written (HTML5
     * header element). This property does not influence the style of the control. Use the property `titleStyle`
     * for this purpose instead.
     *
     * **Note:** this property will be overridden if there is title element associated and it has `level` property
     * set.
     *
     * Default value is `Auto`.
     *
     *
     * @returns Value of property `level`
     */
    getLevel(): TitleLevel;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Defines the text that should be displayed as a title.
     *
     * **Note:** this property is not used if there is a control added to the `content` aggregation **Note:**
     * this property will be overridden if there is title element associated and it has `text` property set.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getTextAlign textAlign}.
     *
     * Defines the alignment of the text within the title. **Note:** This property only has an effect if the
     * overall width of the title control is larger than the displayed text.
     *
     * **Note:** this property will be overridden if there is a control added to the `content` aggregation
     *
     * Default value is `Initial`.
     *
     *
     * @returns Value of property `textAlign`
     */
    getTextAlign(): TextAlign;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * Options for the text direction are RTL and LTR. Alternatively, the control can inherit the text direction
     * from its parent container.
     *
     * **Note:** this property will be overridden if there is a control added to the `content` aggregation
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * ID of the element which is the current target of the association {@link #getTitle title}, or `null`.
     */
    getTitle(): ID | null;
    /**
     * Gets current value of property {@link #getTitleStyle titleStyle}.
     *
     * Defines the style of the title. When using the `Auto` styling, the appearance of the title depends on
     * the current position of the title (e.g. inside a `Toolbar`). This default behavior can be overridden
     * by setting a different style explicitly. The actual appearance of the title and the different styles
     * always depends on the theme being used.
     *
     * Default value is `Auto`.
     *
     *
     * @returns Value of property `titleStyle`
     */
    getTitleStyle(): TitleLevel;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Defines the width of the title.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getWrapping wrapping}.
     *
     * Enables text wrapping.
     *
     * **Note:** Wrapping must only be activated if the surrounding container allows flexible heights. **Note:**
     * this property will be ignored if there is a control added to the `content` aggregation
     *
     * Default value is `false`.
     *
     * @since 1.52
     *
     * @returns Value of property `wrapping`
     */
    getWrapping(): boolean;
    /**
     * Gets current value of property {@link #getWrappingType wrappingType}.
     *
     * Defines the type of text wrapping to be used (hyphenated or normal).
     *
     * **Note:** This property takes effect only when the `wrapping` property is set to `true`. **Note:** this
     * property will be ignored if there is a control added to the `content` aggregation
     *
     * Default value is `Normal`.
     *
     * @since 1.60
     *
     * @returns Value of property `wrappingType`
     */
    getWrappingType(): WrappingType;
    /**
     * Sets the aggregated {@link #getContent content}.
     *
     * @since 1.87
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContent(
      /**
       * The content to set
       */
      oContent: ITitleContent
    ): this;
    /**
     * Sets a new value for property {@link #getLevel level}.
     *
     * Defines the semantic level of the title. This information is e.g. used by assistive technologies like
     * screenreaders to create a hierarchical site map for faster navigation. Depending on this setting either
     * an HTML h1-h6 element is used or when using level `Auto` no explicit level information is written (HTML5
     * header element). This property does not influence the style of the control. Use the property `titleStyle`
     * for this purpose instead.
     *
     * **Note:** this property will be overridden if there is title element associated and it has `level` property
     * set.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLevel(
      /**
       * New value for property `level`
       */
      sLevel?: TitleLevel | keyof typeof TitleLevel
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Defines the text that should be displayed as a title.
     *
     * **Note:** this property is not used if there is a control added to the `content` aggregation **Note:**
     * this property will be overridden if there is title element associated and it has `text` property set.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTextAlign textAlign}.
     *
     * Defines the alignment of the text within the title. **Note:** This property only has an effect if the
     * overall width of the title control is larger than the displayed text.
     *
     * **Note:** this property will be overridden if there is a control added to the `content` aggregation
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Initial`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextAlign(
      /**
       * New value for property `textAlign`
       */
      sTextAlign?: TextAlign | keyof typeof TextAlign
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * Options for the text direction are RTL and LTR. Alternatively, the control can inherit the text direction
     * from its parent container.
     *
     * **Note:** this property will be overridden if there is a control added to the `content` aggregation
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
    /**
     * Sets the title for a `sap.m.Title` or `sap.ui.core.Title`
     *
     *
     * @returns this Title reference for chaining.
     */
    setTitle(
      /**
       * Given variant of a title which can be `sap.m.Title` or `sap.ui.core.Title`.
       */
      vTitle: Title | Title1
    ): this;
    /**
     * Sets a new value for property {@link #getTitleStyle titleStyle}.
     *
     * Defines the style of the title. When using the `Auto` styling, the appearance of the title depends on
     * the current position of the title (e.g. inside a `Toolbar`). This default behavior can be overridden
     * by setting a different style explicitly. The actual appearance of the title and the different styles
     * always depends on the theme being used.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleStyle(
      /**
       * New value for property `titleStyle`
       */
      sTitleStyle?: TitleLevel | keyof typeof TitleLevel
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Defines the width of the title.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getWrapping wrapping}.
     *
     * Enables text wrapping.
     *
     * **Note:** Wrapping must only be activated if the surrounding container allows flexible heights. **Note:**
     * this property will be ignored if there is a control added to the `content` aggregation
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.52
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWrapping(
      /**
       * New value for property `wrapping`
       */
      bWrapping?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getWrappingType wrappingType}.
     *
     * Defines the type of text wrapping to be used (hyphenated or normal).
     *
     * **Note:** This property takes effect only when the `wrapping` property is set to `true`. **Note:** this
     * property will be ignored if there is a control added to the `content` aggregation
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Normal`.
     *
     * @since 1.60
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWrappingType(
      /**
       * New value for property `wrappingType`
       */
      sWrappingType?: WrappingType | keyof typeof WrappingType
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Title constructor.
   */
  export interface $TitleSettings extends $ControlSettings {
    /**
     * Defines the text that should be displayed as a title.
     *
     * **Note:** this property is not used if there is a control added to the `content` aggregation **Note:**
     * this property will be overridden if there is title element associated and it has `text` property set.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Defines the semantic level of the title. This information is e.g. used by assistive technologies like
     * screenreaders to create a hierarchical site map for faster navigation. Depending on this setting either
     * an HTML h1-h6 element is used or when using level `Auto` no explicit level information is written (HTML5
     * header element). This property does not influence the style of the control. Use the property `titleStyle`
     * for this purpose instead.
     *
     * **Note:** this property will be overridden if there is title element associated and it has `level` property
     * set.
     */
    level?:
      | (TitleLevel | keyof typeof TitleLevel)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the style of the title. When using the `Auto` styling, the appearance of the title depends on
     * the current position of the title (e.g. inside a `Toolbar`). This default behavior can be overridden
     * by setting a different style explicitly. The actual appearance of the title and the different styles
     * always depends on the theme being used.
     */
    titleStyle?:
      | (TitleLevel | keyof typeof TitleLevel)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the width of the title.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the alignment of the text within the title. **Note:** This property only has an effect if the
     * overall width of the title control is larger than the displayed text.
     *
     * **Note:** this property will be overridden if there is a control added to the `content` aggregation
     */
    textAlign?:
      | (TextAlign | keyof typeof TextAlign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Options for the text direction are RTL and LTR. Alternatively, the control can inherit the text direction
     * from its parent container.
     *
     * **Note:** this property will be overridden if there is a control added to the `content` aggregation
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Enables text wrapping.
     *
     * **Note:** Wrapping must only be activated if the surrounding container allows flexible heights. **Note:**
     * this property will be ignored if there is a control added to the `content` aggregation
     *
     * @since 1.52
     */
    wrapping?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the type of text wrapping to be used (hyphenated or normal).
     *
     * **Note:** This property takes effect only when the `wrapping` property is set to `true`. **Note:** this
     * property will be ignored if there is a control added to the `content` aggregation
     *
     * @since 1.60
     */
    wrappingType?:
      | (WrappingType | keyof typeof WrappingType)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Holds a control that implements `sap.ui.core.ITitleContent` and renders this control instead of simple
     * text
     *
     * **Note:** if a control is placed in this aggregation, the following properties of `sap.m.Title` will
     * be overridden - `text`, `textAlign`, `textDirection`; the following will be ignored - `wrapping`, `wrappingType`.
     * The `title` association will be ignored too.
     *
     * @since 1.87
     */
    content?: ITitleContent;

    /**
     * Defines a relationship to a generic title description.
     *
     * **Note:** if a control is placed in `content` aggregation, the title element associated will be ignored;
     * otherwise the properties `text`, `level` and tooltip (text only) of this element will override
     * the corresponding properties of the `Title` control.
     */
    title?: Title1 | string;
  }
}

declare module "sap/m/ToggleButton" {
  import {
    default as Button,
    $ButtonSettings,
    Button$PressEventParameters,
  } from "sap/m/Button";

  import { IToolbarInteractiveControl } from "sap/m/library";

  import { AccessibilityInfo } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * An enhanced {@link sap.m.Button} that can be toggled between pressed and normal state.
   *
   * Clicking or tapping a `ToggleButton` changes its state to `pressed`. The button returns to its initial
   * state when the user clicks or taps it again.
   */
  export default class ToggleButton
    extends Button
    implements IToolbarInteractiveControl
  {
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new `ToggleButton`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/button/ Toggle Button}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ToggleButtonSettings
    );
    /**
     * Constructor for a new `ToggleButton`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/button/ Toggle Button}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ToggleButtonSettings
    );

    /**
     * Creates a new subclass of class sap.m.ToggleButton with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.Button.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ToggleButton>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ToggleButton.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.ToggleButton`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ToggleButton` itself.
     *
     * Fired when the user clicks or taps on the control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ToggleButton$PressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ToggleButton` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.ToggleButton`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.ToggleButton` itself.
     *
     * Fired when the user clicks or taps on the control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: ToggleButton$PressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.ToggleButton` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.ToggleButton`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: ToggleButton$PressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: ToggleButton$PressEventParameters
    ): this;
    /**
     * See:
     * 	sap.ui.core.Control#getAccessibilityInfo
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Current accessibility state of the control.
     */
    getAccessibilityInfo(): AccessibilityInfo;
    /**
     * Gets current value of property {@link #getPressed pressed}.
     *
     * The property is “true” when the control is toggled. The default state of this property is "false".
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `pressed`
     */
    getPressed(): boolean;
    /**
     * Sets a new value for property {@link #getPressed pressed}.
     *
     * The property is “true” when the control is toggled. The default state of this property is "false".
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPressed(
      /**
       * New value for property `pressed`
       */
      bPressed?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ToggleButton constructor.
   */
  export interface $ToggleButtonSettings extends $ButtonSettings {
    /**
     * The property is “true” when the control is toggled. The default state of this property is "false".
     */
    pressed?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Fired when the user clicks or taps on the control.
     */
    press?: (oEvent: ToggleButton$PressEvent) => void;
  }

  /**
   * Parameters of the ToggleButton#press event.
   */
  export interface ToggleButton$PressEventParameters
    extends Button$PressEventParameters {
    /**
     * The current pressed state of the control.
     */
    pressed?: boolean;
  }

  /**
   * Event object of the ToggleButton#press event.
   */
  export type ToggleButton$PressEvent = Event<
    ToggleButton$PressEventParameters,
    ToggleButton
  >;
}

declare module "sap/m/Token" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { ID, TextDirection } from "sap/ui/core/library";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Overview: Tokens are small items of information (similar to tags) that mainly serve to visualize previously
   * selected items. Tokens are manipulated by a {@link sap.m.Tokenizer Tokenizer}. Structure: The tokens
   * store single text items or sometimes key-value pairs, such as "John Miller (ID1234567)". Each token also
   * contains a delete icon, which is invisible if the token is in edit mode.
   *
   * Usage: When to use:: Tokens can only be used with the Tokenizer as a container.
   */
  export default class Token extends Control {
    /**
     * Constructor for a new Token.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/token/ Token}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $TokenSettings
    );
    /**
     * Constructor for a new Token.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/token/ Token}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $TokenSettings
    );

    /**
     * Creates a new subclass of class sap.m.Token with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Token>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Token.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:delete delete} event of this `sap.m.Token`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Token` itself.
     *
     * This event is fired if the user clicks the token's delete icon.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDelete(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Token` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:delete delete} event of this `sap.m.Token`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Token` itself.
     *
     * This event is fired if the user clicks the token's delete icon.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDelete(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Token` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:deselect deselect} event of this `sap.m.Token`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Token` itself.
     *
     * This event is fired when the token gets deselected.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDeselect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Token` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:deselect deselect} event of this `sap.m.Token`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Token` itself.
     *
     * This event is fired when the token gets deselected.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDeselect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Token` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.Token`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Token` itself.
     *
     * This event is fired when the user clicks on the token.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Token` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.Token`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Token` itself.
     *
     * This event is fired when the user clicks on the token.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Token` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:select select} event of this `sap.m.Token`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Token` itself.
     *
     * This event is fired when the token gets selected.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Token` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:select select} event of this `sap.m.Token`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Token` itself.
     *
     * This event is fired when the token gets selected.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Token` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:delete delete} event of this `sap.m.Token`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachDelete(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:deselect deselect} event of this `sap.m.Token`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachDeselect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.Token`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:select select} event of this `sap.m.Token`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:delete delete} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireDelete(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:deselect deselect} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireDeselect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:select select} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getEditable editable}.
     *
     * Indicates the editable status of the token. If it is set to `true`, token displays a delete icon.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `editable`
     */
    getEditable(): boolean;
    /**
     * Gets current value of property {@link #getKey key}.
     *
     * Key of the token.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `key`
     */
    getKey(): string;
    /**
     * Gets current value of property {@link #getSelected selected}.
     *
     * Indicates the current selection status of the token.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `selected`
     */
    getSelected(): boolean;
    /**
     * Gets current value of property {@link #getText text}.
     *
     * Displayed text of the token.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `text`
     */
    getText(): string;
    /**
     * Gets current value of property {@link #getTextDirection textDirection}.
     *
     * This property specifies the text directionality with enumerated options. By default, the control inherits
     * text direction from the DOM.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Value of property `textDirection`
     */
    getTextDirection(): TextDirection;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Sets a new value for property {@link #getEditable editable}.
     *
     * Indicates the editable status of the token. If it is set to `true`, token displays a delete icon.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEditable(
      /**
       * New value for property `editable`
       */
      bEditable?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getKey key}.
     *
     * Key of the token.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setKey(
      /**
       * New value for property `key`
       */
      sKey?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSelected selected}.
     *
     * Indicates the current selection status of the token.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSelected(
      /**
       * New value for property `selected`
       */
      bSelected?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getText text}.
     *
     * Displayed text of the token.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setText(
      /**
       * New value for property `text`
       */
      sText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getTextDirection textDirection}.
     *
     * This property specifies the text directionality with enumerated options. By default, the control inherits
     * text direction from the DOM.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Inherit`.
     *
     * @since 1.28.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTextDirection(
      /**
       * New value for property `textDirection`
       */
      sTextDirection?: TextDirection | keyof typeof TextDirection
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Token constructor.
   */
  export interface $TokenSettings extends $ControlSettings {
    /**
     * Indicates the current selection status of the token.
     */
    selected?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Key of the token.
     */
    key?: string | PropertyBindingInfo;

    /**
     * Displayed text of the token.
     */
    text?: string | PropertyBindingInfo;

    /**
     * Indicates the editable status of the token. If it is set to `true`, token displays a delete icon.
     */
    editable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This property specifies the text directionality with enumerated options. By default, the control inherits
     * text direction from the DOM.
     *
     * @since 1.28.0
     */
    textDirection?:
      | (TextDirection | keyof typeof TextDirection)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Association to controls / IDs which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Association to controls / IDs which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * This event is fired if the user clicks the token's delete icon.
     */
    delete?: (oEvent: Event) => void;

    /**
     * This event is fired when the user clicks on the token.
     */
    press?: (oEvent: Event) => void;

    /**
     * This event is fired when the token gets selected.
     */
    select?: (oEvent: Event) => void;

    /**
     * This event is fired when the token gets deselected.
     */
    deselect?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the Token#delete event.
   */
  export interface Token$DeleteEventParameters {}

  /**
   * Event object of the Token#delete event.
   */
  export type Token$DeleteEvent = Event<Token$DeleteEventParameters, Token>;

  /**
   * Parameters of the Token#deselect event.
   */
  export interface Token$DeselectEventParameters {}

  /**
   * Event object of the Token#deselect event.
   */
  export type Token$DeselectEvent = Event<Token$DeselectEventParameters, Token>;

  /**
   * Parameters of the Token#press event.
   */
  export interface Token$PressEventParameters {}

  /**
   * Event object of the Token#press event.
   */
  export type Token$PressEvent = Event<Token$PressEventParameters, Token>;

  /**
   * Parameters of the Token#select event.
   */
  export interface Token$SelectEventParameters {}

  /**
   * Event object of the Token#select event.
   */
  export type Token$SelectEvent = Event<Token$SelectEventParameters, Token>;
}

declare module "sap/m/Tokenizer" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { ID, CSSSize } from "sap/ui/core/library";

  import Token from "sap/m/Token";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import ScrollEnablement from "sap/ui/core/delegate/ScrollEnablement";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * Overview: A Тokenizer is a container for {@link sap.m.Token Tokens}. The tokenizer supports keyboard
   * navigation and token selection. It also handles all actions associated with the tokens like adding, deleting,
   * selecting and editing. Structure: The tokenizer consists of two parts: - Tokens - displays the available
   * tokens. - N-more indicator - contains the number of the remaining tokens that cannot be displayed due
   * to the limited space. The tokens are stored in the `tokens` aggregation. The tokenizer can determine,
   * by setting the `editable` property, whether the tokens in it are editable. Still the Token itself can
   * determine if it is `editable`. This allows you to have non-editable Tokens in an editable Tokenizer.
   *
   * @since 1.22
   */
  export default class Tokenizer extends Control {
    /**
     * Constructor for a new Tokenizer.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/token/ Tokenizer}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $TokenizerSettings
    );
    /**
     * Constructor for a new Tokenizer.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/token/ Tokenizer}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $TokenizerSettings
    );

    /**
     * Creates a new subclass of class sap.m.Tokenizer with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Tokenizer>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Tokenizer.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some ariaDescribedBy into the association {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaDescribedBy(
      /**
       * The ariaDescribedBy to add; if empty, nothing is inserted
       */
      vAriaDescribedBy: ID | Control
    ): this;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds some token to the aggregation {@link #getTokens tokens}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addToken(
      /**
       * The token to add; if empty, nothing is inserted
       */
      oToken: Token
    ): this;
    /**
     * Function validates the given text and adds a new token if validation was successful.
     *
     * @deprecated As of version 1.81. replaced by {@link MultiInput.prototype.addValidator}
     */
    addValidateToken(
      /**
       * Parameter bag containing the following fields:
       */
      oParameters: {
        /**
         * The source text {sap.m.Token}
         */
        text: string;
        /**
         * Suggested token
         */
        token?: object;
        /**
         * Any object used to find the suggested token
         */
        suggestionObject?: object;
        /**
         * Callback which gets called after validation has finished
         */
        validationCallback?: Function;
      }
    ): void;
    /**
     * Function adds a validation callback called before any new token gets added to the tokens aggregation.
     *
     * @deprecated As of version 1.81. replaced by {@link MultiInput.prototype.addValidator}
     */
    addValidator(
      /**
       * The validation function
       */
      fValidator: Function
    ): void;
    /**
     * Function to execute after the n-more popover is closed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    afterPopupClose(): void;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:renderModeChange renderModeChange} event of
     * this `sap.m.Tokenizer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Tokenizer` itself.
     *
     * Fired when the render mode of the Tokenizer changes between `Narrow` (collapsed) and `Loose` (expanded).
     *
     * @since 1.133
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachRenderModeChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Tokenizer$RenderModeChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Tokenizer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:renderModeChange renderModeChange} event of
     * this `sap.m.Tokenizer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Tokenizer` itself.
     *
     * Fired when the render mode of the Tokenizer changes between `Narrow` (collapsed) and `Loose` (expanded).
     *
     * @since 1.133
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachRenderModeChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Tokenizer$RenderModeChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Tokenizer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tokenChange tokenChange} event of this `sap.m.Tokenizer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Tokenizer` itself.
     *
     * Fired when the tokens aggregation changed (add / remove token)
     *
     * @deprecated As of version 1.82. replaced by `tokenDelete` event.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTokenChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Tokenizer$TokenChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Tokenizer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tokenChange tokenChange} event of this `sap.m.Tokenizer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Tokenizer` itself.
     *
     * Fired when the tokens aggregation changed (add / remove token)
     *
     * @deprecated As of version 1.82. replaced by `tokenDelete` event.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTokenChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Tokenizer$TokenChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Tokenizer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tokenDelete tokenDelete} event of this `sap.m.Tokenizer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Tokenizer` itself.
     *
     * Fired when a token is deleted by clicking icon, pressing backspace or delete button.  Once the
     * event is fired, application is responsible for removing / destroying the token from the aggregation.
     *
     * @since 1.82
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTokenDelete(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Tokenizer$TokenDeleteEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Tokenizer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tokenDelete tokenDelete} event of this `sap.m.Tokenizer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Tokenizer` itself.
     *
     * Fired when a token is deleted by clicking icon, pressing backspace or delete button.  Once the
     * event is fired, application is responsible for removing / destroying the token from the aggregation.
     *
     * @since 1.82
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTokenDelete(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Tokenizer$TokenDeleteEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Tokenizer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tokenUpdate tokenUpdate} event of this `sap.m.Tokenizer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Tokenizer` itself.
     *
     * Fired when the tokens aggregation changed due to a user interaction (add / remove token)
     *
     * @since 1.46
     * @deprecated As of version 1.82. replaced by `tokenDelete` event.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTokenUpdate(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Tokenizer$TokenUpdateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Tokenizer` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:tokenUpdate tokenUpdate} event of this `sap.m.Tokenizer`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Tokenizer` itself.
     *
     * Fired when the tokens aggregation changed due to a user interaction (add / remove token)
     *
     * @since 1.46
     * @deprecated As of version 1.82. replaced by `tokenDelete` event.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTokenUpdate(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Tokenizer$TokenUpdateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Tokenizer` itself
       */
      oListener?: object
    ): this;
    /**
     * Checks whether the Tokenizer or one of its internal DOM elements has the focus.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The control that has the focus
     */
    checkFocus(): object;
    /**
     * Destroys all the tokens in the aggregation {@link #getTokens tokens}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyTokens(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:renderModeChange renderModeChange} event of
     * this `sap.m.Tokenizer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.133
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachRenderModeChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Tokenizer$RenderModeChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:tokenChange tokenChange} event of this `sap.m.Tokenizer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @deprecated As of version 1.82. replaced by `tokenDelete` event.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachTokenChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Tokenizer$TokenChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:tokenDelete tokenDelete} event of this `sap.m.Tokenizer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.82
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachTokenDelete(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Tokenizer$TokenDeleteEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:tokenUpdate tokenUpdate} event of this `sap.m.Tokenizer`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.46
     * @deprecated As of version 1.82. replaced by `tokenDelete` event.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachTokenUpdate(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Tokenizer$TokenUpdateEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:renderModeChange renderModeChange} to attached listeners.
     *
     * @since 1.133
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireRenderModeChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Tokenizer$RenderModeChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:tokenChange tokenChange} to attached listeners.
     *
     * @deprecated As of version 1.82. replaced by `tokenDelete` event.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireTokenChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Tokenizer$TokenChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:tokenDelete tokenDelete} to attached listeners.
     *
     * @since 1.82
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireTokenDelete(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Tokenizer$TokenDeleteEventParameters
    ): this;
    /**
     * Fires event {@link #event:tokenUpdate tokenUpdate} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @since 1.46
     * @deprecated As of version 1.82. replaced by `tokenDelete` event.
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireTokenUpdate(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Tokenizer$TokenUpdateEventParameters
    ): boolean;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaDescribedBy ariaDescribedBy}.
     */
    getAriaDescribedBy(): ID[];
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets current value of property {@link #getEditable editable}.
     *
     * true if tokens shall be editable otherwise false
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `editable`
     */
    getEditable(): boolean;
    /**
     * Flag indicating if tabindex attribute should be rendered
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns True if tabindex should be rendered and false if not
     */
    getEffectiveTabIndex(): boolean;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Defines if the Tokenizer is enabled
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets the count of hidden tokens that will be used for the n-More indicator. If the count is 0, there
     * is no n-More indicator shown.
     *
     * @since 1.80
     *
     * @returns The number of hidden tokens
     */
    getHiddenTokensCount(): number;
    /**
     * Gets current value of property {@link #getMaxWidth maxWidth}.
     *
     * Defines the maximum width of the Tokenizer.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Value of property `maxWidth`
     */
    getMaxWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getRenderMode renderMode}.
     *
     * Defines the mode that the Tokenizer will use:
     * 	 - `sap.m.TokenizerRenderMode.Loose` mode shows all tokens, no matter the width of the Tokenizer
     * 	 - `sap.m.TokenizerRenderMode.Narrow` mode forces the Tokenizer to show only as much tokens as possible
     *     in its width and add an n-More indicator
     *
     * **Note**: Have in mind that the `renderMode` property is used internally by the Tokenizer and controls
     * that use the Tokenizer. Therefore, modifying this property may alter the expected behavior of the control.
     *
     * Default value is `RenderMode.Narrow`.
     *
     *
     * @returns Value of property `renderMode`
     */
    getRenderMode(): string;
    /**
     * Function returns the internally used scroll delegate.
     *
     *
     * @returns The scroll delegate
     */
    getScrollDelegate(): ScrollEnablement;
    /**
     * Function returns the tokens' width.
     *
     *
     * @returns The complete width of all tokens
     */
    getScrollWidth(): number;
    /**
     * Function returns all currently selected tokens.
     *
     *
     * @returns Array of selected tokens or empty array
     */
    getSelectedTokens(): Token[];
    /**
     * Gets content of aggregation {@link #getTokens tokens}.
     *
     * the currently displayed tokens
     */
    getTokens(): Token[];
    /**
     * Gets the accessibility text aggregation id.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Returns the InvisibleText control id
     */
    getTokensInfoId(): string;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Defines the width of the Tokenizer.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Checks if the token is one and truncated.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    hasOneTruncatedToken(): boolean;
    /**
     * Checks for the provided `sap.m.Token` in the aggregation {@link #getTokens tokens}. and returns its index
     * if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfToken(
      /**
       * The token whose index is looked for
       */
      oToken: Token
    ): int;
    /**
     * Inserts a token into the aggregation {@link #getTokens tokens}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertToken(
      /**
       * The token to insert; if empty, nothing is inserted
       */
      oToken: Token,
      /**
       * The `0`-based index the token should be inserted at; for a negative value of `iIndex`, the token is inserted
       * at position 0; for a value greater than the current size of the aggregation, the token is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Handle the focus event on the control.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    onclick(
      /**
       * The occuring event
       */
      oEvent: jQuery.Event
    ): void;
    /**
     * Removes all the controls in the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaDescribedBy(): ID[];
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all the controls from the aggregation {@link #getTokens tokens}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllTokens(): Token[];
    /**
     * Function removes all validation callbacks
     *
     * @deprecated As of version 1.81. replaced by {@link MultiInput.prototype.addValidator}
     */
    removeAllValidators(): void;
    /**
     * Removes an ariaDescribedBy from the association named {@link #getAriaDescribedBy ariaDescribedBy}.
     *
     *
     * @returns The removed ariaDescribedBy or `null`
     */
    removeAriaDescribedBy(
      /**
       * The ariaDescribedBy to be removed or its index or ID
       */
      vAriaDescribedBy: int | ID | Control
    ): ID | null;
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes a token from the aggregation {@link #getTokens tokens}.
     *
     *
     * @returns The removed token or `null`
     */
    removeToken(
      /**
       * The token to remove or its index or id
       */
      vToken: int | string | Token
    ): Token | null;
    /**
     * Function removes a validation callback.
     *
     * @deprecated As of version 1.81. replaced by {@link MultiInput.prototype.addValidator}
     */
    removeValidator(
      /**
       * The validation function
       */
      fValidator: Function
    ): void;
    /**
     * Function scrolls the tokens to the end.
     */
    scrollToEnd(): void;
    /**
     * Function scrolls the tokens to the start.
     */
    scrollToStart(): void;
    /**
     * Function selects all tokens.
     *
     *
     * @returns this instance for method chaining
     */
    selectAllTokens(
      /**
       * [optional] true for selecting, false for deselecting
       */
      bSelect: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEditable editable}.
     *
     * true if tokens shall be editable otherwise false
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEditable(
      /**
       * New value for property `editable`
       */
      bEditable?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Defines if the Tokenizer is enabled
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets the first token truncation.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns `this` instance for method chaining
     */
    setFirstTokenTruncated(
      /**
       * The value to set
       */
      bValue: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getMaxWidth maxWidth}.
     *
     * Defines the maximum width of the Tokenizer.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxWidth(
      /**
       * New value for property `maxWidth`
       */
      sMaxWidth?: CSSSize
    ): this;
    /**
     * Function sets the tokenizer's width in pixels.
     */
    setPixelWidth(
      /**
       * The new width in pixels
       */
      nWidth: number
    ): void;
    /**
     * Sets a new value for property {@link #getRenderMode renderMode}.
     *
     * Defines the mode that the Tokenizer will use:
     * 	 - `sap.m.TokenizerRenderMode.Loose` mode shows all tokens, no matter the width of the Tokenizer
     * 	 - `sap.m.TokenizerRenderMode.Narrow` mode forces the Tokenizer to show only as much tokens as possible
     *     in its width and add an n-More indicator
     *
     * **Note**: Have in mind that the `renderMode` property is used internally by the Tokenizer and controls
     * that use the Tokenizer. Therefore, modifying this property may alter the expected behavior of the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `RenderMode.Narrow`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRenderMode(
      /**
       * New value for property `renderMode`
       */
      sRenderMode?: string
    ): this;
    /**
     * Method for handling the state for tabindex rendering
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     */
    setShouldRenderTabIndex(
      /**
       * If tabindex should be rendered
       */
      bShouldRenderTabIndex: boolean
    ): void;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Defines the width of the Tokenizer.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Tokenizer constructor.
   */
  export interface $TokenizerSettings extends $ControlSettings {
    /**
     * true if tokens shall be editable otherwise false
     */
    editable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines if the Tokenizer is enabled
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the width of the Tokenizer.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the maximum width of the Tokenizer.
     */
    maxWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the mode that the Tokenizer will use:
     * 	 - `sap.m.TokenizerRenderMode.Loose` mode shows all tokens, no matter the width of the Tokenizer
     * 	 - `sap.m.TokenizerRenderMode.Narrow` mode forces the Tokenizer to show only as much tokens as possible
     *     in its width and add an n-More indicator
     *
     * **Note**: Have in mind that the `renderMode` property is used internally by the Tokenizer and controls
     * that use the Tokenizer. Therefore, modifying this property may alter the expected behavior of the control.
     */
    renderMode?: string | PropertyBindingInfo;

    /**
     * the currently displayed tokens
     */
    tokens?: Token[] | Token | AggregationBindingInfo | `{${string}}`;

    /**
     * Association to controls / ids which describe this control (see WAI-ARIA attribute aria-describedby).
     */
    ariaDescribedBy?: Array<Control | string>;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Fired when the tokens aggregation changed (add / remove token)
     *
     * @deprecated As of version 1.82. replaced by `tokenDelete` event.
     */
    tokenChange?: (oEvent: Tokenizer$TokenChangeEvent) => void;

    /**
     * Fired when the tokens aggregation changed due to a user interaction (add / remove token)
     *
     * @since 1.46
     * @deprecated As of version 1.82. replaced by `tokenDelete` event.
     */
    tokenUpdate?: (oEvent: Tokenizer$TokenUpdateEvent) => void;

    /**
     * Fired when a token is deleted by clicking icon, pressing backspace or delete button.  Once the
     * event is fired, application is responsible for removing / destroying the token from the aggregation.
     *
     * @since 1.82
     */
    tokenDelete?: (oEvent: Tokenizer$TokenDeleteEvent) => void;

    /**
     * Fired when the render mode of the Tokenizer changes between `Narrow` (collapsed) and `Loose` (expanded).
     *
     * @since 1.133
     */
    renderModeChange?: (oEvent: Tokenizer$RenderModeChangeEvent) => void;
  }

  /**
   * Parameters of the Tokenizer#renderModeChange event.
   */
  export interface Tokenizer$RenderModeChangeEventParameters {
    /**
     * The render mode of the Tokenizer.
     */
    renderMode?: string;
  }

  /**
   * Event object of the Tokenizer#renderModeChange event.
   */
  export type Tokenizer$RenderModeChangeEvent = Event<
    Tokenizer$RenderModeChangeEventParameters,
    Tokenizer
  >;

  /**
   * Parameters of the Tokenizer#tokenChange event.
   *
   * @deprecated As of version 1.82. replaced by `tokenDelete` event.
   */
  export interface Tokenizer$TokenChangeEventParameters {
    /**
     * type of tokenChange event. There are four TokenChange types: "added", "removed", "removedAll", "tokensChanged".
     * Use sap.m.Tokenizer.TokenChangeType.Added for "added", sap.m.Tokenizer.TokenChangeType.Removed for "removed",
     * sap.m.Tokenizer.TokenChangeType.RemovedAll for "removedAll" and sap.m.Tokenizer.TokenChangeType.TokensChanged
     * for "tokensChanged".
     */
    type?: string;

    /**
     * the added token or removed token. This parameter is used when tokenChange type is "added" or "removed".
     */
    token?: Token;

    /**
     * the array of removed tokens. This parameter is used when tokenChange type is "removedAll".
     */
    tokens?: Token[];

    /**
     * the array of tokens that are added. This parameter is used when tokenChange type is "tokenChanged".
     */
    addedTokens?: Token[];

    /**
     * the array of tokens that are removed. This parameter is used when tokenChange type is "tokenChanged".
     */
    removedTokens?: Token[];
  }

  /**
   * Event object of the Tokenizer#tokenChange event.
   *
   * @deprecated As of version 1.82. replaced by `tokenDelete` event.
   */
  export type Tokenizer$TokenChangeEvent = Event<
    Tokenizer$TokenChangeEventParameters,
    Tokenizer
  >;

  /**
   * Parameters of the Tokenizer#tokenDelete event.
   */
  export interface Tokenizer$TokenDeleteEventParameters {
    /**
     * The array of tokens that are removed.
     */
    tokens?: Token[];

    /**
     * Keycode of the key pressed for deletion (backspace or delete).
     */
    keyCode?: number;
  }

  /**
   * Event object of the Tokenizer#tokenDelete event.
   */
  export type Tokenizer$TokenDeleteEvent = Event<
    Tokenizer$TokenDeleteEventParameters,
    Tokenizer
  >;

  /**
   * Parameters of the Tokenizer#tokenUpdate event.
   *
   * @deprecated As of version 1.82. replaced by `tokenDelete` event.
   */
  export interface Tokenizer$TokenUpdateEventParameters {
    /**
     * Type of tokenChange event. There are two TokenUpdate types: "added", "removed" Use sap.m.Tokenizer.TokenUpdateType.Added
     * for "added" and sap.m.Tokenizer.TokenUpdateType.Removed for "removed".
     */
    type?: string;

    /**
     * The array of tokens that are added. This parameter is used when tokenUpdate type is "added".
     */
    addedTokens?: Token[];

    /**
     * The array of tokens that are removed. This parameter is used when tokenUpdate type is "removed".
     */
    removedTokens?: Token[];
  }

  /**
   * Event object of the Tokenizer#tokenUpdate event.
   *
   * @deprecated As of version 1.82. replaced by `tokenDelete` event.
   */
  export type Tokenizer$TokenUpdateEvent = Event<
    Tokenizer$TokenUpdateEventParameters,
    Tokenizer
  >;
}

declare module "sap/m/Toolbar" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { Toolbar as Toolbar1, ID, CSSSize } from "sap/ui/core/library";

  import { IBar, ToolbarDesign, ToolbarStyle } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Title from "sap/m/Title";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * Horizontal container most commonly used to display buttons, labels, selects and various other input controls.
   *
   * Overview:
   *
   * By default, the `Toolbar` items are shrinkable if they have percent-based width (for example, {@link sap.m.Input }
   * and {@link sap.m.Slider}) or implement the {@link sap.ui.core.IShrinkable} interface (for example, {@link sap.m.Text }
   * and {@link sap.m.Label}). This behavior can be overridden by providing {@link sap.m.ToolbarLayoutData }
   * for the `Toolbar` items.
   *
   * **Note:** It is recommended that you use {@link sap.m.OverflowToolbar} over `sap.m.Toolbar`, unless you
   * want to avoid the overflow behavior in favor of shrinking.
   *
   * Usage:
   *
   * You can add a visual separator between the preceding and succeeding {@link sap.m.Toolbar} item with the
   * use of the {@link sap.m.ToolbarSeparator}. The separator is theme dependent and can be a padding, a margin
   * or a line.
   *
   * To add horizontal space between the `Toolbar` items, use the {@link sap.m.ToolbarSpacer}. You can define
   * the width of the horizontal space or make it flexible to cover the remaining space between the `Toolbar`
   * items (for example, to to push an item to the edge of the `Toolbar`.
   *
   * **Note:** The {@link sap.m.ToolbarSpacer} is a flex control that is intended to control its own behavior,
   * thus {@link sap.m.ToolbarLayoutData} is not supported as value for the `layoutData` aggregation of {@link sap.m.ToolbarSpacer }
   * and if set it's ignored.
   *
   * @since 1.16
   */
  export default class Toolbar extends Control implements Toolbar1, IBar {
    __implements__sap_ui_core_Toolbar: boolean;
    __implements__sap_m_IBar: boolean;
    /**
     * Constructor for a new `Toolbar`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/toolbar-overview/ Toolbar}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ToolbarSettings
    );
    /**
     * Constructor for a new `Toolbar`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/toolbar-overview/ Toolbar}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ToolbarSettings
    );

    /**
     * Creates a new subclass of class sap.m.Toolbar with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Toolbar>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Toolbar.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Sets classes according to the context of the page. Possible contexts are header, footer and subheader.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns `this` for chaining
     */
    _applyContextClassFor(): IBar;
    /**
     * Sets HTML tag according to the context of the page. Possible contexts are header, footer and subheader.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns `this` for chaining
     */
    _applyTag(): IBar;
    /**
     * Adds some ariaLabelledBy into the association {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAriaLabelledBy(
      /**
       * The ariaLabelledBy to add; if empty, nothing is inserted
       */
      vAriaLabelledBy: ID | Control
    ): this;
    /**
     * Adds some content to the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContent(
      /**
       * The content to add; if empty, nothing is inserted
       */
      oContent: Control
    ): this;
    /**
     * Sets classes and HTML tag according to the context of the page. Possible contexts are header, footer,
     * subheader
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns `this` for chaining
     */
    applyTagAndContextClassFor(): IBar;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.Toolbar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Toolbar` itself.
     *
     * Fired when the user clicks on the toolbar, if the Active property is set to "true".
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Toolbar$PressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Toolbar` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.Toolbar`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Toolbar` itself.
     *
     * Fired when the user clicks on the toolbar, if the Active property is set to "true".
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Toolbar$PressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Toolbar` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.Toolbar`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Toolbar$PressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Toolbar$PressEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getActive active}.
     *
     * Indicates that the whole toolbar is clickable. The Press event is fired only if Active is set to true.
     * Note: This property should be used when there are no interactive controls inside the toolbar and the
     * toolbar itself is meant to be interactive.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `active`
     */
    getActive(): boolean;
    /**
     * Gets current value of property {@link #getAriaHasPopup ariaHasPopup}.
     *
     * Defines the aria-haspopup attribute of the `Toolbar`. if the active `design` is true.
     *
     * **Guidance for choosing appropriate value:**
     * 	 -  We recommend that you use the {@link sap.ui.core.aria.HasPopup} enumeration.
     * 	 -  If you use controls based on `sap.m.Popover` or `sap.m.Dialog`, then you must use `AriaHasPopup.Dialog`
     *     (both `sap.m.Popover` and `sap.m.Dialog` have role "dialog" assigned internally).
     * 	 -  If you use other controls, or directly `sap.ui.core.Popup`, you need to check the container role/type
     *     and map the value of `ariaHasPopup` accordingly.
     *
     * @since 1.79.0
     *
     * @returns Value of property `ariaHasPopup`
     */
    getAriaHasPopup(): string;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getAriaLabelledBy ariaLabelledBy}.
     */
    getAriaLabelledBy(): ID[];
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * The content of the toolbar.
     */
    getContent(): Control[];
    /**
     * Gets current value of property {@link #getDesign design}.
     *
     * Defines the toolbar design.
     *
     * **Note:** Design settings are theme-dependent. They also determine the default height of the toolbar.
     *
     * Default value is `Auto`.
     *
     * @since 1.16.8
     *
     * @returns Value of property `design`
     */
    getDesign(): ToolbarDesign;
    /**
     * Gets current value of property {@link #getEnabled enabled}.
     *
     * Sets the enabled property of all controls defined in the content aggregation. Note: This property does
     * not apply to the toolbar itself, but rather to its items.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabled`
     */
    getEnabled(): boolean;
    /**
     * Gets current value of property {@link #getHeight height}.
     *
     * Defines the height of the control. By default, the `height` property depends on the used theme and the
     * `design` property.
     *
     * **Note:** It is not recommended to use this property if the `sapMTBHeader-CTX` class is used
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `height`
     */
    getHeight(): CSSSize;
    /**
     * Gets the HTML tag of the root domref
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns the HTML-tag
     */
    getHTMLTag(): string;
    /**
     * Gets current value of property {@link #getStyle style}.
     *
     * Defines the visual style of the `Toolbar`.
     *
     * **Note:** The visual styles are theme-dependent.
     *
     * Default value is `Standard`.
     *
     * @since 1.54
     *
     * @returns Value of property `style`
     */
    getStyle(): ToolbarStyle;
    /**
     * Returns the first sap.m.Title control instance inside the toolbar for the accessibility
     *
     * @since 1.44
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The `sap.m.Title` instance or undefined
     */
    getTitleControl(): Title | undefined;
    /**
     * Returns the first sap.m.Title control id inside the toolbar for the accessibility
     *
     * @since 1.28
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns The `sap.m.Title` ID
     */
    getTitleId(): ID;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Defines the width of the control. By default, Toolbar is a block element. If the width is not explicitly
     * set, the control will assume its natural size.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContent content}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContent(
      /**
       * The content whose index is looked for
       */
      oContent: Control
    ): int;
    /**
     * Inserts a content into the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContent(
      /**
       * The content to insert; if empty, nothing is inserted
       */
      oContent: Control,
      /**
       * The `0`-based index the content should be inserted at; for a negative value of `iIndex`, the content
       * is inserted at position 0; for a value greater than the current size of the aggregation, the content
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Returns if the bar is sensitive to the container context. Implementation of the IBar interface
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns isContextSensitive
     */
    isContextSensitive(): boolean;
    /**
     * Removes all the controls in the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAriaLabelledBy(): ID[];
    /**
     * Removes all the controls from the aggregation {@link #getContent content}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContent(): Control[];
    /**
     * Removes an ariaLabelledBy from the association named {@link #getAriaLabelledBy ariaLabelledBy}.
     *
     *
     * @returns The removed ariaLabelledBy or `null`
     */
    removeAriaLabelledBy(
      /**
       * The ariaLabelledBy to be removed or its index or ID
       */
      vAriaLabelledBy: int | ID | Control
    ): ID | null;
    /**
     * Removes a content from the aggregation {@link #getContent content}.
     *
     *
     * @returns The removed content or `null`
     */
    removeContent(
      /**
       * The content to remove or its index or id
       */
      vContent: int | string | Control
    ): Control | null;
    /**
     * Sets a new value for property {@link #getActive active}.
     *
     * Indicates that the whole toolbar is clickable. The Press event is fired only if Active is set to true.
     * Note: This property should be used when there are no interactive controls inside the toolbar and the
     * toolbar itself is meant to be interactive.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setActive(
      /**
       * New value for property `active`
       */
      bActive?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getAriaHasPopup ariaHasPopup}.
     *
     * Defines the aria-haspopup attribute of the `Toolbar`. if the active `design` is true.
     *
     * **Guidance for choosing appropriate value:**
     * 	 -  We recommend that you use the {@link sap.ui.core.aria.HasPopup} enumeration.
     * 	 -  If you use controls based on `sap.m.Popover` or `sap.m.Dialog`, then you must use `AriaHasPopup.Dialog`
     *     (both `sap.m.Popover` and `sap.m.Dialog` have role "dialog" assigned internally).
     * 	 -  If you use other controls, or directly `sap.ui.core.Popup`, you need to check the container role/type
     *     and map the value of `ariaHasPopup` accordingly.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.79.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAriaHasPopup(
      /**
       * New value for property `ariaHasPopup`
       */
      sAriaHasPopup?: string
    ): this;
    /**
     * Sets a new value for property {@link #getDesign design}.
     *
     * Defines the toolbar design.
     *
     * **Note:** Design settings are theme-dependent. They also determine the default height of the toolbar.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     * @since 1.16.8
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDesign(
      /**
       * New value for property `design`
       */
      sDesign?: ToolbarDesign | keyof typeof ToolbarDesign
    ): this;
    /**
     * Sets a new value for property {@link #getEnabled enabled}.
     *
     * Sets the enabled property of all controls defined in the content aggregation. Note: This property does
     * not apply to the toolbar itself, but rather to its items.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabled(
      /**
       * New value for property `enabled`
       */
      bEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getHeight height}.
     *
     * Defines the height of the control. By default, the `height` property depends on the used theme and the
     * `design` property.
     *
     * **Note:** It is not recommended to use this property if the `sapMTBHeader-CTX` class is used
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeight(
      /**
       * New value for property `height`
       */
      sHeight?: CSSSize
    ): this;
    /**
     * Sets the HTML tag of the root domref
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns this for chaining
     */
    setHTMLTag(sTag: string): IBar;
    /**
     * Sets a new value for property {@link #getStyle style}.
     *
     * Defines the visual style of the `Toolbar`.
     *
     * **Note:** The visual styles are theme-dependent.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Standard`.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setStyle(
      /**
       * New value for property `style`
       */
      sStyle?: ToolbarStyle | keyof typeof ToolbarStyle
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Defines the width of the control. By default, Toolbar is a block element. If the width is not explicitly
     * set, the control will assume its natural size.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Toolbar constructor.
   */
  export interface $ToolbarSettings extends $ControlSettings {
    /**
     * Defines the width of the control. By default, Toolbar is a block element. If the width is not explicitly
     * set, the control will assume its natural size.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates that the whole toolbar is clickable. The Press event is fired only if Active is set to true.
     * Note: This property should be used when there are no interactive controls inside the toolbar and the
     * toolbar itself is meant to be interactive.
     */
    active?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the enabled property of all controls defined in the content aggregation. Note: This property does
     * not apply to the toolbar itself, but rather to its items.
     */
    enabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the height of the control. By default, the `height` property depends on the used theme and the
     * `design` property.
     *
     * **Note:** It is not recommended to use this property if the `sapMTBHeader-CTX` class is used
     */
    height?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the toolbar design.
     *
     * **Note:** Design settings are theme-dependent. They also determine the default height of the toolbar.
     *
     * @since 1.16.8
     */
    design?:
      | (ToolbarDesign | keyof typeof ToolbarDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the visual style of the `Toolbar`.
     *
     * **Note:** The visual styles are theme-dependent.
     *
     * @since 1.54
     */
    style?:
      | (ToolbarStyle | keyof typeof ToolbarStyle)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the aria-haspopup attribute of the `Toolbar`. if the active `design` is true.
     *
     * **Guidance for choosing appropriate value:**
     * 	 -  We recommend that you use the {@link sap.ui.core.aria.HasPopup} enumeration.
     * 	 -  If you use controls based on `sap.m.Popover` or `sap.m.Dialog`, then you must use `AriaHasPopup.Dialog`
     *     (both `sap.m.Popover` and `sap.m.Dialog` have role "dialog" assigned internally).
     * 	 -  If you use other controls, or directly `sap.ui.core.Popup`, you need to check the container role/type
     *     and map the value of `ariaHasPopup` accordingly.
     *
     * @since 1.79.0
     */
    ariaHasPopup?: string | PropertyBindingInfo;

    /**
     * The content of the toolbar.
     */
    content?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * Association to controls / ids which label this control (see WAI-ARIA attribute aria-labelledby).
     */
    ariaLabelledBy?: Array<Control | string>;

    /**
     * Fired when the user clicks on the toolbar, if the Active property is set to "true".
     */
    press?: (oEvent: Toolbar$PressEvent) => void;
  }

  /**
   * Parameters of the Toolbar#press event.
   */
  export interface Toolbar$PressEventParameters {
    /**
     * The toolbar item that was pressed
     */
    srcControl?: Control;
  }

  /**
   * Event object of the Toolbar#press event.
   */
  export type Toolbar$PressEvent = Event<Toolbar$PressEventParameters, Toolbar>;
}

declare module "sap/m/ToolbarLayoutData" {
  import {
    default as LayoutData,
    $LayoutDataSettings,
  } from "sap/ui/core/LayoutData";

  import { CSSSize } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Defines layout data for the {@link sap.m.Toolbar} items.
   *
   * **Note:** The {@link sap.m.ToolbarSpacer} is a flex control that is intended to control its own behavior,
   * thus `sap.m.ToolbarLayoutData` is not supported as value for the `layoutData` aggregation of {@link sap.m.ToolbarSpacer }
   * and if set it's ignored.
   *
   * @since 1.20
   */
  export default class ToolbarLayoutData extends LayoutData {
    /**
     * Constructor for a new `ToolbarLayoutData`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ToolbarLayoutDataSettings
    );
    /**
     * Constructor for a new `ToolbarLayoutData`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ToolbarLayoutDataSettings
    );

    /**
     * Creates a new subclass of class sap.m.ToolbarLayoutData with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.LayoutData.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ToolbarLayoutData>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ToolbarLayoutData.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getMaxWidth maxWidth}.
     *
     * Sets the maximum width of the toolbar item.
     *
     *
     * @returns Value of property `maxWidth`
     */
    getMaxWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getMinWidth minWidth}.
     *
     * Sets the minimum width of the toolbar item.
     *
     *
     * @returns Value of property `minWidth`
     */
    getMinWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getShrinkable shrinkable}.
     *
     * Determines whether the control, when in a toolbar, is shrinkable or not. For controls with fixed width
     * (100px, 5rem, etc...) this property is ignored.
     *
     * **Notes:**
     * 	 - Nested layout controls should not be shrinkable.
     * 	 - This property has no effect on `sap.m.Breadcrumbs` as it is shrinkable by default.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `shrinkable`
     */
    getShrinkable(): boolean;
    /**
     * Sets a new value for property {@link #getMaxWidth maxWidth}.
     *
     * Sets the maximum width of the toolbar item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxWidth(
      /**
       * New value for property `maxWidth`
       */
      sMaxWidth?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getMinWidth minWidth}.
     *
     * Sets the minimum width of the toolbar item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMinWidth(
      /**
       * New value for property `minWidth`
       */
      sMinWidth?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getShrinkable shrinkable}.
     *
     * Determines whether the control, when in a toolbar, is shrinkable or not. For controls with fixed width
     * (100px, 5rem, etc...) this property is ignored.
     *
     * **Notes:**
     * 	 - Nested layout controls should not be shrinkable.
     * 	 - This property has no effect on `sap.m.Breadcrumbs` as it is shrinkable by default.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShrinkable(
      /**
       * New value for property `shrinkable`
       */
      bShrinkable?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ToolbarLayoutData constructor.
   */
  export interface $ToolbarLayoutDataSettings extends $LayoutDataSettings {
    /**
     * Determines whether the control, when in a toolbar, is shrinkable or not. For controls with fixed width
     * (100px, 5rem, etc...) this property is ignored.
     *
     * **Notes:**
     * 	 - Nested layout controls should not be shrinkable.
     * 	 - This property has no effect on `sap.m.Breadcrumbs` as it is shrinkable by default.
     */
    shrinkable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the minimum width of the toolbar item.
     */
    minWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the maximum width of the toolbar item.
     */
    maxWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/ToolbarSeparator" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import {
    IOverflowToolbarContent,
    OverflowToolbarConfig,
  } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * Creates a visual separator (theme dependent: padding, margin, line) between the preceding and succeeding
   * {@link sap.m.Toolbar} item.
   *
   * @since 1.26
   */
  export default class ToolbarSeparator
    extends Control
    implements IOverflowToolbarContent
  {
    __implements__sap_m_IOverflowToolbarContent: boolean;
    /**
     * Constructor for a new `ToolbarSeparator`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.ui.core.Control#constructor sap.ui.core.Control }
     * can be used.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ToolbarSeparatorSettings
    );
    /**
     * Constructor for a new `ToolbarSeparator`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.ui.core.Control#constructor sap.ui.core.Control }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ToolbarSeparatorSettings
    );

    /**
     * Creates a new subclass of class sap.m.ToolbarSeparator with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ToolbarSeparator>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ToolbarSeparator.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Sets the behavior of the `ToolbarSeparator` inside an `OverflowToolbar` configuration. Required by the
     * {@link sap.m.IOverflowToolbarContent} interface.
     *
     * @since 1.65
     *
     * @returns Configuration information for the `sap.m.IOverflowToolbarContent` interface.
     */
    getOverflowToolbarConfig(): OverflowToolbarConfig;
  }
  /**
   * Describes the settings that can be provided to the ToolbarSeparator constructor.
   */
  export interface $ToolbarSeparatorSettings extends $ControlSettings {}
}

declare module "sap/m/ToolbarSpacer" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { CSSSize } from "sap/ui/core/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Adds horizontal space between the items used within a {@link sap.m.Toolbar}.
   *
   * **Note:** The `sap.m.ToolbarSpacer` is a flex control that is intended to control its own behavior, thus
   * {@link sap.m.ToolbarLayoutData} is not supported as value for the `layoutData` aggregation of `sap.m.ToolbarSpacer`
   * and if set it's ignored.
   *
   * @since 1.16
   */
  export default class ToolbarSpacer extends Control {
    /**
     * Constructor for a new `ToolbarSpacer`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ToolbarSpacerSettings
    );
    /**
     * Constructor for a new `ToolbarSpacer`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ToolbarSpacerSettings
    );

    /**
     * Creates a new subclass of class sap.m.ToolbarSpacer with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ToolbarSpacer>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ToolbarSpacer.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Defines the width of the horizontal space. Note: Empty("") value makes the space flexible which means
     * it covers the remaining space between toolbar items. This feature can be used to push next item to the
     * edge of the toolbar.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Defines the width of the horizontal space. Note: Empty("") value makes the space flexible which means
     * it covers the remaining space between toolbar items. This feature can be used to push next item to the
     * edge of the toolbar.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ToolbarSpacer constructor.
   */
  export interface $ToolbarSpacerSettings extends $ControlSettings {
    /**
     * Defines the width of the horizontal space. Note: Empty("") value makes the space flexible which means
     * it covers the remaining space between toolbar items. This feature can be used to push next item to the
     * edge of the toolbar.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/Tree" {
  import { default as ListBase, $ListBaseSettings } from "sap/m/ListBase";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { ListGrowingDirection } from "sap/m/library";

  import Event from "sap/ui/base/Event";

  /**
   * The `Tree` control provides a tree structure for displaying data in a hierarchy. **Note:** Growing feature
   * is not supported by `Tree`.
   *
   * @since 1.42
   */
  export default class Tree extends ListBase {
    /**
     * Constructor for a new Tree.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:/tree/ Tree}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $TreeSettings
    );
    /**
     * Constructor for a new Tree.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:/tree/ Tree}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $TreeSettings
    );

    /**
     * Creates a new subclass of class sap.m.Tree with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ListBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Tree>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Tree.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:toggleOpenState toggleOpenState} event of this
     * `sap.m.Tree`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Tree` itself.
     *
     * Fired when an item has been expanded or collapsed by user interaction.
     *
     * @since 1.50
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachToggleOpenState(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Tree$ToggleOpenStateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Tree` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:toggleOpenState toggleOpenState} event of this
     * `sap.m.Tree`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Tree` itself.
     *
     * Fired when an item has been expanded or collapsed by user interaction.
     *
     * @since 1.50
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachToggleOpenState(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Tree$ToggleOpenStateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Tree` itself
       */
      oListener?: object
    ): this;
    /**
     * Collapses one or multiple items.
     *
     * @since 1.56.0
     *
     * @returns A reference to the Tree control
     */
    collapse(
      /**
       * The index or indices of the tree items to be collapsed
       */
      vParam: int | int[]
    ): this;
    /**
     * Collapses all nodes.
     *
     * @since 1.48.0
     *
     * @returns A reference to the Tree control
     */
    collapseAll(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:toggleOpenState toggleOpenState} event of
     * this `sap.m.Tree`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.50
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachToggleOpenState(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Tree$ToggleOpenStateEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Expands one or multiple items. Note that items that are hidden at the time of calling this API can't
     * be expanded.
     *
     * @since 1.56.0
     *
     * @returns A reference to the Tree control
     */
    expand(
      /**
       * The index or indices of the item to be expanded
       */
      vParam: int | int[]
    ): this;
    /**
     * Defines the level to which the tree is expanded. The function can be used to define the initial expanding
     * state. An alternative way to define the initial expanding state is to set the parameter `numberOfExpandedLevels`
     * of the binding.
     *
     * Example:
     * ```javascript
     *
     *   oTree.bindItems({
     *      path: "...",
     *      parameters: {
     *         numberOfExpandedLevels: 1
     *      }
     *   });
     * ```
     *
     *
     * @since 1.48.0
     *
     * @returns Returns `this` to allow method chaining
     */
    expandToLevel(
      /**
       * The level to which the data is expanded
       */
      iLevel: int
    ): this;
    /**
     * Fires event {@link #event:toggleOpenState toggleOpenState} to attached listeners.
     *
     * @since 1.50
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireToggleOpenState(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Tree$ToggleOpenStateEventParameters
    ): this;
    /**
     * The `growing` property is not supported by the `Tree` control.
     *
     * @deprecated As of version 1.46. the `growing` property is not supported by the `Tree` control.
     *
     * @returns Returns `this` to allow method chaining
     */
    setGrowing(
      /**
       * New value for the `growing` property, ignored.
       */
      bValue: boolean
    ): this;
    /**
     * The `growingDirection` property is not supported by the `Tree` control.
     *
     * @deprecated As of version 1.46. the `growingDirection` property is not supported by the `Tree` control.
     *
     * @returns Returns `this` to allow method chaining
     */
    setGrowingDirection(
      /**
       * New value for the `growingDirection` property, ignored.
       */
      sValue: ListGrowingDirection | keyof typeof ListGrowingDirection
    ): this;
    /**
     * The `growingScrollToLoad` property is not supported by the `Tree` control.
     *
     * @deprecated As of version 1.46. the `growingScrollToLoad` property is not supported by the `Tree` control.
     *
     * @returns Returns `this` to allow method chaining
     */
    setGrowingScrollToLoad(
      /**
       * New value for the `growingScrollToLoad` property, ignored.
       */
      bValue: boolean
    ): this;
    /**
     * The `growingThreshold` property is not supported by the `Tree` control.
     *
     * @deprecated As of version 1.46. the `growingThreshold` property is not supported by the `Tree` control.
     *
     * @returns Returns `this` to allow method chaining
     */
    setGrowingThreshold(
      /**
       * New value for the `growingThreshold` property, ignored.
       */
      iValue: int
    ): this;
    /**
     * The `growingTriggerText` property is not supported by the `Tree` control.
     *
     * @deprecated As of version 1.46. the `growingTriggerText` property is not supported by the `Tree` control.
     *
     * @returns Returns `this` to allow method chaining
     */
    setGrowingTriggerText(
      /**
       * New value for the `growingTriggerText` property, ignored.
       */
      sValue: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Tree constructor.
   */
  export interface $TreeSettings extends $ListBaseSettings {
    /**
     * Fired when an item has been expanded or collapsed by user interaction.
     *
     * @since 1.50
     */
    toggleOpenState?: (oEvent: Tree$ToggleOpenStateEvent) => void;
  }

  /**
   * Parameters of the Tree#toggleOpenState event.
   */
  export interface Tree$ToggleOpenStateEventParameters {
    /**
     * Index of the expanded/collapsed item
     */
    itemIndex?: int;

    /**
     * Binding context of the item
     */
    itemContext?: object;

    /**
     * Flag that indicates whether the item has been expanded or collapsed
     */
    expanded?: boolean;
  }

  /**
   * Event object of the Tree#toggleOpenState event.
   */
  export type Tree$ToggleOpenStateEvent = Event<
    Tree$ToggleOpenStateEventParameters,
    Tree
  >;
}

declare module "sap/m/TreeItemBase" {
  import {
    default as ListItemBase,
    $ListItemBaseSettings,
  } from "sap/m/ListItemBase";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * The `sap.m.TreeItemBase` contains the basic features of all specific tree items.
   *
   * @since 1.42.0
   */
  export default class TreeItemBase extends ListItemBase {
    /**
     * Constructor for a new TreeItemBase.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.ListItemBase#constructor sap.m.ListItemBase }
     * can be used.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $TreeItemBaseSettings
    );
    /**
     * Constructor for a new TreeItemBase.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.m.ListItemBase#constructor sap.m.ListItemBase }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $TreeItemBaseSettings
    );

    /**
     * Creates a new subclass of class sap.m.TreeItemBase with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ListItemBase.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, TreeItemBase>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.TreeItemBase.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets the expanding information of the node.
     *
     * @since 1.42.0
     */
    getExpanded(): boolean;
    /**
     * Gets the context of the node.
     *
     * @since 1.42.0
     */
    getItemNodeContext(): Object;
    /**
     * Gets the node level in the hierarchy.
     *
     * @since 1.42.0
     */
    getLevel(): int;
    /**
     * Gets the parent node control.
     *
     * @since 1.42.0
     */
    getParentNode(): TreeItemBase | undefined;
    /**
     * Gets the context of the parent node control.
     *
     * @since 1.42.0
     */
    getParentNodeContext(): Object;
    /**
     * Determines if the node is a leaf.
     *
     * @since 1.42.0
     */
    isLeaf(): boolean;
    /**
     * Checks if the node is the top level node.
     *
     * @since 1.42.0
     */
    isTopLevel(): boolean;
  }
  /**
   * Describes the settings that can be provided to the TreeItemBase constructor.
   */
  export interface $TreeItemBaseSettings extends $ListItemBaseSettings {}
}

declare module "sap/m/upload/ActionsPlaceholder" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { UploadSetwithTableActionPlaceHolder } from "sap/m/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The control acts as placeholder to position specific action controls (Upload, Upload from cloud) on headertoolbar
   * of table with connected plugin {@link sap.m.plugins.UploadSetwithTable UploadSetwithTable} Plugin.
   *  The type of action control placed on the headertoolbar is determined by the {@link sap.m.UploadSetwithTableActionPlaceHolder UploadSetwithTableActionPlaceHolder }
   * enum set.
   *  This control is supposed to be used only within the association of the {@link sap.m.plugins.UploadSetwithTable UploadSetwithTable }
   * Plugin.
   *
   * @since 1.120
   */
  export default class ActionsPlaceholder extends Control {
    /**
     * Constructor for a new ActionsPlaceholder.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $ActionsPlaceholderSettings
    );
    /**
     * Constructor for a new ActionsPlaceholder.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control. It is generated automatically if an ID is not provided.
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $ActionsPlaceholderSettings
    );

    /**
     * Creates a new subclass of class sap.m.upload.ActionsPlaceholder with name `sClassName` and enriches it
     * with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ActionsPlaceholder>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.upload.ActionsPlaceholder.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getPlaceholderFor placeholderFor}.
     *
     * Defines the enum value that determines which control gets substituted.
     *
     *
     * @returns Value of property `placeholderFor`
     */
    getPlaceholderFor(): UploadSetwithTableActionPlaceHolder;
    /**
     * Sets a new value for property {@link #getPlaceholderFor placeholderFor}.
     *
     * Defines the enum value that determines which control gets substituted.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPlaceholderFor(
      /**
       * New value for property `placeholderFor`
       */
      sPlaceholderFor:
        | UploadSetwithTableActionPlaceHolder
        | keyof typeof UploadSetwithTableActionPlaceHolder
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ActionsPlaceholder constructor.
   */
  export interface $ActionsPlaceholderSettings extends $ControlSettings {
    /**
     * Defines the enum value that determines which control gets substituted.
     */
    placeholderFor?:
      | (
          | UploadSetwithTableActionPlaceHolder
          | keyof typeof UploadSetwithTableActionPlaceHolder
        )
      | PropertyBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/upload/Column" {
  import {
    default as Column1,
    $ColumnSettings as $ColumnSettings1,
  } from "sap/m/Column";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The `sap.m.upload.Column` allows defining personalization properties for a column. This Element is built
   * on {@link sap.m.Column sap.m.column}.
   *  It is supposed to be used only with the columns aggregation of {@link sap.m.upload.UploadSetwithTable UploadSetwithTable }
   * control.
   *
   * @since 1.120
   * @experimental As of version 1.120.
   */
  export default class Column extends Column1 {
    /**
     * Constructor for a new Column.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control.
       */
      mSettings?: $ColumnSettings
    );
    /**
     * Constructor for a new Column.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control. It is generated automatically if an ID is not provided.
       */
      sId?: string,
      /**
       * Initial settings for the new control.
       */
      mSettings?: $ColumnSettings
    );

    /**
     * Creates a new subclass of class sap.m.upload.Column with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.Column.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Column>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.upload.Column.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getColumnPersonalizationText columnPersonalizationText}.
     *
     * Defines the text that is used for column inside personalization dialog.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `columnPersonalizationText`
     */
    getColumnPersonalizationText(): string;
    /**
     * Gets current value of property {@link #getFilterable filterable}.
     *
     * Defines if the column is used in filter panel.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `filterable`
     */
    getFilterable(): boolean;
    /**
     * Gets current value of property {@link #getGroupable groupable}.
     *
     * Defines if the column is used in a group panel.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `groupable`
     */
    getGroupable(): boolean;
    /**
     * Gets current value of property {@link #getPath path}.
     *
     * Defines the model path that is used for applying personalization.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `path`
     */
    getPath(): string;
    /**
     * Gets current value of property {@link #getSortable sortable}.
     *
     * Defines if the column is used in sort panel.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `sortable`
     */
    getSortable(): boolean;
    /**
     * Sets a new value for property {@link #getColumnPersonalizationText columnPersonalizationText}.
     *
     * Defines the text that is used for column inside personalization dialog.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setColumnPersonalizationText(
      /**
       * New value for property `columnPersonalizationText`
       */
      sColumnPersonalizationText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getFilterable filterable}.
     *
     * Defines if the column is used in filter panel.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFilterable(
      /**
       * New value for property `filterable`
       */
      bFilterable?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getGroupable groupable}.
     *
     * Defines if the column is used in a group panel.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setGroupable(
      /**
       * New value for property `groupable`
       */
      bGroupable?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getPath path}.
     *
     * Defines the model path that is used for applying personalization.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPath(
      /**
       * New value for property `path`
       */
      sPath?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSortable sortable}.
     *
     * Defines if the column is used in sort panel.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSortable(
      /**
       * New value for property `sortable`
       */
      bSortable?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Column constructor.
   *
   * @experimental As of version 1.120.
   */
  export interface $ColumnSettings extends $ColumnSettings1 {
    /**
     * Defines the text that is used for column inside personalization dialog.
     */
    columnPersonalizationText?: string | PropertyBindingInfo;

    /**
     * Defines the model path that is used for applying personalization.
     */
    path?: string | PropertyBindingInfo;

    /**
     * Defines if the column is used in sort panel.
     */
    sortable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines if the column is used in a group panel.
     */
    groupable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines if the column is used in filter panel.
     */
    filterable?: boolean | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/upload/FilePreviewDialog" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import Button from "sap/m/Button";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * Overview:
   *
   * Dialog with a carousel to preview files uploaded using the UploadSetwithTable control. This Element should
   * only be used within the {@link sap.m.upload.UploadSetwithTable UploadSetwithTable} control or {@link sap.m.plugins.UploadSetwithTable UploadSetwithTable }
   * Plugin as an association.
   *
   * Supported File Types for Preview:
   *
   * Following are the supported file types that can be previewed:
   *
   *
   * 	 - Image (PNG, JPEG, BMP, GIF)
   * 	 - PDF
   * 	 - Text (Txt)
   * 	 - Video (MP4, MPEG, Quicktime, MsVideo)
   * 	 - SAP 3D Visual models (VDS)
   *
   * @since 1.120
   */
  export default class FilePreviewDialog extends UI5Element {
    /**
     * Constructor for a new FilePreviewDialog.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control.
       */
      mSettings?: $FilePreviewDialogSettings
    );
    /**
     * Constructor for a new FilePreviewDialog.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Id for the new control, it is generated automatically if no id is provided.
       */
      sId?: string,
      /**
       * Initial settings for the new control.
       */
      mSettings?: $FilePreviewDialogSettings
    );

    /**
     * Creates a new subclass of class sap.m.upload.FilePreviewDialog with name `sClassName` and enriches it
     * with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, FilePreviewDialog>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.upload.FilePreviewDialog.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some additionalFooterButton to the aggregation {@link #getAdditionalFooterButtons additionalFooterButtons}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAdditionalFooterButton(
      /**
       * The additionalFooterButton to add; if empty, nothing is inserted
       */
      oAdditionalFooterButton: Button
    ): this;
    /**
     * Destroys all the additionalFooterButtons in the aggregation {@link #getAdditionalFooterButtons additionalFooterButtons}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyAdditionalFooterButtons(): this;
    /**
     * Gets content of aggregation {@link #getAdditionalFooterButtons additionalFooterButtons}.
     *
     * Custom buttons, to be displayed in the preview dialog footer.
     * Control by default adds two buttons (download and close).
     */
    getAdditionalFooterButtons(): Button[];
    /**
     * Gets current value of property {@link #getCustomPageContentHandler customPageContentHandler}.
     *
     * Callback function to insert custom content into the preview dialog using a control to display the preview
     * of unsupported file types.
     * Use this property as callback function to insert a control with the content into the preview dialog.
     *
     * Callback function returns a promise that resolves with a control that is displayed in the preview dialog.
     * Reject the promise to display the default illustrated message.
     * Callback function is invoked with {@link sap.m.upload.UploadItem item} for each unsupported file type.
     *
     *
     * Example: There is a file with an xml extension and you want to display the content inside a codeeditor
     * control for the file type.
     *
     *
     * ```javascript
     *
     * 	<UploadSetwithTable>
     * 		<upload:FilePreviewDialog customPageContentHandler="{onCustomContentHandler}"></upload:FilePreviewDialog>
     * 	</UploadSetwithTable>
     * ```
     *
     *
     *
     * ```javascript
     *
     * 	onCustomContentHandler: function(oItem) {
     *
     * 			return new Promise(function(resolve, reject) {
     *
     * 				switch (oItem.getMediaType().toLowerCase()) {
     *
     * 					case "application/xml":
     *
     * 						var oCodeEditor = new CodeEditor({
     * 							value: "XML content",
     * 							width: "100%",
     * 							height: "100%"
     * 						});
     *
     * 						resolve(oCodeEditor);
     * 						break;
     *
     * 					default:
     * 						reject(); // reject the promise to display the default illustrated message.
     * 						break;
     * 				}
     * 			});
     * 	}
     * ```
     *
     *
     * @since 1.136
     *
     * @returns Value of property `customPageContentHandler`
     */
    getCustomPageContentHandler(): Function;
    /**
     * Gets current value of property {@link #getMaxFileSizeforPreview maxFileSizeforPreview}.
     *
     * Size limit of the file in megabytes that is allowed to be previewed.
     * If not set, files of any size can be previewed.
     *
     *
     * @returns Value of property `maxFileSizeforPreview`
     */
    getMaxFileSizeforPreview(): float;
    /**
     * Gets current value of property {@link #getShowCarouselArrows showCarouselArrows}.
     *
     * Show or hide carousel's arrows.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showCarouselArrows`
     */
    getShowCarouselArrows(): boolean;
    /**
     * Checks for the provided `sap.m.Button` in the aggregation {@link #getAdditionalFooterButtons additionalFooterButtons}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfAdditionalFooterButton(
      /**
       * The additionalFooterButton whose index is looked for
       */
      oAdditionalFooterButton: Button
    ): int;
    /**
     * Inserts a additionalFooterButton into the aggregation {@link #getAdditionalFooterButtons additionalFooterButtons}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertAdditionalFooterButton(
      /**
       * The additionalFooterButton to insert; if empty, nothing is inserted
       */
      oAdditionalFooterButton: Button,
      /**
       * The `0`-based index the additionalFooterButton should be inserted at; for a negative value of `iIndex`,
       * the additionalFooterButton is inserted at position 0; for a value greater than the current size of the
       * aggregation, the additionalFooterButton is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes a additionalFooterButton from the aggregation {@link #getAdditionalFooterButtons additionalFooterButtons}.
     *
     *
     * @returns The removed additionalFooterButton or `null`
     */
    removeAdditionalFooterButton(
      /**
       * The additionalFooterButton to remove or its index or id
       */
      vAdditionalFooterButton: int | string | Button
    ): Button | null;
    /**
     * Removes all the controls from the aggregation {@link #getAdditionalFooterButtons additionalFooterButtons}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAdditionalFooterButtons(): Button[];
    /**
     * Sets a new value for property {@link #getCustomPageContentHandler customPageContentHandler}.
     *
     * Callback function to insert custom content into the preview dialog using a control to display the preview
     * of unsupported file types.
     * Use this property as callback function to insert a control with the content into the preview dialog.
     *
     * Callback function returns a promise that resolves with a control that is displayed in the preview dialog.
     * Reject the promise to display the default illustrated message.
     * Callback function is invoked with {@link sap.m.upload.UploadItem item} for each unsupported file type.
     *
     *
     * Example: There is a file with an xml extension and you want to display the content inside a codeeditor
     * control for the file type.
     *
     *
     * ```javascript
     *
     * 	<UploadSetwithTable>
     * 		<upload:FilePreviewDialog customPageContentHandler="{onCustomContentHandler}"></upload:FilePreviewDialog>
     * 	</UploadSetwithTable>
     * ```
     *
     *
     *
     * ```javascript
     *
     * 	onCustomContentHandler: function(oItem) {
     *
     * 			return new Promise(function(resolve, reject) {
     *
     * 				switch (oItem.getMediaType().toLowerCase()) {
     *
     * 					case "application/xml":
     *
     * 						var oCodeEditor = new CodeEditor({
     * 							value: "XML content",
     * 							width: "100%",
     * 							height: "100%"
     * 						});
     *
     * 						resolve(oCodeEditor);
     * 						break;
     *
     * 					default:
     * 						reject(); // reject the promise to display the default illustrated message.
     * 						break;
     * 				}
     * 			});
     * 	}
     * ```
     *
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.136
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCustomPageContentHandler(
      /**
       * New value for property `customPageContentHandler`
       */
      fnCustomPageContentHandler?: Function
    ): this;
    /**
     * Sets a new value for property {@link #getMaxFileSizeforPreview maxFileSizeforPreview}.
     *
     * Size limit of the file in megabytes that is allowed to be previewed.
     * If not set, files of any size can be previewed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxFileSizeforPreview(
      /**
       * New value for property `maxFileSizeforPreview`
       */
      fMaxFileSizeforPreview?: float
    ): this;
    /**
     * Sets a new value for property {@link #getShowCarouselArrows showCarouselArrows}.
     *
     * Show or hide carousel's arrows.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowCarouselArrows(
      /**
       * New value for property `showCarouselArrows`
       */
      bShowCarouselArrows?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the FilePreviewDialog constructor.
   */
  export interface $FilePreviewDialogSettings extends $ElementSettings {
    /**
     * Show or hide carousel's arrows.
     */
    showCarouselArrows?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Size limit of the file in megabytes that is allowed to be previewed.
     * If not set, files of any size can be previewed.
     */
    maxFileSizeforPreview?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * Callback function to insert custom content into the preview dialog using a control to display the preview
     * of unsupported file types.
     * Use this property as callback function to insert a control with the content into the preview dialog.
     *
     * Callback function returns a promise that resolves with a control that is displayed in the preview dialog.
     * Reject the promise to display the default illustrated message.
     * Callback function is invoked with {@link sap.m.upload.UploadItem item} for each unsupported file type.
     *
     *
     * Example: There is a file with an xml extension and you want to display the content inside a codeeditor
     * control for the file type.
     *
     *
     * ```javascript
     *
     * 	<UploadSetwithTable>
     * 		<upload:FilePreviewDialog customPageContentHandler="{onCustomContentHandler}"></upload:FilePreviewDialog>
     * 	</UploadSetwithTable>
     * ```
     *
     *
     *
     * ```javascript
     *
     * 	onCustomContentHandler: function(oItem) {
     *
     * 			return new Promise(function(resolve, reject) {
     *
     * 				switch (oItem.getMediaType().toLowerCase()) {
     *
     * 					case "application/xml":
     *
     * 						var oCodeEditor = new CodeEditor({
     * 							value: "XML content",
     * 							width: "100%",
     * 							height: "100%"
     * 						});
     *
     * 						resolve(oCodeEditor);
     * 						break;
     *
     * 					default:
     * 						reject(); // reject the promise to display the default illustrated message.
     * 						break;
     * 				}
     * 			});
     * 	}
     * ```
     *
     *
     * @since 1.136
     */
    customPageContentHandler?: Function | PropertyBindingInfo | `{${string}}`;

    /**
     * Custom buttons, to be displayed in the preview dialog footer.
     * Control by default adds two buttons (download and close).
     */
    additionalFooterButtons?:
      | Button[]
      | Button
      | AggregationBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/upload/Uploader" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import UploadSetItem from "sap/m/upload/UploadSetItem";

  import Item from "sap/ui/core/Item";

  import UploaderHttpRequestMethod from "sap/m/upload/UploaderHttpRequestMethod";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * A basic implementation for uploading and downloading one or multiple files.
   *
   * @since 1.63
   * @deprecated As of version 1.129. replaced by {@link sap.m.upload.UploaderTableItem}
   */
  export default class Uploader extends UI5Element {
    /**
     * Constructor for a new Uploader.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $UploaderSettings
    );
    /**
     * Constructor for a new Uploader.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $UploaderSettings
    );

    /**
     * Creates a new subclass of class sap.m.upload.Uploader with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Uploader>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.upload.Uploader.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Starts function for uploading one file object to given url. Returns promise that resolves when the upload
     * is finished or rejects when the upload fails.
     *
     *
     * @returns Promise that resolves when the upload is finished or rejects when the upload fails.
     */
    static uploadFile(
      /**
       * File or Blob object to be uploaded.
       */
      oFile: File | Blob,
      /**
       * Upload Url.
       */
      sUrl: string,
      /**
       * Collection of request header fields to be send along.
       */
      aHeaderFields?: Item[]
    ): Promise<any>;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadAborted uploadAborted} event of this `sap.m.upload.Uploader`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.Uploader` itself.
     *
     * The event is fired when an XHR request reports its abortion.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadAborted(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Uploader$UploadAbortedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.Uploader` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadAborted uploadAborted} event of this `sap.m.upload.Uploader`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.Uploader` itself.
     *
     * The event is fired when an XHR request reports its abortion.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadAborted(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Uploader$UploadAbortedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.Uploader` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadCompleted uploadCompleted} event of this
     * `sap.m.upload.Uploader`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.Uploader` itself.
     *
     * The event is fired when an XHR request reports successful completion of upload process.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadCompleted(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Uploader$UploadCompletedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.Uploader` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadCompleted uploadCompleted} event of this
     * `sap.m.upload.Uploader`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.Uploader` itself.
     *
     * The event is fired when an XHR request reports successful completion of upload process.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadCompleted(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Uploader$UploadCompletedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.Uploader` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadProgressed uploadProgressed} event of
     * this `sap.m.upload.Uploader`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.Uploader` itself.
     *
     * The event is fired every time an XHR request reports progress in uploading.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadProgressed(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Uploader$UploadProgressedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.Uploader` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadProgressed uploadProgressed} event of
     * this `sap.m.upload.Uploader`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.Uploader` itself.
     *
     * The event is fired every time an XHR request reports progress in uploading.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadProgressed(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Uploader$UploadProgressedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.Uploader` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadStarted uploadStarted} event of this `sap.m.upload.Uploader`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.Uploader` itself.
     *
     * The event is fired just after the POST request was sent.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadStarted(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Uploader$UploadStartedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.Uploader` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadStarted uploadStarted} event of this `sap.m.upload.Uploader`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.Uploader` itself.
     *
     * The event is fired just after the POST request was sent.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadStarted(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Uploader$UploadStartedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.Uploader` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:uploadAborted uploadAborted} event of this
     * `sap.m.upload.Uploader`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUploadAborted(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Uploader$UploadAbortedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:uploadCompleted uploadCompleted} event of
     * this `sap.m.upload.Uploader`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUploadCompleted(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Uploader$UploadCompletedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:uploadProgressed uploadProgressed} event of
     * this `sap.m.upload.Uploader`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUploadProgressed(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Uploader$UploadProgressedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:uploadStarted uploadStarted} event of this
     * `sap.m.upload.Uploader`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUploadStarted(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Uploader$UploadStartedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Starts the process of downloading a file.
     *
     *
     * @returns True if the download process successfully
     */
    downloadItem(
      /**
       * Item representing the file to be downloaded.
       */
      oItem: UploadSetItem,
      /**
       * List of header fields to be added to the GET request.
       */
      aHeaderFields: Item[],
      /**
       * True if the location to where download the file should be first queried by a browser dialog.
       */
      bAskForLocation: boolean
    ): boolean;
    /**
     * Fires event {@link #event:uploadAborted uploadAborted} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUploadAborted(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Uploader$UploadAbortedEventParameters
    ): this;
    /**
     * Fires event {@link #event:uploadCompleted uploadCompleted} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUploadCompleted(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Uploader$UploadCompletedEventParameters
    ): this;
    /**
     * Fires event {@link #event:uploadProgressed uploadProgressed} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUploadProgressed(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Uploader$UploadProgressedEventParameters
    ): this;
    /**
     * Fires event {@link #event:uploadStarted uploadStarted} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUploadStarted(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Uploader$UploadStartedEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getDownloadUrl downloadUrl}.
     *
     * URL where the next file is going to be download from.
     *
     *
     * @returns Value of property `downloadUrl`
     */
    getDownloadUrl(): string;
    /**
     * Gets current value of property {@link #getHttpRequestMethod httpRequestMethod}.
     *
     * HTTP request method chosen for file upload.
     *
     * Default value is `Post`.
     *
     * @since 1.90
     *
     * @returns Value of property `httpRequestMethod`
     */
    getHttpRequestMethod(): UploaderHttpRequestMethod;
    /**
     * Gets current value of property {@link #getUploadUrl uploadUrl}.
     *
     * URL where the next file is going to be uploaded to.
     *
     *
     * @returns Value of property `uploadUrl`
     */
    getUploadUrl(): string;
    /**
     * Gets current value of property {@link #getUseMultipart useMultipart}.
     *
     * This property decides the type of request. If set to "true", the request gets sent as a multipart/form-data
     * request instead of file only request.
     *
     * Default value is `false`.
     *
     * @since 1.92
     *
     * @returns Value of property `useMultipart`
     */
    getUseMultipart(): boolean;
    /**
     * Sets a new value for property {@link #getDownloadUrl downloadUrl}.
     *
     * URL where the next file is going to be download from.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDownloadUrl(
      /**
       * New value for property `downloadUrl`
       */
      sDownloadUrl?: string
    ): this;
    /**
     * Sets a new value for property {@link #getHttpRequestMethod httpRequestMethod}.
     *
     * HTTP request method chosen for file upload.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Post`.
     *
     * @since 1.90
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHttpRequestMethod(
      /**
       * New value for property `httpRequestMethod`
       */
      sHttpRequestMethod?: UploaderHttpRequestMethod
    ): this;
    /**
     * Sets a new value for property {@link #getUploadUrl uploadUrl}.
     *
     * URL where the next file is going to be uploaded to.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUploadUrl(
      /**
       * New value for property `uploadUrl`
       */
      sUploadUrl?: string
    ): this;
    /**
     * Sets a new value for property {@link #getUseMultipart useMultipart}.
     *
     * This property decides the type of request. If set to "true", the request gets sent as a multipart/form-data
     * request instead of file only request.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.92
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUseMultipart(
      /**
       * New value for property `useMultipart`
       */
      bUseMultipart?: boolean
    ): this;
    /**
     * Attempts to terminate the process of uploading the specified file.
     */
    terminateItem(
      /**
       * Item representing the file whose ongoing upload process is to be terminated.
       */
      oItem: UploadSetItem
    ): void;
    /**
     * Starts the process of uploading the specified file.
     */
    uploadItem(
      /**
       * Item representing the file to be uploaded.
       */
      oItem: UploadSetItem,
      /**
       * Collection of request header fields to be send along.
       */
      aHeaderFields?: Item[]
    ): void;
  }
  /**
   * Describes the settings that can be provided to the Uploader constructor.
   *
   * @deprecated As of version 1.129. replaced by {@link sap.m.upload.UploaderTableItem}
   */
  export interface $UploaderSettings extends $ElementSettings {
    /**
     * URL where the next file is going to be uploaded to.
     */
    uploadUrl?: string | PropertyBindingInfo;

    /**
     * URL where the next file is going to be download from.
     */
    downloadUrl?: string | PropertyBindingInfo;

    /**
     * HTTP request method chosen for file upload.
     *
     * @since 1.90
     */
    httpRequestMethod?:
      | UploaderHttpRequestMethod
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * This property decides the type of request. If set to "true", the request gets sent as a multipart/form-data
     * request instead of file only request.
     *
     * @since 1.92
     */
    useMultipart?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The event is fired just after the POST request was sent.
     */
    uploadStarted?: (oEvent: Uploader$UploadStartedEvent) => void;

    /**
     * The event is fired every time an XHR request reports progress in uploading.
     */
    uploadProgressed?: (oEvent: Uploader$UploadProgressedEvent) => void;

    /**
     * The event is fired when an XHR request reports successful completion of upload process.
     */
    uploadCompleted?: (oEvent: Uploader$UploadCompletedEvent) => void;

    /**
     * The event is fired when an XHR request reports its abortion.
     */
    uploadAborted?: (oEvent: Uploader$UploadAbortedEvent) => void;
  }

  /**
   * Parameters of the Uploader#uploadAborted event.
   */
  export interface Uploader$UploadAbortedEventParameters {
    /**
     * The item that is going to be deleted.
     */
    item?: UploadSetItem;
  }

  /**
   * Event object of the Uploader#uploadAborted event.
   */
  export type Uploader$UploadAbortedEvent = Event<
    Uploader$UploadAbortedEventParameters,
    Uploader
  >;

  /**
   * Parameters of the Uploader#uploadCompleted event.
   */
  export interface Uploader$UploadCompletedEventParameters {
    /**
     * The item that was uploaded.
     */
    item?: UploadSetItem;

    /**
     * A JSON object containing the additional response parameters like response, responseXML, readyState, status
     * and headers. Sample response object:
     * ```javascript
     *
     * {
     *    response: "\n...\n",
     *    responseXML: null,
     *    readyState: 2,
     *    status: 404,
     *    headers: "allow: GET, HEAD"
     * }
     * ```
     */
    responseXHR?: object;
  }

  /**
   * Event object of the Uploader#uploadCompleted event.
   */
  export type Uploader$UploadCompletedEvent = Event<
    Uploader$UploadCompletedEventParameters,
    Uploader
  >;

  /**
   * Parameters of the Uploader#uploadProgressed event.
   */
  export interface Uploader$UploadProgressedEventParameters {
    /**
     * The item that is being uploaded.
     */
    item?: UploadSetItem;

    /**
     * The number of bytes transferred since the beginning of the operation. This doesn't include headers and
     * other overhead, but only the content itself
     */
    loaded?: int;

    /**
     * The total number of bytes of content that will be transferred during the operation. If the total size
     * is unknown, this value is zero.
     */
    total?: int;
  }

  /**
   * Event object of the Uploader#uploadProgressed event.
   */
  export type Uploader$UploadProgressedEvent = Event<
    Uploader$UploadProgressedEventParameters,
    Uploader
  >;

  /**
   * Parameters of the Uploader#uploadStarted event.
   */
  export interface Uploader$UploadStartedEventParameters {
    /**
     * The item that is going to be uploaded.
     */
    item?: UploadSetItem;
  }

  /**
   * Event object of the Uploader#uploadStarted event.
   */
  export type Uploader$UploadStartedEvent = Event<
    Uploader$UploadStartedEventParameters,
    Uploader
  >;
}

declare module "sap/m/upload/UploaderHttpRequestMethod" {
  /**
   * Types of HTTP request methods.
   *
   * @since 1.90
   */
  enum UploaderHttpRequestMethod {
    /**
     * HTTP request POST method.
     */
    Post = "POST",
    /**
     * HTTP request PUT method.
     */
    Put = "PUT",
  }
  export default UploaderHttpRequestMethod;
}

declare module "sap/m/upload/UploaderTableItem" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import UploadItem from "sap/m/upload/UploadItem";

  import Item from "sap/ui/core/Item";

  import UploaderHttpRequestMethod from "sap/m/upload/UploaderHttpRequestMethod";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * A basic implementation for uploading and downloading one or multiple files.
   *
   * @since 1.120
   */
  export default class UploaderTableItem extends UI5Element {
    /**
     * Constructor for a new Uploader.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor();

    /**
     * Creates a new subclass of class sap.m.upload.UploaderTableItem with name `sClassName` and enriches it
     * with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, UploaderTableItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.upload.UploaderTableItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Starts the function for uploading one file object to a given URL. Returns promise that is resolved when
     * the upload is finished, or is rejected when the upload fails.
     *
     *
     * @returns Promise that is resolved when the upload is finished, or is rejected when the upload fails.
     */
    static uploadFile(
      /**
       * File or blob object to be uploaded.
       */
      oFile: File | Blob,
      /**
       * Upload Url.
       */
      sUrl: string,
      /**
       * Collection of request header fields to be send along.
       */
      aHeaderFields?: Item[]
    ): Promise<any>;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadCompleted uploadCompleted} event of this
     * `sap.m.upload.UploaderTableItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploaderTableItem` itself.
     *
     * The event is fired when an XHR request reports successful completion of upload process.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadCompleted(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploaderTableItem$UploadCompletedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploaderTableItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadCompleted uploadCompleted} event of this
     * `sap.m.upload.UploaderTableItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploaderTableItem` itself.
     *
     * The event is fired when an XHR request reports successful completion of upload process.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadCompleted(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploaderTableItem$UploadCompletedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploaderTableItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadProgressed uploadProgressed} event of
     * this `sap.m.upload.UploaderTableItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploaderTableItem` itself.
     *
     * The event is fired every time an XHR request reports progress while uploading.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadProgressed(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploaderTableItem$UploadProgressedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploaderTableItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadProgressed uploadProgressed} event of
     * this `sap.m.upload.UploaderTableItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploaderTableItem` itself.
     *
     * The event is fired every time an XHR request reports progress while uploading.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadProgressed(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploaderTableItem$UploadProgressedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploaderTableItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadStarted uploadStarted} event of this `sap.m.upload.UploaderTableItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploaderTableItem` itself.
     *
     * The event is fired just after the POST request is sent.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadStarted(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploaderTableItem$UploadStartedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploaderTableItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadStarted uploadStarted} event of this `sap.m.upload.UploaderTableItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploaderTableItem` itself.
     *
     * The event is fired just after the POST request is sent.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadStarted(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploaderTableItem$UploadStartedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploaderTableItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadTerminated uploadTerminated} event of
     * this `sap.m.upload.UploaderTableItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploaderTableItem` itself.
     *
     * The event is fired when an XHR request reports its termination.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadTerminated(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploaderTableItem$UploadTerminatedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploaderTableItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadTerminated uploadTerminated} event of
     * this `sap.m.upload.UploaderTableItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploaderTableItem` itself.
     *
     * The event is fired when an XHR request reports its termination.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadTerminated(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploaderTableItem$UploadTerminatedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploaderTableItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:uploadCompleted uploadCompleted} event of
     * this `sap.m.upload.UploaderTableItem`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUploadCompleted(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploaderTableItem$UploadCompletedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:uploadProgressed uploadProgressed} event of
     * this `sap.m.upload.UploaderTableItem`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUploadProgressed(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploaderTableItem$UploadProgressedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:uploadStarted uploadStarted} event of this
     * `sap.m.upload.UploaderTableItem`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUploadStarted(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploaderTableItem$UploadStartedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:uploadTerminated uploadTerminated} event of
     * this `sap.m.upload.UploaderTableItem`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUploadTerminated(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploaderTableItem$UploadTerminatedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Starts the process of downloading a file. Plugin uses the URL set in the item or the downloadUrl set
     * in the uploader class to download the file. If the URL is not set, a warning is logged. API downloads
     * the file with xhr response of blob type or string type.
     *
     *
     * @returns It returns true if the download is processed successfully
     */
    download(
      /**
       * Item representing the file to be downloaded.
       */
      oItem: UploadItem,
      /**
       * List of header fields to be added to the GET request.
       */
      aHeaderFields: Item[],
      /**
       * If it is true, the location of where the file is to be downloaded is queried by a browser dialog.
       */
      bAskForLocation: boolean
    ): boolean;
    /**
     * Fires event {@link #event:uploadCompleted uploadCompleted} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUploadCompleted(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploaderTableItem$UploadCompletedEventParameters
    ): this;
    /**
     * Fires event {@link #event:uploadProgressed uploadProgressed} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUploadProgressed(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploaderTableItem$UploadProgressedEventParameters
    ): this;
    /**
     * Fires event {@link #event:uploadStarted uploadStarted} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUploadStarted(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploaderTableItem$UploadStartedEventParameters
    ): this;
    /**
     * Fires event {@link #event:uploadTerminated uploadTerminated} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUploadTerminated(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploaderTableItem$UploadTerminatedEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getDownloadUrl downloadUrl}.
     *
     * URL where the next file is going to be downloaded from.
     *
     *
     * @returns Value of property `downloadUrl`
     */
    getDownloadUrl(): string;
    /**
     * Gets current value of property {@link #getHttpRequestMethod httpRequestMethod}.
     *
     * HTTP request method chosen for file upload.
     *
     * Default value is `Post`.
     *
     *
     * @returns Value of property `httpRequestMethod`
     */
    getHttpRequestMethod(): UploaderHttpRequestMethod;
    /**
     * Gets current value of property {@link #getUploadUrl uploadUrl}.
     *
     * URL where the next file is going to be uploaded to.
     *
     *
     * @returns Value of property `uploadUrl`
     */
    getUploadUrl(): string;
    /**
     * Gets current value of property {@link #getUseMultipart useMultipart}.
     *
     * This property decides the type of request. If set to "true", the request gets sent as a multipart/form-data
     * request instead of file only request.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `useMultipart`
     */
    getUseMultipart(): boolean;
    /**
     * Sets a new value for property {@link #getDownloadUrl downloadUrl}.
     *
     * URL where the next file is going to be downloaded from.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDownloadUrl(
      /**
       * New value for property `downloadUrl`
       */
      sDownloadUrl?: string
    ): this;
    /**
     * Sets a new value for property {@link #getHttpRequestMethod httpRequestMethod}.
     *
     * HTTP request method chosen for file upload.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Post`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHttpRequestMethod(
      /**
       * New value for property `httpRequestMethod`
       */
      sHttpRequestMethod?: UploaderHttpRequestMethod
    ): this;
    /**
     * Sets a new value for property {@link #getUploadUrl uploadUrl}.
     *
     * URL where the next file is going to be uploaded to.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUploadUrl(
      /**
       * New value for property `uploadUrl`
       */
      sUploadUrl?: string
    ): this;
    /**
     * Sets a new value for property {@link #getUseMultipart useMultipart}.
     *
     * This property decides the type of request. If set to "true", the request gets sent as a multipart/form-data
     * request instead of file only request.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUseMultipart(
      /**
       * New value for property `useMultipart`
       */
      bUseMultipart?: boolean
    ): this;
    /**
     * Attempts to terminate the process of uploading the specified file.
     */
    terminateItem(
      /**
       * Item representing the file whose ongoing upload process is to be terminated.
       */
      oItem: UploadItem
    ): void;
    /**
     * Starts the process of uploading the specified file.
     */
    uploadItem(
      /**
       * Item representing the file to be uploaded.
       */
      oItem: UploadItem,
      /**
       * Collection of request header fields to be send along.
       */
      aHeaderFields?: Item[]
    ): void;
  }
  /**
   * Describes the settings that can be provided to the UploaderTableItem constructor.
   */
  export interface $UploaderTableItemSettings extends $ElementSettings {
    /**
     * URL where the next file is going to be uploaded to.
     */
    uploadUrl?: string | PropertyBindingInfo;

    /**
     * URL where the next file is going to be downloaded from.
     */
    downloadUrl?: string | PropertyBindingInfo;

    /**
     * HTTP request method chosen for file upload.
     */
    httpRequestMethod?:
      | UploaderHttpRequestMethod
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * This property decides the type of request. If set to "true", the request gets sent as a multipart/form-data
     * request instead of file only request.
     */
    useMultipart?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The event is fired just after the POST request is sent.
     */
    uploadStarted?: (oEvent: UploaderTableItem$UploadStartedEvent) => void;

    /**
     * The event is fired every time an XHR request reports progress while uploading.
     */
    uploadProgressed?: (
      oEvent: UploaderTableItem$UploadProgressedEvent
    ) => void;

    /**
     * The event is fired when an XHR request reports successful completion of upload process.
     */
    uploadCompleted?: (oEvent: UploaderTableItem$UploadCompletedEvent) => void;

    /**
     * The event is fired when an XHR request reports its termination.
     */
    uploadTerminated?: (
      oEvent: UploaderTableItem$UploadTerminatedEvent
    ) => void;
  }

  /**
   * Parameters of the UploaderTableItem#uploadCompleted event.
   */
  export interface UploaderTableItem$UploadCompletedEventParameters {
    /**
     * The item {@link sap.m.upload.UploadItem UploadItem} that was uploaded.
     */
    item?: any;

    /**
     * A JSON object containing the additional response parameters like response, responseXML, readyState, status
     * and headers. Sample response object:
     * ```javascript
     *
     * {
     *    response: "\n...\n",
     *    responseXML: null,
     *    readyState: 2,
     *    status: 404,
     *    headers: "allow: GET, HEAD"
     * }
     * ```
     */
    responseXHR?: object;
  }

  /**
   * Event object of the UploaderTableItem#uploadCompleted event.
   */
  export type UploaderTableItem$UploadCompletedEvent = Event<
    UploaderTableItem$UploadCompletedEventParameters,
    UploaderTableItem
  >;

  /**
   * Parameters of the UploaderTableItem#uploadProgressed event.
   */
  export interface UploaderTableItem$UploadProgressedEventParameters {
    /**
     * The item {@link sap.m.upload.UploadItem UploadItem} that is being uploaded.
     */
    item?: any;

    /**
     * The number of bytes transferred since the beginning of the operation. This doesn't include headers and
     * other overhead, but only the content itself
     */
    loaded?: int;

    /**
     * The total number of bytes of content that is transferred during the operation. If the total size is unknown,
     * this value is zero.
     */
    total?: int;
  }

  /**
   * Event object of the UploaderTableItem#uploadProgressed event.
   */
  export type UploaderTableItem$UploadProgressedEvent = Event<
    UploaderTableItem$UploadProgressedEventParameters,
    UploaderTableItem
  >;

  /**
   * Parameters of the UploaderTableItem#uploadStarted event.
   */
  export interface UploaderTableItem$UploadStartedEventParameters {
    /**
     * The item {@link sap.m.upload.UploadItem UploadItem} that is going to be uploaded.
     */
    item?: any;
  }

  /**
   * Event object of the UploaderTableItem#uploadStarted event.
   */
  export type UploaderTableItem$UploadStartedEvent = Event<
    UploaderTableItem$UploadStartedEventParameters,
    UploaderTableItem
  >;

  /**
   * Parameters of the UploaderTableItem#uploadTerminated event.
   */
  export interface UploaderTableItem$UploadTerminatedEventParameters {
    /**
     * The item that is going to be deleted.
     */
    item?: UploadItem;
  }

  /**
   * Event object of the UploaderTableItem#uploadTerminated event.
   */
  export type UploaderTableItem$UploadTerminatedEvent = Event<
    UploaderTableItem$UploadTerminatedEventParameters,
    UploaderTableItem
  >;
}

declare module "sap/m/upload/UploadItem" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import Item from "sap/ui/core/Item";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { UploadState } from "sap/m/library";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * `sap.m.upload.UploadItem` represents one item to be uploaded using the {@link sap.m.plugins.UploadSetwithTable UploadSetwithTable}
   *
   * **Note:** This element should only be used within the {@link sap.m.plugins.UploadSetwithTable UploadSetwithTable }
   * plugin.
   *
   * @since 1.124
   */
  export default class UploadItem extends UI5Element {
    /**
     * Constructor for a new UploadItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control.
       */
      mSettings?: $UploadItemSettings
    );
    /**
     * Constructor for a new UploadItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Id for the new control, it is generated automatically if no ID is provided.
       */
      sId?: string,
      /**
       * Initial settings for the new control.
       */
      mSettings?: $UploadItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.upload.UploadItem with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, UploadItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.upload.UploadItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some headerField to the aggregation {@link #getHeaderFields headerFields}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addHeaderField(
      /**
       * The headerField to add; if empty, nothing is inserted
       */
      oHeaderField: Item
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadProgress uploadProgress} event of this
     * `sap.m.upload.UploadItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadItem` itself.
     *
     * The event is fired every time an XHR request reports progress while uploading.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadProgress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadItem$UploadProgressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadProgress uploadProgress} event of this
     * `sap.m.upload.UploadItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadItem` itself.
     *
     * The event is fired every time an XHR request reports progress while uploading.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadProgress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadItem$UploadProgressEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadTerminated uploadTerminated} event of
     * this `sap.m.upload.UploadItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadItem` itself.
     *
     * This event is fired right after the upload is terminated.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadTerminated(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadItem$UploadTerminatedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadTerminated uploadTerminated} event of
     * this `sap.m.upload.UploadItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadItem` itself.
     *
     * This event is fired right after the upload is terminated.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadTerminated(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadItem$UploadTerminatedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the headerFields in the aggregation {@link #getHeaderFields headerFields}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyHeaderFields(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:uploadProgress uploadProgress} event of this
     * `sap.m.upload.UploadItem`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUploadProgress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadItem$UploadProgressEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:uploadTerminated uploadTerminated} event of
     * this `sap.m.upload.UploadItem`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUploadTerminated(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadItem$UploadTerminatedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Downloads the item. Only possible when the item has a valid URL specified in the `url` property.
     *
     *
     * @returns `true` if download is possible, `false` otherwise.
     */
    download(
      /**
       * Whether to ask for a location where to download the file or not.
       */
      bAskForLocation: boolean
    ): boolean;
    /**
     * Fires event {@link #event:uploadProgress uploadProgress} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUploadProgress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadItem$UploadProgressEventParameters
    ): this;
    /**
     * Fires event {@link #event:uploadTerminated uploadTerminated} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUploadTerminated(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadItem$UploadTerminatedEventParameters
    ): this;
    /**
     * Returns the details of the file selected from the CloudFilePicker control.
     *
     *
     * @returns oCloudFileInfo Specifies the details of the file selected from the cloudFilePicker control.
     */
    getCloudFileInfo(): /* was: sap.suite.ui.commons.CloudFileInfo */ any;
    /**
     * Gets current value of property {@link #getFileName fileName}.
     *
     * Specifies the name of the uploaded file.
     *
     *
     * @returns Value of property `fileName`
     */
    getFileName(): string;
    /**
     * Returns file object.
     *
     *
     * @returns File object.
     */
    getFileObject(): File | Blob;
    /**
     * Gets current value of property {@link #getFileSize fileSize}.
     *
     * Specifies file size of the item in bytes.
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `fileSize`
     */
    getFileSize(): float;
    /**
     * Gets content of aggregation {@link #getHeaderFields headerFields}.
     *
     * Header fields to be included in the header section of an XMLHttpRequest (XHR) request
     */
    getHeaderFields(): Item[];
    /**
     * Gets current value of property {@link #getIsTrustedSource isTrustedSource}.
     *
     * This property is used in the {@link sap.m.upload.FilePreviewDialog FilePreviewDialog} to determine if
     * the file is from a trusted source before displaying. This property must be set to true if the file is
     * from a trusted source.
     *
     * Default value is `false`.
     *
     * @since 1.125
     *
     * @returns Value of property `isTrustedSource`
     */
    getIsTrustedSource(): boolean;
    /**
     * Gets current value of property {@link #getMediaType mediaType}.
     *
     * Specifies the MIME type of the file.
     *
     *
     * @returns Value of property `mediaType`
     */
    getMediaType(): string;
    /**
     * Gets current value of property {@link #getPreviewable previewable}.
     *
     * Specifies whether the item can be previewed.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `previewable`
     */
    getPreviewable(): boolean;
    /**
     * Gets current value of property {@link #getUploadState uploadState}.
     *
     * State of the item relevant to its upload process.
     *
     *
     * @returns Value of property `uploadState`
     */
    getUploadState(): UploadState;
    /**
     * Gets current value of property {@link #getUploadUrl uploadUrl}.
     *
     * URL where the uploaded files are stored. If empty, uploadUrl from the uploader is considered.
     *
     *
     * @returns Value of property `uploadUrl`
     */
    getUploadUrl(): string;
    /**
     * Gets current value of property {@link #getUrl url}.
     *
     * Specifies the URL where the file is located.
     *
     *
     * @returns Value of property `url`
     */
    getUrl(): string;
    /**
     * Checks for the provided `sap.ui.core.Item` in the aggregation {@link #getHeaderFields headerFields}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfHeaderField(
      /**
       * The headerField whose index is looked for
       */
      oHeaderField: Item
    ): int;
    /**
     * Inserts a headerField into the aggregation {@link #getHeaderFields headerFields}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertHeaderField(
      /**
       * The headerField to insert; if empty, nothing is inserted
       */
      oHeaderField: Item,
      /**
       * The `0`-based index the headerField should be inserted at; for a negative value of `iIndex`, the headerField
       * is inserted at position 0; for a value greater than the current size of the aggregation, the headerField
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Validates if the item is restricted, to check if it is restricted for the file type, media type, maximum
     * file name length and maximum file size limit.
     *
     *
     * @returns `true` if item is restricted, `false` otherwise.
     */
    isRestricted(): boolean;
    /**
     * Removes all the controls from the aggregation {@link #getHeaderFields headerFields}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllHeaderFields(): Item[];
    /**
     * Removes a headerField from the aggregation {@link #getHeaderFields headerFields}.
     *
     *
     * @returns The removed headerField or `null`
     */
    removeHeaderField(
      /**
       * The headerField to remove or its index or id
       */
      vHeaderField: int | string | Item
    ): Item | null;
    /**
     * Sets a new value for property {@link #getFileName fileName}.
     *
     * Specifies the name of the uploaded file.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFileName(
      /**
       * New value for property `fileName`
       */
      sFileName?: string
    ): this;
    /**
     * Sets a new value for property {@link #getFileSize fileSize}.
     *
     * Specifies file size of the item in bytes.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `0`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFileSize(
      /**
       * New value for property `fileSize`
       */
      fFileSize?: float
    ): this;
    /**
     * Sets a new value for property {@link #getIsTrustedSource isTrustedSource}.
     *
     * This property is used in the {@link sap.m.upload.FilePreviewDialog FilePreviewDialog} to determine if
     * the file is from a trusted source before displaying. This property must be set to true if the file is
     * from a trusted source.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.125
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIsTrustedSource(
      /**
       * New value for property `isTrustedSource`
       */
      bIsTrustedSource?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getMediaType mediaType}.
     *
     * Specifies the MIME type of the file.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMediaType(
      /**
       * New value for property `mediaType`
       */
      sMediaType?: string
    ): this;
    /**
     * Sets a new value for property {@link #getPreviewable previewable}.
     *
     * Specifies whether the item can be previewed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPreviewable(
      /**
       * New value for property `previewable`
       */
      bPreviewable?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getUploadState uploadState}.
     *
     * State of the item relevant to its upload process.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUploadState(
      /**
       * New value for property `uploadState`
       */
      sUploadState?: UploadState | keyof typeof UploadState
    ): this;
    /**
     * Sets a new value for property {@link #getUploadUrl uploadUrl}.
     *
     * URL where the uploaded files are stored. If empty, uploadUrl from the uploader is considered.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUploadUrl(
      /**
       * New value for property `uploadUrl`
       */
      sUploadUrl?: string
    ): this;
    /**
     * Sets a new value for property {@link #getUrl url}.
     *
     * Specifies the URL where the file is located.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUrl(
      /**
       * New value for property `url`
       */
      sUrl?: string
    ): this;
    /**
     * API to terminate the upload of an item. With success, the event `uploadTerminated` is fired on the `UploadItem`.
     * Termination is only possible if the item is in `Uploading` state and uploadItem is associated with `UploadSetwithTable`
     * plugin.
     *
     * @since 1.134
     */
    terminateUpload(): void;
  }
  /**
   * Describes the settings that can be provided to the UploadItem constructor.
   */
  export interface $UploadItemSettings extends $ElementSettings {
    /**
     * Specifies the name of the uploaded file.
     */
    fileName?: string | PropertyBindingInfo;

    /**
     * Specifies the MIME type of the file.
     */
    mediaType?: string | PropertyBindingInfo;

    /**
     * Specifies the URL where the file is located.
     */
    url?: string | PropertyBindingInfo;

    /**
     * URL where the uploaded files are stored. If empty, uploadUrl from the uploader is considered.
     */
    uploadUrl?: string | PropertyBindingInfo;

    /**
     * State of the item relevant to its upload process.
     */
    uploadState?:
      | (UploadState | keyof typeof UploadState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies whether the item can be previewed.
     */
    previewable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies file size of the item in bytes.
     */
    fileSize?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * This property is used in the {@link sap.m.upload.FilePreviewDialog FilePreviewDialog} to determine if
     * the file is from a trusted source before displaying. This property must be set to true if the file is
     * from a trusted source.
     *
     * @since 1.125
     */
    isTrustedSource?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Header fields to be included in the header section of an XMLHttpRequest (XHR) request
     */
    headerFields?: Item[] | Item | AggregationBindingInfo | `{${string}}`;

    /**
     * The event is fired every time an XHR request reports progress while uploading.
     */
    uploadProgress?: (oEvent: UploadItem$UploadProgressEvent) => void;

    /**
     * This event is fired right after the upload is terminated.
     */
    uploadTerminated?: (oEvent: UploadItem$UploadTerminatedEvent) => void;
  }

  /**
   * Parameters of the UploadItem#uploadProgress event.
   */
  export interface UploadItem$UploadProgressEventParameters {
    /**
     * The number of bytes transferred since the beginning of the operation. laoded parameter doesn't include
     * headers and other overhead, but only the content itself
     */
    loaded?: int;

    /**
     * The total number of bytes of content that is transferred during the operation. If the total size is unknown,
     * this value is zero.
     */
    total?: int;
  }

  /**
   * Event object of the UploadItem#uploadProgress event.
   */
  export type UploadItem$UploadProgressEvent = Event<
    UploadItem$UploadProgressEventParameters,
    UploadItem
  >;

  /**
   * Parameters of the UploadItem#uploadTerminated event.
   */
  export interface UploadItem$UploadTerminatedEventParameters {
    /**
     * The file whose upload has just been terminated.
     */
    item?: UploadItem;
  }

  /**
   * Event object of the UploadItem#uploadTerminated event.
   */
  export type UploadItem$UploadTerminatedEvent = Event<
    UploadItem$UploadTerminatedEventParameters,
    UploadItem
  >;
}

declare module "sap/m/upload/UploadItemConfiguration" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * `sap.m.UploadItemConfiguration` represents the configuration for the items in the {@link sap.m.plugins.UploadSetwithTable UploadSetwithTable }
   * plugin.
   * The configuration template represents the paths in the model to the file name, mediaType, url, uploadUrl,
   * previewable, and file size properties in reference to the {@link sap.m.upload.UploadItem UploadItem}.
   * This is essential for the plugin in understanding the structure of the model data bound to continue with
   * operations.
   * **Note:** Configuration is mandatory for the plugin to offer the features such as file preview, download,
   * rename etc. The element must be used only within the {@link sap.m.plugins.UploadSetwithTable UploadSetwithTable }
   * plugin.
   *
   * @since 1.124
   */
  export default class UploadItemConfiguration extends UI5Element {
    /**
     * Constructor for a new UploadItemConfiguration.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new Element.
       */
      mSettings?: $UploadItemConfigurationSettings
    );
    /**
     * Constructor for a new UploadItemConfiguration.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Id for the new Element, it is generated automatically if no ID is provided.
       */
      sId?: string,
      /**
       * Initial settings for the new Element.
       */
      mSettings?: $UploadItemConfigurationSettings
    );

    /**
     * Creates a new subclass of class sap.m.upload.UploadItemConfiguration with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, UploadItemConfiguration>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.upload.UploadItemConfiguration.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getFileNamePath fileNamePath}.
     *
     * Specifies the path in the model to the file name
     *
     *
     * @returns Value of property `fileNamePath`
     */
    getFileNamePath(): string;
    /**
     * Gets current value of property {@link #getFileSizePath fileSizePath}.
     *
     * Specifies path in the model to the file size.
     *
     *
     * @returns Value of property `fileSizePath`
     */
    getFileSizePath(): string;
    /**
     * Gets current value of property {@link #getIsTrustedSourcePath isTrustedSourcePath}.
     *
     * Specifies the path in the model to confirm if the file is from a trusted source. This is used to determine
     * if the file is uploaded from a trusted source. If the file is uploaded from a trusted source, the file
     * can be previewed. Set this property to the path in the model that determines if the file is uploaded
     * from a trusted source.
     *
     * @since 1.125
     *
     * @returns Value of property `isTrustedSourcePath`
     */
    getIsTrustedSourcePath(): string;
    /**
     * Gets current value of property {@link #getMediaTypePath mediaTypePath}.
     *
     * Specifies the path in the model to the file mediaType.
     *
     *
     * @returns Value of property `mediaTypePath`
     */
    getMediaTypePath(): string;
    /**
     * Gets current value of property {@link #getPreviewablePath previewablePath}.
     *
     * Specifies the path in the model to determine if the file uploaded can be previewed.
     *
     *
     * @returns Value of property `previewablePath`
     */
    getPreviewablePath(): string;
    /**
     * Gets current value of property {@link #getUploadUrlPath uploadUrlPath}.
     *
     * Specifies the path in the model for upload URL. Used to upload the file.
     *
     *
     * @returns Value of property `uploadUrlPath`
     */
    getUploadUrlPath(): string;
    /**
     * Gets current value of property {@link #getUrlPath urlPath}.
     *
     * Specifies the path in the model to the file URL. It is used to download/access the file.
     *
     *
     * @returns Value of property `urlPath`
     */
    getUrlPath(): string;
    /**
     * Sets a new value for property {@link #getFileNamePath fileNamePath}.
     *
     * Specifies the path in the model to the file name
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFileNamePath(
      /**
       * New value for property `fileNamePath`
       */
      sFileNamePath?: string
    ): this;
    /**
     * Sets a new value for property {@link #getFileSizePath fileSizePath}.
     *
     * Specifies path in the model to the file size.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFileSizePath(
      /**
       * New value for property `fileSizePath`
       */
      sFileSizePath?: string
    ): this;
    /**
     * Sets a new value for property {@link #getIsTrustedSourcePath isTrustedSourcePath}.
     *
     * Specifies the path in the model to confirm if the file is from a trusted source. This is used to determine
     * if the file is uploaded from a trusted source. If the file is uploaded from a trusted source, the file
     * can be previewed. Set this property to the path in the model that determines if the file is uploaded
     * from a trusted source.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.125
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIsTrustedSourcePath(
      /**
       * New value for property `isTrustedSourcePath`
       */
      sIsTrustedSourcePath?: string
    ): this;
    /**
     * Sets a new value for property {@link #getMediaTypePath mediaTypePath}.
     *
     * Specifies the path in the model to the file mediaType.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMediaTypePath(
      /**
       * New value for property `mediaTypePath`
       */
      sMediaTypePath?: string
    ): this;
    /**
     * Sets a new value for property {@link #getPreviewablePath previewablePath}.
     *
     * Specifies the path in the model to determine if the file uploaded can be previewed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPreviewablePath(
      /**
       * New value for property `previewablePath`
       */
      sPreviewablePath?: string
    ): this;
    /**
     * Sets a new value for property {@link #getUploadUrlPath uploadUrlPath}.
     *
     * Specifies the path in the model for upload URL. Used to upload the file.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUploadUrlPath(
      /**
       * New value for property `uploadUrlPath`
       */
      sUploadUrlPath?: string
    ): this;
    /**
     * Sets a new value for property {@link #getUrlPath urlPath}.
     *
     * Specifies the path in the model to the file URL. It is used to download/access the file.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUrlPath(
      /**
       * New value for property `urlPath`
       */
      sUrlPath?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the UploadItemConfiguration constructor.
   */
  export interface $UploadItemConfigurationSettings extends $ElementSettings {
    /**
     * Specifies the path in the model to the file name
     */
    fileNamePath?: string | PropertyBindingInfo;

    /**
     * Specifies the path in the model to the file mediaType.
     */
    mediaTypePath?: string | PropertyBindingInfo;

    /**
     * Specifies the path in the model to the file URL. It is used to download/access the file.
     */
    urlPath?: string | PropertyBindingInfo;

    /**
     * Specifies the path in the model for upload URL. Used to upload the file.
     */
    uploadUrlPath?: string | PropertyBindingInfo;

    /**
     * Specifies the path in the model to determine if the file uploaded can be previewed.
     */
    previewablePath?: string | PropertyBindingInfo;

    /**
     * Specifies path in the model to the file size.
     */
    fileSizePath?: string | PropertyBindingInfo;

    /**
     * Specifies the path in the model to confirm if the file is from a trusted source. This is used to determine
     * if the file is uploaded from a trusted source. If the file is uploaded from a trusted source, the file
     * can be previewed. Set this property to the path in the model that determines if the file is uploaded
     * from a trusted source.
     *
     * @since 1.125
     */
    isTrustedSourcePath?: string | PropertyBindingInfo;
  }
}

declare module "sap/m/upload/UploadSet" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import Item from "sap/ui/core/Item";

  import UploadSetItem from "sap/m/upload/UploadSetItem";

  import Event from "sap/ui/base/Event";

  import { URI } from "sap/ui/core/library";

  import FileUploader from "sap/ui/unified/FileUploader";

  import UploaderHttpRequestMethod from "sap/m/upload/UploaderHttpRequestMethod";

  import IllustratedMessage from "sap/m/IllustratedMessage";

  import List from "sap/m/List";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { ListMode } from "sap/m/library";

  import IllustratedMessageType from "sap/m/IllustratedMessageType";

  import OverflowToolbar from "sap/m/OverflowToolbar";

  import Uploader from "sap/m/upload/Uploader";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * This control allows you to upload one or more files from your devices (desktop, tablet, or phone) and
   * attach them to your application.
   *  This control builds on the {@link sap.m.UploadCollection} control, providing better handling of headers
   * and requests, unified behavior of instant and deferred uploads, as well as improved progress indication.
   *  We now ensure that the control handles item insertion and deletion if the items aggregation is not bound
   * to a model. It allows the connected model to not only manage the insertion and deletion updates but it
   * also helps to avoid template-related issues and ensures better data handling.
   *
   * @since 1.63
   * @deprecated As of version 1.129. replaced by {@link sap.m.plugins.UploadSetwithTable}
   */
  export default class UploadSet extends Control {
    /**
     * Constructor for a new UploadSet.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control.
       */
      mSettings?: $UploadSetSettings
    );
    /**
     * Constructor for a new UploadSet.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given.
       */
      sId?: string,
      /**
       * Initial settings for the new control.
       */
      mSettings?: $UploadSetSettings
    );

    /**
     * Creates a new subclass of class sap.m.upload.UploadSet with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, UploadSet>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.upload.UploadSet.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some headerField to the aggregation {@link #getHeaderFields headerFields}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addHeaderField(
      /**
       * The headerField to add; if empty, nothing is inserted
       */
      oHeaderField: Item
    ): this;
    /**
     * Adds some incompleteItem to the aggregation {@link #getIncompleteItems incompleteItems}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addIncompleteItem(
      /**
       * The incompleteItem to add; if empty, nothing is inserted
       */
      oIncompleteItem: UploadSetItem
    ): this;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: UploadSetItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterItemAdded afterItemAdded} event of this
     * `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired when a new file is added to the set of items to be uploaded.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterItemAdded(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$AfterItemAddedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterItemAdded afterItemAdded} event of this
     * `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired when a new file is added to the set of items to be uploaded.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterItemAdded(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$AfterItemAddedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterItemEdited afterItemEdited} event of this
     * `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired after item edit is confirmed.
     *
     * @since 1.83
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterItemEdited(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$AfterItemEditedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterItemEdited afterItemEdited} event of this
     * `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired after item edit is confirmed.
     *
     * @since 1.83
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterItemEdited(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$AfterItemEditedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterItemRemoved afterItemRemoved} event of
     * this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired after the item is removed on click of ok button in confirmation dialog.
     *
     * @since 1.83
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterItemRemoved(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$AfterItemRemovedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:afterItemRemoved afterItemRemoved} event of
     * this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired after the item is removed on click of ok button in confirmation dialog.
     *
     * @since 1.83
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachAfterItemRemoved(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$AfterItemRemovedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeItemAdded beforeItemAdded} event of this
     * `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired just before a new file is added to the set of items to be uploaded.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeItemAdded(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$BeforeItemAddedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeItemAdded beforeItemAdded} event of this
     * `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired just before a new file is added to the set of items to be uploaded.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeItemAdded(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$BeforeItemAddedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeItemEdited beforeItemEdited} event of
     * this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired when the edit button is clicked for an item and no other item is being edited at
     * the same time.
     * If there is another item that has unsaved changes, the editing of the clicked item cannot be started.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeItemEdited(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$BeforeItemEditedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeItemEdited beforeItemEdited} event of
     * this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired when the edit button is clicked for an item and no other item is being edited at
     * the same time.
     * If there is another item that has unsaved changes, the editing of the clicked item cannot be started.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeItemEdited(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$BeforeItemEditedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeItemRemoved beforeItemRemoved} event of
     * this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired just before the confirmation dialog for 'Remove' action is displayed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeItemRemoved(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$BeforeItemRemovedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeItemRemoved beforeItemRemoved} event of
     * this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired just before the confirmation dialog for 'Remove' action is displayed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeItemRemoved(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$BeforeItemRemovedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeUploadStarts beforeUploadStarts} event
     * of this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired right before the upload process begins.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeUploadStarts(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$BeforeUploadStartsEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeUploadStarts beforeUploadStarts} event
     * of this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired right before the upload process begins.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeUploadStarts(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$BeforeUploadStartsEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeUploadTermination beforeUploadTermination }
     * event of this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired right before the upload is terminated.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeUploadTermination(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$BeforeUploadTerminationEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeUploadTermination beforeUploadTermination }
     * event of this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired right before the upload is terminated.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeUploadTermination(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$BeforeUploadTerminationEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileNameLengthExceeded fileNameLengthExceeded }
     * event of this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the file name length restriction specified
     *     in the `maxFileNameLength` property.
     * 	 - When the file name length restriction changes, and the file to be uploaded fails to meet the new
     *     restriction.
     * 	 - Listeners can use the item parameter to remove the incomplete item that failed to meet the restriction
     *
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileNameLengthExceeded(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$FileNameLengthExceededEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileNameLengthExceeded fileNameLengthExceeded }
     * event of this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the file name length restriction specified
     *     in the `maxFileNameLength` property.
     * 	 - When the file name length restriction changes, and the file to be uploaded fails to meet the new
     *     restriction.
     * 	 - Listeners can use the item parameter to remove the incomplete item that failed to meet the restriction
     *
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileNameLengthExceeded(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$FileNameLengthExceededEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileRenamed fileRenamed} event of this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * The event is triggered when the file name is changed.
     *
     * @since 1.100.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileRenamed(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$FileRenamedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileRenamed fileRenamed} event of this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * The event is triggered when the file name is changed.
     *
     * @since 1.100.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileRenamed(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$FileRenamedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileSizeExceeded fileSizeExceeded} event of
     * this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the file size restriction specified in
     *     the `maxFileSize` property.
     * 	 - When the file size restriction changes, and the file to be uploaded fails to meet the new restriction.
     *
     * 	 - Listeners can use the item parameter to remove the incomplete item that failed to meet the restriction
     *
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileSizeExceeded(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$FileSizeExceededEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileSizeExceeded fileSizeExceeded} event of
     * this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the file size restriction specified in
     *     the `maxFileSize` property.
     * 	 - When the file size restriction changes, and the file to be uploaded fails to meet the new restriction.
     *
     * 	 - Listeners can use the item parameter to remove the incomplete item that failed to meet the restriction
     *
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileSizeExceeded(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$FileSizeExceededEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileTypeMismatch fileTypeMismatch} event of
     * this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the file type restriction (`fileType` property).
     *
     * 	 - When the file type restriction changes, and the file to be uploaded fails to meet the new restriction.
     *
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileTypeMismatch(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$FileTypeMismatchEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileTypeMismatch fileTypeMismatch} event of
     * this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the file type restriction (`fileType` property).
     *
     * 	 - When the file type restriction changes, and the file to be uploaded fails to meet the new restriction.
     *
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileTypeMismatch(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$FileTypeMismatchEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemDragStart itemDragStart} event of this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired when the user starts dragging an uploaded item.
     *
     * @since 1.99
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemDragStart(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemDragStart itemDragStart} event of this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired when the user starts dragging an uploaded item.
     *
     * @since 1.99
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemDragStart(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemDrop itemDrop} event of this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired when an uploaded item is dropped on the new list position.
     *
     * @since 1.99
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemDrop(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:itemDrop itemDrop} event of this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired when an uploaded item is dropped on the new list position.
     *
     * @since 1.99
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachItemDrop(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:mediaTypeMismatch mediaTypeMismatch} event of
     * this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the media type restriction specified in
     *     the `mediaTypes` property.
     * 	 - When the media type restriction changes, and the file to be uploaded fails to meet the new restriction.
     *
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachMediaTypeMismatch(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$MediaTypeMismatchEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:mediaTypeMismatch mediaTypeMismatch} event of
     * this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the media type restriction specified in
     *     the `mediaTypes` property.
     * 	 - When the media type restriction changes, and the file to be uploaded fails to meet the new restriction.
     *
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachMediaTypeMismatch(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$MediaTypeMismatchEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionChanged selectionChanged} event of
     * this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired simultaneously with the respective event in the inner {@link sap.m.List} control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionChanged(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$SelectionChangedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionChanged selectionChanged} event of
     * this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired simultaneously with the respective event in the inner {@link sap.m.List} control.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionChanged(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$SelectionChangedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadCompleted uploadCompleted} event of this
     * `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired right after the upload process is finished.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadCompleted(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$UploadCompletedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadCompleted uploadCompleted} event of this
     * `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired right after the upload process is finished.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadCompleted(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$UploadCompletedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadTerminated uploadTerminated} event of
     * this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired right after the upload is terminated.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadTerminated(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$UploadTerminatedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadTerminated uploadTerminated} event of
     * this `sap.m.upload.UploadSet`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSet` itself.
     *
     * This event is fired right after the upload is terminated.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadTerminated(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSet$UploadTerminatedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSet` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the headerFields in the aggregation {@link #getHeaderFields headerFields}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyHeaderFields(): this;
    /**
     * Destroys the illustratedMessage in the aggregation {@link #getIllustratedMessage illustratedMessage}.
     *
     * @since 1.121
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyIllustratedMessage(): this;
    /**
     * Destroys all the incompleteItems in the aggregation {@link #getIncompleteItems incompleteItems}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyIncompleteItems(): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Destroys the toolbar in the aggregation {@link #getToolbar toolbar}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyToolbar(): this;
    /**
     * Destroys the uploader in the aggregation {@link #getUploader uploader}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyUploader(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterItemAdded afterItemAdded} event of this
     * `sap.m.upload.UploadSet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterItemAdded(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSet$AfterItemAddedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterItemEdited afterItemEdited} event of
     * this `sap.m.upload.UploadSet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.83
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterItemEdited(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSet$AfterItemEditedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:afterItemRemoved afterItemRemoved} event of
     * this `sap.m.upload.UploadSet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.83
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachAfterItemRemoved(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSet$AfterItemRemovedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeItemAdded beforeItemAdded} event of
     * this `sap.m.upload.UploadSet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeItemAdded(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSet$BeforeItemAddedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeItemEdited beforeItemEdited} event of
     * this `sap.m.upload.UploadSet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeItemEdited(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSet$BeforeItemEditedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeItemRemoved beforeItemRemoved} event
     * of this `sap.m.upload.UploadSet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeItemRemoved(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSet$BeforeItemRemovedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeUploadStarts beforeUploadStarts} event
     * of this `sap.m.upload.UploadSet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeUploadStarts(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSet$BeforeUploadStartsEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeUploadTermination beforeUploadTermination }
     * event of this `sap.m.upload.UploadSet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeUploadTermination(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSet$BeforeUploadTerminationEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:fileNameLengthExceeded fileNameLengthExceeded }
     * event of this `sap.m.upload.UploadSet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachFileNameLengthExceeded(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSet$FileNameLengthExceededEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:fileRenamed fileRenamed} event of this `sap.m.upload.UploadSet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.100.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachFileRenamed(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSet$FileRenamedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:fileSizeExceeded fileSizeExceeded} event of
     * this `sap.m.upload.UploadSet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachFileSizeExceeded(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSet$FileSizeExceededEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:fileTypeMismatch fileTypeMismatch} event of
     * this `sap.m.upload.UploadSet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachFileTypeMismatch(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSet$FileTypeMismatchEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:itemDragStart itemDragStart} event of this
     * `sap.m.upload.UploadSet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.99
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachItemDragStart(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:itemDrop itemDrop} event of this `sap.m.upload.UploadSet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.99
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachItemDrop(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:mediaTypeMismatch mediaTypeMismatch} event
     * of this `sap.m.upload.UploadSet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachMediaTypeMismatch(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSet$MediaTypeMismatchEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:selectionChanged selectionChanged} event of
     * this `sap.m.upload.UploadSet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelectionChanged(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSet$SelectionChangedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:uploadCompleted uploadCompleted} event of
     * this `sap.m.upload.UploadSet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUploadCompleted(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSet$UploadCompletedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:uploadTerminated uploadTerminated} event of
     * this `sap.m.upload.UploadSet`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUploadTerminated(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSet$UploadTerminatedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:afterItemAdded afterItemAdded} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterItemAdded(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSet$AfterItemAddedEventParameters
    ): this;
    /**
     * Fires event {@link #event:afterItemEdited afterItemEdited} to attached listeners.
     *
     * @since 1.83
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterItemEdited(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSet$AfterItemEditedEventParameters
    ): this;
    /**
     * Fires event {@link #event:afterItemRemoved afterItemRemoved} to attached listeners.
     *
     * @since 1.83
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireAfterItemRemoved(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSet$AfterItemRemovedEventParameters
    ): this;
    /**
     * Fires event {@link #event:beforeItemAdded beforeItemAdded} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireBeforeItemAdded(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSet$BeforeItemAddedEventParameters
    ): boolean;
    /**
     * Fires event {@link #event:beforeItemEdited beforeItemEdited} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireBeforeItemEdited(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSet$BeforeItemEditedEventParameters
    ): boolean;
    /**
     * Fires event {@link #event:beforeItemRemoved beforeItemRemoved} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireBeforeItemRemoved(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSet$BeforeItemRemovedEventParameters
    ): boolean;
    /**
     * Fires event {@link #event:beforeUploadStarts beforeUploadStarts} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireBeforeUploadStarts(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSet$BeforeUploadStartsEventParameters
    ): boolean;
    /**
     * Fires event {@link #event:beforeUploadTermination beforeUploadTermination} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireBeforeUploadTermination(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSet$BeforeUploadTerminationEventParameters
    ): boolean;
    /**
     * Fires event {@link #event:fileNameLengthExceeded fileNameLengthExceeded} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireFileNameLengthExceeded(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSet$FileNameLengthExceededEventParameters
    ): this;
    /**
     * Fires event {@link #event:fileRenamed fileRenamed} to attached listeners.
     *
     * @since 1.100.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireFileRenamed(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSet$FileRenamedEventParameters
    ): this;
    /**
     * Fires event {@link #event:fileSizeExceeded fileSizeExceeded} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireFileSizeExceeded(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSet$FileSizeExceededEventParameters
    ): this;
    /**
     * Fires event {@link #event:fileTypeMismatch fileTypeMismatch} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireFileTypeMismatch(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSet$FileTypeMismatchEventParameters
    ): this;
    /**
     * Fires event {@link #event:itemDragStart itemDragStart} to attached listeners.
     *
     * @since 1.99
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireItemDragStart(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:itemDrop itemDrop} to attached listeners.
     *
     * @since 1.99
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireItemDrop(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:mediaTypeMismatch mediaTypeMismatch} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireMediaTypeMismatch(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSet$MediaTypeMismatchEventParameters
    ): this;
    /**
     * Fires event {@link #event:selectionChanged selectionChanged} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelectionChanged(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSet$SelectionChangedEventParameters
    ): this;
    /**
     * Fires event {@link #event:uploadCompleted uploadCompleted} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUploadCompleted(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSet$UploadCompletedEventParameters
    ): this;
    /**
     * Fires event {@link #event:uploadTerminated uploadTerminated} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUploadTerminated(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSet$UploadTerminatedEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getCloudFilePickerButtonText cloudFilePickerButtonText}.
     *
     * The text of the CloudFile picker button. The default text is "Upload from cloud" (translated to the respective
     * language).
     *
     * Default value is `empty string`.
     *
     * @experimental As of version 1.106.
     *
     * @returns Value of property `cloudFilePickerButtonText`
     */
    getCloudFilePickerButtonText(): string;
    /**
     * Gets current value of property {@link #getCloudFilePickerEnabled cloudFilePickerEnabled}.
     *
     * Enables CloudFile picker feature to upload files from cloud.
     *
     * Default value is `false`.
     *
     * @experimental As of version 1.106.
     *
     * @returns Value of property `cloudFilePickerEnabled`
     */
    getCloudFilePickerEnabled(): boolean;
    /**
     * Gets current value of property {@link #getCloudFilePickerServiceUrl cloudFilePickerServiceUrl}.
     *
     * Url of the FileShare OData V4 service supplied for CloudFile picker control.
     *
     * Default value is `empty string`.
     *
     * @experimental As of version 1.106.
     *
     * @returns Value of property `cloudFilePickerServiceUrl`
     */
    getCloudFilePickerServiceUrl(): URI;
    /**
     * Returns an instance of the default `sap.ui.unified.FileUploader` used for adding files using the operating
     * system's open file dialog, so that it can be customized, for example made invisible or assigned a different
     * icon.
     *
     *
     * @returns Instance of the default `sap.ui.unified.FileUploader`.
     */
    getDefaultFileUploader(): FileUploader;
    /**
     * Gets current value of property {@link #getDirectory directory}.
     *
     * Lets the user upload entire files from directories and sub directories.
     *
     * Default value is `false`.
     *
     * @since 1.107
     *
     * @returns Value of property `directory`
     */
    getDirectory(): boolean;
    /**
     * Gets current value of property {@link #getDragDropDescription dragDropDescription}.
     *
     * Defines custom text for the drag and drop description label.
     *
     *
     * @returns Value of property `dragDropDescription`
     */
    getDragDropDescription(): string;
    /**
     * Gets current value of property {@link #getDragDropText dragDropText}.
     *
     * Defines custom text for the drag and drop text label.
     *
     *
     * @returns Value of property `dragDropText`
     */
    getDragDropText(): string;
    /**
     * Gets current value of property {@link #getFileTypes fileTypes}.
     *
     * Allowed file types for files to be uploaded.
     * If this property is not set, any file can be uploaded.
     *
     *
     * @returns Value of property `fileTypes`
     */
    getFileTypes(): string[];
    /**
     * Gets content of aggregation {@link #getHeaderFields headerFields}.
     *
     * Header fields to be included in the header section of an XHR request.
     */
    getHeaderFields(): Item[];
    /**
     * Gets current value of property {@link #getHttpRequestMethod httpRequestMethod}.
     *
     * HTTP request method chosen for file upload.
     *
     * Default value is `Post`.
     *
     * @since 1.90
     *
     * @returns Value of property `httpRequestMethod`
     */
    getHttpRequestMethod(): UploaderHttpRequestMethod;
    /**
     * Gets content of aggregation {@link #getIllustratedMessage illustratedMessage}.
     *
     * An illustrated message is displayed when no data is loaded or provided
     *
     * @since 1.121
     */
    getIllustratedMessage(): IllustratedMessage;
    /**
     * Gets content of aggregation {@link #getIncompleteItems incompleteItems}.
     *
     * Items representing files yet to be uploaded.
     */
    getIncompleteItems(): UploadSetItem[];
    /**
     * Gets current value of property {@link #getInstantUpload instantUpload}.
     *
     * Defines whether the upload process should be triggered as soon as the file is added.
     *  If set to `false`, no upload is triggered when a file is added.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `instantUpload`
     */
    getInstantUpload(): boolean;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * Items representing files that have already been uploaded.
     */
    getItems(): UploadSetItem[];
    /**
     * Provides access to the instance of the inner {@link sap.m.List} control, so that it can be customized.
     *
     *
     * @returns The inner {@link sap.m.List} control.
     */
    getList(): List;
    /**
     * Gets current value of property {@link #getMaxFileNameLength maxFileNameLength}.
     *
     * Maximum length of names of files to be uploaded.
     * If set to `null` or `0`, any files can be uploaded, regardless of their names length.
     *
     *
     * @returns Value of property `maxFileNameLength`
     */
    getMaxFileNameLength(): int;
    /**
     * Gets current value of property {@link #getMaxFileSize maxFileSize}.
     *
     * Size limit in megabytes for files to be uploaded.
     * If set to `null` or `0`, files of any size can be uploaded.
     *
     *
     * @returns Value of property `maxFileSize`
     */
    getMaxFileSize(): float;
    /**
     * Gets current value of property {@link #getMediaTypes mediaTypes}.
     *
     * Allowed media types for files to be uploaded.
     * If this property is not set, any file can be uploaded.
     *
     *
     * @returns Value of property `mediaTypes`
     */
    getMediaTypes(): string[];
    /**
     * Gets current value of property {@link #getMode mode}.
     *
     * Defines the selection mode of the control (e.g. None, SingleSelect, MultiSelect, SingleSelectLeft, SingleSelectMaster).
     * Since the UploadSet reacts like a list for attachments, the API is close to the ListBase Interface. sap.m.ListMode.Delete
     * mode is not supported and will be automatically set to sap.m.ListMode.None. In addition, if instant upload
     * is set to false the mode sap.m.ListMode.MultiSelect is not supported and will be automatically set to
     * sap.m.ListMode.None.
     *
     * Default value is `MultiSelect`.
     *
     * @since 1.100.0
     *
     * @returns Value of property `mode`
     */
    getMode(): ListMode;
    /**
     * Gets current value of property {@link #getMultiple multiple}.
     *
     * Lets the user select multiple files from the same folder and then upload them.
     *
     * If multiple property is set to false, the control shows an error message if more than one file is chosen
     * for drag & drop.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `multiple`
     */
    getMultiple(): boolean;
    /**
     * Gets current value of property {@link #getNoDataDescription noDataDescription}.
     *
     * Defines custom text for the 'No data' description label.
     *
     * @deprecated As of version 1.121. Use illustratedMessage instead.
     *
     * @returns Value of property `noDataDescription`
     */
    getNoDataDescription(): string;
    /**
     * Gets current value of property {@link #getNoDataIllustrationType noDataIllustrationType}.
     *
     * Determines which illustration type is displayed when the control holds no data.
     *
     * Default value is `NoData`.
     *
     * @since 1.117
     * @deprecated As of version 1.121. Use illustratedMessage instead.
     *
     * @returns Value of property `noDataIllustrationType`
     */
    getNoDataIllustrationType(): IllustratedMessageType;
    /**
     * Gets current value of property {@link #getNoDataText noDataText}.
     *
     * Defines custom text for the 'No data' text label.
     *
     * @deprecated As of version 1.121. Use illustratedMessage instead.
     *
     * @returns Value of property `noDataText`
     */
    getNoDataText(): string;
    /**
     * Gets current value of property {@link #getSameFilenameAllowed sameFilenameAllowed}.
     *
     * Allows the user to use the same name for a file while editing the file name. 'Same name' refers to an
     * already existing file name in the list.
     *
     * Default value is `false`.
     *
     * @since 1.100.0
     *
     * @returns Value of property `sameFilenameAllowed`
     */
    getSameFilenameAllowed(): boolean;
    /**
     * Retrieves the currently selected UploadSetItem.
     *
     * @since 1.100.0
     *
     * @returns The currently selected item or `null`
     */
    getSelectedItem(): UploadSetItem | null;
    /**
     * Returns an array containing the selected UploadSetItems.
     *
     * @since 1.100.0
     *
     * @returns Array of all selected items
     */
    getSelectedItems(): UploadSetItem[];
    /**
     * Gets current value of property {@link #getShowIcons showIcons}.
     *
     * Defines whether file icons should be displayed.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showIcons`
     */
    getShowIcons(): boolean;
    /**
     * Gets current value of property {@link #getTerminationEnabled terminationEnabled}.
     *
     * Defines whether it is allowed to terminate the upload process.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `terminationEnabled`
     */
    getTerminationEnabled(): boolean;
    /**
     * Gets content of aggregation {@link #getToolbar toolbar}.
     *
     * Main toolbar of the `UploadSet` control.
     */
    getToolbar(): OverflowToolbar;
    /**
     * Gets current value of property {@link #getUploadButtonInvisible uploadButtonInvisible}.
     *
     * If set to true, the button used for uploading files become invisible.
     *
     * Default value is `false`.
     *
     * @since 1.99.0
     *
     * @returns Value of property `uploadButtonInvisible`
     */
    getUploadButtonInvisible(): boolean;
    /**
     * Gets current value of property {@link #getUploadEnabled uploadEnabled}.
     *
     * Defines whether the upload action is allowed.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `uploadEnabled`
     */
    getUploadEnabled(): boolean;
    /**
     * Gets content of aggregation {@link #getUploader uploader}.
     *
     * Defines the uploader to be used. If not specified, the default implementation is used.
     */
    getUploader(): Uploader;
    /**
     * Gets current value of property {@link #getUploadUrl uploadUrl}.
     *
     * URL where the uploaded files will be stored.
     *
     *
     * @returns Value of property `uploadUrl`
     */
    getUploadUrl(): string;
    /**
     * Checks for the provided `sap.ui.core.Item` in the aggregation {@link #getHeaderFields headerFields}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfHeaderField(
      /**
       * The headerField whose index is looked for
       */
      oHeaderField: Item
    ): int;
    /**
     * Checks for the provided `sap.m.upload.UploadSetItem` in the aggregation {@link #getIncompleteItems incompleteItems}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfIncompleteItem(
      /**
       * The incompleteItem whose index is looked for
       */
      oIncompleteItem: UploadSetItem
    ): int;
    /**
     * Checks for the provided `sap.m.upload.UploadSetItem` in the aggregation {@link #getItems items}. and
     * returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: UploadSetItem
    ): int;
    /**
     * Inserts a headerField into the aggregation {@link #getHeaderFields headerFields}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertHeaderField(
      /**
       * The headerField to insert; if empty, nothing is inserted
       */
      oHeaderField: Item,
      /**
       * The `0`-based index the headerField should be inserted at; for a negative value of `iIndex`, the headerField
       * is inserted at position 0; for a value greater than the current size of the aggregation, the headerField
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a incompleteItem into the aggregation {@link #getIncompleteItems incompleteItems}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertIncompleteItem(
      /**
       * The incompleteItem to insert; if empty, nothing is inserted
       */
      oIncompleteItem: UploadSetItem,
      /**
       * The `0`-based index the incompleteItem should be inserted at; for a negative value of `iIndex`, the incompleteItem
       * is inserted at position 0; for a value greater than the current size of the aggregation, the incompleteItem
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: UploadSetItem,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Opens the FileUploader dialog. When an UploadSetItem is provided, this method can be used to update a
     * file with a new version.
     *
     * @since 1.103.0
     *
     * @returns this to allow method chaining
     */
    openFileDialog(
      /**
       * The UploadSetItem to update with a new version. This parameter is mandatory.
       */
      item: UploadSetItem
    ): this;
    /**
     * Attaches all necessary handlers to the given uploader instance, so that the progress and status of the
     * upload can be displayed and monitored. This is necessary in case when custom uploader is used.
     */
    registerUploaderEvents(
      /**
       * Instance of `sap.m.upload.Uploader` to which the default request handlers are attached.
       */
      oUploader: Uploader
    ): void;
    /**
     * Removes all the controls from the aggregation {@link #getHeaderFields headerFields}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllHeaderFields(): Item[];
    /**
     * Removes all the controls from the aggregation {@link #getIncompleteItems incompleteItems}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllIncompleteItems(): UploadSetItem[];
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): UploadSetItem[];
    /**
     * Removes a headerField from the aggregation {@link #getHeaderFields headerFields}.
     *
     *
     * @returns The removed headerField or `null`
     */
    removeHeaderField(
      /**
       * The headerField to remove or its index or id
       */
      vHeaderField: int | string | Item
    ): Item | null;
    /**
     * Removes a incompleteItem from the aggregation {@link #getIncompleteItems incompleteItems}.
     *
     *
     * @returns The removed incompleteItem or `null`
     */
    removeIncompleteItem(
      /**
       * The incompleteItem to remove or its index or id
       */
      vIncompleteItem: int | string | UploadSetItem
    ): UploadSetItem | null;
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | UploadSetItem
    ): UploadSetItem | null;
    /**
     * Select all items in "MultiSelection" mode.
     *
     * @since 1.100.0
     *
     * @returns this to allow method chaining
     */
    selectAll(): this;
    /**
     * Sets a new value for property {@link #getCloudFilePickerButtonText cloudFilePickerButtonText}.
     *
     * The text of the CloudFile picker button. The default text is "Upload from cloud" (translated to the respective
     * language).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @experimental As of version 1.106.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCloudFilePickerButtonText(
      /**
       * New value for property `cloudFilePickerButtonText`
       */
      sCloudFilePickerButtonText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getCloudFilePickerEnabled cloudFilePickerEnabled}.
     *
     * Enables CloudFile picker feature to upload files from cloud.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @experimental As of version 1.106.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCloudFilePickerEnabled(
      /**
       * New value for property `cloudFilePickerEnabled`
       */
      bCloudFilePickerEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getCloudFilePickerServiceUrl cloudFilePickerServiceUrl}.
     *
     * Url of the FileShare OData V4 service supplied for CloudFile picker control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     * @experimental As of version 1.106.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCloudFilePickerServiceUrl(
      /**
       * New value for property `cloudFilePickerServiceUrl`
       */
      sCloudFilePickerServiceUrl?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getDirectory directory}.
     *
     * Lets the user upload entire files from directories and sub directories.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.107
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDirectory(
      /**
       * New value for property `directory`
       */
      bDirectory?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getDragDropDescription dragDropDescription}.
     *
     * Defines custom text for the drag and drop description label.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDragDropDescription(
      /**
       * New value for property `dragDropDescription`
       */
      sDragDropDescription?: string
    ): this;
    /**
     * Sets a new value for property {@link #getDragDropText dragDropText}.
     *
     * Defines custom text for the drag and drop text label.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDragDropText(
      /**
       * New value for property `dragDropText`
       */
      sDragDropText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getFileTypes fileTypes}.
     *
     * Allowed file types for files to be uploaded.
     * If this property is not set, any file can be uploaded.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFileTypes(
      /**
       * New value for property `fileTypes`
       */
      sFileTypes?: string[]
    ): this;
    /**
     * Sets a new value for property {@link #getHttpRequestMethod httpRequestMethod}.
     *
     * HTTP request method chosen for file upload.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Post`.
     *
     * @since 1.90
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHttpRequestMethod(
      /**
       * New value for property `httpRequestMethod`
       */
      sHttpRequestMethod?: UploaderHttpRequestMethod
    ): this;
    /**
     * Sets the aggregated {@link #getIllustratedMessage illustratedMessage}.
     *
     * @since 1.121
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIllustratedMessage(
      /**
       * The illustratedMessage to set
       */
      oIllustratedMessage: IllustratedMessage
    ): this;
    /**
     * Sets a new value for property {@link #getInstantUpload instantUpload}.
     *
     * Defines whether the upload process should be triggered as soon as the file is added.
     *  If set to `false`, no upload is triggered when a file is added.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInstantUpload(
      /**
       * New value for property `instantUpload`
       */
      bInstantUpload?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getMaxFileNameLength maxFileNameLength}.
     *
     * Maximum length of names of files to be uploaded.
     * If set to `null` or `0`, any files can be uploaded, regardless of their names length.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxFileNameLength(
      /**
       * New value for property `maxFileNameLength`
       */
      iMaxFileNameLength?: int
    ): this;
    /**
     * Sets a new value for property {@link #getMaxFileSize maxFileSize}.
     *
     * Size limit in megabytes for files to be uploaded.
     * If set to `null` or `0`, files of any size can be uploaded.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxFileSize(
      /**
       * New value for property `maxFileSize`
       */
      fMaxFileSize?: float
    ): this;
    /**
     * Sets a new value for property {@link #getMediaTypes mediaTypes}.
     *
     * Allowed media types for files to be uploaded.
     * If this property is not set, any file can be uploaded.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMediaTypes(
      /**
       * New value for property `mediaTypes`
       */
      sMediaTypes?: string[]
    ): this;
    /**
     * Sets a new value for property {@link #getMode mode}.
     *
     * Defines the selection mode of the control (e.g. None, SingleSelect, MultiSelect, SingleSelectLeft, SingleSelectMaster).
     * Since the UploadSet reacts like a list for attachments, the API is close to the ListBase Interface. sap.m.ListMode.Delete
     * mode is not supported and will be automatically set to sap.m.ListMode.None. In addition, if instant upload
     * is set to false the mode sap.m.ListMode.MultiSelect is not supported and will be automatically set to
     * sap.m.ListMode.None.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `MultiSelect`.
     *
     * @since 1.100.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMode(
      /**
       * New value for property `mode`
       */
      sMode?: ListMode | keyof typeof ListMode
    ): this;
    /**
     * Sets a new value for property {@link #getMultiple multiple}.
     *
     * Lets the user select multiple files from the same folder and then upload them.
     *
     * If multiple property is set to false, the control shows an error message if more than one file is chosen
     * for drag & drop.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMultiple(
      /**
       * New value for property `multiple`
       */
      bMultiple?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getNoDataDescription noDataDescription}.
     *
     * Defines custom text for the 'No data' description label.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @deprecated As of version 1.121. Use illustratedMessage instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNoDataDescription(
      /**
       * New value for property `noDataDescription`
       */
      sNoDataDescription?: string
    ): this;
    /**
     * Sets a new value for property {@link #getNoDataIllustrationType noDataIllustrationType}.
     *
     * Determines which illustration type is displayed when the control holds no data.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `NoData`.
     *
     * @since 1.117
     * @deprecated As of version 1.121. Use illustratedMessage instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNoDataIllustrationType(
      /**
       * New value for property `noDataIllustrationType`
       */
      sNoDataIllustrationType?: IllustratedMessageType
    ): this;
    /**
     * Sets a new value for property {@link #getNoDataText noDataText}.
     *
     * Defines custom text for the 'No data' text label.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @deprecated As of version 1.121. Use illustratedMessage instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNoDataText(
      /**
       * New value for property `noDataText`
       */
      sNoDataText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSameFilenameAllowed sameFilenameAllowed}.
     *
     * Allows the user to use the same name for a file while editing the file name. 'Same name' refers to an
     * already existing file name in the list.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.100.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSameFilenameAllowed(
      /**
       * New value for property `sameFilenameAllowed`
       */
      bSameFilenameAllowed?: boolean
    ): this;
    /**
     * Selects or deselects the given list item.
     *
     * @since 1.100.0
     *
     * @returns this to allow method chaining
     */
    setSelectedItem(
      /**
       * The item whose selection is to be changed. This parameter is mandatory.
       */
      uploadSetItem: UploadSetItem,
      /**
       * The selection state of the item.
       */
      select?: boolean
    ): this;
    /**
     * Sets an UploadSetItem to be selected by ID. In single selection mode, the method removes the previous
     * selection.
     *
     * @since 1.100.0
     *
     * @returns this to allow method chaining
     */
    setSelectedItemById(
      /**
       * The ID of the item whose selection is to be changed.
       */
      id: string,
      /**
       * The selection state of the item.
       */
      select?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowIcons showIcons}.
     *
     * Defines whether file icons should be displayed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowIcons(
      /**
       * New value for property `showIcons`
       */
      bShowIcons?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getTerminationEnabled terminationEnabled}.
     *
     * Defines whether it is allowed to terminate the upload process.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTerminationEnabled(
      /**
       * New value for property `terminationEnabled`
       */
      bTerminationEnabled?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getToolbar toolbar}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setToolbar(
      /**
       * The toolbar to set
       */
      oToolbar: OverflowToolbar
    ): this;
    /**
     * Sets a new value for property {@link #getUploadButtonInvisible uploadButtonInvisible}.
     *
     * If set to true, the button used for uploading files become invisible.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.99.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUploadButtonInvisible(
      /**
       * New value for property `uploadButtonInvisible`
       */
      bUploadButtonInvisible?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getUploadEnabled uploadEnabled}.
     *
     * Defines whether the upload action is allowed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUploadEnabled(
      /**
       * New value for property `uploadEnabled`
       */
      bUploadEnabled?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getUploader uploader}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUploader(
      /**
       * The uploader to set
       */
      oUploader: Uploader
    ): this;
    /**
     * Sets a new value for property {@link #getUploadUrl uploadUrl}.
     *
     * URL where the uploaded files will be stored.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUploadUrl(
      /**
       * New value for property `uploadUrl`
       */
      sUploadUrl?: string
    ): this;
    /**
     * Starts uploading all files that comply with the restrictions defined in the `fileTypes`, `maxFileNameLength`,
     * `maxFileSize`, and `mediaTypes` properties.
     * This method works only when the `uploadEnabled` property is set to `true`.
     */
    upload(): void;
    /**
     * Starts uploading the file if it complies with the restrictions defined in the `fileTypes`, `maxFileNameLength`,
     * `maxFileSize`, and `mediaTypes` properties.
     * This method works only when the `uploadEnabled` property is set to `true`.
     */
    uploadItem(
      /**
       * File to upload.
       */
      oItem: object
    ): void;
  }
  /**
   * Describes the settings that can be provided to the UploadSet constructor.
   *
   * @deprecated As of version 1.129. replaced by {@link sap.m.plugins.UploadSetwithTable}
   */
  export interface $UploadSetSettings extends $ControlSettings {
    /**
     * Allowed file types for files to be uploaded.
     * If this property is not set, any file can be uploaded.
     */
    fileTypes?: string[] | PropertyBindingInfo | `{${string}}`;

    /**
     * Maximum length of names of files to be uploaded.
     * If set to `null` or `0`, any files can be uploaded, regardless of their names length.
     */
    maxFileNameLength?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Size limit in megabytes for files to be uploaded.
     * If set to `null` or `0`, files of any size can be uploaded.
     */
    maxFileSize?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * Allowed media types for files to be uploaded.
     * If this property is not set, any file can be uploaded.
     */
    mediaTypes?: string[] | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines custom text for the 'No data' text label.
     *
     * @deprecated As of version 1.121. Use illustratedMessage instead.
     */
    noDataText?: string | PropertyBindingInfo;

    /**
     * Defines custom text for the 'No data' description label.
     *
     * @deprecated As of version 1.121. Use illustratedMessage instead.
     */
    noDataDescription?: string | PropertyBindingInfo;

    /**
     * Determines which illustration type is displayed when the control holds no data.
     *
     * @since 1.117
     * @deprecated As of version 1.121. Use illustratedMessage instead.
     */
    noDataIllustrationType?:
      | IllustratedMessageType
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines custom text for the drag and drop text label.
     */
    dragDropText?: string | PropertyBindingInfo;

    /**
     * Defines custom text for the drag and drop description label.
     */
    dragDropDescription?: string | PropertyBindingInfo;

    /**
     * Defines whether the upload process should be triggered as soon as the file is added.
     *  If set to `false`, no upload is triggered when a file is added.
     */
    instantUpload?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether file icons should be displayed.
     */
    showIcons?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether it is allowed to terminate the upload process.
     */
    terminationEnabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether the upload action is allowed.
     */
    uploadEnabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * URL where the uploaded files will be stored.
     */
    uploadUrl?: string | PropertyBindingInfo;

    /**
     * If set to true, the button used for uploading files become invisible.
     *
     * @since 1.99.0
     */
    uploadButtonInvisible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Allows the user to use the same name for a file while editing the file name. 'Same name' refers to an
     * already existing file name in the list.
     *
     * @since 1.100.0
     */
    sameFilenameAllowed?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * HTTP request method chosen for file upload.
     *
     * @since 1.90
     */
    httpRequestMethod?:
      | UploaderHttpRequestMethod
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Lets the user select multiple files from the same folder and then upload them.
     *
     * If multiple property is set to false, the control shows an error message if more than one file is chosen
     * for drag & drop.
     */
    multiple?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the selection mode of the control (e.g. None, SingleSelect, MultiSelect, SingleSelectLeft, SingleSelectMaster).
     * Since the UploadSet reacts like a list for attachments, the API is close to the ListBase Interface. sap.m.ListMode.Delete
     * mode is not supported and will be automatically set to sap.m.ListMode.None. In addition, if instant upload
     * is set to false the mode sap.m.ListMode.MultiSelect is not supported and will be automatically set to
     * sap.m.ListMode.None.
     *
     * @since 1.100.0
     */
    mode?:
      | (ListMode | keyof typeof ListMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Enables CloudFile picker feature to upload files from cloud.
     *
     * @experimental As of version 1.106.
     */
    cloudFilePickerEnabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Url of the FileShare OData V4 service supplied for CloudFile picker control.
     *
     * @experimental As of version 1.106.
     */
    cloudFilePickerServiceUrl?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * The text of the CloudFile picker button. The default text is "Upload from cloud" (translated to the respective
     * language).
     *
     * @experimental As of version 1.106.
     */
    cloudFilePickerButtonText?: string | PropertyBindingInfo;

    /**
     * Lets the user upload entire files from directories and sub directories.
     *
     * @since 1.107
     */
    directory?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Items representing files that have already been uploaded.
     */
    items?:
      | UploadSetItem[]
      | UploadSetItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Items representing files yet to be uploaded.
     */
    incompleteItems?:
      | UploadSetItem[]
      | UploadSetItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Header fields to be included in the header section of an XHR request.
     */
    headerFields?: Item[] | Item | AggregationBindingInfo | `{${string}}`;

    /**
     * Main toolbar of the `UploadSet` control.
     */
    toolbar?: OverflowToolbar;

    /**
     * Defines the uploader to be used. If not specified, the default implementation is used.
     */
    uploader?: Uploader;

    /**
     * An illustrated message is displayed when no data is loaded or provided
     *
     * @since 1.121
     */
    illustratedMessage?: IllustratedMessage;

    /**
     * This event is fired when a new file is added to the set of items to be uploaded.
     */
    afterItemAdded?: (oEvent: UploadSet$AfterItemAddedEvent) => void;

    /**
     * The event is triggered when the file name is changed.
     *
     * @since 1.100.0
     */
    fileRenamed?: (oEvent: UploadSet$FileRenamedEvent) => void;

    /**
     * This event is fired after the item is removed on click of ok button in confirmation dialog.
     *
     * @since 1.83
     */
    afterItemRemoved?: (oEvent: UploadSet$AfterItemRemovedEvent) => void;

    /**
     * This event is fired after item edit is confirmed.
     *
     * @since 1.83
     */
    afterItemEdited?: (oEvent: UploadSet$AfterItemEditedEvent) => void;

    /**
     * This event is fired just before a new file is added to the set of items to be uploaded.
     */
    beforeItemAdded?: (oEvent: UploadSet$BeforeItemAddedEvent) => void;

    /**
     * This event is fired just before the confirmation dialog for 'Remove' action is displayed.
     */
    beforeItemRemoved?: (oEvent: UploadSet$BeforeItemRemovedEvent) => void;

    /**
     * This event is fired when the edit button is clicked for an item and no other item is being edited at
     * the same time.
     * If there is another item that has unsaved changes, the editing of the clicked item cannot be started.
     */
    beforeItemEdited?: (oEvent: UploadSet$BeforeItemEditedEvent) => void;

    /**
     * This event is fired right before the upload process begins.
     */
    beforeUploadStarts?: (oEvent: UploadSet$BeforeUploadStartsEvent) => void;

    /**
     * This event is fired right after the upload process is finished.
     */
    uploadCompleted?: (oEvent: UploadSet$UploadCompletedEvent) => void;

    /**
     * This event is fired right before the upload is terminated.
     */
    beforeUploadTermination?: (
      oEvent: UploadSet$BeforeUploadTerminationEvent
    ) => void;

    /**
     * This event is fired right after the upload is terminated.
     */
    uploadTerminated?: (oEvent: UploadSet$UploadTerminatedEvent) => void;

    /**
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the file type restriction (`fileType` property).
     *
     * 	 - When the file type restriction changes, and the file to be uploaded fails to meet the new restriction.
     */
    fileTypeMismatch?: (oEvent: UploadSet$FileTypeMismatchEvent) => void;

    /**
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the file name length restriction specified
     *     in the `maxFileNameLength` property.
     * 	 - When the file name length restriction changes, and the file to be uploaded fails to meet the new
     *     restriction.
     * 	 - Listeners can use the item parameter to remove the incomplete item that failed to meet the restriction
     */
    fileNameLengthExceeded?: (
      oEvent: UploadSet$FileNameLengthExceededEvent
    ) => void;

    /**
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the file size restriction specified in
     *     the `maxFileSize` property.
     * 	 - When the file size restriction changes, and the file to be uploaded fails to meet the new restriction.
     *
     * 	 - Listeners can use the item parameter to remove the incomplete item that failed to meet the restriction
     */
    fileSizeExceeded?: (oEvent: UploadSet$FileSizeExceededEvent) => void;

    /**
     * This event is fired in either of the following cases:
     * 	 - When a file that is selected to be uploaded fails to meet the media type restriction specified in
     *     the `mediaTypes` property.
     * 	 - When the media type restriction changes, and the file to be uploaded fails to meet the new restriction.
     */
    mediaTypeMismatch?: (oEvent: UploadSet$MediaTypeMismatchEvent) => void;

    /**
     * This event is fired simultaneously with the respective event in the inner {@link sap.m.List} control.
     */
    selectionChanged?: (oEvent: UploadSet$SelectionChangedEvent) => void;

    /**
     * This event is fired when the user starts dragging an uploaded item.
     *
     * @since 1.99
     */
    itemDragStart?: (oEvent: Event) => void;

    /**
     * This event is fired when an uploaded item is dropped on the new list position.
     *
     * @since 1.99
     */
    itemDrop?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the UploadSet#afterItemAdded event.
   */
  export interface UploadSet$AfterItemAddedEventParameters {
    /**
     * The file that has just been added.
     */
    item?: UploadSetItem;
  }

  /**
   * Event object of the UploadSet#afterItemAdded event.
   */
  export type UploadSet$AfterItemAddedEvent = Event<
    UploadSet$AfterItemAddedEventParameters,
    UploadSet
  >;

  /**
   * Parameters of the UploadSet#afterItemEdited event.
   */
  export interface UploadSet$AfterItemEditedEventParameters {
    /**
     * The item edited.
     */
    item?: UploadSetItem;
  }

  /**
   * Event object of the UploadSet#afterItemEdited event.
   */
  export type UploadSet$AfterItemEditedEvent = Event<
    UploadSet$AfterItemEditedEventParameters,
    UploadSet
  >;

  /**
   * Parameters of the UploadSet#afterItemRemoved event.
   */
  export interface UploadSet$AfterItemRemovedEventParameters {
    /**
     * The item removed from the set of items to be uploaded.
     */
    item?: UploadSetItem;
  }

  /**
   * Event object of the UploadSet#afterItemRemoved event.
   */
  export type UploadSet$AfterItemRemovedEvent = Event<
    UploadSet$AfterItemRemovedEventParameters,
    UploadSet
  >;

  /**
   * Parameters of the UploadSet#beforeItemAdded event.
   */
  export interface UploadSet$BeforeItemAddedEventParameters {
    /**
     * The file to be added to the set of items to be uploaded.
     */
    item?: UploadSetItem;
  }

  /**
   * Event object of the UploadSet#beforeItemAdded event.
   */
  export type UploadSet$BeforeItemAddedEvent = Event<
    UploadSet$BeforeItemAddedEventParameters,
    UploadSet
  >;

  /**
   * Parameters of the UploadSet#beforeItemEdited event.
   */
  export interface UploadSet$BeforeItemEditedEventParameters {
    /**
     * The item to be edited.
     */
    item?: UploadSetItem;
  }

  /**
   * Event object of the UploadSet#beforeItemEdited event.
   */
  export type UploadSet$BeforeItemEditedEvent = Event<
    UploadSet$BeforeItemEditedEventParameters,
    UploadSet
  >;

  /**
   * Parameters of the UploadSet#beforeItemRemoved event.
   */
  export interface UploadSet$BeforeItemRemovedEventParameters {
    /**
     * The item to be removed from the set of items to be uploaded.
     */
    item?: UploadSetItem;
  }

  /**
   * Event object of the UploadSet#beforeItemRemoved event.
   */
  export type UploadSet$BeforeItemRemovedEvent = Event<
    UploadSet$BeforeItemRemovedEventParameters,
    UploadSet
  >;

  /**
   * Parameters of the UploadSet#beforeUploadStarts event.
   */
  export interface UploadSet$BeforeUploadStartsEventParameters {
    /**
     * The file whose upload is just about to start.
     */
    item?: UploadSetItem;
  }

  /**
   * Event object of the UploadSet#beforeUploadStarts event.
   */
  export type UploadSet$BeforeUploadStartsEvent = Event<
    UploadSet$BeforeUploadStartsEventParameters,
    UploadSet
  >;

  /**
   * Parameters of the UploadSet#beforeUploadTermination event.
   */
  export interface UploadSet$BeforeUploadTerminationEventParameters {
    /**
     * The file whose upload is about to be terminated.
     */
    item?: UploadSetItem;
  }

  /**
   * Event object of the UploadSet#beforeUploadTermination event.
   */
  export type UploadSet$BeforeUploadTerminationEvent = Event<
    UploadSet$BeforeUploadTerminationEventParameters,
    UploadSet
  >;

  /**
   * Parameters of the UploadSet#fileNameLengthExceeded event.
   */
  export interface UploadSet$FileNameLengthExceededEventParameters {
    /**
     * The file that fails to meet the file name length restriction specified in the `maxFileNameLength` property.
     */
    item?: UploadSetItem;
  }

  /**
   * Event object of the UploadSet#fileNameLengthExceeded event.
   */
  export type UploadSet$FileNameLengthExceededEvent = Event<
    UploadSet$FileNameLengthExceededEventParameters,
    UploadSet
  >;

  /**
   * Parameters of the UploadSet#fileRenamed event.
   */
  export interface UploadSet$FileRenamedEventParameters {
    /**
     * The renamed UI element as an UploadSetItem.
     */
    item?: UploadSetItem;
  }

  /**
   * Event object of the UploadSet#fileRenamed event.
   */
  export type UploadSet$FileRenamedEvent = Event<
    UploadSet$FileRenamedEventParameters,
    UploadSet
  >;

  /**
   * Parameters of the UploadSet#fileSizeExceeded event.
   */
  export interface UploadSet$FileSizeExceededEventParameters {
    /**
     * The file that fails to meet the file size restriction specified in the `maxFileSize` property.
     */
    item?: UploadSetItem;

    /**
     * The size of a file in MB, that fails to meet the file size restriction specified in the `maxFileSize`
     * property.
     */
    fileSize?: float;
  }

  /**
   * Event object of the UploadSet#fileSizeExceeded event.
   */
  export type UploadSet$FileSizeExceededEvent = Event<
    UploadSet$FileSizeExceededEventParameters,
    UploadSet
  >;

  /**
   * Parameters of the UploadSet#fileTypeMismatch event.
   */
  export interface UploadSet$FileTypeMismatchEventParameters {
    /**
     * The file that fails to meet the file type restriction specified in the `fileType` property.
     */
    item?: UploadSetItem;
  }

  /**
   * Event object of the UploadSet#fileTypeMismatch event.
   */
  export type UploadSet$FileTypeMismatchEvent = Event<
    UploadSet$FileTypeMismatchEventParameters,
    UploadSet
  >;

  /**
   * Parameters of the UploadSet#itemDragStart event.
   */
  export interface UploadSet$ItemDragStartEventParameters {}

  /**
   * Event object of the UploadSet#itemDragStart event.
   */
  export type UploadSet$ItemDragStartEvent = Event<
    UploadSet$ItemDragStartEventParameters,
    UploadSet
  >;

  /**
   * Parameters of the UploadSet#itemDrop event.
   */
  export interface UploadSet$ItemDropEventParameters {}

  /**
   * Event object of the UploadSet#itemDrop event.
   */
  export type UploadSet$ItemDropEvent = Event<
    UploadSet$ItemDropEventParameters,
    UploadSet
  >;

  /**
   * Parameters of the UploadSet#mediaTypeMismatch event.
   */
  export interface UploadSet$MediaTypeMismatchEventParameters {
    /**
     * The file that fails to meet the media type restriction specified in the `mediaTypes` property.
     */
    item?: UploadSetItem;
  }

  /**
   * Event object of the UploadSet#mediaTypeMismatch event.
   */
  export type UploadSet$MediaTypeMismatchEvent = Event<
    UploadSet$MediaTypeMismatchEventParameters,
    UploadSet
  >;

  /**
   * Parameters of the UploadSet#selectionChanged event.
   */
  export interface UploadSet$SelectionChangedEventParameters {
    /**
     * Items whose selection status has just been changed.
     */
    items?: UploadSetItem[];
  }

  /**
   * Event object of the UploadSet#selectionChanged event.
   */
  export type UploadSet$SelectionChangedEvent = Event<
    UploadSet$SelectionChangedEventParameters,
    UploadSet
  >;

  /**
   * Parameters of the UploadSet#uploadCompleted event.
   */
  export interface UploadSet$UploadCompletedEventParameters {
    /**
     * The file whose upload has just been completed.
     */
    item?: UploadSetItem;

    /**
     * Response message which comes from the server.
     *
     * On the server side this response has to be put within the "body" tags of the response document
     * of the iFrame. It can consist of a return code and an optional message. This does not work in cross-domain
     * scenarios.
     */
    response?: string;

    /**
     * ReadyState of the XHR request.
     *
     * Required for receiving a `readyState` is to set the property `sendXHR` to true. This property is not
     * supported by Internet Explorer 9.
     */
    readyState?: int;

    /**
     * Status of the XHR request.
     *
     * Required for receiving a `status` is to set the property `sendXHR` to true. This property is not supported
     * by Internet Explorer 9.
     */
    status?: int;

    /**
     * Http-Response which comes from the server.
     *
     * Required for receiving `responseXML` is to set the property `sendXHR` to true.
     *
     * This property is not supported by Internet Explorer 9.
     */
    responseXML?: string;

    /**
     * Http-Response-Headers which come from the server.
     *
     * Provided as a JSON-map, i.e. each header-field is reflected by a property in the `headers` object, with
     * the property value reflecting the header-field's content.
     *
     * Required for receiving `headers` is to set the property `sendXHR` to true. This property is not supported
     * by Internet Explorer 9.
     */
    headers?: object;
  }

  /**
   * Event object of the UploadSet#uploadCompleted event.
   */
  export type UploadSet$UploadCompletedEvent = Event<
    UploadSet$UploadCompletedEventParameters,
    UploadSet
  >;

  /**
   * Parameters of the UploadSet#uploadTerminated event.
   */
  export interface UploadSet$UploadTerminatedEventParameters {
    /**
     * The file whose upload has just been terminated.
     */
    item?: UploadSetItem;
  }

  /**
   * Event object of the UploadSet#uploadTerminated event.
   */
  export type UploadSet$UploadTerminatedEvent = Event<
    UploadSet$UploadTerminatedEventParameters,
    UploadSet
  >;
}

declare module "sap/m/upload/UploadSetItem" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import ObjectAttribute from "sap/m/ObjectAttribute";

  import Item from "sap/ui/core/Item";

  import ObjectMarker from "sap/m/ObjectMarker";

  import ObjectStatus from "sap/m/ObjectStatus";

  import CustomListItem from "sap/m/CustomListItem";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { UploadState, UploadType } from "sap/m/library";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * Item that represents one file to be uploaded using the {@link sap.m.upload.UploadSet} control.
   *
   * @since 1.63
   * @deprecated As of version 1.129. replaced by {@link sap.m.upload.UploadItem}
   */
  export default class UploadSetItem extends UI5Element {
    /**
     * Constructor for a new UploadSetItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control.
       */
      mSettings?: $UploadSetItemSettings
    );
    /**
     * Constructor for a new UploadSetItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, will be generated automatically if no ID is provided.
       */
      sId?: string,
      /**
       * Initial settings for the new control.
       */
      mSettings?: $UploadSetItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.upload.UploadSetItem with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, UploadSetItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.upload.UploadSetItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some attribute to the aggregation {@link #getAttributes attributes}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAttribute(
      /**
       * The attribute to add; if empty, nothing is inserted
       */
      oAttribute: ObjectAttribute
    ): this;
    /**
     * Adds some headerField to the aggregation {@link #getHeaderFields headerFields}.
     *
     * @since 1.90
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addHeaderField(
      /**
       * The headerField to add; if empty, nothing is inserted
       */
      oHeaderField: Item
    ): this;
    /**
     * Adds some marker to the aggregation {@link #getMarkers markers}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addMarker(
      /**
       * The marker to add; if empty, nothing is inserted
       */
      oMarker: ObjectMarker
    ): this;
    /**
     * Adds some markerAsStatus to the aggregation {@link #getMarkersAsStatus markersAsStatus}.
     *
     * @since 1.117
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addMarkerAsStatus(
      /**
       * The markerAsStatus to add; if empty, nothing is inserted
       */
      oMarkerAsStatus: ObjectStatus
    ): this;
    /**
     * Adds some status to the aggregation {@link #getStatuses statuses}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addStatus(
      /**
       * The status to add; if empty, nothing is inserted
       */
      oStatus: ObjectStatus
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:openPressed openPressed} event of this `sap.m.upload.UploadSetItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSetItem` itself.
     *
     * This event is fired when an open action is invoked on an item.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachOpenPressed(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetItem$OpenPressedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSetItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:openPressed openPressed} event of this `sap.m.upload.UploadSetItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSetItem` itself.
     *
     * This event is fired when an open action is invoked on an item.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachOpenPressed(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetItem$OpenPressedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSetItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:removePressed removePressed} event of this `sap.m.upload.UploadSetItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSetItem` itself.
     *
     * This event is fired when a remove action is invoked on an item.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachRemovePressed(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetItem$RemovePressedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSetItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:removePressed removePressed} event of this `sap.m.upload.UploadSetItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.upload.UploadSetItem` itself.
     *
     * This event is fired when a remove action is invoked on an item.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachRemovePressed(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadSetItem$RemovePressedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.upload.UploadSetItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the attributes in the aggregation {@link #getAttributes attributes}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyAttributes(): this;
    /**
     * Destroys all the headerFields in the aggregation {@link #getHeaderFields headerFields}.
     *
     * @since 1.90
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyHeaderFields(): this;
    /**
     * Destroys all the markers in the aggregation {@link #getMarkers markers}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyMarkers(): this;
    /**
     * Destroys all the markersAsStatus in the aggregation {@link #getMarkersAsStatus markersAsStatus}.
     *
     * @since 1.117
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyMarkersAsStatus(): this;
    /**
     * Destroys all the statuses in the aggregation {@link #getStatuses statuses}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyStatuses(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:openPressed openPressed} event of this `sap.m.upload.UploadSetItem`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachOpenPressed(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSetItem$OpenPressedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:removePressed removePressed} event of this
     * `sap.m.upload.UploadSetItem`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachRemovePressed(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadSetItem$RemovePressedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Downloads the item. Only possible when the item has a valid URL specified in the `url` property.
     *
     *
     * @returns `true` if download is possible, `false` otherwise.
     */
    download(
      /**
       * Whether to ask for a location where to download the file or not.
       */
      bAskForLocation: boolean
    ): boolean;
    /**
     * Fires event {@link #event:openPressed openPressed} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireOpenPressed(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSetItem$OpenPressedEventParameters
    ): boolean;
    /**
     * Fires event {@link #event:removePressed removePressed} to attached listeners.
     *
     * Listeners may prevent the default action of this event by calling the `preventDefault` method on the
     * event object. The return value of this method indicates whether the default action should be executed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Whether or not to prevent the default action
     */
    fireRemovePressed(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadSetItem$RemovePressedEventParameters
    ): boolean;
    /**
     * Gets content of aggregation {@link #getAttributes attributes}.
     *
     * Attributes of the item.
     */
    getAttributes(): ObjectAttribute[];
    /**
     * Returns edit state of the item.
     *
     * @since 1.104.0
     *
     * @returns edit state of uploadSetItem
     */
    getEditState(): boolean;
    /**
     * Gets current value of property {@link #getEnabledEdit enabledEdit}.
     *
     * Enables or disables the edit button.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabledEdit`
     */
    getEnabledEdit(): boolean;
    /**
     * Gets current value of property {@link #getEnabledRemove enabledRemove}.
     *
     * Enables or disables the remove button.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enabledRemove`
     */
    getEnabledRemove(): boolean;
    /**
     * Gets current value of property {@link #getFileName fileName}.
     *
     * Specifies the name of the uploaded file.
     *
     *
     * @returns Value of property `fileName`
     */
    getFileName(): string;
    /**
     * Returns file object.
     *
     *
     * @returns File object.
     */
    getFileObject(): File | Blob;
    /**
     * Gets content of aggregation {@link #getHeaderFields headerFields}.
     *
     * Header fields to be included in the header section of an XMLHttpRequest (XHR) request
     *
     * @since 1.90
     */
    getHeaderFields(): Item[];
    /**
     * Returns list item.
     *
     *
     * @returns List item.
     */
    getListItem(): CustomListItem;
    /**
     * Gets content of aggregation {@link #getMarkers markers}.
     *
     * Markers of the item.
     */
    getMarkers(): ObjectMarker[];
    /**
     * Gets content of aggregation {@link #getMarkersAsStatus markersAsStatus}.
     *
     * Statuses of the item, but it would be appearing in the markers section
     *
     * @since 1.117
     */
    getMarkersAsStatus(): ObjectStatus[];
    /**
     * Gets current value of property {@link #getMediaType mediaType}.
     *
     * Specifies the MIME type of the file.
     *
     *
     * @returns Value of property `mediaType`
     */
    getMediaType(): string;
    /**
     * Gets current value of property {@link #getSelected selected}.
     *
     * Defines the selected state of the UploadSetItem.
     *
     * Default value is `false`.
     *
     * @since 1.100.0
     *
     * @returns Value of property `selected`
     */
    getSelected(): boolean;
    /**
     * Gets content of aggregation {@link #getStatuses statuses}.
     *
     * Statuses of the item.
     */
    getStatuses(): ObjectStatus[];
    /**
     * Gets current value of property {@link #getThumbnailUrl thumbnailUrl}.
     *
     * Specifies the URL where the thumbnail of the file is located. Can also be set to an SAPUI5 icon URL.
     *
     *
     * @returns Value of property `thumbnailUrl`
     */
    getThumbnailUrl(): string;
    /**
     * Gets current value of property {@link #getUploadState uploadState}.
     *
     * State of the item relevant to its upload process.
     *
     *
     * @returns Value of property `uploadState`
     */
    getUploadState(): UploadState;
    /**
     * Returns the upload type of the item The method by default returns Native It is recommended to use this
     * method, when the user has uploded the instance
     *
     * @since 1.117.0
     *
     * @returns edit state of uploadSetItem
     */
    getUploadType(): UploadType;
    /**
     * Gets current value of property {@link #getUploadUrl uploadUrl}.
     *
     * URL where the uploaded files will be stored. If empty, uploadUrl from the uploader is considered.
     *
     * @since 1.90
     *
     * @returns Value of property `uploadUrl`
     */
    getUploadUrl(): string;
    /**
     * Gets current value of property {@link #getUrl url}.
     *
     * Specifies the URL where the file is located.
     * If the application doesn't provide a value for this property, the icon and the file name are not clickable
     * in {@link sap.m.upload.UploadSet}.
     *
     *
     * @returns Value of property `url`
     */
    getUrl(): string;
    /**
     * Gets current value of property {@link #getVisibleEdit visibleEdit}.
     *
     * Shows or hides the edit button.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visibleEdit`
     */
    getVisibleEdit(): boolean;
    /**
     * Gets current value of property {@link #getVisibleRemove visibleRemove}.
     *
     * Shows or hides the remove button.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visibleRemove`
     */
    getVisibleRemove(): boolean;
    /**
     * Checks for the provided `sap.m.ObjectAttribute` in the aggregation {@link #getAttributes attributes}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfAttribute(
      /**
       * The attribute whose index is looked for
       */
      oAttribute: ObjectAttribute
    ): int;
    /**
     * Checks for the provided `sap.ui.core.Item` in the aggregation {@link #getHeaderFields headerFields}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.90
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfHeaderField(
      /**
       * The headerField whose index is looked for
       */
      oHeaderField: Item
    ): int;
    /**
     * Checks for the provided `sap.m.ObjectMarker` in the aggregation {@link #getMarkers markers}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfMarker(
      /**
       * The marker whose index is looked for
       */
      oMarker: ObjectMarker
    ): int;
    /**
     * Checks for the provided `sap.m.ObjectStatus` in the aggregation {@link #getMarkersAsStatus markersAsStatus}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.117
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfMarkerAsStatus(
      /**
       * The markerAsStatus whose index is looked for
       */
      oMarkerAsStatus: ObjectStatus
    ): int;
    /**
     * Checks for the provided `sap.m.ObjectStatus` in the aggregation {@link #getStatuses statuses}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfStatus(
      /**
       * The status whose index is looked for
       */
      oStatus: ObjectStatus
    ): int;
    /**
     * Inserts a attribute into the aggregation {@link #getAttributes attributes}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertAttribute(
      /**
       * The attribute to insert; if empty, nothing is inserted
       */
      oAttribute: ObjectAttribute,
      /**
       * The `0`-based index the attribute should be inserted at; for a negative value of `iIndex`, the attribute
       * is inserted at position 0; for a value greater than the current size of the aggregation, the attribute
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a headerField into the aggregation {@link #getHeaderFields headerFields}.
     *
     * @since 1.90
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertHeaderField(
      /**
       * The headerField to insert; if empty, nothing is inserted
       */
      oHeaderField: Item,
      /**
       * The `0`-based index the headerField should be inserted at; for a negative value of `iIndex`, the headerField
       * is inserted at position 0; for a value greater than the current size of the aggregation, the headerField
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a marker into the aggregation {@link #getMarkers markers}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertMarker(
      /**
       * The marker to insert; if empty, nothing is inserted
       */
      oMarker: ObjectMarker,
      /**
       * The `0`-based index the marker should be inserted at; for a negative value of `iIndex`, the marker is
       * inserted at position 0; for a value greater than the current size of the aggregation, the marker is inserted
       * at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a markerAsStatus into the aggregation {@link #getMarkersAsStatus markersAsStatus}.
     *
     * @since 1.117
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertMarkerAsStatus(
      /**
       * The markerAsStatus to insert; if empty, nothing is inserted
       */
      oMarkerAsStatus: ObjectStatus,
      /**
       * The `0`-based index the markerAsStatus should be inserted at; for a negative value of `iIndex`, the markerAsStatus
       * is inserted at position 0; for a value greater than the current size of the aggregation, the markerAsStatus
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a status into the aggregation {@link #getStatuses statuses}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertStatus(
      /**
       * The status to insert; if empty, nothing is inserted
       */
      oStatus: ObjectStatus,
      /**
       * The `0`-based index the status should be inserted at; for a negative value of `iIndex`, the status is
       * inserted at position 0; for a value greater than the current size of the aggregation, the status is inserted
       * at the last position
       */
      iIndex: int
    ): this;
    /**
     * Validates if the item is restricted, which means that it is restricted for the file type, media type,
     * maximum file name length and maximum file size limit.
     *
     * @since 1.98
     *
     * @returns `true` if item is restricted, `false` otherwise.
     */
    isRestricted(): boolean;
    /**
     * Removes all the controls from the aggregation {@link #getAttributes attributes}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAttributes(): ObjectAttribute[];
    /**
     * Removes all the controls from the aggregation {@link #getHeaderFields headerFields}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.90
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllHeaderFields(): Item[];
    /**
     * Removes all the controls from the aggregation {@link #getMarkers markers}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllMarkers(): ObjectMarker[];
    /**
     * Removes all the controls from the aggregation {@link #getMarkersAsStatus markersAsStatus}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.117
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllMarkersAsStatus(): ObjectStatus[];
    /**
     * Removes all the controls from the aggregation {@link #getStatuses statuses}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllStatuses(): ObjectStatus[];
    /**
     * Removes a attribute from the aggregation {@link #getAttributes attributes}.
     *
     *
     * @returns The removed attribute or `null`
     */
    removeAttribute(
      /**
       * The attribute to remove or its index or id
       */
      vAttribute: int | string | ObjectAttribute
    ): ObjectAttribute | null;
    /**
     * Removes a headerField from the aggregation {@link #getHeaderFields headerFields}.
     *
     * @since 1.90
     *
     * @returns The removed headerField or `null`
     */
    removeHeaderField(
      /**
       * The headerField to remove or its index or id
       */
      vHeaderField: int | string | Item
    ): Item | null;
    /**
     * Removes a marker from the aggregation {@link #getMarkers markers}.
     *
     *
     * @returns The removed marker or `null`
     */
    removeMarker(
      /**
       * The marker to remove or its index or id
       */
      vMarker: int | string | ObjectMarker
    ): ObjectMarker | null;
    /**
     * Removes a markerAsStatus from the aggregation {@link #getMarkersAsStatus markersAsStatus}.
     *
     * @since 1.117
     *
     * @returns The removed markerAsStatus or `null`
     */
    removeMarkerAsStatus(
      /**
       * The markerAsStatus to remove or its index or id
       */
      vMarkerAsStatus: int | string | ObjectStatus
    ): ObjectStatus | null;
    /**
     * Removes a status from the aggregation {@link #getStatuses statuses}.
     *
     *
     * @returns The removed status or `null`
     */
    removeStatus(
      /**
       * The status to remove or its index or id
       */
      vStatus: int | string | ObjectStatus
    ): ObjectStatus | null;
    /**
     * Sets a new value for property {@link #getEnabledEdit enabledEdit}.
     *
     * Enables or disables the edit button.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabledEdit(
      /**
       * New value for property `enabledEdit`
       */
      bEnabledEdit?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnabledRemove enabledRemove}.
     *
     * Enables or disables the remove button.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnabledRemove(
      /**
       * New value for property `enabledRemove`
       */
      bEnabledRemove?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getFileName fileName}.
     *
     * Specifies the name of the uploaded file.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFileName(
      /**
       * New value for property `fileName`
       */
      sFileName?: string
    ): this;
    /**
     * Sets a new value for property {@link #getMediaType mediaType}.
     *
     * Specifies the MIME type of the file.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMediaType(
      /**
       * New value for property `mediaType`
       */
      sMediaType?: string
    ): this;
    /**
     * Set current progress.
     *
     *
     * @returns Returns instance for chaining.
     */
    setProgress(
      /**
       * Current progress.
       */
      iProgress: int
    ): this;
    /**
     * Sets a new value for property {@link #getSelected selected}.
     *
     * Defines the selected state of the UploadSetItem.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.100.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSelected(
      /**
       * New value for property `selected`
       */
      bSelected?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getThumbnailUrl thumbnailUrl}.
     *
     * Specifies the URL where the thumbnail of the file is located. Can also be set to an SAPUI5 icon URL.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setThumbnailUrl(
      /**
       * New value for property `thumbnailUrl`
       */
      sThumbnailUrl?: string
    ): this;
    /**
     * Sets a new value for property {@link #getUploadState uploadState}.
     *
     * State of the item relevant to its upload process.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUploadState(
      /**
       * New value for property `uploadState`
       */
      sUploadState?: UploadState | keyof typeof UploadState
    ): this;
    /**
     * Sets a new value for property {@link #getUploadUrl uploadUrl}.
     *
     * URL where the uploaded files will be stored. If empty, uploadUrl from the uploader is considered.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.90
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUploadUrl(
      /**
       * New value for property `uploadUrl`
       */
      sUploadUrl?: string
    ): this;
    /**
     * Sets a new value for property {@link #getUrl url}.
     *
     * Specifies the URL where the file is located.
     * If the application doesn't provide a value for this property, the icon and the file name are not clickable
     * in {@link sap.m.upload.UploadSet}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUrl(
      /**
       * New value for property `url`
       */
      sUrl?: string
    ): this;
    /**
     * Sets a new value for property {@link #getVisibleEdit visibleEdit}.
     *
     * Shows or hides the edit button.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisibleEdit(
      /**
       * New value for property `visibleEdit`
       */
      bVisibleEdit?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getVisibleRemove visibleRemove}.
     *
     * Shows or hides the remove button.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisibleRemove(
      /**
       * New value for property `visibleRemove`
       */
      bVisibleRemove?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the UploadSetItem constructor.
   *
   * @deprecated As of version 1.129. replaced by {@link sap.m.upload.UploadItem}
   */
  export interface $UploadSetItemSettings extends $ElementSettings {
    /**
     * Enables or disables the remove button.
     */
    enabledRemove?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Enables or disables the edit button.
     */
    enabledEdit?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the name of the uploaded file.
     */
    fileName?: string | PropertyBindingInfo;

    /**
     * Specifies the MIME type of the file.
     */
    mediaType?: string | PropertyBindingInfo;

    /**
     * Specifies the URL where the thumbnail of the file is located. Can also be set to an SAPUI5 icon URL.
     */
    thumbnailUrl?: string | PropertyBindingInfo;

    /**
     * State of the item relevant to its upload process.
     */
    uploadState?:
      | (UploadState | keyof typeof UploadState)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Specifies the URL where the file is located.
     * If the application doesn't provide a value for this property, the icon and the file name are not clickable
     * in {@link sap.m.upload.UploadSet}.
     */
    url?: string | PropertyBindingInfo;

    /**
     * Shows or hides the remove button.
     */
    visibleRemove?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Shows or hides the edit button.
     */
    visibleEdit?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * URL where the uploaded files will be stored. If empty, uploadUrl from the uploader is considered.
     *
     * @since 1.90
     */
    uploadUrl?: string | PropertyBindingInfo;

    /**
     * Defines the selected state of the UploadSetItem.
     *
     * @since 1.100.0
     */
    selected?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Attributes of the item.
     */
    attributes?:
      | ObjectAttribute[]
      | ObjectAttribute
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Markers of the item.
     */
    markers?:
      | ObjectMarker[]
      | ObjectMarker
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Statuses of the item.
     */
    statuses?:
      | ObjectStatus[]
      | ObjectStatus
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Statuses of the item, but it would be appearing in the markers section
     *
     * @since 1.117
     */
    markersAsStatus?:
      | ObjectStatus[]
      | ObjectStatus
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Header fields to be included in the header section of an XMLHttpRequest (XHR) request
     *
     * @since 1.90
     */
    headerFields?: Item[] | Item | AggregationBindingInfo | `{${string}}`;

    /**
     * This event is fired when an open action is invoked on an item.
     */
    openPressed?: (oEvent: UploadSetItem$OpenPressedEvent) => void;

    /**
     * This event is fired when a remove action is invoked on an item.
     */
    removePressed?: (oEvent: UploadSetItem$RemovePressedEvent) => void;
  }

  /**
   * Parameters of the UploadSetItem#openPressed event.
   */
  export interface UploadSetItem$OpenPressedEventParameters {
    /**
     * The item on which the open action has been invoked.
     */
    item?: UploadSetItem;
  }

  /**
   * Event object of the UploadSetItem#openPressed event.
   */
  export type UploadSetItem$OpenPressedEvent = Event<
    UploadSetItem$OpenPressedEventParameters,
    UploadSetItem
  >;

  /**
   * Parameters of the UploadSetItem#removePressed event.
   */
  export interface UploadSetItem$RemovePressedEventParameters {
    /**
     * The item on which the open action has been invoked.
     */
    item?: UploadSetItem;
  }

  /**
   * Event object of the UploadSetItem#removePressed event.
   */
  export type UploadSetItem$RemovePressedEvent = Event<
    UploadSetItem$RemovePressedEventParameters,
    UploadSetItem
  >;
}

declare module "sap/m/upload/UploadSetToolbarPlaceholder" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * Used to create a customizable toolbar for the UploadSet. A FileUploader instance is required in the toolbar
   * and it is placed by the application.
   *
   * @since 1.103.0
   * @deprecated As of version 1.129. replaced by {@link sap.m.upload.ActionsPlaceholder}
   */
  export default class UploadSetToolbarPlaceholder extends Control {
    /**
     * Constructor for a new UploadSetToolbarPlaceholder.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.ui.core.Control#constructor sap.ui.core.Control }
     * can be used.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $UploadSetToolbarPlaceholderSettings
    );
    /**
     * Constructor for a new UploadSetToolbarPlaceholder.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.ui.core.Control#constructor sap.ui.core.Control }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $UploadSetToolbarPlaceholderSettings
    );

    /**
     * Creates a new subclass of class sap.m.upload.UploadSetToolbarPlaceholder with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, UploadSetToolbarPlaceholder>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.upload.UploadSetToolbarPlaceholder.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the UploadSetToolbarPlaceholder constructor.
   *
   * @deprecated As of version 1.129. replaced by {@link sap.m.upload.ActionsPlaceholder}
   */
  export interface $UploadSetToolbarPlaceholderSettings
    extends $ControlSettings {}
}

declare module "sap/m/UploadCollection" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import UploadCollectionParameter from "sap/m/UploadCollectionParameter";

  import UploadCollectionItem from "sap/m/UploadCollectionItem";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import Toolbar from "sap/m/Toolbar";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { ListMode, ListSeparators } from "sap/m/library";

  import OverflowToolbar from "sap/m/OverflowToolbar";

  import Event from "sap/ui/base/Event";

  /**
   * This control allows you to upload single or multiple files from your devices (desktop, tablet or phone)
   * and attach them to the application.
   *
   * The consuming application needs to take into account that the consistency checks of the model during
   * the upload of the file need to be performed, for example, if the user is editing or deleting a file.
   *
   *  As of version 1.63, there is an {@link sap.m.upload.UploadSet} control available that is based on this
   * control. {@link sap.m.upload.UploadSet} provides enhanced handling of headers and requests, unified behavior
   * of instant and deferred uploads, as well as improved progress indication.
   *
   * @deprecated As of version 1.88. replaced by {@link sap.m.upload.UploadSet}
   */
  export default class UploadCollection extends Control {
    /**
     * Constructor for a new UploadCollection.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $UploadCollectionSettings
    );
    /**
     * Constructor for a new UploadCollection.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $UploadCollectionSettings
    );

    /**
     * Creates a new subclass of class sap.m.UploadCollection with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, UploadCollection>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.UploadCollection.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some headerParameter to the aggregation {@link #getHeaderParameters headerParameters}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addHeaderParameter(
      /**
       * The headerParameter to add; if empty, nothing is inserted
       */
      oHeaderParameter: UploadCollectionParameter
    ): this;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: UploadCollectionItem
    ): this;
    /**
     * Adds some parameter to the aggregation {@link #getParameters parameters}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addParameter(
      /**
       * The parameter to add; if empty, nothing is inserted
       */
      oParameter: UploadCollectionParameter
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeUploadStarts beforeUploadStarts} event
     * of this `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * The event is triggered before the actual upload starts. An event is fired per file. All the necessary
     * header parameters should be set here.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeUploadStarts(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$BeforeUploadStartsEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:beforeUploadStarts beforeUploadStarts} event
     * of this `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * The event is triggered before the actual upload starts. An event is fired per file. All the necessary
     * header parameters should be set here.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachBeforeUploadStarts(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$BeforeUploadStartsEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * The event is triggered when files are selected in the FileUploader dialog. Applications can set parameters
     * and headerParameters which will be dispatched to the embedded FileUploader control. Restriction: parameters
     * and headerParameters are not supported by Internet Explorer 9.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:change change} event of this `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * The event is triggered when files are selected in the FileUploader dialog. Applications can set parameters
     * and headerParameters which will be dispatched to the embedded FileUploader control. Restriction: parameters
     * and headerParameters are not supported by Internet Explorer 9.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$ChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileDeleted fileDeleted} event of this `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * The event is triggered when an uploaded attachment is selected and the Delete button is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileDeleted(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$FileDeletedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileDeleted fileDeleted} event of this `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * The event is triggered when an uploaded attachment is selected and the Delete button is pressed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileDeleted(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$FileDeletedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:filenameLengthExceed filenameLengthExceed} event
     * of this `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * The event is triggered when the name of a chosen file is longer than the value specified with the maximumFilenameLength
     * property (only if provided by the application).
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFilenameLengthExceed(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$FilenameLengthExceedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:filenameLengthExceed filenameLengthExceed} event
     * of this `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * The event is triggered when the name of a chosen file is longer than the value specified with the maximumFilenameLength
     * property (only if provided by the application).
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFilenameLengthExceed(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$FilenameLengthExceedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileRenamed fileRenamed} event of this `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * The event is triggered when the file name is changed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileRenamed(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$FileRenamedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileRenamed fileRenamed} event of this `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * The event is triggered when the file name is changed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileRenamed(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$FileRenamedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileSizeExceed fileSizeExceed} event of this
     * `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * The event is triggered when the file size of an uploaded file is exceeded (only if the maxFileSize property
     * was provided by the application). This event is not supported by Internet Explorer 9.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileSizeExceed(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$FileSizeExceedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:fileSizeExceed fileSizeExceed} event of this
     * `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * The event is triggered when the file size of an uploaded file is exceeded (only if the maxFileSize property
     * was provided by the application). This event is not supported by Internet Explorer 9.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachFileSizeExceed(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$FileSizeExceedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionChange selectionChange} event of this
     * `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * Fires when selection is changed via user interaction inside the control.
     *
     * @since 1.36.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$SelectionChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectionChange selectionChange} event of this
     * `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * Fires when selection is changed via user interaction inside the control.
     *
     * @since 1.36.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectionChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$SelectionChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:typeMissmatch typeMissmatch} event of this `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * The event is triggered when the file type or the MIME type don't match the permitted types (only if the
     * fileType property or the mimeType property are provided by the application).
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTypeMissmatch(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$TypeMissmatchEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:typeMissmatch typeMissmatch} event of this `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * The event is triggered when the file type or the MIME type don't match the permitted types (only if the
     * fileType property or the mimeType property are provided by the application).
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachTypeMissmatch(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$TypeMissmatchEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadComplete uploadComplete} event of this
     * `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * The event is triggered as soon as the upload request is completed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadComplete(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$UploadCompleteEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadComplete uploadComplete} event of this
     * `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * The event is triggered as soon as the upload request is completed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadComplete(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$UploadCompleteEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadTerminated uploadTerminated} event of
     * this `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * The event is triggered as soon as the upload request was terminated by the user.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadTerminated(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$UploadTerminatedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:uploadTerminated uploadTerminated} event of
     * this `sap.m.UploadCollection`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollection` itself.
     *
     * The event is triggered as soon as the upload request was terminated by the user.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachUploadTerminated(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: UploadCollection$UploadTerminatedEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollection` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getItems items} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the headerParameters in the aggregation {@link #getHeaderParameters headerParameters}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyHeaderParameters(): this;
    /**
     * Destroys the infoToolbar in the aggregation {@link #getInfoToolbar infoToolbar}.
     *
     * @since 1.44.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyInfoToolbar(): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Destroys all the parameters in the aggregation {@link #getParameters parameters}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyParameters(): this;
    /**
     * Destroys the toolbar in the aggregation {@link #getToolbar toolbar}.
     *
     * @since 1.34.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyToolbar(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:beforeUploadStarts beforeUploadStarts} event
     * of this `sap.m.UploadCollection`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachBeforeUploadStarts(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadCollection$BeforeUploadStartsEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:change change} event of this `sap.m.UploadCollection`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadCollection$ChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:fileDeleted fileDeleted} event of this `sap.m.UploadCollection`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachFileDeleted(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadCollection$FileDeletedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:filenameLengthExceed filenameLengthExceed }
     * event of this `sap.m.UploadCollection`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachFilenameLengthExceed(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadCollection$FilenameLengthExceedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:fileRenamed fileRenamed} event of this `sap.m.UploadCollection`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachFileRenamed(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadCollection$FileRenamedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:fileSizeExceed fileSizeExceed} event of this
     * `sap.m.UploadCollection`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachFileSizeExceed(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadCollection$FileSizeExceedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:selectionChange selectionChange} event of
     * this `sap.m.UploadCollection`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.36.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelectionChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadCollection$SelectionChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:typeMissmatch typeMissmatch} event of this
     * `sap.m.UploadCollection`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachTypeMissmatch(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadCollection$TypeMissmatchEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:uploadComplete uploadComplete} event of this
     * `sap.m.UploadCollection`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUploadComplete(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadCollection$UploadCompleteEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:uploadTerminated uploadTerminated} event of
     * this `sap.m.UploadCollection`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachUploadTerminated(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: UploadCollection$UploadTerminatedEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Downloads the given item. This function delegates to {@link sap.m.UploadCollectionItem#download uploadCollectionItem.download}.
     *
     * @since 1.36.0
     *
     * @returns True if the download has started successfully. False if the download couldn't be started.
     */
    downloadItem(
      /**
       * The item to download. This parameter is mandatory.
       */
      uploadCollectionItem: UploadCollectionItem,
      /**
       * Decides whether to ask for a location to download or not.
       */
      askForLocation: boolean
    ): boolean;
    /**
     * Fires event {@link #event:beforeUploadStarts beforeUploadStarts} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireBeforeUploadStarts(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadCollection$BeforeUploadStartsEventParameters
    ): this;
    /**
     * Fires event {@link #event:change change} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadCollection$ChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:fileDeleted fileDeleted} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireFileDeleted(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadCollection$FileDeletedEventParameters
    ): this;
    /**
     * Fires event {@link #event:filenameLengthExceed filenameLengthExceed} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireFilenameLengthExceed(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadCollection$FilenameLengthExceedEventParameters
    ): this;
    /**
     * Fires event {@link #event:fileRenamed fileRenamed} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireFileRenamed(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadCollection$FileRenamedEventParameters
    ): this;
    /**
     * Fires event {@link #event:fileSizeExceed fileSizeExceed} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireFileSizeExceed(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadCollection$FileSizeExceedEventParameters
    ): this;
    /**
     * Fires event {@link #event:selectionChange selectionChange} to attached listeners.
     *
     * @since 1.36.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelectionChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadCollection$SelectionChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:typeMissmatch typeMissmatch} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireTypeMissmatch(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadCollection$TypeMissmatchEventParameters
    ): this;
    /**
     * Fires event {@link #event:uploadComplete uploadComplete} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUploadComplete(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadCollection$UploadCompleteEventParameters
    ): this;
    /**
     * Fires event {@link #event:uploadTerminated uploadTerminated} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireUploadTerminated(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: UploadCollection$UploadTerminatedEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getFileType fileType}.
     *
     * Defines the allowed file types for the upload. The chosen files will be checked against an array of file
     * types. If at least one file does not fit the file type requirements, the upload is prevented. Example:
     * ["jpg", "png", "bmp"].
     *
     *
     * @returns Value of property `fileType`
     */
    getFileType(): string[];
    /**
     * Gets content of aggregation {@link #getHeaderParameters headerParameters}.
     *
     * Specifies the header parameters for the FileUploader that are submitted only with XHR requests. Header
     * parameters are not supported by Internet Explorer 8 and 9.
     */
    getHeaderParameters(): UploadCollectionParameter[];
    /**
     * Gets content of aggregation {@link #getInfoToolbar infoToolbar}.
     *
     * Specifies the info toolbar for filtering information. Sorting information will not displayed.
     *
     * @since 1.44.0
     */
    getInfoToolbar(): Toolbar;
    /**
     * Gets current value of property {@link #getInstantUpload instantUpload}.
     *
     * If false, no upload is triggered when a file is selected. In addition, if a file was selected, a new
     * FileUploader instance is created to ensure that multiple files can be chosen.
     *
     * Default value is `true`.
     *
     * @since 1.30.0
     *
     * @returns Value of property `instantUpload`
     */
    getInstantUpload(): boolean;
    /**
     * Provides access to the internally used request headers to allow adding them to the "Access-Control-Allow-Headers"
     * header parameter if needed.
     *
     * @since 1.50.0
     *
     * @returns An array of request header strings
     */
    getInternalRequestHeaderNames(): string[];
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * Uploaded items.
     */
    getItems(): UploadCollectionItem[];
    /**
     * Gets current value of property {@link #getMaximumFilenameLength maximumFilenameLength}.
     *
     * Specifies the maximum length of a file name. If the maximum file name length is exceeded, the corresponding
     * event 'filenameLengthExceed' is triggered.
     *
     *
     * @returns Value of property `maximumFilenameLength`
     */
    getMaximumFilenameLength(): int;
    /**
     * Gets current value of property {@link #getMaximumFileSize maximumFileSize}.
     *
     * Specifies a file size limit in megabytes that prevents the upload if at least one file exceeds the limit.
     * This property is not supported by Internet Explorer 8 and 9.
     *
     *
     * @returns Value of property `maximumFileSize`
     */
    getMaximumFileSize(): float;
    /**
     * Gets current value of property {@link #getMimeType mimeType}.
     *
     * Defines the allowed MIME types of files to be uploaded. The chosen files will be checked against an array
     * of MIME types. If at least one file does not fit the MIME type requirements, the upload is prevented.
     * This property is not supported by Internet Explorer 8 and 9. Example: mimeType ["image/png", "image/jpeg"].
     *
     *
     * @returns Value of property `mimeType`
     */
    getMimeType(): string[];
    /**
     * Gets current value of property {@link #getMode mode}.
     *
     * Defines the selection mode of the control (e.g. None, SingleSelect, MultiSelect, SingleSelectLeft, SingleSelectMaster).
     * Since the UploadCollection reacts like a list for attachments, the API is close to the ListBase Interface.
     * sap.m.ListMode.Delete mode is not supported and will be automatically set to sap.m.ListMode.None. In
     * addition, if instant upload is set to false the mode sap.m.ListMode.MultiSelect is not supported and
     * will be automatically set to sap.m.ListMode.None.
     *
     * Default value is `"None"`.
     *
     * @since 1.34.0
     *
     * @returns Value of property `mode`
     */
    getMode(): ListMode;
    /**
     * Gets current value of property {@link #getMultiple multiple}.
     *
     * Lets the user select multiple files from the same folder and then upload them. Internet Explorer 8 and
     * 9 do not support this property. Please note that the various operating systems for mobile devices can
     * react differently to the property so that fewer upload functions may be available in some cases.
     *
     * If multiple property is set to false, the control shows an error message if more than one file is chosen
     * for drag & drop.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `multiple`
     */
    getMultiple(): boolean;
    /**
     * Gets current value of property {@link #getNoDataDescription noDataDescription}.
     *
     * Allows you to set your own text for the 'No data' description label.
     *
     * @since 1.46.0
     *
     * @returns Value of property `noDataDescription`
     */
    getNoDataDescription(): string;
    /**
     * Gets current value of property {@link #getNoDataText noDataText}.
     *
     * Allows you to set your own text for the 'No data' text label.
     *
     *
     * @returns Value of property `noDataText`
     */
    getNoDataText(): string;
    /**
     * Gets current value of property {@link #getNumberOfAttachmentsText numberOfAttachmentsText}.
     *
     * Sets the title text in the toolbar of the list of attachments. To show as well the number of attachments
     * in brackets like the default text does. The number of attachments could be retrieved via "getItems().length".
     * If a new title is set, the default is deactivated. The default value is set to language-dependent "Attachments
     * (n)".
     *
     * @since 1.30.0
     *
     * @returns Value of property `numberOfAttachmentsText`
     */
    getNumberOfAttachmentsText(): string;
    /**
     * Gets content of aggregation {@link #getParameters parameters}.
     *
     * Specifies the parameters for the FileUploader that are rendered as a hidden input field.
     */
    getParameters(): UploadCollectionParameter[];
    /**
     * Gets current value of property {@link #getSameFilenameAllowed sameFilenameAllowed}.
     *
     * Allows the user to use the same name for a file when editing the file name. 'Same name' refers to an
     * already existing file name in the list.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `sameFilenameAllowed`
     */
    getSameFilenameAllowed(): boolean;
    /**
     * Retrieves the currently selected UploadCollectionItem.
     *
     * @since 1.34.0
     *
     * @returns The currently selected item or `null`
     */
    getSelectedItem(): UploadCollectionItem | null;
    /**
     * Returns an array containing the selected UploadCollectionItems.
     *
     * @since 1.34.0
     *
     * @returns Array of all selected items
     */
    getSelectedItems(): UploadCollectionItem[];
    /**
     * Gets current value of property {@link #getShowSeparators showSeparators}.
     *
     * Defines whether separators are shown between list items.
     *
     * Default value is `"All"`.
     *
     *
     * @returns Value of property `showSeparators`
     */
    getShowSeparators(): ListSeparators;
    /**
     * Gets current value of property {@link #getTerminationEnabled terminationEnabled}.
     *
     * If true, the button that is used to terminate the instant file upload gets visible. The button normally
     * appears when a file is being uploaded.
     *
     * Default value is `true`.
     *
     * @since 1.42.0
     *
     * @returns Value of property `terminationEnabled`
     */
    getTerminationEnabled(): boolean;
    /**
     * Gets content of aggregation {@link #getToolbar toolbar}.
     *
     * Specifies the toolbar.
     *
     * @since 1.34.0
     */
    getToolbar(): OverflowToolbar;
    /**
     * Gets current value of property {@link #getUploadButtonInvisible uploadButtonInvisible}.
     *
     * If true, the button used for uploading files is invisible.
     *
     * Default value is `false`.
     *
     * @since 1.42.0
     *
     * @returns Value of property `uploadButtonInvisible`
     */
    getUploadButtonInvisible(): boolean;
    /**
     * Gets current value of property {@link #getUploadEnabled uploadEnabled}.
     *
     * Enables the upload of a file. If property instantUpload is false it is not allowed to change uploadEnabled
     * at runtime.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `uploadEnabled`
     */
    getUploadEnabled(): boolean;
    /**
     * Gets current value of property {@link #getUploadUrl uploadUrl}.
     *
     * Specifies the URL where the uploaded files have to be stored.
     *
     * Default value is `"../../../upload"`.
     *
     *
     * @returns Value of property `uploadUrl`
     */
    getUploadUrl(): string;
    /**
     * Checks for the provided `sap.m.UploadCollectionParameter` in the aggregation {@link #getHeaderParameters headerParameters}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfHeaderParameter(
      /**
       * The headerParameter whose index is looked for
       */
      oHeaderParameter: UploadCollectionParameter
    ): int;
    /**
     * Checks for the provided `sap.m.UploadCollectionItem` in the aggregation {@link #getItems items}. and
     * returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: UploadCollectionItem
    ): int;
    /**
     * Checks for the provided `sap.m.UploadCollectionParameter` in the aggregation {@link #getParameters parameters}.
     * and returns its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfParameter(
      /**
       * The parameter whose index is looked for
       */
      oParameter: UploadCollectionParameter
    ): int;
    /**
     * Inserts a headerParameter into the aggregation {@link #getHeaderParameters headerParameters}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertHeaderParameter(
      /**
       * The headerParameter to insert; if empty, nothing is inserted
       */
      oHeaderParameter: UploadCollectionParameter,
      /**
       * The `0`-based index the headerParameter should be inserted at; for a negative value of `iIndex`, the
       * headerParameter is inserted at position 0; for a value greater than the current size of the aggregation,
       * the headerParameter is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: UploadCollectionItem,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a parameter into the aggregation {@link #getParameters parameters}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertParameter(
      /**
       * The parameter to insert; if empty, nothing is inserted
       */
      oParameter: UploadCollectionParameter,
      /**
       * The `0`-based index the parameter should be inserted at; for a negative value of `iIndex`, the parameter
       * is inserted at position 0; for a value greater than the current size of the aggregation, the parameter
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Opens the FileUploader dialog. When an UploadCollectionItem is provided, this method can be used to update
     * a file with a new version. In this case, the upload progress can be sequenced using the events: beforeUploadStarts,
     * uploadComplete and uploadTerminated. For this use, multiple properties from the UploadCollection have
     * to be set to false. If no UploadCollectionItem is provided, only the dialog opens and no further configuration
     * of the UploadCollection is needed.
     *
     * @since 1.38.0
     *
     * @returns this to allow method chaining
     */
    openFileDialog(
      /**
       * The item to update with a new version. This parameter is mandatory.
       */
      item: UploadCollectionItem
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getHeaderParameters headerParameters}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllHeaderParameters(): UploadCollectionParameter[];
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): UploadCollectionItem[];
    /**
     * Removes all the controls from the aggregation {@link #getParameters parameters}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllParameters(): UploadCollectionParameter[];
    /**
     * Removes a headerParameter from the aggregation {@link #getHeaderParameters headerParameters}.
     *
     *
     * @returns The removed headerParameter or `null`
     */
    removeHeaderParameter(
      /**
       * The headerParameter to remove or its index or id
       */
      vHeaderParameter: int | string | UploadCollectionParameter
    ): UploadCollectionParameter | null;
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | UploadCollectionItem
    ): UploadCollectionItem | null;
    /**
     * Removes a parameter from the aggregation {@link #getParameters parameters}.
     *
     *
     * @returns The removed parameter or `null`
     */
    removeParameter(
      /**
       * The parameter to remove or its index or id
       */
      vParameter: int | string | UploadCollectionParameter
    ): UploadCollectionParameter | null;
    /**
     * Select all items in "MultiSelection" mode.
     *
     * @since 1.34.0
     *
     * @returns this to allow method chaining
     */
    selectAll(): this;
    /**
     * Sets a new value for property {@link #getFileType fileType}.
     *
     * Defines the allowed file types for the upload. The chosen files will be checked against an array of file
     * types. If at least one file does not fit the file type requirements, the upload is prevented. Example:
     * ["jpg", "png", "bmp"].
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFileType(
      /**
       * New value for property `fileType`
       */
      sFileType?: string[]
    ): this;
    /**
     * Sets the aggregated {@link #getInfoToolbar infoToolbar}.
     *
     * @since 1.44.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInfoToolbar(
      /**
       * The infoToolbar to set
       */
      oInfoToolbar: Toolbar
    ): this;
    /**
     * Sets a new value for property {@link #getInstantUpload instantUpload}.
     *
     * If false, no upload is triggered when a file is selected. In addition, if a file was selected, a new
     * FileUploader instance is created to ensure that multiple files can be chosen.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInstantUpload(
      /**
       * New value for property `instantUpload`
       */
      bInstantUpload?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getMaximumFilenameLength maximumFilenameLength}.
     *
     * Specifies the maximum length of a file name. If the maximum file name length is exceeded, the corresponding
     * event 'filenameLengthExceed' is triggered.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaximumFilenameLength(
      /**
       * New value for property `maximumFilenameLength`
       */
      iMaximumFilenameLength?: int
    ): this;
    /**
     * Sets a new value for property {@link #getMaximumFileSize maximumFileSize}.
     *
     * Specifies a file size limit in megabytes that prevents the upload if at least one file exceeds the limit.
     * This property is not supported by Internet Explorer 8 and 9.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaximumFileSize(
      /**
       * New value for property `maximumFileSize`
       */
      fMaximumFileSize?: float
    ): this;
    /**
     * Sets a new value for property {@link #getMimeType mimeType}.
     *
     * Defines the allowed MIME types of files to be uploaded. The chosen files will be checked against an array
     * of MIME types. If at least one file does not fit the MIME type requirements, the upload is prevented.
     * This property is not supported by Internet Explorer 8 and 9. Example: mimeType ["image/png", "image/jpeg"].
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMimeType(
      /**
       * New value for property `mimeType`
       */
      sMimeType?: string[]
    ): this;
    /**
     * Sets a new value for property {@link #getMode mode}.
     *
     * Defines the selection mode of the control (e.g. None, SingleSelect, MultiSelect, SingleSelectLeft, SingleSelectMaster).
     * Since the UploadCollection reacts like a list for attachments, the API is close to the ListBase Interface.
     * sap.m.ListMode.Delete mode is not supported and will be automatically set to sap.m.ListMode.None. In
     * addition, if instant upload is set to false the mode sap.m.ListMode.MultiSelect is not supported and
     * will be automatically set to sap.m.ListMode.None.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"None"`.
     *
     * @since 1.34.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMode(
      /**
       * New value for property `mode`
       */
      sMode?: ListMode | keyof typeof ListMode
    ): this;
    /**
     * Sets a new value for property {@link #getMultiple multiple}.
     *
     * Lets the user select multiple files from the same folder and then upload them. Internet Explorer 8 and
     * 9 do not support this property. Please note that the various operating systems for mobile devices can
     * react differently to the property so that fewer upload functions may be available in some cases.
     *
     * If multiple property is set to false, the control shows an error message if more than one file is chosen
     * for drag & drop.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMultiple(
      /**
       * New value for property `multiple`
       */
      bMultiple?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getNoDataDescription noDataDescription}.
     *
     * Allows you to set your own text for the 'No data' description label.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.46.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNoDataDescription(
      /**
       * New value for property `noDataDescription`
       */
      sNoDataDescription?: string
    ): this;
    /**
     * Sets a new value for property {@link #getNoDataText noDataText}.
     *
     * Allows you to set your own text for the 'No data' text label.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNoDataText(
      /**
       * New value for property `noDataText`
       */
      sNoDataText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getNumberOfAttachmentsText numberOfAttachmentsText}.
     *
     * Sets the title text in the toolbar of the list of attachments. To show as well the number of attachments
     * in brackets like the default text does. The number of attachments could be retrieved via "getItems().length".
     * If a new title is set, the default is deactivated. The default value is set to language-dependent "Attachments
     * (n)".
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNumberOfAttachmentsText(
      /**
       * New value for property `numberOfAttachmentsText`
       */
      sNumberOfAttachmentsText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSameFilenameAllowed sameFilenameAllowed}.
     *
     * Allows the user to use the same name for a file when editing the file name. 'Same name' refers to an
     * already existing file name in the list.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSameFilenameAllowed(
      /**
       * New value for property `sameFilenameAllowed`
       */
      bSameFilenameAllowed?: boolean
    ): this;
    /**
     * Selects or deselects the given list item.
     *
     * @since 1.34.0
     *
     * @returns this to allow method chaining
     */
    setSelectedItem(
      /**
       * The item whose selection is to be changed. This parameter is mandatory.
       */
      uploadCollectionItem: UploadCollectionItem,
      /**
       * The selection state of the item.
       */
      select?: boolean
    ): this;
    /**
     * Sets an UploadCollectionItem to be selected by ID. In single selection mode, the method removes the previous
     * selection.
     *
     * @since 1.34.0
     *
     * @returns this to allow method chaining
     */
    setSelectedItemById(
      /**
       * The ID of the item whose selection is to be changed.
       */
      id: string,
      /**
       * The selection state of the item.
       */
      select?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowSeparators showSeparators}.
     *
     * Defines whether separators are shown between list items.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"All"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowSeparators(
      /**
       * New value for property `showSeparators`
       */
      sShowSeparators?: ListSeparators | keyof typeof ListSeparators
    ): this;
    /**
     * Sets a new value for property {@link #getTerminationEnabled terminationEnabled}.
     *
     * If true, the button that is used to terminate the instant file upload gets visible. The button normally
     * appears when a file is being uploaded.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.42.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTerminationEnabled(
      /**
       * New value for property `terminationEnabled`
       */
      bTerminationEnabled?: boolean
    ): this;
    /**
     * Sets the aggregated {@link #getToolbar toolbar}.
     *
     * @since 1.34.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setToolbar(
      /**
       * The toolbar to set
       */
      oToolbar: OverflowToolbar
    ): this;
    /**
     * Sets a new value for property {@link #getUploadButtonInvisible uploadButtonInvisible}.
     *
     * If true, the button used for uploading files is invisible.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.42.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUploadButtonInvisible(
      /**
       * New value for property `uploadButtonInvisible`
       */
      bUploadButtonInvisible?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getUploadEnabled uploadEnabled}.
     *
     * Enables the upload of a file. If property instantUpload is false it is not allowed to change uploadEnabled
     * at runtime.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUploadEnabled(
      /**
       * New value for property `uploadEnabled`
       */
      bUploadEnabled?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getUploadUrl uploadUrl}.
     *
     * Specifies the URL where the uploaded files have to be stored.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"../../../upload"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUploadUrl(
      /**
       * New value for property `uploadUrl`
       */
      sUploadUrl?: string
    ): this;
    /**
     * Unbinds aggregation {@link #getItems items} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindItems(): this;
    /**
     * Starts the upload for all selected files.
     *
     * @since 1.30.0
     */
    upload(): void;
  }
  /**
   * Describes the settings that can be provided to the UploadCollection constructor.
   *
   * @deprecated As of version 1.88. replaced by {@link sap.m.upload.UploadSet}
   */
  export interface $UploadCollectionSettings extends $ControlSettings {
    /**
     * Defines the allowed file types for the upload. The chosen files will be checked against an array of file
     * types. If at least one file does not fit the file type requirements, the upload is prevented. Example:
     * ["jpg", "png", "bmp"].
     */
    fileType?: string[] | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the maximum length of a file name. If the maximum file name length is exceeded, the corresponding
     * event 'filenameLengthExceed' is triggered.
     */
    maximumFilenameLength?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies a file size limit in megabytes that prevents the upload if at least one file exceeds the limit.
     * This property is not supported by Internet Explorer 8 and 9.
     */
    maximumFileSize?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the allowed MIME types of files to be uploaded. The chosen files will be checked against an array
     * of MIME types. If at least one file does not fit the MIME type requirements, the upload is prevented.
     * This property is not supported by Internet Explorer 8 and 9. Example: mimeType ["image/png", "image/jpeg"].
     */
    mimeType?: string[] | PropertyBindingInfo | `{${string}}`;

    /**
     * Lets the user select multiple files from the same folder and then upload them. Internet Explorer 8 and
     * 9 do not support this property. Please note that the various operating systems for mobile devices can
     * react differently to the property so that fewer upload functions may be available in some cases.
     *
     * If multiple property is set to false, the control shows an error message if more than one file is chosen
     * for drag & drop.
     */
    multiple?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Allows you to set your own text for the 'No data' text label.
     */
    noDataText?: string | PropertyBindingInfo;

    /**
     * Allows you to set your own text for the 'No data' description label.
     *
     * @since 1.46.0
     */
    noDataDescription?: string | PropertyBindingInfo;

    /**
     * Allows the user to use the same name for a file when editing the file name. 'Same name' refers to an
     * already existing file name in the list.
     */
    sameFilenameAllowed?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines whether separators are shown between list items.
     */
    showSeparators?:
      | (ListSeparators | keyof typeof ListSeparators)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Enables the upload of a file. If property instantUpload is false it is not allowed to change uploadEnabled
     * at runtime.
     */
    uploadEnabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the URL where the uploaded files have to be stored.
     */
    uploadUrl?: string | PropertyBindingInfo;

    /**
     * If false, no upload is triggered when a file is selected. In addition, if a file was selected, a new
     * FileUploader instance is created to ensure that multiple files can be chosen.
     *
     * @since 1.30.0
     */
    instantUpload?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the title text in the toolbar of the list of attachments. To show as well the number of attachments
     * in brackets like the default text does. The number of attachments could be retrieved via "getItems().length".
     * If a new title is set, the default is deactivated. The default value is set to language-dependent "Attachments
     * (n)".
     *
     * @since 1.30.0
     */
    numberOfAttachmentsText?: string | PropertyBindingInfo;

    /**
     * Defines the selection mode of the control (e.g. None, SingleSelect, MultiSelect, SingleSelectLeft, SingleSelectMaster).
     * Since the UploadCollection reacts like a list for attachments, the API is close to the ListBase Interface.
     * sap.m.ListMode.Delete mode is not supported and will be automatically set to sap.m.ListMode.None. In
     * addition, if instant upload is set to false the mode sap.m.ListMode.MultiSelect is not supported and
     * will be automatically set to sap.m.ListMode.None.
     *
     * @since 1.34.0
     */
    mode?:
      | (ListMode | keyof typeof ListMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * If true, the button used for uploading files is invisible.
     *
     * @since 1.42.0
     */
    uploadButtonInvisible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * If true, the button that is used to terminate the instant file upload gets visible. The button normally
     * appears when a file is being uploaded.
     *
     * @since 1.42.0
     */
    terminationEnabled?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Uploaded items.
     */
    items?:
      | UploadCollectionItem[]
      | UploadCollectionItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Specifies the header parameters for the FileUploader that are submitted only with XHR requests. Header
     * parameters are not supported by Internet Explorer 8 and 9.
     */
    headerParameters?:
      | UploadCollectionParameter[]
      | UploadCollectionParameter
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Specifies the parameters for the FileUploader that are rendered as a hidden input field.
     */
    parameters?:
      | UploadCollectionParameter[]
      | UploadCollectionParameter
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Specifies the toolbar.
     *
     * @since 1.34.0
     */
    toolbar?: OverflowToolbar;

    /**
     * Specifies the info toolbar for filtering information. Sorting information will not displayed.
     *
     * @since 1.44.0
     */
    infoToolbar?: Toolbar;

    /**
     * The event is triggered when files are selected in the FileUploader dialog. Applications can set parameters
     * and headerParameters which will be dispatched to the embedded FileUploader control. Restriction: parameters
     * and headerParameters are not supported by Internet Explorer 9.
     */
    change?: (oEvent: UploadCollection$ChangeEvent) => void;

    /**
     * The event is triggered when an uploaded attachment is selected and the Delete button is pressed.
     */
    fileDeleted?: (oEvent: UploadCollection$FileDeletedEvent) => void;

    /**
     * The event is triggered when the name of a chosen file is longer than the value specified with the maximumFilenameLength
     * property (only if provided by the application).
     */
    filenameLengthExceed?: (
      oEvent: UploadCollection$FilenameLengthExceedEvent
    ) => void;

    /**
     * The event is triggered when the file name is changed.
     */
    fileRenamed?: (oEvent: UploadCollection$FileRenamedEvent) => void;

    /**
     * The event is triggered when the file size of an uploaded file is exceeded (only if the maxFileSize property
     * was provided by the application). This event is not supported by Internet Explorer 9.
     */
    fileSizeExceed?: (oEvent: UploadCollection$FileSizeExceedEvent) => void;

    /**
     * The event is triggered when the file type or the MIME type don't match the permitted types (only if the
     * fileType property or the mimeType property are provided by the application).
     */
    typeMissmatch?: (oEvent: UploadCollection$TypeMissmatchEvent) => void;

    /**
     * The event is triggered as soon as the upload request is completed.
     */
    uploadComplete?: (oEvent: UploadCollection$UploadCompleteEvent) => void;

    /**
     * The event is triggered as soon as the upload request was terminated by the user.
     */
    uploadTerminated?: (oEvent: UploadCollection$UploadTerminatedEvent) => void;

    /**
     * The event is triggered before the actual upload starts. An event is fired per file. All the necessary
     * header parameters should be set here.
     */
    beforeUploadStarts?: (
      oEvent: UploadCollection$BeforeUploadStartsEvent
    ) => void;

    /**
     * Fires when selection is changed via user interaction inside the control.
     *
     * @since 1.36.0
     */
    selectionChange?: (oEvent: UploadCollection$SelectionChangeEvent) => void;
  }

  /**
   * Parameters of the UploadCollection#beforeUploadStarts event.
   */
  export interface UploadCollection$BeforeUploadStartsEventParameters {
    /**
     * Specifies the name of the file to be uploaded.
     */
    fileName?: string;

    /**
     * A function that adds a header parameter to the file that will be uploaded. The function accepts one parameter
     * of type `sap.m.UploadCollectionParameter` which specifies the header parameter that will be added.
     */
    addHeaderParameter?: Function;

    /**
     * A function that returns the corresponding header parameter (type `sap.m.UploadCollectionParameter`) if
     * available. The function accepts one optional parameter of type `string`, which is the name of the header
     * parameter. If no parameter is provided all header parameters are returned.
     */
    getHeaderParameter?: Function;
  }

  /**
   * Event object of the UploadCollection#beforeUploadStarts event.
   */
  export type UploadCollection$BeforeUploadStartsEvent = Event<
    UploadCollection$BeforeUploadStartsEventParameters,
    UploadCollection
  >;

  /**
   * Parameters of the UploadCollection#change event.
   */
  export interface UploadCollection$ChangeEventParameters {
    /**
     * A unique Id of the attached document. This parameter is deprecated since 1.28.0. Use the `files` parameter
     * instead.
     */
    documentId?: string;

    /**
     * A FileList of individually selected files from the underlying system. See www.w3.org for the FileList
     * Interface definition. Restriction: Internet Explorer 9 supports only single file with property file.name.
     * Since version 1.28.0.
     */
    files?: object[];
  }

  /**
   * Event object of the UploadCollection#change event.
   */
  export type UploadCollection$ChangeEvent = Event<
    UploadCollection$ChangeEventParameters,
    UploadCollection
  >;

  /**
   * Parameters of the UploadCollection#fileDeleted event.
   */
  export interface UploadCollection$FileDeletedEventParameters {
    /**
     * A unique Id of the attached document. This parameter is deprecated since 1.28.0. Use the `item` parameter
     * instead.
     */
    documentId?: string;

    /**
     * An item to be deleted from the collection. Since version 1.28.0.
     */
    item?: UploadCollectionItem;
  }

  /**
   * Event object of the UploadCollection#fileDeleted event.
   */
  export type UploadCollection$FileDeletedEvent = Event<
    UploadCollection$FileDeletedEventParameters,
    UploadCollection
  >;

  /**
   * Parameters of the UploadCollection#filenameLengthExceed event.
   */
  export interface UploadCollection$FilenameLengthExceedEventParameters {
    /**
     * A unique Id of the attached document. This parameter is deprecated since 1.28.0. Use the `files` parameter
     * instead.
     */
    documentId?: string;

    /**
     * A FileList of individually selected files from the underlying system. Restriction: Internet Explorer
     * 9 supports only single file with property file.name. Since version 1.28.0.
     */
    files?: object[];
  }

  /**
   * Event object of the UploadCollection#filenameLengthExceed event.
   */
  export type UploadCollection$FilenameLengthExceedEvent = Event<
    UploadCollection$FilenameLengthExceedEventParameters,
    UploadCollection
  >;

  /**
   * Parameters of the UploadCollection#fileRenamed event.
   */
  export interface UploadCollection$FileRenamedEventParameters {
    /**
     * A unique Id of the attached document. This parameter is deprecated since 1.28.0. Use the `item` parameter
     * instead.
     */
    documentId?: string;

    /**
     * The new file name. This parameter is deprecated since 1.28.0. Use the `item` parameter instead.
     */
    fileName?: string;

    /**
     * The renamed UI element as an UploadCollectionItem. Since 1.28.0.
     */
    item?: UploadCollectionItem;
  }

  /**
   * Event object of the UploadCollection#fileRenamed event.
   */
  export type UploadCollection$FileRenamedEvent = Event<
    UploadCollection$FileRenamedEventParameters,
    UploadCollection
  >;

  /**
   * Parameters of the UploadCollection#fileSizeExceed event.
   */
  export interface UploadCollection$FileSizeExceedEventParameters {
    /**
     * A unique Id of the attached document. This parameter is deprecated since 1.28.0. Use the `files` parameter
     * instead.
     */
    documentId?: string;

    /**
     * The size in MB of a file to be uploaded. This parameter is deprecated since 1.28.0. Use the `files` parameter
     * instead.
     */
    fileSize?: string;

    /**
     * A FileList of individually selected files from the underlying system. Restriction: Internet Explorer
     * 9 supports only single file with property file.name. Since 1.28.0.
     */
    files?: object[];
  }

  /**
   * Event object of the UploadCollection#fileSizeExceed event.
   */
  export type UploadCollection$FileSizeExceedEvent = Event<
    UploadCollection$FileSizeExceedEventParameters,
    UploadCollection
  >;

  /**
   * Parameters of the UploadCollection#selectionChange event.
   */
  export interface UploadCollection$SelectionChangeEventParameters {
    /**
     * The item whose selection has changed. In `MultiSelect` mode, only the topmost selected item is returned.
     * This parameter can be used for single-selection modes.
     */
    selectedItem?: UploadCollectionItem;

    /**
     * Array of items whose selection has changed. This parameter can be used for `MultiSelect` mode.
     */
    selectedItems?: UploadCollectionItem[];

    /**
     * Indicates whether the `listItem` parameter is selected or not.
     */
    selected?: boolean;
  }

  /**
   * Event object of the UploadCollection#selectionChange event.
   */
  export type UploadCollection$SelectionChangeEvent = Event<
    UploadCollection$SelectionChangeEventParameters,
    UploadCollection
  >;

  /**
   * Parameters of the UploadCollection#typeMissmatch event.
   */
  export interface UploadCollection$TypeMissmatchEventParameters {
    /**
     * A unique Id of the attached document. This parameter is deprecated since 1.28.0. Use the `files` parameter
     * instead.
     */
    documentId?: string;

    /**
     * File type. This parameter is deprecated since 1.28.0. Use the `files` parameter instead.
     */
    fileType?: string;

    /**
     * MIME type. This parameter is deprecated since 1.28.0. Use the `files` parameter instead.
     */
    mimeType?: string;

    /**
     * A FileList of individually selected files from the underlying system. Restriction: Internet Explorer
     * 9 supports only single file. Since 1.28.0.
     */
    files?: object[];
  }

  /**
   * Event object of the UploadCollection#typeMissmatch event.
   */
  export type UploadCollection$TypeMissmatchEvent = Event<
    UploadCollection$TypeMissmatchEventParameters,
    UploadCollection
  >;

  /**
   * Parameters of the UploadCollection#uploadComplete event.
   */
  export interface UploadCollection$UploadCompleteEventParameters {
    /**
     * Ready state XHR. This parameter is deprecated since 1.28.0. Use the `files` parameter instead.
     */
    readyStateXHR?: string;

    /**
     * Response of the completed upload request. This parameter is deprecated since 1.28.0. Use the `files`
     * parameter instead.
     */
    response?: string;

    /**
     * Status Code of the completed upload event. This parameter is deprecated since 1.28.0. Use the `files`
     * parameter instead.
     */
    status?: string;

    /**
     * A list of uploaded files. Each entry contains the following members. fileName : The name of a file to
     * be uploaded. response : Response message which comes from the server. On the server side, this response
     * has to be put within the 'body' tags of the response document of the iFrame. It can consist of a return
     * code and an optional message. This does not work in cross-domain scenarios. reponse : deprecated Since
     * version 1.48.0. This parameter is deprecated, use parameter response instead. responseRaw : HTTP-Response
     * which comes from the server. This property is not supported by Internet Explorer Versions lower than
     * 9. status : Status of the XHR request. This property is not supported by Internet Explorer 9 and lower.
     * headers : HTTP-Response-Headers which come from the server. Provided as a JSON-map, i.e. each header-field
     * is reflected by a property in the header-object, with the property value reflecting the header-field's
     * content. This property is not supported by Internet Explorer 9 and lower. Since 1.28.0.
     */
    files?: object[];
  }

  /**
   * Event object of the UploadCollection#uploadComplete event.
   */
  export type UploadCollection$UploadCompleteEvent = Event<
    UploadCollection$UploadCompleteEventParameters,
    UploadCollection
  >;

  /**
   * Parameters of the UploadCollection#uploadTerminated event.
   */
  export interface UploadCollection$UploadTerminatedEventParameters {
    /**
     * Specifies the name of the file of which the upload is to be terminated.
     */
    fileName?: string;

    /**
     * A function that returns the corresponding header parameter (type `sap.m.UploadCollectionParameter`) if
     * available. The function accepts one optional parameter of type `string`, which is the name of the header
     * parameter. If no parameter is provided all header parameters are returned.
     */
    getHeaderParameter?: Function;
  }

  /**
   * Event object of the UploadCollection#uploadTerminated event.
   */
  export type UploadCollection$UploadTerminatedEvent = Event<
    UploadCollection$UploadTerminatedEventParameters,
    UploadCollection
  >;
}

declare module "sap/m/UploadCollectionItem" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import ObjectAttribute from "sap/m/ObjectAttribute";

  import ObjectMarker from "sap/m/ObjectMarker";

  import ObjectStatus from "sap/m/ObjectStatus";

  import Event from "sap/ui/base/Event";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import { ID } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import FileUploader from "sap/ui/unified/FileUploader";

  /**
   * Defines a structure of the element of the 'items' aggregation.
   *
   * @since 1.26.0
   * @deprecated As of version 1.88. replaced by {@link sap.m.upload.UploadSetItem}.
   */
  export default class UploadCollectionItem extends UI5Element {
    /**
     * Constructor for a new UploadCollectionItem
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $UploadCollectionItemSettings
    );
    /**
     * Constructor for a new UploadCollectionItem
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, will be generated automatically if no ID is provided.
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $UploadCollectionItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.UploadCollectionItem with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, UploadCollectionItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.UploadCollectionItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some attribute to the aggregation {@link #getAttributes attributes}.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addAttribute(
      /**
       * The attribute to add; if empty, nothing is inserted
       */
      oAttribute: ObjectAttribute
    ): this;
    /**
     * Adds some marker to the aggregation {@link #getMarkers markers}.
     *
     * @since 1.40.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addMarker(
      /**
       * The marker to add; if empty, nothing is inserted
       */
      oMarker: ObjectMarker
    ): this;
    /**
     * Adds some status to the aggregation {@link #getStatuses statuses}.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addStatus(
      /**
       * The status to add; if empty, nothing is inserted
       */
      oStatus: ObjectStatus
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:deletePress deletePress} event of this `sap.m.UploadCollectionItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollectionItem` itself.
     *
     * When a deletePress event handler is attached to the item and the user presses the delete button, this
     * event is triggered. If this event is triggered, it overwrites the default delete behavior of UploadCollection
     * and the fileDeleted event of UploadCollection is not triggered.
     *
     * @since 1.50.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDeletePress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollectionItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:deletePress deletePress} event of this `sap.m.UploadCollectionItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollectionItem` itself.
     *
     * When a deletePress event handler is attached to the item and the user presses the delete button, this
     * event is triggered. If this event is triggered, it overwrites the default delete behavior of UploadCollection
     * and the fileDeleted event of UploadCollection is not triggered.
     *
     * @since 1.50.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachDeletePress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollectionItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.UploadCollectionItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollectionItem` itself.
     *
     * This event is triggered when the user presses the filename link. If this event is provided, it overwrites
     * the default behavior of opening the file.
     *
     * @since 1.50.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollectionItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:press press} event of this `sap.m.UploadCollectionItem`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.UploadCollectionItem` itself.
     *
     * This event is triggered when the user presses the filename link. If this event is provided, it overwrites
     * the default behavior of opening the file.
     *
     * @since 1.50.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachPress(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.UploadCollectionItem` itself
       */
      oListener?: object
    ): this;
    /**
     * Binds aggregation {@link #getAttributes attributes} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindAttributes(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Binds aggregation {@link #getMarkers markers} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     * @since 1.40.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindMarkers(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Binds aggregation {@link #getStatuses statuses} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindStatuses(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the attributes in the aggregation {@link #getAttributes attributes}.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyAttributes(): this;
    /**
     * Destroys all the markers in the aggregation {@link #getMarkers markers}.
     *
     * @since 1.40.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyMarkers(): this;
    /**
     * Destroys all the statuses in the aggregation {@link #getStatuses statuses}.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyStatuses(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:deletePress deletePress} event of this `sap.m.UploadCollectionItem`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.50.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachDeletePress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:press press} event of this `sap.m.UploadCollectionItem`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.50.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachPress(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Downloads the item. The sap.ui.core.util.File method is used here. For further details on this method,
     * see {sap.ui.core.util.File.save}.
     *
     * @since 1.36.0
     *
     * @returns `true` if download is possible, otherwise `false`
     */
    download(
      /**
       * Decides whether to ask for a location to download or not.
       */
      askForLocation: boolean
    ): boolean;
    /**
     * Fires event {@link #event:deletePress deletePress} to attached listeners.
     *
     * @since 1.50.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireDeletePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:press press} to attached listeners.
     *
     * @since 1.50.0
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    firePress(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets current value of property {@link #getAriaLabelForPicture ariaLabelForPicture}.
     *
     * Aria label for the icon (or for the image).
     *
     * @since 1.30.0
     *
     * @returns Value of property `ariaLabelForPicture`
     */
    getAriaLabelForPicture(): string;
    /**
     * Gets content of aggregation {@link #getAttributes attributes}.
     *
     * Attributes of an uploaded item, for example, 'Uploaded By', 'Uploaded On', 'File Size' attributes are
     * displayed after an item has been uploaded. Additionally, the Active property of sap.m.ObjectAttribute
     * is supported.
     *  Note that if one of the deprecated properties contributor, fileSize or UploadedDate is filled in addition
     * to this attribute, two attributes with the same title are displayed as these properties get displayed
     * as an attribute. Example: An application passes the property ‘contributor’ with the value ‘A’ and the
     * aggregation attributes ‘contributor’: ‘B’. As a result, the attributes ‘contributor’:’A’ and ‘contributor’:’B’
     * are displayed. To make sure the title does not appear twice, check if one of the properties is filled.
     *
     * @since 1.30.0
     */
    getAttributes(): ObjectAttribute[];
    /**
     * Gets current value of property {@link #getContributor contributor}.
     *
     * Specifies the name of the user who uploaded the file.
     *
     * @deprecated As of version 1.30. This property is deprecated; use the aggregation attributes instead.
     * However, if the property is filled, it is displayed as an attribute. To make sure the title does not
     * appear twice, do not use the property.
     *
     * @returns Value of property `contributor`
     */
    getContributor(): string;
    /**
     * Gets current value of property {@link #getDocumentId documentId}.
     *
     * Specifies a unique identifier of the file (created by the application).
     *
     *
     * @returns Value of property `documentId`
     */
    getDocumentId(): string;
    /**
     * Gets current value of property {@link #getEnableDelete enableDelete}.
     *
     * Enables/Disables the Delete button. If the value is true, the Delete button is enabled and the delete
     * function can be used. If the value is false, the delete function is not available.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enableDelete`
     */
    getEnableDelete(): boolean;
    /**
     * Gets current value of property {@link #getEnableEdit enableEdit}.
     *
     * Enables/Disables the Edit button. If the value is true, the Edit button is enabled and the edit function
     * can be used. If the value is false, the edit function is not available.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `enableEdit`
     */
    getEnableEdit(): boolean;
    /**
     * Gets current value of property {@link #getFileName fileName}.
     *
     * Specifies the name of the uploaded file.
     *
     *
     * @returns Value of property `fileName`
     */
    getFileName(): string;
    /**
     * Gets current value of property {@link #getFileSize fileSize}.
     *
     * Specifies the size of the uploaded file (in megabytes).
     *
     * @deprecated As of version 1.30. This property is deprecated; use the aggregation attributes instead.
     *
     * @returns Value of property `fileSize`
     */
    getFileSize(): float;
    /**
     * ID of the element which is the current target of the association {@link #getFileUploader fileUploader},
     * or `null`.
     *
     * @since 1.30.0
     */
    getFileUploader(): ID | null;
    /**
     * Gets content of aggregation {@link #getMarkers markers}.
     *
     * Markers of an uploaded item Markers will be displayed after an item has been uploaded But not in Edit
     * mode
     *
     * @since 1.40.0
     */
    getMarkers(): ObjectMarker[];
    /**
     * Gets current value of property {@link #getMimeType mimeType}.
     *
     * Specifies the MIME type of the file.
     *
     *
     * @returns Value of property `mimeType`
     */
    getMimeType(): string;
    /**
     * Gets current value of property {@link #getSelected selected}.
     *
     * Defines the selected state of the UploadCollectionItem.
     *
     * Default value is `false`.
     *
     * @since 1.34.0
     *
     * @returns Value of property `selected`
     */
    getSelected(): boolean;
    /**
     * Gets content of aggregation {@link #getStatuses statuses}.
     *
     * Statuses of an uploaded item Statuses will be displayed after an item has been uploaded
     *
     * @since 1.30.0
     */
    getStatuses(): ObjectStatus[];
    /**
     * Gets current value of property {@link #getThumbnailUrl thumbnailUrl}.
     *
     * Specifies the URL where the thumbnail of the file is located. This can also be an SAPUI5 icon URL.
     *
     *
     * @returns Value of property `thumbnailUrl`
     */
    getThumbnailUrl(): string;
    /**
     * Gets current value of property {@link #getUploadedDate uploadedDate}.
     *
     * Specifies the date on which the file was uploaded. The application has to define the date format.
     *
     * @deprecated As of version 1.30. This property is deprecated; use the aggregation attributes instead.
     *
     * @returns Value of property `uploadedDate`
     */
    getUploadedDate(): string;
    /**
     * Gets current value of property {@link #getUrl url}.
     *
     * Specifies the URL where the file is located. If the application doesn't provide a value for this property,
     * the icon and the file name of the UploadCollectionItem are not clickable.
     *
     *
     * @returns Value of property `url`
     */
    getUrl(): string;
    /**
     * Gets current value of property {@link #getVisibleDelete visibleDelete}.
     *
     * Show/Hide the Delete button. If the value is true, the Delete button is visible. If the value is false,
     * the Delete button is not visible.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visibleDelete`
     */
    getVisibleDelete(): boolean;
    /**
     * Gets current value of property {@link #getVisibleEdit visibleEdit}.
     *
     * Show/Hide the Edit button. If the value is true, the Edit button is visible. If the value is false, the
     * Edit button is not visible.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visibleEdit`
     */
    getVisibleEdit(): boolean;
    /**
     * Checks for the provided `sap.m.ObjectAttribute` in the aggregation {@link #getAttributes attributes}.
     * and returns its index if found or -1 otherwise.
     *
     * @since 1.30.0
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfAttribute(
      /**
       * The attribute whose index is looked for
       */
      oAttribute: ObjectAttribute
    ): int;
    /**
     * Checks for the provided `sap.m.ObjectMarker` in the aggregation {@link #getMarkers markers}. and returns
     * its index if found or -1 otherwise.
     *
     * @since 1.40.0
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfMarker(
      /**
       * The marker whose index is looked for
       */
      oMarker: ObjectMarker
    ): int;
    /**
     * Checks for the provided `sap.m.ObjectStatus` in the aggregation {@link #getStatuses statuses}. and returns
     * its index if found or -1 otherwise.
     *
     * @since 1.30.0
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfStatus(
      /**
       * The status whose index is looked for
       */
      oStatus: ObjectStatus
    ): int;
    /**
     * Inserts a attribute into the aggregation {@link #getAttributes attributes}.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertAttribute(
      /**
       * The attribute to insert; if empty, nothing is inserted
       */
      oAttribute: ObjectAttribute,
      /**
       * The `0`-based index the attribute should be inserted at; for a negative value of `iIndex`, the attribute
       * is inserted at position 0; for a value greater than the current size of the aggregation, the attribute
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a marker into the aggregation {@link #getMarkers markers}.
     *
     * @since 1.40.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertMarker(
      /**
       * The marker to insert; if empty, nothing is inserted
       */
      oMarker: ObjectMarker,
      /**
       * The `0`-based index the marker should be inserted at; for a negative value of `iIndex`, the marker is
       * inserted at position 0; for a value greater than the current size of the aggregation, the marker is inserted
       * at the last position
       */
      iIndex: int
    ): this;
    /**
     * Inserts a status into the aggregation {@link #getStatuses statuses}.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertStatus(
      /**
       * The status to insert; if empty, nothing is inserted
       */
      oStatus: ObjectStatus,
      /**
       * The `0`-based index the status should be inserted at; for a negative value of `iIndex`, the status is
       * inserted at position 0; for a value greater than the current size of the aggregation, the status is inserted
       * at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getAttributes attributes}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.30.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllAttributes(): ObjectAttribute[];
    /**
     * Removes all the controls from the aggregation {@link #getMarkers markers}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.40.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllMarkers(): ObjectMarker[];
    /**
     * Removes all the controls from the aggregation {@link #getStatuses statuses}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     * @since 1.30.0
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllStatuses(): ObjectStatus[];
    /**
     * Removes a attribute from the aggregation {@link #getAttributes attributes}.
     *
     * @since 1.30.0
     *
     * @returns The removed attribute or `null`
     */
    removeAttribute(
      /**
       * The attribute to remove or its index or id
       */
      vAttribute: int | string | ObjectAttribute
    ): ObjectAttribute | null;
    /**
     * Removes a marker from the aggregation {@link #getMarkers markers}.
     *
     * @since 1.40.0
     *
     * @returns The removed marker or `null`
     */
    removeMarker(
      /**
       * The marker to remove or its index or id
       */
      vMarker: int | string | ObjectMarker
    ): ObjectMarker | null;
    /**
     * Removes a status from the aggregation {@link #getStatuses statuses}.
     *
     * @since 1.30.0
     *
     * @returns The removed status or `null`
     */
    removeStatus(
      /**
       * The status to remove or its index or id
       */
      vStatus: int | string | ObjectStatus
    ): ObjectStatus | null;
    /**
     * Sets a new value for property {@link #getAriaLabelForPicture ariaLabelForPicture}.
     *
     * Aria label for the icon (or for the image).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAriaLabelForPicture(
      /**
       * New value for property `ariaLabelForPicture`
       */
      sAriaLabelForPicture?: string
    ): this;
    /**
     * Sets a new value for property {@link #getContributor contributor}.
     *
     * Specifies the name of the user who uploaded the file.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @deprecated As of version 1.30. This property is deprecated; use the aggregation attributes instead.
     * However, if the property is filled, it is displayed as an attribute. To make sure the title does not
     * appear twice, do not use the property.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContributor(
      /**
       * New value for property `contributor`
       */
      sContributor?: string
    ): this;
    /**
     * Sets a new value for property {@link #getDocumentId documentId}.
     *
     * Specifies a unique identifier of the file (created by the application).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDocumentId(
      /**
       * New value for property `documentId`
       */
      sDocumentId?: string
    ): this;
    /**
     * Sets a new value for property {@link #getEnableDelete enableDelete}.
     *
     * Enables/Disables the Delete button. If the value is true, the Delete button is enabled and the delete
     * function can be used. If the value is false, the delete function is not available.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableDelete(
      /**
       * New value for property `enableDelete`
       */
      bEnableDelete?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getEnableEdit enableEdit}.
     *
     * Enables/Disables the Edit button. If the value is true, the Edit button is enabled and the edit function
     * can be used. If the value is false, the edit function is not available.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableEdit(
      /**
       * New value for property `enableEdit`
       */
      bEnableEdit?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getFileName fileName}.
     *
     * Specifies the name of the uploaded file.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFileName(
      /**
       * New value for property `fileName`
       */
      sFileName?: string
    ): this;
    /**
     * Sets a new value for property {@link #getFileSize fileSize}.
     *
     * Specifies the size of the uploaded file (in megabytes).
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @deprecated As of version 1.30. This property is deprecated; use the aggregation attributes instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFileSize(
      /**
       * New value for property `fileSize`
       */
      fFileSize?: float
    ): this;
    /**
     * Sets the associated {@link #getFileUploader fileUploader}.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFileUploader(
      /**
       * ID of an element which becomes the new target of this fileUploader association; alternatively, an element
       * instance may be given
       */
      oFileUploader: ID | FileUploader
    ): this;
    /**
     * Sets a new value for property {@link #getMimeType mimeType}.
     *
     * Specifies the MIME type of the file.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMimeType(
      /**
       * New value for property `mimeType`
       */
      sMimeType?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSelected selected}.
     *
     * Defines the selected state of the UploadCollectionItem.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.34.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSelected(
      /**
       * New value for property `selected`
       */
      bSelected?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getThumbnailUrl thumbnailUrl}.
     *
     * Specifies the URL where the thumbnail of the file is located. This can also be an SAPUI5 icon URL.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setThumbnailUrl(
      /**
       * New value for property `thumbnailUrl`
       */
      sThumbnailUrl?: string
    ): this;
    /**
     * Sets a new value for property {@link #getUploadedDate uploadedDate}.
     *
     * Specifies the date on which the file was uploaded. The application has to define the date format.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @deprecated As of version 1.30. This property is deprecated; use the aggregation attributes instead.
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUploadedDate(
      /**
       * New value for property `uploadedDate`
       */
      sUploadedDate?: string
    ): this;
    /**
     * Sets a new value for property {@link #getUrl url}.
     *
     * Specifies the URL where the file is located. If the application doesn't provide a value for this property,
     * the icon and the file name of the UploadCollectionItem are not clickable.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setUrl(
      /**
       * New value for property `url`
       */
      sUrl?: string
    ): this;
    /**
     * Sets a new value for property {@link #getVisibleDelete visibleDelete}.
     *
     * Show/Hide the Delete button. If the value is true, the Delete button is visible. If the value is false,
     * the Delete button is not visible.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisibleDelete(
      /**
       * New value for property `visibleDelete`
       */
      bVisibleDelete?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getVisibleEdit visibleEdit}.
     *
     * Show/Hide the Edit button. If the value is true, the Edit button is visible. If the value is false, the
     * Edit button is not visible.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisibleEdit(
      /**
       * New value for property `visibleEdit`
       */
      bVisibleEdit?: boolean
    ): this;
    /**
     * Unbinds aggregation {@link #getAttributes attributes} from model data.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindAttributes(): this;
    /**
     * Unbinds aggregation {@link #getMarkers markers} from model data.
     *
     * @since 1.40.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindMarkers(): this;
    /**
     * Unbinds aggregation {@link #getStatuses statuses} from model data.
     *
     * @since 1.30.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindStatuses(): this;
  }
  /**
   * Describes the settings that can be provided to the UploadCollectionItem constructor.
   *
   * @deprecated As of version 1.88. replaced by {@link sap.m.upload.UploadSetItem}.
   */
  export interface $UploadCollectionItemSettings extends $ElementSettings {
    /**
     * Specifies the name of the user who uploaded the file.
     *
     * @deprecated As of version 1.30. This property is deprecated; use the aggregation attributes instead.
     * However, if the property is filled, it is displayed as an attribute. To make sure the title does not
     * appear twice, do not use the property.
     */
    contributor?: string | PropertyBindingInfo;

    /**
     * Specifies a unique identifier of the file (created by the application).
     */
    documentId?: string | PropertyBindingInfo;

    /**
     * Specifies the name of the uploaded file.
     */
    fileName?: string | PropertyBindingInfo;

    /**
     * Specifies the size of the uploaded file (in megabytes).
     *
     * @deprecated As of version 1.30. This property is deprecated; use the aggregation attributes instead.
     */
    fileSize?: float | PropertyBindingInfo | `{${string}}`;

    /**
     * Specifies the MIME type of the file.
     */
    mimeType?: string | PropertyBindingInfo;

    /**
     * Specifies the URL where the thumbnail of the file is located. This can also be an SAPUI5 icon URL.
     */
    thumbnailUrl?: string | PropertyBindingInfo;

    /**
     * Specifies the date on which the file was uploaded. The application has to define the date format.
     *
     * @deprecated As of version 1.30. This property is deprecated; use the aggregation attributes instead.
     */
    uploadedDate?: string | PropertyBindingInfo;

    /**
     * Specifies the URL where the file is located. If the application doesn't provide a value for this property,
     * the icon and the file name of the UploadCollectionItem are not clickable.
     */
    url?: string | PropertyBindingInfo;

    /**
     * Enables/Disables the Edit button. If the value is true, the Edit button is enabled and the edit function
     * can be used. If the value is false, the edit function is not available.
     */
    enableEdit?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Enables/Disables the Delete button. If the value is true, the Delete button is enabled and the delete
     * function can be used. If the value is false, the delete function is not available.
     */
    enableDelete?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Show/Hide the Edit button. If the value is true, the Edit button is visible. If the value is false, the
     * Edit button is not visible.
     */
    visibleEdit?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Show/Hide the Delete button. If the value is true, the Delete button is visible. If the value is false,
     * the Delete button is not visible.
     */
    visibleDelete?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Aria label for the icon (or for the image).
     *
     * @since 1.30.0
     */
    ariaLabelForPicture?: string | PropertyBindingInfo;

    /**
     * Defines the selected state of the UploadCollectionItem.
     *
     * @since 1.34.0
     */
    selected?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Attributes of an uploaded item, for example, 'Uploaded By', 'Uploaded On', 'File Size' attributes are
     * displayed after an item has been uploaded. Additionally, the Active property of sap.m.ObjectAttribute
     * is supported.
     *  Note that if one of the deprecated properties contributor, fileSize or UploadedDate is filled in addition
     * to this attribute, two attributes with the same title are displayed as these properties get displayed
     * as an attribute. Example: An application passes the property ‘contributor’ with the value ‘A’ and the
     * aggregation attributes ‘contributor’: ‘B’. As a result, the attributes ‘contributor’:’A’ and ‘contributor’:’B’
     * are displayed. To make sure the title does not appear twice, check if one of the properties is filled.
     *
     * @since 1.30.0
     */
    attributes?:
      | ObjectAttribute[]
      | ObjectAttribute
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Statuses of an uploaded item Statuses will be displayed after an item has been uploaded
     *
     * @since 1.30.0
     */
    statuses?:
      | ObjectStatus[]
      | ObjectStatus
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * Markers of an uploaded item Markers will be displayed after an item has been uploaded But not in Edit
     * mode
     *
     * @since 1.40.0
     */
    markers?:
      | ObjectMarker[]
      | ObjectMarker
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * ID of the FileUploader instance
     *
     * @since 1.30.0
     */
    fileUploader?: FileUploader | string;

    /**
     * This event is triggered when the user presses the filename link. If this event is provided, it overwrites
     * the default behavior of opening the file.
     *
     * @since 1.50.0
     */
    press?: (oEvent: Event) => void;

    /**
     * When a deletePress event handler is attached to the item and the user presses the delete button, this
     * event is triggered. If this event is triggered, it overwrites the default delete behavior of UploadCollection
     * and the fileDeleted event of UploadCollection is not triggered.
     *
     * @since 1.50.0
     */
    deletePress?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the UploadCollectionItem#deletePress event.
   */
  export interface UploadCollectionItem$DeletePressEventParameters {}

  /**
   * Event object of the UploadCollectionItem#deletePress event.
   */
  export type UploadCollectionItem$DeletePressEvent = Event<
    UploadCollectionItem$DeletePressEventParameters,
    UploadCollectionItem
  >;

  /**
   * Parameters of the UploadCollectionItem#press event.
   */
  export interface UploadCollectionItem$PressEventParameters {}

  /**
   * Event object of the UploadCollectionItem#press event.
   */
  export type UploadCollectionItem$PressEvent = Event<
    UploadCollectionItem$PressEventParameters,
    UploadCollectionItem
  >;
}

declare module "sap/m/UploadCollectionParameter" {
  import { default as UI5Element, $ElementSettings } from "sap/ui/core/Element";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * Defines a structure of the element of the 'parameters' aggregation.
   *
   * @deprecated As of version 1.88. the concept has been discarded.
   */
  export default class UploadCollectionParameter extends UI5Element {
    /**
     * Constructor for a new UploadCollectionParameter.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $UploadCollectionParameterSettings
    );
    /**
     * Constructor for a new UploadCollectionParameter.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $UploadCollectionParameterSettings
    );

    /**
     * Creates a new subclass of class sap.m.UploadCollectionParameter with name `sClassName` and enriches it
     * with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Element.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, UploadCollectionParameter>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.UploadCollectionParameter.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getName name}.
     *
     * Specifies the name of the parameter.
     *
     * @since 1.12.2
     *
     * @returns Value of property `name`
     */
    getName(): string;
    /**
     * Gets current value of property {@link #getValue value}.
     *
     * Specifies the value of the parameter.
     *
     * @since 1.12.2
     *
     * @returns Value of property `value`
     */
    getValue(): string;
    /**
     * Sets a new value for property {@link #getName name}.
     *
     * Specifies the name of the parameter.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.12.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setName(
      /**
       * New value for property `name`
       */
      sName?: string
    ): this;
    /**
     * Sets a new value for property {@link #getValue value}.
     *
     * Specifies the value of the parameter.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * @since 1.12.2
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValue(
      /**
       * New value for property `value`
       */
      sValue?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the UploadCollectionParameter constructor.
   *
   * @deprecated As of version 1.88. the concept has been discarded.
   */
  export interface $UploadCollectionParameterSettings extends $ElementSettings {
    /**
     * Specifies the name of the parameter.
     *
     * @since 1.12.2
     */
    name?: string | PropertyBindingInfo;

    /**
     * Specifies the value of the parameter.
     *
     * @since 1.12.2
     */
    value?: string | PropertyBindingInfo;
  }
}

declare module "sap/m/UploadCollectionToolbarPlaceholder" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  /**
   * Used to create a customizable toolbar for the UploadCollection. A FileUploader instance is required in
   * the toolbar and will be placed by the application.
   *
   * @since 1.34.0
   * @deprecated As of version 1.88. replaced by {@link sap.m.upload.UploadSetToolbarPlaceholder}.
   */
  export default class UploadCollectionToolbarPlaceholder extends Control {
    /**
     * Constructor for a new UploadCollectionToolbarPlaceholder.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.ui.core.Control#constructor sap.ui.core.Control }
     * can be used.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $UploadCollectionToolbarPlaceholderSettings
    );
    /**
     * Constructor for a new UploadCollectionToolbarPlaceholder.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     *
     * This class does not have its own settings, but all settings applicable to the base type {@link sap.ui.core.Control#constructor sap.ui.core.Control }
     * can be used.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $UploadCollectionToolbarPlaceholderSettings
    );

    /**
     * Creates a new subclass of class sap.m.UploadCollectionToolbarPlaceholder with name `sClassName` and enriches
     * it with the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, UploadCollectionToolbarPlaceholder>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.UploadCollectionToolbarPlaceholder.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
  }
  /**
   * Describes the settings that can be provided to the UploadCollectionToolbarPlaceholder constructor.
   *
   * @deprecated As of version 1.88. replaced by {@link sap.m.upload.UploadSetToolbarPlaceholder}.
   */
  export interface $UploadCollectionToolbarPlaceholderSettings
    extends $ControlSettings {}
}

declare module "sap/m/VariantItem" {
  import { default as Item, $ItemSettings } from "sap/ui/core/Item";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { SharingMode } from "sap/m/library";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The VariantItem class describes a variant item.
   */
  export default class VariantItem extends Item {
    /**
     * Constructor for a new sap.m.VariantItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $VariantItemSettings
    );
    /**
     * Constructor for a new sap.m.VariantItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $VariantItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.VariantItem with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Item.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, VariantItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.VariantItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getAuthor author}.
     *
     * Contains the author information of the item.
     *
     *
     * @returns Value of property `author`
     */
    getAuthor(): string;
    /**
     * Gets current value of property {@link #getChangeable changeable}.
     *
     * Indicates if the item is changeable.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `changeable`
     */
    getChangeable(): boolean;
    /**
     * Gets current value of property {@link #getContexts contexts}.
     *
     * Contains the contexts information of the item.
     *  **Note**: This property must not be bound.
     *  **Note**: This property is used exclusively for SAPUI5 flexibility. Do not use it otherwise.
     *
     * Default value is `{}`.
     *
     *
     * @returns Value of property `contexts`
     */
    getContexts(): object;
    /**
     * Gets current value of property {@link #getExecuteOnSelect executeOnSelect}.
     *
     * Indicates if the item is marked as apply automatically.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `executeOnSelect`
     */
    getExecuteOnSelect(): boolean;
    /**
     * Gets current value of property {@link #getFavorite favorite}.
     *
     * Indicates if the item is marked as favorite.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `favorite`
     */
    getFavorite(): boolean;
    /**
     * Gets current value of property {@link #getRemove remove}.
     *
     * Indicates if the item is removable.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `remove`
     */
    getRemove(): boolean;
    /**
     * Gets current value of property {@link #getRename rename}.
     *
     * Indicates if the item is renamable.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `rename`
     */
    getRename(): boolean;
    /**
     * Gets current value of property {@link #getSharing sharing}.
     *
     * Contains the information is the item is public or private.
     *
     * Default value is `Private`.
     *
     *
     * @returns Value of property `sharing`
     */
    getSharing(): SharingMode;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Contains the title if the item.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getVisible visible}.
     *
     * Indicates if the item is visible.
     *
     *
     * **Note:** This property should not be used by applications, if the variant management control is either
     * {@link sap.ui.comp.smartvariants.SmartVariantManagement `SmartVariantManagement`} or {@link sap.ui.fl.variants.VariantManagement `VariantManagement`}.
     *
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `visible`
     */
    getVisible(): boolean;
    /**
     * Sets a new value for property {@link #getAuthor author}.
     *
     * Contains the author information of the item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setAuthor(
      /**
       * New value for property `author`
       */
      sAuthor?: string
    ): this;
    /**
     * Sets a new value for property {@link #getChangeable changeable}.
     *
     * Indicates if the item is changeable.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setChangeable(
      /**
       * New value for property `changeable`
       */
      bChangeable?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getContexts contexts}.
     *
     * Contains the contexts information of the item.
     *  **Note**: This property must not be bound.
     *  **Note**: This property is used exclusively for SAPUI5 flexibility. Do not use it otherwise.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `{}`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setContexts(
      /**
       * New value for property `contexts`
       */
      oContexts?: object
    ): this;
    /**
     * Sets a new value for property {@link #getExecuteOnSelect executeOnSelect}.
     *
     * Indicates if the item is marked as apply automatically.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setExecuteOnSelect(
      /**
       * New value for property `executeOnSelect`
       */
      bExecuteOnSelect?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getFavorite favorite}.
     *
     * Indicates if the item is marked as favorite.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFavorite(
      /**
       * New value for property `favorite`
       */
      bFavorite?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getRemove remove}.
     *
     * Indicates if the item is removable.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRemove(
      /**
       * New value for property `remove`
       */
      bRemove?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getRename rename}.
     *
     * Indicates if the item is renamable.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRename(
      /**
       * New value for property `rename`
       */
      bRename?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getSharing sharing}.
     *
     * Contains the information is the item is public or private.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Private`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSharing(
      /**
       * New value for property `sharing`
       */
      sSharing?: SharingMode
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Contains the title if the item.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getVisible visible}.
     *
     * Indicates if the item is visible.
     *
     *
     * **Note:** This property should not be used by applications, if the variant management control is either
     * {@link sap.ui.comp.smartvariants.SmartVariantManagement `SmartVariantManagement`} or {@link sap.ui.fl.variants.VariantManagement `VariantManagement`}.
     *
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setVisible(
      /**
       * New value for property `visible`
       */
      bVisible?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the VariantItem constructor.
   */
  export interface $VariantItemSettings extends $ItemSettings {
    /**
     * Contains the information is the item is public or private.
     */
    sharing?: SharingMode | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates if the item is removable.
     */
    remove?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates if the item is marked as favorite.
     */
    favorite?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates if the item is marked as apply automatically.
     */
    executeOnSelect?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates if the item is renamable.
     */
    rename?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Contains the title if the item.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Indicates if the item is visible.
     *
     *
     * **Note:** This property should not be used by applications, if the variant management control is either
     * {@link sap.ui.comp.smartvariants.SmartVariantManagement `SmartVariantManagement`} or {@link sap.ui.fl.variants.VariantManagement `VariantManagement`}.
     */
    visible?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates if the item is changeable.
     */
    changeable?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Contains the author information of the item.
     */
    author?: string | PropertyBindingInfo;

    /**
     * Contains the contexts information of the item.
     *  **Note**: This property must not be bound.
     *  **Note**: This property is used exclusively for SAPUI5 flexibility. Do not use it otherwise.
     */
    contexts?: object | PropertyBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/VariantManagement" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { IShrinkable, TitleLevel, CSSSize } from "sap/ui/core/library";

  import {
    IOverflowToolbarContent,
    IToolbarInteractiveControl,
    VariantManagementRename,
    VariantManagementExe,
    VariantManagementFav,
  } from "sap/m/library";

  import VariantItem from "sap/m/VariantItem";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Title from "sap/m/Title";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * Can be used to manage variants. You can use this control to create and maintain personalization changes.
   * The persistency and retrieval of such changes has to be handled by the hosting application.
   *  **Note:** On the user interface, variants are generally referred to as "views".
   *
   * @since 1.103
   */
  export default class VariantManagement
    extends Control
    implements IShrinkable, IOverflowToolbarContent, IToolbarInteractiveControl
  {
    __implements__sap_ui_core_IShrinkable: boolean;
    __implements__sap_m_IOverflowToolbarContent: boolean;
    __implements__sap_m_IToolbarInteractiveControl: boolean;
    /**
     * Constructor for a new `VariantManagement`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $VariantManagementSettings
    );
    /**
     * Constructor for a new `VariantManagement`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $VariantManagementSettings
    );

    /**
     * Creates a new subclass of class sap.m.VariantManagement with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, VariantManagement>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.VariantManagement.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: VariantItem
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cancel cancel} event of this `sap.m.VariantManagement`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.VariantManagement` itself.
     *
     * This event is fired when users presses the cancel button inside Save As dialog.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCancel(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.VariantManagement` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:cancel cancel} event of this `sap.m.VariantManagement`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.VariantManagement` itself.
     *
     * This event is fired when users presses the cancel button inside Save As dialog.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCancel(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.VariantManagement` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:manage manage} event of this `sap.m.VariantManagement`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.VariantManagement` itself.
     *
     * This event is fired when users apply changes variant information in the Manage Views dialog. Some
     * of the parameters may be ommitted, depending on user selection.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachManage(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: VariantManagement$ManageEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.VariantManagement` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:manage manage} event of this `sap.m.VariantManagement`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.VariantManagement` itself.
     *
     * This event is fired when users apply changes variant information in the Manage Views dialog. Some
     * of the parameters may be ommitted, depending on user selection.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachManage(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: VariantManagement$ManageEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.VariantManagement` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:manageCancel manageCancel} event of this `sap.m.VariantManagement`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.VariantManagement` itself.
     *
     * This event is fired when users presses the cancel button inside Manage Views dialog.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachManageCancel(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.VariantManagement` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:manageCancel manageCancel} event of this `sap.m.VariantManagement`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.VariantManagement` itself.
     *
     * This event is fired when users presses the cancel button inside Manage Views dialog.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachManageCancel(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.VariantManagement` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:save save} event of this `sap.m.VariantManagement`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.VariantManagement` itself.
     *
     * This event is fired when the Save View dialog or the Save As dialog is closed with the Save button.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSave(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: VariantManagement$SaveEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.VariantManagement` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:save save} event of this `sap.m.VariantManagement`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.VariantManagement` itself.
     *
     * This event is fired when the Save View dialog or the Save As dialog is closed with the Save button.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSave(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: VariantManagement$SaveEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.VariantManagement` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:select select} event of this `sap.m.VariantManagement`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.VariantManagement` itself.
     *
     * This event is fired when a new variant is selected.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelect(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: VariantManagement$SelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.VariantManagement` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:select select} event of this `sap.m.VariantManagement`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.VariantManagement` itself.
     *
     * This event is fired when a new variant is selected.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelect(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: VariantManagement$SelectEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.VariantManagement` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:cancel cancel} event of this `sap.m.VariantManagement`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachCancel(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:manage manage} event of this `sap.m.VariantManagement`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachManage(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: VariantManagement$ManageEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:manageCancel manageCancel} event of this `sap.m.VariantManagement`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachManageCancel(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:save save} event of this `sap.m.VariantManagement`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSave(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: VariantManagement$SaveEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:select select} event of this `sap.m.VariantManagement`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelect(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: VariantManagement$SelectEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:cancel cancel} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireCancel(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:manage manage} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireManage(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: VariantManagement$ManageEventParameters
    ): this;
    /**
     * Fires event {@link #event:manageCancel manageCancel} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireManageCancel(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:save save} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSave(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: VariantManagement$SaveEventParameters
    ): this;
    /**
     * Fires event {@link #event:select select} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelect(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: VariantManagement$SelectEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getCreationAllowed creationAllowed}.
     *
     * If set to `false`, neither the Save As nor the Save button in the My Views dialog is visible.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `creationAllowed`
     */
    getCreationAllowed(): boolean;
    /**
     * Gets current value of property {@link #getDefaultKey defaultKey}.
     *
     * Identifies the defaulted item
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `defaultKey`
     */
    getDefaultKey(): string;
    /**
     * Gets current value of property {@link #getInErrorState inErrorState}.
     *
     * Indicates that the control is in error state. If set to `true`, an error message will be displayed whenever
     * the variant is opened.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `inErrorState`
     */
    getInErrorState(): boolean;
    /**
     * Retrieves a variant item by its key.
     *
     *
     * @returns For a specific key; `null` if no matching item was found
     */
    getItemByKey(
      /**
       * of the item
       */
      sKey: string
    ): VariantItem | null;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * Items displayed by the `VariantManagement` control.
     */
    getItems(): VariantItem[];
    /**
     * Gets current value of property {@link #getLevel level}.
     *
     * Semantic level of the header. For more information, see {@link sap.m.Title#setLevel}.
     *
     * Default value is `Auto`.
     *
     *
     * @returns Value of property `level`
     */
    getLevel(): TitleLevel;
    /**
     * Gets current value of property {@link #getMaxWidth maxWidth}.
     *
     * Sets the maximum width of the control.
     *
     * Default value is `"100%"`.
     *
     * @since 1.109
     *
     * @returns Value of property `maxWidth`
     */
    getMaxWidth(): CSSSize;
    /**
     * Gets current value of property {@link #getModified modified}.
     *
     * Indicates if the current variant is modified.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `modified`
     */
    getModified(): boolean;
    /**
     * Required by the {@link sap.m.IOverflowToolbarContent} interface. Registers invalidations event which
     * is fired when width of the control is changed.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Configuration information for the `sap.m.IOverflowToolbarContent` interface
     */
    getOverflowToolbarConfig(): {
      canOverflow: boolean;

      invalidationEvents: string[];
    };
    /**
     * Gets current value of property {@link #getPopoverTitle popoverTitle}.
     *
     * The title in the My Views popover.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `popoverTitle`
     */
    getPopoverTitle(): string;
    /**
     * Gets current value of property {@link #getSelectedKey selectedKey}.
     *
     * Identifies the currently selected item
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `selectedKey`
     */
    getSelectedKey(): string;
    /**
     * Gets current value of property {@link #getShowFooter showFooter}.
     *
     * Indicates if the buttons and the complete footer in the My Views dialog are visible.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showFooter`
     */
    getShowFooter(): boolean;
    /**
     * Gets current value of property {@link #getShowSaveAs showSaveAs}.
     *
     * Controls the visibility of the Save As button.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showSaveAs`
     */
    getShowSaveAs(): boolean;
    /**
     * Retrieves for the controls {@link sap.ui.comp.SmartVariantManagement} and {@link sap.ui.fl.variants.VariantManagement }
     * the Standard variant. For all other scenarios the first visible variant will be returned, or `null`
     * if there are none.
     *
     *
     * @returns The key of either the standard variant or the first visible variant or `null`.
     */
    getStandardVariantKey(): string | null;
    /**
     * Gets current value of property {@link #getSupportApplyAutomatically supportApplyAutomatically}.
     *
     * Indicates that apply automatically functionality is supported
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `supportApplyAutomatically`
     */
    getSupportApplyAutomatically(): boolean;
    /**
     * Gets current value of property {@link #getSupportContexts supportContexts}.
     *
     * Indicates that contexts functionality is supported.
     *  **Note:** This property is used internally by the SAPUI5 flexibility layer.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `supportContexts`
     */
    getSupportContexts(): boolean;
    /**
     * Gets current value of property {@link #getSupportDefault supportDefault}.
     *
     * Indicates that default of variants is supported
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `supportDefault`
     */
    getSupportDefault(): boolean;
    /**
     * Gets current value of property {@link #getSupportFavorites supportFavorites}.
     *
     * Indicates that favorite handling is supported
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `supportFavorites`
     */
    getSupportFavorites(): boolean;
    /**
     * Gets current value of property {@link #getSupportPublic supportPublic}.
     *
     * Indicates that public functionality is supported
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `supportPublic`
     */
    getSupportPublic(): boolean;
    /**
     * Returns the title control of the `VariantManagement`. This is used in the key user scenario.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Title part of the `VariantManagement` control.
     */
    getTitle(): Title;
    /**
     * Gets current value of property {@link #getTitleStyle titleStyle}.
     *
     * Defines the style of the title. For more information, see {@link sap.m.Title#setTitleStyle}.
     *
     * Default value is `Auto`.
     *
     * @since 1.109
     *
     * @returns Value of property `titleStyle`
     */
    getTitleStyle(): TitleLevel;
    /**
     * Checks for the provided `sap.m.VariantItem` in the aggregation {@link #getItems items}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: VariantItem
    ): int;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: VariantItem,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): VariantItem[];
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | VariantItem
    ): VariantItem | null;
    /**
     * Sets a new value for property {@link #getCreationAllowed creationAllowed}.
     *
     * If set to `false`, neither the Save As nor the Save button in the My Views dialog is visible.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setCreationAllowed(
      /**
       * New value for property `creationAllowed`
       */
      bCreationAllowed?: boolean
    ): this;
    /**
     * Enables the programmatic selection of a variant.
     */
    setCurrentVariantKey(
      /**
       * of variant to be selected. If the passed key doesn't identify a variant, it will be ignored
       */
      sKey: string
    ): void;
    /**
     * Sets a new value for property {@link #getDefaultKey defaultKey}.
     *
     * Identifies the defaulted item
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDefaultKey(
      /**
       * New value for property `defaultKey`
       */
      sDefaultKey?: string
    ): this;
    /**
     * Sets a new value for property {@link #getInErrorState inErrorState}.
     *
     * Indicates that the control is in error state. If set to `true`, an error message will be displayed whenever
     * the variant is opened.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setInErrorState(
      /**
       * New value for property `inErrorState`
       */
      bInErrorState?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getLevel level}.
     *
     * Semantic level of the header. For more information, see {@link sap.m.Title#setLevel}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLevel(
      /**
       * New value for property `level`
       */
      sLevel?: TitleLevel | keyof typeof TitleLevel
    ): this;
    /**
     * Sets a new value for property {@link #getMaxWidth maxWidth}.
     *
     * Sets the maximum width of the control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"100%"`.
     *
     * @since 1.109
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMaxWidth(
      /**
       * New value for property `maxWidth`
       */
      sMaxWidth?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getModified modified}.
     *
     * Indicates if the current variant is modified.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setModified(
      /**
       * New value for property `modified`
       */
      bModified?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getPopoverTitle popoverTitle}.
     *
     * The title in the My Views popover.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setPopoverTitle(
      /**
       * New value for property `popoverTitle`
       */
      sPopoverTitle?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSelectedKey selectedKey}.
     *
     * Identifies the currently selected item
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSelectedKey(
      /**
       * New value for property `selectedKey`
       */
      sSelectedKey?: string
    ): this;
    /**
     * Sets a new value for property {@link #getShowFooter showFooter}.
     *
     * Indicates if the buttons and the complete footer in the My Views dialog are visible.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowFooter(
      /**
       * New value for property `showFooter`
       */
      bShowFooter?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getShowSaveAs showSaveAs}.
     *
     * Controls the visibility of the Save As button.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setShowSaveAs(
      /**
       * New value for property `showSaveAs`
       */
      bShowSaveAs?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getSupportApplyAutomatically supportApplyAutomatically}.
     *
     * Indicates that apply automatically functionality is supported
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSupportApplyAutomatically(
      /**
       * New value for property `supportApplyAutomatically`
       */
      bSupportApplyAutomatically?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getSupportContexts supportContexts}.
     *
     * Indicates that contexts functionality is supported.
     *  **Note:** This property is used internally by the SAPUI5 flexibility layer.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSupportContexts(
      /**
       * New value for property `supportContexts`
       */
      bSupportContexts?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getSupportDefault supportDefault}.
     *
     * Indicates that default of variants is supported
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSupportDefault(
      /**
       * New value for property `supportDefault`
       */
      bSupportDefault?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getSupportFavorites supportFavorites}.
     *
     * Indicates that favorite handling is supported
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSupportFavorites(
      /**
       * New value for property `supportFavorites`
       */
      bSupportFavorites?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getSupportPublic supportPublic}.
     *
     * Indicates that public functionality is supported
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSupportPublic(
      /**
       * New value for property `supportPublic`
       */
      bSupportPublic?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getTitleStyle titleStyle}.
     *
     * Defines the style of the title. For more information, see {@link sap.m.Title#setTitleStyle}.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Auto`.
     *
     * @since 1.109
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitleStyle(
      /**
       * New value for property `titleStyle`
       */
      sTitleStyle?: TitleLevel | keyof typeof TitleLevel
    ): this;
  }
  /**
   * Describes the settings that can be provided to the VariantManagement constructor.
   */
  export interface $VariantManagementSettings extends $ControlSettings {
    /**
     * Indicates that default of variants is supported
     */
    supportDefault?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates that favorite handling is supported
     */
    supportFavorites?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates that apply automatically functionality is supported
     */
    supportApplyAutomatically?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates that public functionality is supported
     */
    supportPublic?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates that contexts functionality is supported.
     *  **Note:** This property is used internally by the SAPUI5 flexibility layer.
     */
    supportContexts?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Identifies the currently selected item
     */
    selectedKey?: string | PropertyBindingInfo;

    /**
     * Identifies the defaulted item
     */
    defaultKey?: string | PropertyBindingInfo;

    /**
     * Controls the visibility of the Save As button.
     */
    showSaveAs?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * If set to `false`, neither the Save As nor the Save button in the My Views dialog is visible.
     */
    creationAllowed?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates if the buttons and the complete footer in the My Views dialog are visible.
     */
    showFooter?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates if the current variant is modified.
     */
    modified?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The title in the My Views popover.
     */
    popoverTitle?: string | PropertyBindingInfo;

    /**
     * Indicates that the control is in error state. If set to `true`, an error message will be displayed whenever
     * the variant is opened.
     */
    inErrorState?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Semantic level of the header. For more information, see {@link sap.m.Title#setLevel}.
     */
    level?:
      | (TitleLevel | keyof typeof TitleLevel)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the style of the title. For more information, see {@link sap.m.Title#setTitleStyle}.
     *
     * @since 1.109
     */
    titleStyle?:
      | (TitleLevel | keyof typeof TitleLevel)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Sets the maximum width of the control.
     *
     * @since 1.109
     */
    maxWidth?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Items displayed by the `VariantManagement` control.
     */
    items?:
      | VariantItem[]
      | VariantItem
      | AggregationBindingInfo
      | `{${string}}`;

    /**
     * This event is fired when the Save View dialog or the Save As dialog is closed with the Save button.
     */
    save?: (oEvent: VariantManagement$SaveEvent) => void;

    /**
     * This event is fired when users presses the cancel button inside Save As dialog.
     */
    cancel?: (oEvent: Event) => void;

    /**
     * This event is fired when users presses the cancel button inside Manage Views dialog.
     */
    manageCancel?: (oEvent: Event) => void;

    /**
     * This event is fired when users apply changes variant information in the Manage Views dialog. Some
     * of the parameters may be ommitted, depending on user selection.
     */
    manage?: (oEvent: VariantManagement$ManageEvent) => void;

    /**
     * This event is fired when a new variant is selected.
     */
    select?: (oEvent: VariantManagement$SelectEvent) => void;
  }

  /**
   * Parameters of the VariantManagement#cancel event.
   */
  export interface VariantManagement$CancelEventParameters {}

  /**
   * Event object of the VariantManagement#cancel event.
   */
  export type VariantManagement$CancelEvent = Event<
    VariantManagement$CancelEventParameters,
    VariantManagement
  >;

  /**
   * Parameters of the VariantManagement#manage event.
   */
  export interface VariantManagement$ManageEventParameters {
    /**
     * List of changed variants.
     */
    renamed?: VariantManagementRename[];

    /**
     * List of deleted variant keys
     */
    deleted?: string[];

    /**
     * List of variant keys and the associated Execute on Selection indicator.
     */
    exe?: VariantManagementExe[];

    /**
     * List of variant keys and the associated favorite indicator.
     */
    fav?: VariantManagementFav[];

    /**
     * The default variant key
     */
    def?: string;

    /**
     * List of variant keys and the associated contexts array. Each entry contains a `key` (the variant key)
     * and a `contexts` array describing the contexts.
     *  **Note:** This property is used internally by the SAPUI5 flexibility layer.
     */
    contexts?: object[];
  }

  /**
   * Event object of the VariantManagement#manage event.
   */
  export type VariantManagement$ManageEvent = Event<
    VariantManagement$ManageEventParameters,
    VariantManagement
  >;

  /**
   * Parameters of the VariantManagement#manageCancel event.
   */
  export interface VariantManagement$ManageCancelEventParameters {}

  /**
   * Event object of the VariantManagement#manageCancel event.
   */
  export type VariantManagement$ManageCancelEvent = Event<
    VariantManagement$ManageCancelEventParameters,
    VariantManagement
  >;

  /**
   * Parameters of the VariantManagement#save event.
   */
  export interface VariantManagement$SaveEventParameters {
    /**
     * Variant title
     */
    name?: string;

    /**
     * Indicates if an existing variant is updated or if a new variant is created.
     */
    overwrite?: boolean;

    /**
     * Variant key. This property is only set, when `overwrite` is set to `true`.
     */
    key?: string;

    /**
     * Apply Automatically indicator
     */
    execute?: boolean;

    /**
     * The default variant indicator
     */
    def?: boolean;

    /**
     * Indicates the check box state for 'Public'.
     */
    public?: boolean;

    /**
     * Array describing the contexts.
     *  **Note:** This property is used internally by the SAPUI5 flexibility layer.
     */
    contexts?: object[];

    /**
     * Indicates the check box state for 'Create Tile'.
     *  **Note:** This event parameter is used only internally.
     */
    tile?: boolean;
  }

  /**
   * Event object of the VariantManagement#save event.
   */
  export type VariantManagement$SaveEvent = Event<
    VariantManagement$SaveEventParameters,
    VariantManagement
  >;

  /**
   * Parameters of the VariantManagement#select event.
   */
  export interface VariantManagement$SelectEventParameters {
    /**
     * Variant key
     */
    key?: string;
  }

  /**
   * Event object of the VariantManagement#select event.
   */
  export type VariantManagement$SelectEvent = Event<
    VariantManagement$SelectEventParameters,
    VariantManagement
  >;
}

declare module "sap/m/VBox" {
  import { default as FlexBox, $FlexBoxSettings } from "sap/m/FlexBox";

  import { FlexDirection } from "sap/m/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The VBox control builds the container for a vertical flexible box layout. VBox is a convenience control,
   * as it is just a specialized FlexBox control.
   *
   *  **Note:** Be sure to check the `renderType` setting to avoid issues due to browser inconsistencies.
   */
  export default class VBox extends FlexBox {
    /**
     * Constructor for a new VBox.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	https://www.w3.org/TR/css-flexbox-1/
     * 	https://www.w3.org/TR/css-flexbox-1/#propdef-justify-content
     * 	https://www.w3.org/TR/css-flexbox-1/#propdef-flex-direction
     * 	https://www.w3schools.com/css/css3_flexbox.asp#flex-direction
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $VBoxSettings
    );
    /**
     * Constructor for a new VBox.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	https://www.w3.org/TR/css-flexbox-1/
     * 	https://www.w3.org/TR/css-flexbox-1/#propdef-justify-content
     * 	https://www.w3.org/TR/css-flexbox-1/#propdef-flex-direction
     * 	https://www.w3schools.com/css/css3_flexbox.asp#flex-direction
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $VBoxSettings
    );

    /**
     * Creates a new subclass of class sap.m.VBox with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.FlexBox.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, VBox>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.VBox.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getDirection direction}.
     *
     * Determines the direction of the layout of child elements.
     *
     * Default value is `Column`.
     *
     *
     * @returns Value of property `direction`
     */
    getDirection(): FlexDirection;
    /**
     * Sets a new value for property {@link #getDirection direction}.
     *
     * Determines the direction of the layout of child elements.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Column`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setDirection(
      /**
       * New value for property `direction`
       */
      sDirection?: FlexDirection | keyof typeof FlexDirection
    ): this;
  }
  /**
   * Describes the settings that can be provided to the VBox constructor.
   */
  export interface $VBoxSettings extends $FlexBoxSettings {
    /**
     * Determines the direction of the layout of child elements.
     */
    direction?:
      | (FlexDirection | keyof typeof FlexDirection)
      | PropertyBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/ViewSettingsCustomItem" {
  import {
    default as ViewSettingsItem,
    $ViewSettingsItemSettings,
  } from "sap/m/ViewSettingsItem";

  import Control from "sap/ui/core/Control";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  /**
   * The ViewSettingsCustomItem control is used for modelling custom filters in the ViewSettingsDialog.
   *
   * @since 1.16
   */
  export default class ViewSettingsCustomItem extends ViewSettingsItem {
    /**
     * Constructor for a new ViewSettingsCustomItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ViewSettingsCustomItemSettings
    );
    /**
     * Constructor for a new ViewSettingsCustomItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ViewSettingsCustomItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.ViewSettingsCustomItem with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ViewSettingsItem.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ViewSettingsCustomItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ViewSettingsCustomItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Creates a clone of the ViewSettingsCustomItem instance.
     *
     *
     * @returns reference to the newly created clone
     */
    clone(
      /**
       * a suffix to be appended to the cloned object id
       */
      sIdSuffix?: string,
      /**
       * an array of local IDs within the cloned hierarchy (internally used)
       */
      aLocalIds?: string[],
      /**
       * configuration object {@link https://openui5.hana.ondemand.com/api/sap.ui.base.ManagedObject#methods/clone}
       */
      oOptions?: {
        cloneChildren: boolean;

        cloneBindings: boolean;
      }
    ): this;
    /**
     * Destroys the customControl in the aggregation {@link #getCustomControl customControl}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyCustomControl(): this;
    /**
     * Internally the control is handled as a managed object instead of an aggregation because this control
     * is sometimes aggregated in other controls like a popover or a dialog.
     *
     *
     * @returns oControl a control used for filtering purposes
     */
    getCustomControl(): Control;
    /**
     * Gets current value of property {@link #getFilterCount filterCount}.
     *
     * The number of currently active filters for this custom filter item. It will be displayed in the filter
     * list of the ViewSettingsDialog to represent the filter state of the custom control.
     *
     * Default value is `0`.
     *
     *
     * @returns Value of property `filterCount`
     */
    getFilterCount(): int;
    /**
     * Internally the control is handled as a managed object instead of an aggregation as this control is sometimes
     * aggregated in other controls like a popover or a dialog.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setCustomControl(
      /**
       * A control used for filtering purposes
       */
      oControl: Control
    ): this;
    /**
     * Sets the filterCount without invalidating the control as it is never rendered directly.
     *
     *
     * @returns Reference to `this` for method chaining
     */
    setFilterCount(
      /**
       * The new value for property filterCount
       */
      iValue: int
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ViewSettingsCustomItem constructor.
   */
  export interface $ViewSettingsCustomItemSettings
    extends $ViewSettingsItemSettings {
    /**
     * The number of currently active filters for this custom filter item. It will be displayed in the filter
     * list of the ViewSettingsDialog to represent the filter state of the custom control.
     */
    filterCount?: int | PropertyBindingInfo | `{${string}}`;

    /**
     * A custom control for the filter field. It can be used for complex filtering mechanisms.
     */
    customControl?: Control;
  }
}

declare module "sap/m/ViewSettingsCustomTab" {
  import { default as Item, $ItemSettings } from "sap/ui/core/Item";

  import Control from "sap/ui/core/Control";

  import { URI } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * The ViewSettingsCustomTab control is used for adding custom tabs in the ViewSettingsDialog.
   *
   * @since 1.30
   */
  export default class ViewSettingsCustomTab extends Item {
    /**
     * Constructor for a new ViewSettingsCustomTab.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ViewSettingsCustomTabSettings
    );
    /**
     * Constructor for a new ViewSettingsCustomTab.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ViewSettingsCustomTabSettings
    );

    /**
     * Creates a new subclass of class sap.m.ViewSettingsCustomTab with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Item.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ViewSettingsCustomTab>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ViewSettingsCustomTab.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some content to the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContent(
      /**
       * The content to add; if empty, nothing is inserted
       */
      oContent: Control
    ): this;
    /**
     * Destroys all the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * The content of this Custom tab
     */
    getContent(): Control[];
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Custom tab button icon
     *
     * Default value is `"sap-icon://competitor"`.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Custom tab title
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContent content}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContent(
      /**
       * The content whose index is looked for
       */
      oContent: Control
    ): int;
    /**
     * Inserts a content into the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContent(
      /**
       * The content to insert; if empty, nothing is inserted
       */
      oContent: Control,
      /**
       * The `0`-based index the content should be inserted at; for a negative value of `iIndex`, the content
       * is inserted at position 0; for a value greater than the current size of the aggregation, the content
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getContent content}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContent(): Control[];
    /**
     * Removes a content from the aggregation {@link #getContent content}.
     *
     *
     * @returns The removed content or `null`
     */
    removeContent(
      /**
       * The content to remove or its index or id
       */
      vContent: int | string | Control
    ): Control | null;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Custom tab button icon
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"sap-icon://competitor"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets a new value for property {@link #getTitle title}.
     *
     * Custom tab title
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setTitle(
      /**
       * New value for property `title`
       */
      sTitle?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ViewSettingsCustomTab constructor.
   */
  export interface $ViewSettingsCustomTabSettings extends $ItemSettings {
    /**
     * Custom tab button icon
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Custom tab title
     */
    title?: string | PropertyBindingInfo;

    /**
     * The content of this Custom tab
     */
    content?: Control[] | Control | AggregationBindingInfo | `{${string}}`;
  }
}

declare module "sap/m/ViewSettingsFilterItem" {
  import {
    default as ViewSettingsItem,
    $ViewSettingsItemSettings,
  } from "sap/m/ViewSettingsItem";

  import {
    AggregationBindingInfo,
    PropertyBindingInfo,
  } from "sap/ui/base/ManagedObject";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import Event from "sap/ui/base/Event";

  /**
   * A ViewSettingsFilterItem control is used for modelling filter behaviour in the ViewSettingsDialog. It
   * is derived from a core Item, but does not support the base class properties like textDirection and enabled.
   * Setting these properties will not have any effects.
   *
   * @since 1.16
   */
  export default class ViewSettingsFilterItem extends ViewSettingsItem {
    /**
     * Constructor for a new ViewSettingsFilterItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $ViewSettingsFilterItemSettings
    );
    /**
     * Constructor for a new ViewSettingsFilterItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $ViewSettingsFilterItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.ViewSettingsFilterItem with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.m.ViewSettingsItem.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ViewSettingsFilterItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ViewSettingsFilterItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: ViewSettingsItem
    ): this;
    /**
     * Binds aggregation {@link #getItems items} to model data.
     *
     * See {@link sap.ui.base.ManagedObject#bindAggregation ManagedObject.bindAggregation} for a detailed description
     * of the possible properties of `oBindingInfo`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    bindItems(
      /**
       * The binding information
       */
      oBindingInfo: AggregationBindingInfo
    ): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * Items with key and value that are logically grouped under this filter item. They are used to display
     * filter details in the ViewSettingsDialog.
     */
    getItems(): ViewSettingsItem[];
    /**
     * Gets current value of property {@link #getMultiSelect multiSelect}.
     *
     * If set to (true), multi selection will be allowed for the items aggregation.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `multiSelect`
     */
    getMultiSelect(): boolean;
    /**
     * Checks for the provided `sap.m.ViewSettingsItem` in the aggregation {@link #getItems items}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: ViewSettingsItem
    ): int;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: ViewSettingsItem,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): ViewSettingsItem[];
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | ViewSettingsItem
    ): ViewSettingsItem | null;
    /**
     * Sets a new value for property {@link #getMultiSelect multiSelect}.
     *
     * If set to (true), multi selection will be allowed for the items aggregation.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setMultiSelect(
      /**
       * New value for property `multiSelect`
       */
      bMultiSelect?: boolean
    ): this;
    /**
     * Unbinds aggregation {@link #getItems items} from model data.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    unbindItems(): this;
  }
  /**
   * Describes the settings that can be provided to the ViewSettingsFilterItem constructor.
   */
  export interface $ViewSettingsFilterItemSettings
    extends $ViewSettingsItemSettings {
    /**
     * If set to (true), multi selection will be allowed for the items aggregation.
     */
    multiSelect?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Items with key and value that are logically grouped under this filter item. They are used to display
     * filter details in the ViewSettingsDialog.
     */
    items?:
      | ViewSettingsItem[]
      | ViewSettingsItem
      | AggregationBindingInfo
      | `{${string}}`;
  }

  /**
   * Parameters of the ViewSettingsFilterItem#filterDetailItemsAggregationChange event.
   */
  export interface ViewSettingsFilterItem$FilterDetailItemsAggregationChangeEventParameters {}

  /**
   * Event object of the ViewSettingsFilterItem#filterDetailItemsAggregationChange event.
   */
  export type ViewSettingsFilterItem$FilterDetailItemsAggregationChangeEvent =
    Event<
      ViewSettingsFilterItem$FilterDetailItemsAggregationChangeEventParameters,
      ViewSettingsFilterItem
    >;
}

declare module "sap/m/ViewSettingsItem" {
  import { default as Item, $ItemSettings } from "sap/ui/core/Item";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import { PropertyBindingInfo } from "sap/ui/base/ManagedObject";

  import Event from "sap/ui/base/Event";

  /**
   * ViewSettingsItem is used for modelling filter behaviour in the ViewSettingsDialog. It is derived from
   * a core Item, but does not support the base class properties "textDirection" and "enabled", setting these
   * properties will not have any effects. Apps should use the core Item's property `key/` and provide a unique
   * value for it. Not providing a key may lead to unexpected behavior of the sap.m.ViewSettingsDialog.
   *
   * @since 1.16
   */
  export default class ViewSettingsItem extends Item {
    /**
     * Constructor for a new ViewSettingsItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * initial settings for the new control
       */
      mSettings?: $ViewSettingsItemSettings
    );
    /**
     * Constructor for a new ViewSettingsItem.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * id for the new control, generated automatically if no id is given
       */
      sId?: string,
      /**
       * initial settings for the new control
       */
      mSettings?: $ViewSettingsItemSettings
    );

    /**
     * Creates a new subclass of class sap.m.ViewSettingsItem with name `sClassName` and enriches it with the
     * information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Item.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, ViewSettingsItem>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.ViewSettingsItem.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Gets current value of property {@link #getSelected selected}.
     *
     * Selected state of the item. If set to "true", the item will be displayed as selected in the view settings
     * dialog.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `selected`
     */
    getSelected(): boolean;
    /**
     * Gets current value of property {@link #getWrapping wrapping}.
     *
     * Defines the wrapping behavior of the title text.
     *
     * Default value is `false`.
     *
     * @since 1.121.0
     *
     * @returns Value of property `wrapping`
     */
    getWrapping(): boolean;
    /**
     * Sets a new value for property {@link #getSelected selected}.
     *
     * Selected state of the item. If set to "true", the item will be displayed as selected in the view settings
     * dialog.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSelected(
      /**
       * New value for property `selected`
       */
      bSelected?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getWrapping wrapping}.
     *
     * Defines the wrapping behavior of the title text.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.121.0
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWrapping(
      /**
       * New value for property `wrapping`
       */
      bWrapping?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the ViewSettingsItem constructor.
   */
  export interface $ViewSettingsItemSettings extends $ItemSettings {
    /**
     * Selected state of the item. If set to "true", the item will be displayed as selected in the view settings
     * dialog.
     */
    selected?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the wrapping behavior of the title text.
     *
     * @since 1.121.0
     */
    wrapping?: boolean | PropertyBindingInfo | `{${string}}`;
  }

  /**
   * Parameters of the ViewSettingsItem#itemPropertyChanged event.
   */
  export interface ViewSettingsItem$ItemPropertyChangedEventParameters {
    /**
     * Instance of the item that changed.
     */
    changedItem?: ViewSettingsItem;

    /**
     * Key of the changed property.
     */
    propertyKey?: string;

    /**
     * Value of the changed property.
     */
    propertyValue?: any;
  }

  /**
   * Event object of the ViewSettingsItem#itemPropertyChanged event.
   */
  export type ViewSettingsItem$ItemPropertyChangedEvent = Event<
    ViewSettingsItem$ItemPropertyChangedEventParameters,
    ViewSettingsItem
  >;
}

declare module "sap/m/WheelSlider" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import Item from "sap/ui/core/Item";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * Single select list slider with simple text values, that supports cyclic scrolling and expands/collapses
   * upon user interaction.
   *
   * @since 1.73
   */
  export default class WheelSlider extends Control {
    /**
     * Constructor for a new `WheelSlider`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $WheelSliderSettings
    );
    /**
     * Constructor for a new `WheelSlider`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $WheelSliderSettings
    );

    /**
     * Creates a new subclass of class sap.m.WheelSlider with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, WheelSlider>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.WheelSlider.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some item to the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addItem(
      /**
       * The item to add; if empty, nothing is inserted
       */
      oItem: Item
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:collapsed collapsed} event of this `sap.m.WheelSlider`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.WheelSlider` itself.
     *
     * Fires when the slider is collapsed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCollapsed(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.WheelSlider` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:collapsed collapsed} event of this `sap.m.WheelSlider`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.WheelSlider` itself.
     *
     * Fires when the slider is collapsed.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachCollapsed(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.WheelSlider` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:expanded expanded} event of this `sap.m.WheelSlider`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.WheelSlider` itself.
     *
     * Fires when the slider is expanded.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachExpanded(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.WheelSlider` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:expanded expanded} event of this `sap.m.WheelSlider`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.WheelSlider` itself.
     *
     * Fires when the slider is expanded.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachExpanded(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.WheelSlider` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectedKeyChange selectedKeyChange} event of
     * this `sap.m.WheelSlider`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.WheelSlider` itself.
     *
     * Fires when the selected key changes.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectedKeyChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: WheelSlider$SelectedKeyChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.WheelSlider` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:selectedKeyChange selectedKeyChange} event of
     * this `sap.m.WheelSlider`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.WheelSlider` itself.
     *
     * Fires when the selected key changes.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachSelectedKeyChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: WheelSlider$SelectedKeyChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.WheelSlider` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the items in the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyItems(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:collapsed collapsed} event of this `sap.m.WheelSlider`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachCollapsed(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:expanded expanded} event of this `sap.m.WheelSlider`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachExpanded(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:selectedKeyChange selectedKeyChange} event
     * of this `sap.m.WheelSlider`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachSelectedKeyChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: WheelSlider$SelectedKeyChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:collapsed collapsed} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireCollapsed(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:expanded expanded} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireExpanded(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:selectedKeyChange selectedKeyChange} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireSelectedKeyChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: WheelSlider$SelectedKeyChangeEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getIsCyclic isCyclic}.
     *
     * Indicates whether the slider supports cyclic scrolling.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `isCyclic`
     */
    getIsCyclic(): boolean;
    /**
     * Gets current value of property {@link #getIsExpanded isExpanded}.
     *
     * Indicates whether the slider is currently expanded.
     *
     * Default value is `false`.
     *
     *
     * @returns Value of property `isExpanded`
     */
    getIsExpanded(): boolean;
    /**
     * Gets content of aggregation {@link #getItems items}.
     *
     * The items of the slider.
     */
    getItems(): Item[];
    /**
     * Gets current value of property {@link #getLabel label}.
     *
     * Defines the descriptive text for the slider, placed as a label above it.
     *
     *
     * @returns Value of property `label`
     */
    getLabel(): string;
    /**
     * Gets current value of property {@link #getSelectedKey selectedKey}.
     *
     * Defines the key of the currently selected value of the slider.
     *
     *
     * @returns Value of property `selectedKey`
     */
    getSelectedKey(): string;
    /**
     * Checks for the provided `sap.ui.core.Item` in the aggregation {@link #getItems items}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfItem(
      /**
       * The item whose index is looked for
       */
      oItem: Item
    ): int;
    /**
     * Inserts a item into the aggregation {@link #getItems items}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertItem(
      /**
       * The item to insert; if empty, nothing is inserted
       */
      oItem: Item,
      /**
       * The `0`-based index the item should be inserted at; for a negative value of `iIndex`, the item is inserted
       * at position 0; for a value greater than the current size of the aggregation, the item is inserted at
       * the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getItems items}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllItems(): Item[];
    /**
     * Removes a item from the aggregation {@link #getItems items}.
     *
     *
     * @returns The removed item or `null`
     */
    removeItem(
      /**
       * The item to remove or its index or id
       */
      vItem: int | string | Item
    ): Item | null;
    /**
     * Sets a new value for property {@link #getIsCyclic isCyclic}.
     *
     * Indicates whether the slider supports cyclic scrolling.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIsCyclic(
      /**
       * New value for property `isCyclic`
       */
      bIsCyclic?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getIsExpanded isExpanded}.
     *
     * Indicates whether the slider is currently expanded.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIsExpanded(
      /**
       * New value for property `isExpanded`
       */
      bIsExpanded?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getLabel label}.
     *
     * Defines the descriptive text for the slider, placed as a label above it.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLabel(
      /**
       * New value for property `label`
       */
      sLabel?: string
    ): this;
    /**
     * Sets a new value for property {@link #getSelectedKey selectedKey}.
     *
     * Defines the key of the currently selected value of the slider.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setSelectedKey(
      /**
       * New value for property `selectedKey`
       */
      sSelectedKey?: string
    ): this;
  }
  /**
   * Describes the settings that can be provided to the WheelSlider constructor.
   */
  export interface $WheelSliderSettings extends $ControlSettings {
    /**
     * Defines the key of the currently selected value of the slider.
     */
    selectedKey?: string | PropertyBindingInfo;

    /**
     * Indicates whether the slider supports cyclic scrolling.
     */
    isCyclic?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Defines the descriptive text for the slider, placed as a label above it.
     */
    label?: string | PropertyBindingInfo;

    /**
     * Indicates whether the slider is currently expanded.
     */
    isExpanded?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The items of the slider.
     */
    items?: Item[] | Item | AggregationBindingInfo | `{${string}}`;

    /**
     * Fires when the slider is expanded.
     */
    expanded?: (oEvent: Event) => void;

    /**
     * Fires when the slider is collapsed.
     */
    collapsed?: (oEvent: Event) => void;

    /**
     * Fires when the selected key changes.
     */
    selectedKeyChange?: (oEvent: WheelSlider$SelectedKeyChangeEvent) => void;
  }

  /**
   * Parameters of the WheelSlider#collapsed event.
   */
  export interface WheelSlider$CollapsedEventParameters {}

  /**
   * Event object of the WheelSlider#collapsed event.
   */
  export type WheelSlider$CollapsedEvent = Event<
    WheelSlider$CollapsedEventParameters,
    WheelSlider
  >;

  /**
   * Parameters of the WheelSlider#expanded event.
   */
  export interface WheelSlider$ExpandedEventParameters {}

  /**
   * Event object of the WheelSlider#expanded event.
   */
  export type WheelSlider$ExpandedEvent = Event<
    WheelSlider$ExpandedEventParameters,
    WheelSlider
  >;

  /**
   * Parameters of the WheelSlider#selectedKeyChange event.
   */
  export interface WheelSlider$SelectedKeyChangeEventParameters {
    /**
     * The new selected key
     */
    newKey?: string;
  }

  /**
   * Event object of the WheelSlider#selectedKeyChange event.
   */
  export type WheelSlider$SelectedKeyChangeEvent = Event<
    WheelSlider$SelectedKeyChangeEventParameters,
    WheelSlider
  >;
}

declare module "sap/m/WheelSliderContainer" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import WheelSlider from "sap/m/WheelSlider";

  import { CSSSize } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * A picker list container control used to hold sliders of type {@link sap.m.WheelSlider}.
   *
   * @since 1.73
   */
  export default class WheelSliderContainer extends Control {
    /**
     * Constructor for a new `WheelSliderContainer`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $WheelSliderContainerSettings
    );
    /**
     * Constructor for a new `WheelSliderContainer`.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $WheelSliderContainerSettings
    );

    /**
     * Creates a new subclass of class sap.m.WheelSliderContainer with name `sClassName` and enriches it with
     * the information contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, WheelSliderContainer>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.WheelSliderContainer.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some slider to the aggregation {@link #getSliders sliders}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addSlider(
      /**
       * The slider to add; if empty, nothing is inserted
       */
      oSlider: WheelSlider
    ): this;
    /**
     * Destroys all the sliders in the aggregation {@link #getSliders sliders}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroySliders(): this;
    /**
     * Gets current value of property {@link #getHeight height}.
     *
     * Sets the height of the container. If percentage value is used, the parent container must have specified
     * height.
     *
     *
     * @returns Value of property `height`
     */
    getHeight(): CSSSize;
    /**
     * Gets current value of property {@link #getLabelText labelText}.
     *
     * Defines the text of the picker label.
     *
     *
     * @returns Value of property `labelText`
     */
    getLabelText(): string;
    /**
     * Gets content of aggregation {@link #getSliders sliders}.
     *
     * The sliders in the container.
     */
    getSliders(): WheelSlider[];
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Sets the width of the container. The minimum width is 320px.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Checks for the provided `sap.m.WheelSlider` in the aggregation {@link #getSliders sliders}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfSlider(
      /**
       * The slider whose index is looked for
       */
      oSlider: WheelSlider
    ): int;
    /**
     * Inserts a slider into the aggregation {@link #getSliders sliders}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertSlider(
      /**
       * The slider to insert; if empty, nothing is inserted
       */
      oSlider: WheelSlider,
      /**
       * The `0`-based index the slider should be inserted at; for a negative value of `iIndex`, the slider is
       * inserted at position 0; for a value greater than the current size of the aggregation, the slider is inserted
       * at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getSliders sliders}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllSliders(): WheelSlider[];
    /**
     * Removes a slider from the aggregation {@link #getSliders sliders}.
     *
     *
     * @returns The removed slider or `null`
     */
    removeSlider(
      /**
       * The slider to remove or its index or id
       */
      vSlider: int | string | WheelSlider
    ): WheelSlider | null;
    /**
     * Sets a new value for property {@link #getHeight height}.
     *
     * Sets the height of the container. If percentage value is used, the parent container must have specified
     * height.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeight(
      /**
       * New value for property `height`
       */
      sHeight: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getLabelText labelText}.
     *
     * Defines the text of the picker label.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setLabelText(
      /**
       * New value for property `labelText`
       */
      sLabelText: string
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Sets the width of the container. The minimum width is 320px.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth: CSSSize
    ): this;
  }
  /**
   * Describes the settings that can be provided to the WheelSliderContainer constructor.
   */
  export interface $WheelSliderContainerSettings extends $ControlSettings {
    /**
     * Defines the text of the picker label.
     */
    labelText?: string | PropertyBindingInfo;

    /**
     * Sets the width of the container. The minimum width is 320px.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Sets the height of the container. If percentage value is used, the parent container must have specified
     * height.
     */
    height?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * The sliders in the container.
     */
    sliders?:
      | WheelSlider[]
      | WheelSlider
      | AggregationBindingInfo
      | `{${string}}`;
  }
}

declare module "sap/m/Wizard" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { IDynamicPageStickyContent } from "sap/f/library";

  import WizardStep from "sap/m/WizardStep";

  import Event from "sap/ui/base/Event";

  import { PageBackgroundDesign, WizardRenderMode } from "sap/m/library";

  import { ID, CSSSize, TitleLevel } from "sap/ui/core/library";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * Enables users to accomplish a single goal which consists of multiple dependable sub-tasks. Overview:
   * The sap.m.Wizard helps users complete a complex and unfamiliar task by dividing it into sections and
   * guiding the user through it. The wizard has a mandatory title and two main areas - a navigation area
   * at the top showing the step sequence, and a content area below. Structure: Title: The wizard's title
   * defines its purpose. Navigation Area: The navigation area shows the sequence of {@link sap.m.WizardStep wizard steps}.
   *
   * 	 - The minimum number of steps is 3 and the maximum is 8 and are stored in the `steps` aggregation.
   *
   * 	 - Steps can be branching depending on choices the user made in their input - this is set by the `enableBranching`
   *     property.
   * 	 - Steps can have different visual representations - numbers or icons. You can add labels for better
   *     readability   **Note:** Dynamic step insertion is not supported. Even if branching steps are used,
   *     the steps should be known in advance. Content: The content occupies the main part of the page. It can
   *     hold any type of input controls. The content is kept in {@link sap.m.WizardStep wizard steps}. Next Step
   *     Button: The next step button is displayed below the content. It can be hidden by setting `showNextButton`
   *     to `false` and displayed, for example, only after the user has filled all mandatory fields. Usage: When
   *     to use:: When the user has to accomplish a long or unfamiliar task. When not to use:: When the user has
   *     to accomplish a routine task that is clear and familiar. When the task has only two steps or less. Responsive
   *     Behavior: On mobile devices the steps in the StepNavigator are grouped together and overlap. Tapping
   *     on them will show a popover to select the step to navigate to.
   *
   * When using the sap.m.Wizard in SAP Quartz theme, the breakpoints and layout paddings could be determined
   * by the container's width. To enable this concept and add responsive paddings to the navigation area and
   * to the content of the Wizard control, you may add the following classes depending on your use case: `sapUiResponsivePadding--header`,
   * `sapUiResponsivePadding--content`.
   *
   * As the `sap.m.Wizard` is a layout control, when used in the {@link sap.f.DynamicPage}, the {@link sap.f.DynamicPage}'s
   * `fitContent` property needs to be set to 'true' so that the scroll handling is left to the `sap.m.Wizard`
   * control. Also, in order to achieve the target Fiori design, the `sapUiNoContentPadding` class needs to
   * be added to the {@link sap.f.DynamicPage} as well as `sapUiResponsivePadding--header`, `sapUiResponsivePadding--content`
   * to the `sap.m.Wizard`.
   *
   * **Note:** The `sap.m.Wizard` control does not support runtime (dynamic) changes to the available paths
   * (when branching is used) or additional steps being added after the last step. What is meant by runtime
   * (dynamic) changes to the available paths: If the `sap.m.Wizard` is set as branching, and the available
   * paths are:
   * 	 - A -> B -> C
   * 	 - A -> B -> D  Changing the `subsequentSteps` association of step C to point to step D (creating
   *     A -> B -> C -> D path) is not supported.
   *
   * @since 1.30
   */
  export default class Wizard
    extends Control
    implements IDynamicPageStickyContent
  {
    __implements__sap_f_IDynamicPageStickyContent: boolean;
    /**
     * Constructor for a new Wizard.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/wizard/ Wizard}
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $WizardSettings
    );
    /**
     * Constructor for a new Wizard.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     * See:
     * 	{@link fiori:https://experience.sap.com/fiori-design-web/wizard/ Wizard}
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $WizardSettings
    );

    /**
     * Creates a new subclass of class sap.m.Wizard with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, Wizard>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.Wizard.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds a new step to the Wizard.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    addStep(
      /**
       * New WizardStep to add to the Wizard.
       */
      oWizardStep: WizardStep
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:complete complete} event of this `sap.m.Wizard`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Wizard` itself.
     *
     * The complete event is fired when the user clicks the finish button of the Wizard. The finish button is
     * only available on the last step of the Wizard.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachComplete(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Wizard` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:complete complete} event of this `sap.m.Wizard`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Wizard` itself.
     *
     * The complete event is fired when the user clicks the finish button of the Wizard. The finish button is
     * only available on the last step of the Wizard.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachComplete(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Wizard` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navigationChange navigationChange} event of
     * this `sap.m.Wizard`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Wizard` itself.
     *
     * This event is fired when the the current visible step is changed by either taping on the `WizardProgressNavigator`
     * or scrolling through the steps.
     *
     * @since 1.101
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavigationChange(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Wizard$NavigationChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Wizard` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:navigationChange navigationChange} event of
     * this `sap.m.Wizard`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Wizard` itself.
     *
     * This event is fired when the the current visible step is changed by either taping on the `WizardProgressNavigator`
     * or scrolling through the steps.
     *
     * @since 1.101
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachNavigationChange(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Wizard$NavigationChangeEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Wizard` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:stepActivate stepActivate} event of this `sap.m.Wizard`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Wizard` itself.
     *
     * The StepActivated event is fired every time a new step is activated.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachStepActivate(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Wizard$StepActivateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Wizard` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:stepActivate stepActivate} event of this `sap.m.Wizard`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.Wizard` itself.
     *
     * The StepActivated event is fired every time a new step is activated.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachStepActivate(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Wizard$StepActivateEvent) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.Wizard` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all aggregated steps in the Wizard.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    destroySteps(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:complete complete} event of this `sap.m.Wizard`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachComplete(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:navigationChange navigationChange} event of
     * this `sap.m.Wizard`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     * @since 1.101
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachNavigationChange(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Wizard$NavigationChangeEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:stepActivate stepActivate} event of this `sap.m.Wizard`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachStepActivate(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Wizard$StepActivateEvent) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Discards all progress done from the given step(incl.) to the end of the wizard. The verified state of
     * the steps is returned to the initial provided.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    discardProgress(
      /**
       * The step after which the progress is discarded.
       */
      oStep: WizardStep,
      /**
       * Indicating whether we should preserve next step
       */
      bPreserveNextStep: boolean
    ): this;
    /**
     * Fires event {@link #event:complete complete} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireComplete(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:navigationChange navigationChange} to attached listeners.
     *
     * @since 1.101
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireNavigationChange(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Wizard$NavigationChangeEventParameters
    ): this;
    /**
     * Fires event {@link #event:stepActivate stepActivate} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireStepActivate(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: Wizard$StepActivateEventParameters
    ): this;
    /**
     * Gets current value of property {@link #getBackgroundDesign backgroundDesign}.
     *
     * This property is used to set the background color of a Wizard content. The `Standard` option with the
     * default background color is used, if not specified.
     *
     * Default value is `Standard`.
     *
     *
     * @returns Value of property `backgroundDesign`
     */
    getBackgroundDesign(): PageBackgroundDesign;
    /**
     * ID of the element which is the current target of the association {@link #getCurrentStep currentStep},
     * or `null`.
     *
     * @since 1.50
     */
    getCurrentStep(): ID | null;
    /**
     * Gets current value of property {@link #getEnableBranching enableBranching}.
     *
     * Enables the branching functionality of the Wizard. Branching gives the developer the ability to define
     * multiple routes a user is able to take based on the input in the current step. It is up to the developer
     * to programmatically check for what is the input in the current step and set a concrete next step amongst
     * the available subsequent steps. Note: If this property is set to false, `next` and `subSequentSteps`
     * associations of the WizardStep control are ignored.
     *
     * Default value is `false`.
     *
     * @since 1.32
     *
     * @returns Value of property `enableBranching`
     */
    getEnableBranching(): boolean;
    /**
     * Returns the finish button text which will be rendered.
     *
     *
     * @returns The text which will be rendered in the finish button.
     */
    getFinishButtonText(): string;
    /**
     * Gets current value of property {@link #getHeight height}.
     *
     * Determines the height of the Wizard.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Value of property `height`
     */
    getHeight(): CSSSize;
    /**
     * Returns the number of the last activated step in the Wizard.
     *
     *
     * @returns The last activated step.
     */
    getProgress(): number;
    /**
     * Returns the last activated step in the Wizard.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    getProgressStep(): WizardStep;
    /**
     * Gets current value of property {@link #getRenderMode renderMode}.
     *
     * Defines how the steps of the Wizard would be visualized.
     *
     * Default value is `Scroll`.
     *
     * @since 1.84
     *
     * @returns Value of property `renderMode`
     */
    getRenderMode(): WizardRenderMode;
    /**
     * Gets current value of property {@link #getShowNextButton showNextButton}.
     *
     * Controls the visibility of the next button. The developers can choose to control the flow of the steps
     * either through the API (with `nextStep` and `previousStep` methods) or let the user click the next button,
     * and control it with `validateStep` or `invalidateStep` methods.
     *
     * Default value is `true`.
     *
     *
     * @returns Value of property `showNextButton`
     */
    getShowNextButton(): boolean;
    /**
     * Gets content of aggregation {@link #getSteps steps}.
     *
     * The wizard steps to be included in the content of the control.
     */
    getSteps(): WizardStep[];
    /**
     * Gets current value of property {@link #getStepTitleLevel stepTitleLevel}.
     *
     * Defines the semantic level of the step title. When using "Auto" the default value is taken into account.
     *
     * Default value is `H3`.
     *
     * @since 1.115
     *
     * @returns Value of property `stepTitleLevel`
     */
    getStepTitleLevel(): TitleLevel;
    /**
     * Gets current value of property {@link #getWidth width}.
     *
     * Determines the width of the Wizard.
     *
     * Default value is `"auto"`.
     *
     *
     * @returns Value of property `width`
     */
    getWidth(): CSSSize;
    /**
     * Goes to the given step. The step must already be activated and visible. You can't use this method on
     * steps that haven't been reached yet.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    goToStep(
      /**
       * The step to go to.
       */
      oStep: WizardStep,
      /**
       * Defines whether the focus should be changed to the first element.
       */
      bFocusFirstStepElement: boolean
    ): this;
    /**
     * Checks for the provided `sap.m.WizardStep` in the aggregation {@link #getSteps steps}. and returns its
     * index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfStep(
      /**
       * The step whose index is looked for
       */
      oStep: WizardStep
    ): int;
    /**
     * Invalidates the given step.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    invalidateStep(
      /**
       * The step to be invalidated.
       */
      oStep: WizardStep
    ): this;
    /**
     * Validates the current step, and moves one step further.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    nextStep(): this;
    /**
     * Discards the current step and goes one step back.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    previousStep(): this;
    /**
     * Removes all steps from the Wizard.
     *
     *
     * @returns Pointer to the Steps that were removed.
     */
    removeAllSteps(): WizardStep[];
    /**
     * Sets association currentStep to the given step.
     *
     *
     * @returns Reference to the control instance for chaining.
     */
    setCurrentStep(
      /**
       * The step of the wizard that will be currently activated (meaning the last step).
       */
      vStepId: WizardStep | ID
    ): this;
    /**
     * Sets a new value for property {@link #getEnableBranching enableBranching}.
     *
     * Enables the branching functionality of the Wizard. Branching gives the developer the ability to define
     * multiple routes a user is able to take based on the input in the current step. It is up to the developer
     * to programmatically check for what is the input in the current step and set a concrete next step amongst
     * the available subsequent steps. Note: If this property is set to false, `next` and `subSequentSteps`
     * associations of the WizardStep control are ignored.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.32
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setEnableBranching(
      /**
       * New value for property `enableBranching`
       */
      bEnableBranching?: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getFinishButtonText finishButtonText}.
     *
     * Changes the text of the finish button for the last step. This property can be used only if `showNextButton`
     * is set to true. By default the text of the button is "Review".
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"Review"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setFinishButtonText(
      /**
       * New value for property `finishButtonText`
       */
      sFinishButtonText?: string
    ): this;
    /**
     * Sets a new value for property {@link #getHeight height}.
     *
     * Determines the height of the Wizard.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"100%"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setHeight(
      /**
       * New value for property `height`
       */
      sHeight?: CSSSize
    ): this;
    /**
     * Sets a new value for property {@link #getRenderMode renderMode}.
     *
     * Defines how the steps of the Wizard would be visualized.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `Scroll`.
     *
     * @since 1.84
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setRenderMode(
      /**
       * New value for property `renderMode`
       */
      sRenderMode?: WizardRenderMode | keyof typeof WizardRenderMode
    ): this;
    /**
     * Sets the visibility of the next button.
     *
     *
     * @returns Reference to the control instance for chaining.
     */
    setShowNextButton(
      /**
       * True to show the button or false to hide it.
       */
      bValue: boolean
    ): this;
    /**
     * Sets a new value for property {@link #getStepTitleLevel stepTitleLevel}.
     *
     * Defines the semantic level of the step title. When using "Auto" the default value is taken into account.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `H3`.
     *
     * @since 1.115
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setStepTitleLevel(
      /**
       * New value for property `stepTitleLevel`
       */
      sStepTitleLevel?: TitleLevel | keyof typeof TitleLevel
    ): this;
    /**
     * Sets a new value for property {@link #getWidth width}.
     *
     * Determines the width of the Wizard.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `"auto"`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setWidth(
      /**
       * New value for property `width`
       */
      sWidth?: CSSSize
    ): this;
    /**
     * Validates the given step.
     *
     *
     * @returns Pointer to the control instance for chaining.
     */
    validateStep(
      /**
       * The step to be validated.
       */
      oStep: WizardStep
    ): this;
  }
  /**
   * Describes the settings that can be provided to the Wizard constructor.
   */
  export interface $WizardSettings extends $ControlSettings {
    /**
     * Determines the width of the Wizard.
     */
    width?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Determines the height of the Wizard.
     */
    height?: CSSSize | PropertyBindingInfo | `{${string}}`;

    /**
     * Controls the visibility of the next button. The developers can choose to control the flow of the steps
     * either through the API (with `nextStep` and `previousStep` methods) or let the user click the next button,
     * and control it with `validateStep` or `invalidateStep` methods.
     */
    showNextButton?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Changes the text of the finish button for the last step. This property can be used only if `showNextButton`
     * is set to true. By default the text of the button is "Review".
     */
    finishButtonText?: string | PropertyBindingInfo;

    /**
     * Enables the branching functionality of the Wizard. Branching gives the developer the ability to define
     * multiple routes a user is able to take based on the input in the current step. It is up to the developer
     * to programmatically check for what is the input in the current step and set a concrete next step amongst
     * the available subsequent steps. Note: If this property is set to false, `next` and `subSequentSteps`
     * associations of the WizardStep control are ignored.
     *
     * @since 1.32
     */
    enableBranching?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * This property is used to set the background color of a Wizard content. The `Standard` option with the
     * default background color is used, if not specified.
     */
    backgroundDesign?:
      | (PageBackgroundDesign | keyof typeof PageBackgroundDesign)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines how the steps of the Wizard would be visualized.
     *
     * @since 1.84
     */
    renderMode?:
      | (WizardRenderMode | keyof typeof WizardRenderMode)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * Defines the semantic level of the step title. When using "Auto" the default value is taken into account.
     *
     * @since 1.115
     */
    stepTitleLevel?:
      | (TitleLevel | keyof typeof TitleLevel)
      | PropertyBindingInfo
      | `{${string}}`;

    /**
     * The wizard steps to be included in the content of the control.
     */
    steps?: WizardStep[] | WizardStep | AggregationBindingInfo | `{${string}}`;

    /**
     * This association controls the current activated step of the wizard (meaning the last step) For example
     * if we have A->B->C->D steps, we are on step A and we setCurrentStep(C) A,B and C are going to be activated.
     * D will still remain unvisited. The parameter needs to be a Wizard step that is part of the current Wizard
     *
     * @since 1.50
     */
    currentStep?: WizardStep | string;

    /**
     * The StepActivated event is fired every time a new step is activated.
     */
    stepActivate?: (oEvent: Wizard$StepActivateEvent) => void;

    /**
     * This event is fired when the the current visible step is changed by either taping on the `WizardProgressNavigator`
     * or scrolling through the steps.
     *
     * @since 1.101
     */
    navigationChange?: (oEvent: Wizard$NavigationChangeEvent) => void;

    /**
     * The complete event is fired when the user clicks the finish button of the Wizard. The finish button is
     * only available on the last step of the Wizard.
     */
    complete?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the Wizard#complete event.
   */
  export interface Wizard$CompleteEventParameters {}

  /**
   * Event object of the Wizard#complete event.
   */
  export type Wizard$CompleteEvent = Event<
    Wizard$CompleteEventParameters,
    Wizard
  >;

  /**
   * Parameters of the Wizard#navigationChange event.
   */
  export interface Wizard$NavigationChangeEventParameters {
    /**
     * The newly selected step.
     */
    step?: WizardStep;
  }

  /**
   * Event object of the Wizard#navigationChange event.
   */
  export type Wizard$NavigationChangeEvent = Event<
    Wizard$NavigationChangeEventParameters,
    Wizard
  >;

  /**
   * Parameters of the Wizard#stepActivate event.
   */
  export interface Wizard$StepActivateEventParameters {
    /**
     * The index of the activated step as a parameter. One-based.
     */
    index?: int;
  }

  /**
   * Event object of the Wizard#stepActivate event.
   */
  export type Wizard$StepActivateEvent = Event<
    Wizard$StepActivateEventParameters,
    Wizard
  >;
}

declare module "sap/m/WizardStep" {
  import { default as Control, $ControlSettings } from "sap/ui/core/Control";

  import { ID, URI } from "sap/ui/core/library";

  import Event from "sap/ui/base/Event";

  import ElementMetadata from "sap/ui/core/ElementMetadata";

  import {
    PropertyBindingInfo,
    AggregationBindingInfo,
  } from "sap/ui/base/ManagedObject";

  /**
   * A container control used to aggregate user input controls as part of an sap.m.Wizard. Overview: WizardStep
   * gives the developer the ability to validate, invalidate the step and define subsequent steps. The WizardStep
   * control control is supposed to be used only as an aggregation of the {@link sap.m.Wizard Wizard} control,
   * and should not be used as a standalone one. Structure:
   * 	 - Each wizard step has a title. Additionally it can have an icon.
   * 	 - Each wizard step can be validated by setting the `validated` property. This action will trigger the
   *     rendering of the Next step button. If the execution needs to branch after a given step, you should
   *     set all possible next steps in the `subsequentSteps` aggregation.
   *
   * @since 1.30
   */
  export default class WizardStep extends Control {
    /**
     * Constructor for a new WizardStep.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * Initial settings for the new control
       */
      mSettings?: $WizardStepSettings
    );
    /**
     * Constructor for a new WizardStep.
     *
     * Accepts an object literal `mSettings` that defines initial property values, aggregated and associated
     * objects as well as event handlers. See {@link sap.ui.base.ManagedObject#constructor} for a general description
     * of the syntax of the settings object.
     */
    constructor(
      /**
       * ID for the new control, generated automatically if no ID is given
       */
      sId?: string,
      /**
       * Initial settings for the new control
       */
      mSettings?: $WizardStepSettings
    );

    /**
     * Creates a new subclass of class sap.m.WizardStep with name `sClassName` and enriches it with the information
     * contained in `oClassInfo`.
     *
     * `oClassInfo` might contain the same kind of information as described in {@link sap.ui.core.Control.extend}.
     *
     *
     * @returns Created class / constructor function
     */
    static extend<T extends Record<string, unknown>>(
      /**
       * Name of the class being created
       */
      sClassName: string,
      /**
       * Object literal with information about the class
       */
      oClassInfo?: sap.ClassInfo<T, WizardStep>,
      /**
       * Constructor function for the metadata object; if not given, it defaults to the metadata implementation
       * used by this class
       */
      FNMetaImpl?: Function
    ): Function;
    /**
     * Returns a metadata object for class sap.m.WizardStep.
     *
     *
     * @returns Metadata object describing this class
     */
    static getMetadata(): ElementMetadata;
    /**
     * Adds some content to the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addContent(
      /**
       * The content to add; if empty, nothing is inserted
       */
      oContent: Control
    ): this;
    /**
     * Adds some subsequentStep into the association {@link #getSubsequentSteps subsequentSteps}.
     *
     * @since 1.32
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    addSubsequentStep(
      /**
       * The subsequentSteps to add; if empty, nothing is inserted
       */
      vSubsequentStep: ID | WizardStep
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:activate activate} event of this `sap.m.WizardStep`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.WizardStep` itself.
     *
     * This event is fired on next step activation from the Wizard.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachActivate(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.WizardStep` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:activate activate} event of this `sap.m.WizardStep`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.WizardStep` itself.
     *
     * This event is fired on next step activation from the Wizard.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachActivate(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.WizardStep` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:complete complete} event of this `sap.m.WizardStep`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.WizardStep` itself.
     *
     * This event is fired after the user presses the Next button in the Wizard, or on `nextStep` method call
     * from the app developer.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachComplete(
      /**
       * An application-specific payload object that will be passed to the event handler along with the event
       * object when firing the event
       */
      oData: object,
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.WizardStep` itself
       */
      oListener?: object
    ): this;
    /**
     * Attaches event handler `fnFunction` to the {@link #event:complete complete} event of this `sap.m.WizardStep`.
     *
     * When called, the context of the event handler (its `this`) will be bound to `oListener` if specified,
     * otherwise it will be bound to this `sap.m.WizardStep` itself.
     *
     * This event is fired after the user presses the Next button in the Wizard, or on `nextStep` method call
     * from the app developer.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    attachComplete(
      /**
       * The function to be called when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object to call the event handler with. Defaults to this `sap.m.WizardStep` itself
       */
      oListener?: object
    ): this;
    /**
     * Destroys all the content in the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    destroyContent(): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:activate activate} event of this `sap.m.WizardStep`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachActivate(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Detaches event handler `fnFunction` from the {@link #event:complete complete} event of this `sap.m.WizardStep`.
     *
     * The passed function and listener object must match the ones used for event registration.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    detachComplete(
      /**
       * The function to be called, when the event occurs
       */
      fnFunction: (p1: Event) => void,
      /**
       * Context object on which the given function had to be called
       */
      oListener?: object
    ): this;
    /**
     * Fires event {@link #event:activate activate} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireActivate(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Fires event {@link #event:complete complete} to attached listeners.
     *
     * @ui5-protected Do not call from applications (only from related classes in the framework)
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    fireComplete(
      /**
       * Parameters to pass along with the event
       */
      mParameters?: object
    ): this;
    /**
     * Gets content of aggregation {@link #getContent content}.
     *
     * The content of the Wizard Step.
     */
    getContent(): Control[];
    /**
     * Gets current value of property {@link #getIcon icon}.
     *
     * Determines the icon that is displayed for this step. The icon is visualized in the progress navigation
     * part of the Wizard control. **Note:** In order for the icon to be displayed, each step in the Wizard
     * should have this property defined, otherwise the default numbering will be displayed.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `icon`
     */
    getIcon(): URI;
    /**
     * ID of the element which is the current target of the association {@link #getNextStep nextStep}, or `null`.
     *
     * @since 1.32
     */
    getNextStep(): ID | null;
    /**
     * Gets current value of property {@link #getOptional optional}.
     *
     * Indicates whether or not the step is optional. When a step is optional an "(Optional)" label is displayed
     * under the step's title.
     *
     * Default value is `false`.
     *
     * @since 1.54
     *
     * @returns Value of property `optional`
     */
    getOptional(): boolean;
    /**
     * Returns array of IDs of the elements which are the current targets of the association {@link #getSubsequentSteps subsequentSteps}.
     *
     * @since 1.32
     */
    getSubsequentSteps(): ID[];
    /**
     * Gets current value of property {@link #getTitle title}.
     *
     * Determines the title of the step. The title is visualized in the Wizard control.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Value of property `title`
     */
    getTitle(): string;
    /**
     * Gets current value of property {@link #getValidated validated}.
     *
     * Indicates whether or not the step is validated. When a step is validated a Next button is visualized
     * in the Wizard control.
     *
     * Default value is `true`.
     *
     * @since 1.32
     *
     * @returns Value of property `validated`
     */
    getValidated(): boolean;
    /**
     * Checks for the provided `sap.ui.core.Control` in the aggregation {@link #getContent content}. and returns
     * its index if found or -1 otherwise.
     *
     *
     * @returns The index of the provided control in the aggregation if found, or -1 otherwise
     */
    indexOfContent(
      /**
       * The content whose index is looked for
       */
      oContent: Control
    ): int;
    /**
     * Inserts a content into the aggregation {@link #getContent content}.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    insertContent(
      /**
       * The content to insert; if empty, nothing is inserted
       */
      oContent: Control,
      /**
       * The `0`-based index the content should be inserted at; for a negative value of `iIndex`, the content
       * is inserted at position 0; for a value greater than the current size of the aggregation, the content
       * is inserted at the last position
       */
      iIndex: int
    ): this;
    /**
     * Removes all the controls from the aggregation {@link #getContent content}.
     *
     * Additionally, it unregisters them from the hosting UIArea.
     *
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllContent(): Control[];
    /**
     * Removes all the controls in the association named {@link #getSubsequentSteps subsequentSteps}.
     *
     * @since 1.32
     *
     * @returns An array of the removed elements (might be empty)
     */
    removeAllSubsequentSteps(): ID[];
    /**
     * Removes a content from the aggregation {@link #getContent content}.
     *
     *
     * @returns The removed content or `null`
     */
    removeContent(
      /**
       * The content to remove or its index or id
       */
      vContent: int | string | Control
    ): Control | null;
    /**
     * Removes an subsequentStep from the association named {@link #getSubsequentSteps subsequentSteps}.
     *
     * @since 1.32
     *
     * @returns The removed subsequentStep or `null`
     */
    removeSubsequentStep(
      /**
       * The subsequentStep to be removed or its index or ID
       */
      vSubsequentStep: int | ID | WizardStep
    ): ID | null;
    /**
     * Sets a new value for property {@link #getIcon icon}.
     *
     * Determines the icon that is displayed for this step. The icon is visualized in the progress navigation
     * part of the Wizard control. **Note:** In order for the icon to be displayed, each step in the Wizard
     * should have this property defined, otherwise the default numbering will be displayed.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `empty string`.
     *
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setIcon(
      /**
       * New value for property `icon`
       */
      sIcon?: URI
    ): this;
    /**
     * Sets the associated {@link #getNextStep nextStep}.
     *
     * @since 1.32
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setNextStep(
      /**
       * ID of an element which becomes the new target of this nextStep association; alternatively, an element
       * instance may be given
       */
      oNextStep: ID | WizardStep
    ): this;
    /**
     * Sets a new value for property {@link #getOptional optional}.
     *
     * Indicates whether or not the step is optional. When a step is optional an "(Optional)" label is displayed
     * under the step's title.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `false`.
     *
     * @since 1.54
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setOptional(
      /**
       * New value for property `optional`
       */
      bOptional?: boolean
    ): this;
    /**
     * Sets the title property of the WizardStep.
     *
     *
     * @returns this instance for method chaining.
     */
    setTitle(
      /**
       * The new WizardStep title.
       */
      sNewTitle: string
    ): WizardStep;
    /**
     * Sets a new value for property {@link #getValidated validated}.
     *
     * Indicates whether or not the step is validated. When a step is validated a Next button is visualized
     * in the Wizard control.
     *
     * When called with a value of `null` or `undefined`, the default value of the property will be restored.
     *
     * Default value is `true`.
     *
     * @since 1.32
     *
     * @returns Reference to `this` in order to allow method chaining
     */
    setValidated(
      /**
       * New value for property `validated`
       */
      bValidated?: boolean
    ): this;
  }
  /**
   * Describes the settings that can be provided to the WizardStep constructor.
   */
  export interface $WizardStepSettings extends $ControlSettings {
    /**
     * Determines the title of the step. The title is visualized in the Wizard control.
     */
    title?: string | PropertyBindingInfo;

    /**
     * Determines the icon that is displayed for this step. The icon is visualized in the progress navigation
     * part of the Wizard control. **Note:** In order for the icon to be displayed, each step in the Wizard
     * should have this property defined, otherwise the default numbering will be displayed.
     */
    icon?: URI | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether or not the step is validated. When a step is validated a Next button is visualized
     * in the Wizard control.
     *
     * @since 1.32
     */
    validated?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * Indicates whether or not the step is optional. When a step is optional an "(Optional)" label is displayed
     * under the step's title.
     *
     * @since 1.54
     */
    optional?: boolean | PropertyBindingInfo | `{${string}}`;

    /**
     * The content of the Wizard Step.
     */
    content?: Control[] | Control | AggregationBindingInfo | `{${string}}`;

    /**
     * This association is used only when the `enableBranching` property of the Wizard is set to true. Use the
     * association to store the next steps that are about to come after the current. If this is going to be
     * a final step - leave this association empty. **NOTE:** The association needs to be set prior the step
     * is shown. Dynamical addition of subsequent steps is not supported use case especially when the current
     * step is final (the association was empty before the step was displayed).
     *
     * @since 1.32
     */
    subsequentSteps?: Array<WizardStep | string>;

    /**
     * The next step to be taken. It must be defined in order for the previous step to be completed.
     *
     * @since 1.32
     */
    nextStep?: WizardStep | string;

    /**
     * This event is fired after the user presses the Next button in the Wizard, or on `nextStep` method call
     * from the app developer.
     */
    complete?: (oEvent: Event) => void;

    /**
     * This event is fired on next step activation from the Wizard.
     */
    activate?: (oEvent: Event) => void;
  }

  /**
   * Parameters of the WizardStep#activate event.
   */
  export interface WizardStep$ActivateEventParameters {}

  /**
   * Event object of the WizardStep#activate event.
   */
  export type WizardStep$ActivateEvent = Event<
    WizardStep$ActivateEventParameters,
    WizardStep
  >;

  /**
   * Parameters of the WizardStep#complete event.
   */
  export interface WizardStep$CompleteEventParameters {}

  /**
   * Event object of the WizardStep#complete event.
   */
  export type WizardStep$CompleteEvent = Event<
    WizardStep$CompleteEventParameters,
    WizardStep
  >;
}

declare namespace sap {
  /**
   * The main UI5 control library, with responsive controls that can be used in touch devices as well as desktop
   * browsers.
   *
   * @since 1.4
   */
  namespace m {
    /**
     * The public facade of the {@link sap.m.SelectionDetailsItem} element.
     *
     * @since 1.48.0
     */
    class SelectionDetailsItemFacade {
      /**
       * Describes the public facade of the {@link sap.m.SelectionDetailsItem} element.
       */
      constructor();

      /**
       * Adds some action to the aggregation {@link #getActions actions}.
       *
       *
       * @returns Reference to `this` in order to allow method chaining
       */
      addAction(
        /**
         * The action to add; if empty, nothing is inserted
         */
        oAction: import("sap/ui/core/Item").default
      ): this;
      /**
       * Gets current value of property {@link #getEnableNav enableNav}.
       *
       * Determines whether or not the item is active and a navigation event is triggered on press.
       *
       * Default value is `false`.
       *
       *
       * @returns Value of property `enableNav`
       */
      getEnableNav(): boolean;
      /**
       * Removes a action from the aggregation {@link #getActions actions}.
       *
       *
       * @returns The removed action or `null`
       */
      removeAction(
        /**
         * The action to remove or its index or id
         */
        vAction: int | string | import("sap/ui/core/Item").default
      ): import("sap/ui/core/Item").default | null;
      /**
       * Sets a new value for property {@link #getEnableNav enableNav}.
       *
       * Determines whether or not the item is active and a navigation event is triggered on press.
       *
       * When called with a value of `null` or `undefined`, the default value of the property will be restored.
       *
       * Default value is `false`.
       *
       *
       * @returns Reference to `this` in order to allow method chaining
       */
      setEnableNav(
        /**
         * New value for property `enableNav`
         */
        bEnableNav?: boolean
      ): this;
    }
  }

  interface IUI5DefineDependencyNames {
    "sap/f/library": undefined;

    "sap/m/ActionListItem": undefined;

    "sap/m/ActionSelect": undefined;

    "sap/m/ActionSheet": undefined;

    "sap/m/ActionTile": undefined;

    "sap/m/ActionTileContent": undefined;

    "sap/m/App": undefined;

    "sap/m/Avatar": undefined;

    "sap/m/AvatarBadgeColor": undefined;

    "sap/m/AvatarColor": undefined;

    "sap/m/AvatarImageFitType": undefined;

    "sap/m/AvatarShape": undefined;

    "sap/m/AvatarSize": undefined;

    "sap/m/AvatarType": undefined;

    "sap/m/BadgeCustomData": undefined;

    "sap/m/BadgeEnabler": undefined;

    "sap/m/Bar": undefined;

    "sap/m/BarInPageEnabler": undefined;

    "sap/m/Breadcrumbs": undefined;

    "sap/m/BusyDialog": undefined;

    "sap/m/BusyIndicator": undefined;

    "sap/m/Button": undefined;

    "sap/m/Carousel": undefined;

    "sap/m/CarouselLayout": undefined;

    "sap/m/CheckBox": undefined;

    "sap/m/ColorPalette": undefined;

    "sap/m/ColorPalettePopover": undefined;

    "sap/m/Column": undefined;

    "sap/m/ColumnListItem": undefined;

    "sap/m/ComboBox": undefined;

    "sap/m/ComboBoxBase": undefined;

    "sap/m/ComboBoxTextField": undefined;

    "sap/m/ContentConfig": undefined;

    "sap/m/CustomListItem": undefined;

    "sap/m/CustomTile": undefined;

    "sap/m/CustomTreeItem": undefined;

    "sap/m/DatePicker": undefined;

    "sap/m/DateRangeSelection": undefined;

    "sap/m/DateTimeField": undefined;

    "sap/m/DateTimeInput": undefined;

    "sap/m/DateTimePicker": undefined;

    "sap/m/Dialog": undefined;

    "sap/m/DisplayListItem": undefined;

    "sap/m/DraftIndicator": undefined;

    "sap/m/DynamicDate": undefined;

    "sap/m/DynamicDateFormat": undefined;

    "sap/m/DynamicDateOption": undefined;

    "sap/m/DynamicDateRange": undefined;

    "sap/m/DynamicDateUtil": undefined;

    "sap/m/DynamicDateValueHelpUIType": undefined;

    "sap/m/ExpandableText": undefined;

    "sap/m/FacetFilter": undefined;

    "sap/m/FacetFilterItem": undefined;

    "sap/m/FacetFilterList": undefined;

    "sap/m/FeedContent": undefined;

    "sap/m/FeedInput": undefined;

    "sap/m/FeedListItem": undefined;

    "sap/m/FeedListItemAction": undefined;

    "sap/m/FlexBox": undefined;

    "sap/m/FlexItemData": undefined;

    "sap/m/FormattedText": undefined;

    "sap/m/GenericTag": undefined;

    "sap/m/GenericTile": undefined;

    "sap/m/GroupHeaderListItem": undefined;

    "sap/m/GrowingEnablement": undefined;

    "sap/m/GrowingList": undefined;

    "sap/m/HBox": undefined;

    "sap/m/HeaderContainer": undefined;

    "sap/m/IconTabBar": undefined;

    "sap/m/IconTabFilter": undefined;

    "sap/m/IconTabHeader": undefined;

    "sap/m/IconTabSeparator": undefined;

    "sap/m/IllustratedMessage": undefined;

    "sap/m/IllustratedMessageSize": undefined;

    "sap/m/IllustratedMessageType": undefined;

    "sap/m/Illustration": undefined;

    "sap/m/IllustrationPool": undefined;

    "sap/m/Image": undefined;

    "sap/m/ImageContent": undefined;

    "sap/m/Input": undefined;

    "sap/m/InputBase": undefined;

    "sap/m/InputBaseRenderer": undefined;

    "sap/m/InputListItem": undefined;

    "sap/m/InputRenderer": undefined;

    "sap/m/InstanceManager": undefined;

    "sap/m/Label": undefined;

    "sap/m/library": undefined;

    "sap/m/LightBox": undefined;

    "sap/m/LightBoxItem": undefined;

    "sap/m/Link": undefined;

    "sap/m/LinkTileContent": undefined;

    "sap/m/List": undefined;

    "sap/m/ListBase": undefined;

    "sap/m/ListItemBase": undefined;

    "sap/m/MaskInput": undefined;

    "sap/m/MaskInputRule": undefined;

    "sap/m/Menu": undefined;

    "sap/m/MenuButton": undefined;

    "sap/m/MenuItem": undefined;

    "sap/m/MenuItemGroup": undefined;

    "sap/m/MessageBox": undefined;

    "sap/m/MessageItem": undefined;

    "sap/m/MessagePage": undefined;

    "sap/m/MessagePopover": undefined;

    "sap/m/MessagePopoverItem": undefined;

    "sap/m/MessageStrip": undefined;

    "sap/m/MessageToast": undefined;

    "sap/m/MessageView": undefined;

    "sap/m/MultiComboBox": undefined;

    "sap/m/MultiEditField": undefined;

    "sap/m/MultiInput": undefined;

    "sap/m/NavContainer": undefined;

    "sap/m/NewsContent": undefined;

    "sap/m/NotificationList": undefined;

    "sap/m/NotificationListBase": undefined;

    "sap/m/NotificationListGroup": undefined;

    "sap/m/NotificationListItem": undefined;

    "sap/m/NumericContent": undefined;

    "sap/m/ObjectAttribute": undefined;

    "sap/m/ObjectHeader": undefined;

    "sap/m/ObjectIdentifier": undefined;

    "sap/m/ObjectListItem": undefined;

    "sap/m/ObjectMarker": undefined;

    "sap/m/ObjectNumber": undefined;

    "sap/m/ObjectStatus": undefined;

    "sap/m/OverflowToolbar": undefined;

    "sap/m/OverflowToolbarButton": undefined;

    "sap/m/OverflowToolbarLayoutData": undefined;

    "sap/m/OverflowToolbarMenuButton": undefined;

    "sap/m/OverflowToolbarToggleButton": undefined;

    "sap/m/p13n/AbstractContainer": undefined;

    "sap/m/p13n/AbstractContainerItem": undefined;

    "sap/m/p13n/BasePanel": undefined;

    "sap/m/p13n/Container": undefined;

    "sap/m/p13n/Engine": undefined;

    "sap/m/p13n/enums/PersistenceMode": undefined;

    "sap/m/p13n/enums/ProcessingStrategy": undefined;

    "sap/m/p13n/FilterController": undefined;

    "sap/m/p13n/GroupController": undefined;

    "sap/m/p13n/GroupPanel": undefined;

    "sap/m/p13n/MessageStrip": undefined;

    "sap/m/p13n/MetadataHelper": undefined;

    "sap/m/p13n/modules/AdaptationProvider": undefined;

    "sap/m/p13n/Popup": undefined;

    "sap/m/p13n/QueryPanel": undefined;

    "sap/m/p13n/SelectionController": undefined;

    "sap/m/p13n/SelectionPanel": undefined;

    "sap/m/p13n/SortController": undefined;

    "sap/m/p13n/SortPanel": undefined;

    "sap/m/p13n/util/diff": undefined;

    "sap/m/P13nColumnsItem": undefined;

    "sap/m/P13nColumnsPanel": undefined;

    "sap/m/P13nConditionPanel": undefined;

    "sap/m/P13nDialog": undefined;

    "sap/m/P13nDimMeasureItem": undefined;

    "sap/m/P13nDimMeasurePanel": undefined;

    "sap/m/P13nFilterItem": undefined;

    "sap/m/P13nFilterPanel": undefined;

    "sap/m/P13nGroupItem": undefined;

    "sap/m/P13nGroupPanel": undefined;

    "sap/m/P13nItem": undefined;

    "sap/m/P13nOperationsHelper": undefined;

    "sap/m/P13nPanel": undefined;

    "sap/m/P13nSortItem": undefined;

    "sap/m/P13nSortPanel": undefined;

    "sap/m/Page": undefined;

    "sap/m/PageAccessibleLandmarkInfo": undefined;

    "sap/m/PagingButton": undefined;

    "sap/m/Panel": undefined;

    "sap/m/PDFViewer": undefined;

    "sap/m/PlanningCalendar": undefined;

    "sap/m/PlanningCalendarLegend": undefined;

    "sap/m/PlanningCalendarRow": undefined;

    "sap/m/PlanningCalendarView": undefined;

    "sap/m/plugins/CellSelector": undefined;

    "sap/m/plugins/ColumnAIAction": undefined;

    "sap/m/plugins/ColumnResizer": undefined;

    "sap/m/plugins/ContextMenuSetting": undefined;

    "sap/m/plugins/CopyProvider": undefined;

    "sap/m/plugins/DataStateIndicator": undefined;

    "sap/m/plugins/PasteProvider": undefined;

    "sap/m/plugins/UploadSetwithTable": undefined;

    "sap/m/Popover": undefined;

    "sap/m/ProgressIndicator": undefined;

    "sap/m/PullToRefresh": undefined;

    "sap/m/QuickView": undefined;

    "sap/m/QuickViewBase": undefined;

    "sap/m/QuickViewCard": undefined;

    "sap/m/QuickViewGroup": undefined;

    "sap/m/QuickViewGroupElement": undefined;

    "sap/m/QuickViewPage": undefined;

    "sap/m/RadioButton": undefined;

    "sap/m/RadioButtonGroup": undefined;

    "sap/m/RangeSlider": undefined;

    "sap/m/RatingIndicator": undefined;

    "sap/m/ResponsivePopover": undefined;

    "sap/m/ResponsiveScale": undefined;

    "sap/m/routing/RouteMatchedHandler": undefined;

    "sap/m/routing/Router": undefined;

    "sap/m/routing/TargetHandler": undefined;

    "sap/m/routing/Targets": undefined;

    "sap/m/ScrollContainer": undefined;

    "sap/m/SearchField": undefined;

    "sap/m/SegmentedButton": undefined;

    "sap/m/SegmentedButtonItem": undefined;

    "sap/m/Select": undefined;

    "sap/m/SelectDialog": undefined;

    "sap/m/SelectDialogBase": undefined;

    "sap/m/SelectionDetails": undefined;

    "sap/m/SelectionDetailsFacade": undefined;

    "sap/m/SelectionDetailsItem": undefined;

    "sap/m/SelectionDetailsItemLine": undefined;

    "sap/m/SelectList": undefined;

    "sap/m/semantic/AddAction": undefined;

    "sap/m/semantic/CancelAction": undefined;

    "sap/m/semantic/DeleteAction": undefined;

    "sap/m/semantic/DetailPage": undefined;

    "sap/m/semantic/DiscussInJamAction": undefined;

    "sap/m/semantic/EditAction": undefined;

    "sap/m/semantic/FavoriteAction": undefined;

    "sap/m/semantic/FilterAction": undefined;

    "sap/m/semantic/FilterSelect": undefined;

    "sap/m/semantic/FlagAction": undefined;

    "sap/m/semantic/ForwardAction": undefined;

    "sap/m/semantic/FullscreenPage": undefined;

    "sap/m/semantic/GroupAction": undefined;

    "sap/m/semantic/GroupSelect": undefined;

    "sap/m/semantic/MainAction": undefined;

    "sap/m/semantic/MasterPage": undefined;

    "sap/m/semantic/MessagesIndicator": undefined;

    "sap/m/semantic/MultiSelectAction": undefined;

    "sap/m/semantic/NegativeAction": undefined;

    "sap/m/semantic/OpenInAction": undefined;

    "sap/m/semantic/PositiveAction": undefined;

    "sap/m/semantic/PrintAction": undefined;

    "sap/m/semantic/SaveAction": undefined;

    "sap/m/semantic/SemanticButton": undefined;

    "sap/m/semantic/SemanticControl": undefined;

    "sap/m/semantic/SemanticPage": undefined;

    "sap/m/semantic/SemanticSelect": undefined;

    "sap/m/semantic/SemanticToggleButton": undefined;

    "sap/m/semantic/SendEmailAction": undefined;

    "sap/m/semantic/SendMessageAction": undefined;

    "sap/m/semantic/ShareInJamAction": undefined;

    "sap/m/semantic/ShareMenuPage": undefined;

    "sap/m/semantic/SortAction": undefined;

    "sap/m/semantic/SortSelect": undefined;

    "sap/m/Shell": undefined;

    "sap/m/SinglePlanningCalendar": undefined;

    "sap/m/SinglePlanningCalendarDayView": undefined;

    "sap/m/SinglePlanningCalendarMonthView": undefined;

    "sap/m/SinglePlanningCalendarView": undefined;

    "sap/m/SinglePlanningCalendarWeekView": undefined;

    "sap/m/SinglePlanningCalendarWorkWeekView": undefined;

    "sap/m/Slider": undefined;

    "sap/m/SliderTooltipBase": undefined;

    "sap/m/SlideTile": undefined;

    "sap/m/SplitApp": undefined;

    "sap/m/SplitButton": undefined;

    "sap/m/SplitContainer": undefined;

    "sap/m/StandardListItem": undefined;

    "sap/m/StandardTile": undefined;

    "sap/m/StandardTreeItem": undefined;

    "sap/m/StepInput": undefined;

    "sap/m/SuggestionItem": undefined;

    "sap/m/Switch": undefined;

    "sap/m/TabContainer": undefined;

    "sap/m/TabContainerItem": undefined;

    "sap/m/Table": undefined;

    "sap/m/table/columnmenu/ActionItem": undefined;

    "sap/m/table/columnmenu/Entry": undefined;

    "sap/m/table/columnmenu/Item": undefined;

    "sap/m/table/columnmenu/ItemBase": undefined;

    "sap/m/table/columnmenu/Menu": undefined;

    "sap/m/table/columnmenu/MenuBase": undefined;

    "sap/m/table/columnmenu/QuickAction": undefined;

    "sap/m/table/columnmenu/QuickActionBase": undefined;

    "sap/m/table/columnmenu/QuickActionItem": undefined;

    "sap/m/table/columnmenu/QuickGroup": undefined;

    "sap/m/table/columnmenu/QuickGroupItem": undefined;

    "sap/m/table/columnmenu/QuickSort": undefined;

    "sap/m/table/columnmenu/QuickSortItem": undefined;

    "sap/m/table/columnmenu/QuickTotal": undefined;

    "sap/m/table/columnmenu/QuickTotalItem": undefined;

    "sap/m/table/ColumnWidthController": undefined;

    "sap/m/table/Util": undefined;

    "sap/m/TablePersoController": undefined;

    "sap/m/TablePersoDialog": undefined;

    "sap/m/TablePersoProvider": undefined;

    "sap/m/TableSelectDialog": undefined;

    "sap/m/Text": undefined;

    "sap/m/TextArea": undefined;

    "sap/m/Tile": undefined;

    "sap/m/TileAttribute": undefined;

    "sap/m/TileContainer": undefined;

    "sap/m/TileContent": undefined;

    "sap/m/TileInfo": undefined;

    "sap/m/TimePicker": undefined;

    "sap/m/TimePickerClocks": undefined;

    "sap/m/TimePickerInputs": undefined;

    "sap/m/TimePickerSliders": undefined;

    "sap/m/Title": undefined;

    "sap/m/ToggleButton": undefined;

    "sap/m/Token": undefined;

    "sap/m/Tokenizer": undefined;

    "sap/m/Toolbar": undefined;

    "sap/m/ToolbarLayoutData": undefined;

    "sap/m/ToolbarSeparator": undefined;

    "sap/m/ToolbarSpacer": undefined;

    "sap/m/Tree": undefined;

    "sap/m/TreeItemBase": undefined;

    "sap/m/upload/ActionsPlaceholder": undefined;

    "sap/m/upload/Column": undefined;

    "sap/m/upload/FilePreviewDialog": undefined;

    "sap/m/upload/Uploader": undefined;

    "sap/m/upload/UploaderHttpRequestMethod": undefined;

    "sap/m/upload/UploaderTableItem": undefined;

    "sap/m/upload/UploadItem": undefined;

    "sap/m/upload/UploadItemConfiguration": undefined;

    "sap/m/upload/UploadSet": undefined;

    "sap/m/upload/UploadSetItem": undefined;

    "sap/m/upload/UploadSetToolbarPlaceholder": undefined;

    "sap/m/UploadCollection": undefined;

    "sap/m/UploadCollectionItem": undefined;

    "sap/m/UploadCollectionParameter": undefined;

    "sap/m/UploadCollectionToolbarPlaceholder": undefined;

    "sap/m/VariantItem": undefined;

    "sap/m/VariantManagement": undefined;

    "sap/m/VBox": undefined;

    "sap/m/ViewSettingsCustomItem": undefined;

    "sap/m/ViewSettingsCustomTab": undefined;

    "sap/m/ViewSettingsDialog": undefined;

    "sap/m/ViewSettingsFilterItem": undefined;

    "sap/m/ViewSettingsItem": undefined;

    "sap/m/WheelSlider": undefined;

    "sap/m/WheelSliderContainer": undefined;

    "sap/m/Wizard": undefined;

    "sap/m/WizardStep": undefined;
  }
}
